// ====================================================================
// This file is part of FlexibleSUSY.
//
// FlexibleSUSY is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published
// by the Free Software Foundation, either version 3 of the License,
// or (at your option) any later version.
//
// FlexibleSUSY is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with FlexibleSUSY.  If not, see
// <http://www.gnu.org/licenses/>.
// ====================================================================
/**
 * @file MRSSM_two_scale_model.cpp
 * @brief contains methods to solve EWSB and calculate pole masses and 
 *        mixings from DRbar parameters.
 */
// File generated at Wed 23 Jul 2014 21:57:58

#include "MRSSM_two_scale_model.hpp"
#include "wrappers.hpp"
#include "linalg2.hpp"
#include "logger.hpp"
#include "error.hpp"
#include "root_finder.hpp"
#include "gsl_utils.hpp"
#include "config.h"
#include "pv.hpp"



#include <cmath>
#include <iostream>

#ifdef ENABLE_THREADS
#include <thread>
#endif

namespace flexiblesusy {

using namespace MRSSM_info;

#define CLASSNAME MRSSM<Two_scale>

#define PHYSICAL(parameter) physical.parameter
#define INPUT(parameter) model->get_input().parameter
#define LOCALINPUT(parameter) input.parameter

#ifdef ENABLE_THREADS
std::mutex CLASSNAME::mtx_fortran;
#endif

#ifdef ENABLE_THREADS
#define LOCK_MUTEX() mtx_fortran.lock()
#define UNLOCK_MUTEX() mtx_fortran.unlock()
#else
#define LOCK_MUTEX()
#define UNLOCK_MUTEX()
#endif

CLASSNAME::MRSSM(const MRSSM_input_parameters& input_)
   : Two_scale_model()
   , MRSSM_soft_parameters(input_)
   , number_of_ewsb_iterations(100)
   , number_of_mass_iterations(20)
   , ewsb_loop_order(2)
   , pole_mass_loop_order(2)
   , calculate_sm_pole_masses(false)
   , precision(1.0e-3)
   , ewsb_iteration_precision(1.0e-5)
   , physical()
   , problems(MRSSM_info::particle_names)
   , thread_exception()
   , MGlu(0), MFv(Eigen::Array<double,3,1>::Zero()), MSOc(0), MVZ(0), MSd(
      Eigen::Array<double,6,1>::Zero()), MSv(Eigen::Array<double,3,1>::Zero()),
      MSu(Eigen::Array<double,6,1>::Zero()), MSe(Eigen::Array<double,6,1>::Zero())
      , Mhh(Eigen::Array<double,4,1>::Zero()), MAh(Eigen::Array<double,4,1>::Zero(
      )), MRh(Eigen::Array<double,2,1>::Zero()), MHpm(Eigen::Array<double,4,1>
      ::Zero()), MRpm(Eigen::Array<double,2,1>::Zero()), MChi(Eigen::Array<double,
      4,1>::Zero()), MCha1(Eigen::Array<double,2,1>::Zero()), MCha2(Eigen::Array<
      double,2,1>::Zero()), MFe(Eigen::Array<double,3,1>::Zero()), MFd(
      Eigen::Array<double,3,1>::Zero()), MFu(Eigen::Array<double,3,1>::Zero()),
      MVG(0), MVP(0), MVWm(0)

   , ZD(Eigen::Matrix<double,6,6>::Zero()), ZV(Eigen::Matrix<double,3,3>::Zero(
      )), ZU(Eigen::Matrix<double,6,6>::Zero()), ZE(Eigen::Matrix<double,6,6>
      ::Zero()), ZH(Eigen::Matrix<double,4,4>::Zero()), ZA(Eigen::Matrix<double,4,
      4>::Zero()), ZHR(Eigen::Matrix<double,2,2>::Zero()), ZP(Eigen::Matrix<double
      ,4,4>::Zero()), ZRP(Eigen::Matrix<double,2,2>::Zero()), ZN1(Eigen::Matrix<
      std::complex<double>,4,4>::Zero()), ZN2(Eigen::Matrix<std::complex<double>,4
      ,4>::Zero()), UM1(Eigen::Matrix<std::complex<double>,2,2>::Zero()), UP1(
      Eigen::Matrix<std::complex<double>,2,2>::Zero()), UM2(Eigen::Matrix<
      std::complex<double>,2,2>::Zero()), UP2(Eigen::Matrix<std::complex<double>,2
      ,2>::Zero()), ZEL(Eigen::Matrix<std::complex<double>,3,3>::Zero()), ZER(
      Eigen::Matrix<std::complex<double>,3,3>::Zero()), ZDL(Eigen::Matrix<
      std::complex<double>,3,3>::Zero()), ZDR(Eigen::Matrix<std::complex<double>,3
      ,3>::Zero()), ZUL(Eigen::Matrix<std::complex<double>,3,3>::Zero()), ZUR(
      Eigen::Matrix<std::complex<double>,3,3>::Zero())


{
}

CLASSNAME::~MRSSM()
{
}

void CLASSNAME::do_calculate_sm_pole_masses(bool flag)
{
   calculate_sm_pole_masses = flag;
}

bool CLASSNAME::do_calculate_sm_pole_masses() const
{
   return calculate_sm_pole_masses;
}

void CLASSNAME::set_ewsb_loop_order(unsigned loop_order)
{
   ewsb_loop_order = loop_order;
}

void CLASSNAME::set_number_of_ewsb_iterations(std::size_t iterations)
{
   number_of_ewsb_iterations = iterations;
}

void CLASSNAME::set_number_of_mass_iterations(std::size_t iterations)
{
   number_of_mass_iterations = iterations;
}

void CLASSNAME::set_precision(double precision_)
{
   precision = precision_;
   ewsb_iteration_precision = precision_;
}

void CLASSNAME::set_pole_mass_loop_order(unsigned loop_order)
{
   pole_mass_loop_order = loop_order;
}

void CLASSNAME::set_ewsb_iteration_precision(double precision)
{
   ewsb_iteration_precision = precision;
}

double CLASSNAME::get_ewsb_iteration_precision() const
{
   return ewsb_iteration_precision;
}

double CLASSNAME::get_ewsb_loop_order() const
{
   return ewsb_loop_order;
}

const MRSSM_physical& CLASSNAME::get_physical() const
{
   return physical;
}

MRSSM_physical& CLASSNAME::get_physical()
{
   return physical;
}

void CLASSNAME::set_physical(const MRSSM_physical& physical_)
{
   physical = physical_;
}

const Problems<MRSSM_info::NUMBER_OF_PARTICLES>& CLASSNAME::get_problems() const
{
   return problems;
}

Problems<MRSSM_info::NUMBER_OF_PARTICLES>& CLASSNAME::get_problems()
{
   return problems;
}

/**
 * Method which calculates the tadpoles at loop order specified in the
 * pointer to the CLASSNAME::Ewsb_parameters struct.
 *
 * @param x GSL vector of EWSB output parameters
 * @param params pointer to CLASSNAME::Ewsb_parameters struct
 * @param f GSL vector with tadpoles
 *
 * @return GSL_EDOM if x contains Nans, GSL_SUCCESS otherwise.
 */
int CLASSNAME::tadpole_equations(const gsl_vector* x, void* params, gsl_vector* f)
{
   if (contains_nan(x, number_of_ewsb_equations)) {
      for (std::size_t i = 0; i < number_of_ewsb_equations; ++i)
         gsl_vector_set(f, i, std::numeric_limits<double>::max());
      return GSL_EDOM;
   }

   const CLASSNAME::Ewsb_parameters* ewsb_parameters
      = static_cast<CLASSNAME::Ewsb_parameters*>(params);
   MRSSM* model = ewsb_parameters->model;
   const unsigned ewsb_loop_order = ewsb_parameters->ewsb_loop_order;

   double tadpole[number_of_ewsb_equations];

   model->set_mHd2(gsl_vector_get(x, 0));
   model->set_mHu2(gsl_vector_get(x, 1));
   model->set_mS2(gsl_vector_get(x, 2));
   model->set_mT2(gsl_vector_get(x, 3));

   tadpole[0] = model->get_ewsb_eq_hh_1();
   tadpole[1] = model->get_ewsb_eq_hh_2();
   tadpole[2] = model->get_ewsb_eq_hh_3();
   tadpole[3] = model->get_ewsb_eq_hh_4();

   if (ewsb_loop_order > 0) {
      model->calculate_DRbar_parameters();
      tadpole[0] -= Re(model->tadpole_hh(0));
      tadpole[1] -= Re(model->tadpole_hh(1));
      tadpole[2] -= Re(model->tadpole_hh(3));
      tadpole[3] -= Re(model->tadpole_hh(2));

      if (ewsb_loop_order > 1) {

      }
   }

   for (std::size_t i = 0; i < number_of_ewsb_equations; ++i)
      gsl_vector_set(f, i, tadpole[i]);

   return GSL_SUCCESS;
}

/**
 * method which solves the EWSB conditions iteratively, trying GSL
 * root finding methods
 *       gsl_multiroot_fsolver_hybrid, gsl_multiroot_fsolver_hybrids, gsl_multiroot_fsolver_broyden
 * in that order until a solution is found.
 */
int CLASSNAME::solve_ewsb_iteratively()
{
   const gsl_multiroot_fsolver_type* solvers[] = {
      gsl_multiroot_fsolver_hybrid, gsl_multiroot_fsolver_hybrids, gsl_multiroot_fsolver_broyden
   };

   double x_init[number_of_ewsb_equations];
   ewsb_initial_guess(x_init);

#ifdef ENABLE_VERBOSE
   std::cout << "Solving EWSB equations ...\n"
      "\tInitial guess: x_init =";
   for (std::size_t i = 0; i < number_of_ewsb_equations; ++i)
      std::cout << " " << x_init[i];
   std::cout << '\n';
#endif

   int status;
   for (std::size_t i = 0; i < sizeof(solvers)/sizeof(*solvers); ++i) {
      VERBOSE_MSG("\tStarting EWSB iteration using solver " << i);
      status = solve_ewsb_iteratively_with(solvers[i], x_init);
      if (status == GSL_SUCCESS) {
         VERBOSE_MSG("\tSolver " << i << " finished successfully!");
         break;
      }
#ifdef ENABLE_VERBOSE
      else {
         WARNING("\tSolver " << i << " could not find a solution!"
                 " (requested precision: " << ewsb_iteration_precision << ")");
      }
#endif
   }

   if (status != GSL_SUCCESS) {
      problems.flag_no_ewsb();
#ifdef ENABLE_VERBOSE
      WARNING("\tCould not find a solution to the EWSB equations!"
              " (requested precision: " << ewsb_iteration_precision << ")");
#endif
   } else {
      problems.unflag_no_ewsb();
   }

   return status;
}

int CLASSNAME::solve_ewsb_iteratively(unsigned loop_order)
{
   // temporarily set `ewsb_loop_order' to `loop_order' and do
   // iteration
   const unsigned old_loop_order = ewsb_loop_order;
   ewsb_loop_order = loop_order;
   const int status = solve_ewsb_iteratively();
   ewsb_loop_order = old_loop_order;
   return status;
}


int CLASSNAME::solve_ewsb_tree_level()
{
   int error = 0;

   const double old_mHu2 = mHu2;
   const double old_mHd2 = mHd2;
   const double old_mT2 = mT2;
   const double old_mS2 = mS2;

   mHu2 = (0.025*(-15.491933384829668*g1*MDBS*vS*vu + 20*g2*MDWBT*vT*vu - 40*vu
      *AbsSqr(MuU) - 40*vu*AbsSqr(Mu) + 20*vd*BMu - 28.284271247461902*MuU*vS*vu*
      Conj(LamSU) + 14.142135623730951*LamTU*vS*vT*vu*Conj(LamSU) + 20*MuU*vT*vu*
      Conj(LamTU) + 14.142135623730951*LamSU*vS*vT*vu*Conj(LamTU) -
      15.491933384829668*g1*vS*vu*Conj(MDBS) + 20*g2*vT*vu*Conj(MDWBT) -
      28.284271247461902*LamSU*vS*vu*Conj(MuU) + 20*LamTU*vT*vu*Conj(MuU) + 20*vd*
      Conj(BMu) - 3*Power(vu,3)*Sqr(g1) - 5*Power(vu,3)*Sqr(g2) + 3*vu*Sqr(g1)*Sqr
      (vd) + 5*vu*Sqr(g2)*Sqr(vd) - 20*vu*AbsSqr(LamSU)*Sqr(vS) - 10*vu*AbsSqr(
      LamTU)*Sqr(vT)))/vu;
   mHd2 = (0.025*(15.491933384829668*g1*MDBS*vd*vS - 20*g2*MDWBT*vd*vT - 40*vd*
      AbsSqr(MuD) - 40*vd*AbsSqr(Mu) + 20*vu*BMu - 28.284271247461902*MuD*vd*vS*
      Conj(LamSD) - 14.142135623730951*LamTD*vd*vS*vT*Conj(LamSD) - 20*MuD*vd*vT*
      Conj(LamTD) - 14.142135623730951*LamSD*vd*vS*vT*Conj(LamTD) +
      15.491933384829668*g1*vd*vS*Conj(MDBS) - 20*g2*vd*vT*Conj(MDWBT) -
      28.284271247461902*LamSD*vd*vS*Conj(MuD) - 20*LamTD*vd*vT*Conj(MuD) + 20*vu*
      Conj(BMu) - 3*Power(vd,3)*Sqr(g1) - 5*Power(vd,3)*Sqr(g2) - 20*vd*AbsSqr(
      LamSD)*Sqr(vS) - 10*vd*AbsSqr(LamTD)*Sqr(vT) + 3*vd*Sqr(g1)*Sqr(vu) + 5*vd*
      Sqr(g2)*Sqr(vu)))/vd;
   mT2 = (0.125*(-32*vT*Sqr(MDWBT) - 2*g2*MDWBT*Sqr(vd) - 2*vT*AbsSqr(LamTD)*
      Sqr(vd) - 1.4142135623730951*LamTD*vS*Conj(LamSD)*Sqr(vd) - 2*MuD*Conj(LamTD
      )*Sqr(vd) - 1.4142135623730951*LamSD*vS*Conj(LamTD)*Sqr(vd) - 2*g2*Conj(
      MDWBT)*Sqr(vd) - 2*LamTD*Conj(MuD)*Sqr(vd) + 2*g2*MDWBT*Sqr(vu) - 2*vT*
      AbsSqr(LamTU)*Sqr(vu) + 1.4142135623730951*LamTU*vS*Conj(LamSU)*Sqr(vu) + 2*
      MuU*Conj(LamTU)*Sqr(vu) + 1.4142135623730951*LamSU*vS*Conj(LamTU)*Sqr(vu) +
      2*g2*Conj(MDWBT)*Sqr(vu) + 2*LamTU*Conj(MuU)*Sqr(vu)))/vT;
   mS2 = (0.025*(-160*vS*Sqr(MDBS) + 7.745966692414834*g1*MDBS*Sqr(vd) - 20*vS*
      AbsSqr(LamSD)*Sqr(vd) - 14.142135623730951*MuD*Conj(LamSD)*Sqr(vd) -
      7.0710678118654755*LamTD*vT*Conj(LamSD)*Sqr(vd) - 7.0710678118654755*LamSD*
      vT*Conj(LamTD)*Sqr(vd) + 7.745966692414834*g1*Conj(MDBS)*Sqr(vd) -
      14.142135623730951*LamSD*Conj(MuD)*Sqr(vd) - 7.745966692414834*g1*MDBS*Sqr(
      vu) - 20*vS*AbsSqr(LamSU)*Sqr(vu) - 14.142135623730951*MuU*Conj(LamSU)*Sqr(
      vu) + 7.0710678118654755*LamTU*vT*Conj(LamSU)*Sqr(vu) + 7.0710678118654755*
      LamSU*vT*Conj(LamTU)*Sqr(vu) - 7.745966692414834*g1*Conj(MDBS)*Sqr(vu) -
      14.142135623730951*LamSU*Conj(MuU)*Sqr(vu)))/vS;

   const bool is_finite = std::isfinite(mHu2) && std::isfinite(mHd2) &&
      std::isfinite(mT2) && std::isfinite(mS2);

   if (!is_finite) {
      mHu2 = old_mHu2;
      mHd2 = old_mHd2;
      mT2 = old_mT2;
      mS2 = old_mS2;
      error = 1;
   }


   return error;
}

int CLASSNAME::solve_ewsb_tree_level_via_soft_higgs_masses()
{
   int error = 0;

   const double new_mHd2 = (0.025*(15.491933384829668*g1*MDBS*vd*vS - 20*g2*
      MDWBT*vd*vT - 40*vd*AbsSqr(MuD) - 40*vd*AbsSqr(Mu) + 20*vu*BMu -
      28.284271247461902*MuD*vd*vS*Conj(LamSD) - 14.142135623730951*LamTD*vd*vS*vT
      *Conj(LamSD) - 20*MuD*vd*vT*Conj(LamTD) - 14.142135623730951*LamSD*vd*vS*vT*
      Conj(LamTD) + 15.491933384829668*g1*vd*vS*Conj(MDBS) - 20*g2*vd*vT*Conj(
      MDWBT) - 28.284271247461902*LamSD*vd*vS*Conj(MuD) - 20*LamTD*vd*vT*Conj(MuD)
      + 20*vu*Conj(BMu) - 3*Power(vd,3)*Sqr(g1) - 5*Power(vd,3)*Sqr(g2) - 20*vd*
      AbsSqr(LamSD)*Sqr(vS) - 10*vd*AbsSqr(LamTD)*Sqr(vT) + 3*vd*Sqr(g1)*Sqr(vu) +
      5*vd*Sqr(g2)*Sqr(vu)))/vd;
   const double new_mHu2 = (0.025*(-15.491933384829668*g1*MDBS*vS*vu + 20*g2*
      MDWBT*vT*vu - 40*vu*AbsSqr(MuU) - 40*vu*AbsSqr(Mu) + 20*vd*BMu -
      28.284271247461902*MuU*vS*vu*Conj(LamSU) + 14.142135623730951*LamTU*vS*vT*vu
      *Conj(LamSU) + 20*MuU*vT*vu*Conj(LamTU) + 14.142135623730951*LamSU*vS*vT*vu*
      Conj(LamTU) - 15.491933384829668*g1*vS*vu*Conj(MDBS) + 20*g2*vT*vu*Conj(
      MDWBT) - 28.284271247461902*LamSU*vS*vu*Conj(MuU) + 20*LamTU*vT*vu*Conj(MuU)
      + 20*vd*Conj(BMu) - 3*Power(vu,3)*Sqr(g1) - 5*Power(vu,3)*Sqr(g2) + 3*vu*
      Sqr(g1)*Sqr(vd) + 5*vu*Sqr(g2)*Sqr(vd) - 20*vu*AbsSqr(LamSU)*Sqr(vS) - 10*vu
      *AbsSqr(LamTU)*Sqr(vT)))/vu;
   const double new_mS2 = (0.025*(-160*vS*Sqr(MDBS) + 7.745966692414834*g1*MDBS
      *Sqr(vd) - 20*vS*AbsSqr(LamSD)*Sqr(vd) - 14.142135623730951*MuD*Conj(LamSD)*
      Sqr(vd) - 7.0710678118654755*LamTD*vT*Conj(LamSD)*Sqr(vd) -
      7.0710678118654755*LamSD*vT*Conj(LamTD)*Sqr(vd) + 7.745966692414834*g1*Conj(
      MDBS)*Sqr(vd) - 14.142135623730951*LamSD*Conj(MuD)*Sqr(vd) -
      7.745966692414834*g1*MDBS*Sqr(vu) - 20*vS*AbsSqr(LamSU)*Sqr(vu) -
      14.142135623730951*MuU*Conj(LamSU)*Sqr(vu) + 7.0710678118654755*LamTU*vT*
      Conj(LamSU)*Sqr(vu) + 7.0710678118654755*LamSU*vT*Conj(LamTU)*Sqr(vu) -
      7.745966692414834*g1*Conj(MDBS)*Sqr(vu) - 14.142135623730951*LamSU*Conj(MuU)
      *Sqr(vu)))/vS;
   const double new_mT2 = (0.125*(-32*vT*Sqr(MDWBT) - 2*g2*MDWBT*Sqr(vd) - 2*vT
      *AbsSqr(LamTD)*Sqr(vd) - 1.4142135623730951*LamTD*vS*Conj(LamSD)*Sqr(vd) - 2
      *MuD*Conj(LamTD)*Sqr(vd) - 1.4142135623730951*LamSD*vS*Conj(LamTD)*Sqr(vd) -
      2*g2*Conj(MDWBT)*Sqr(vd) - 2*LamTD*Conj(MuD)*Sqr(vd) + 2*g2*MDWBT*Sqr(vu) -
      2*vT*AbsSqr(LamTU)*Sqr(vu) + 1.4142135623730951*LamTU*vS*Conj(LamSU)*Sqr(vu
      ) + 2*MuU*Conj(LamTU)*Sqr(vu) + 1.4142135623730951*LamSU*vS*Conj(LamTU)*Sqr(
      vu) + 2*g2*Conj(MDWBT)*Sqr(vu) + 2*LamTU*Conj(MuU)*Sqr(vu)))/vT;

   if (std::isfinite(new_mHd2))
      mHd2 = new_mHd2;
   else
      error = 1;
   if (std::isfinite(new_mHu2))
      mHu2 = new_mHu2;
   else
      error = 1;
   if (std::isfinite(new_mS2))
      mS2 = new_mS2;
   else
      error = 1;
   if (std::isfinite(new_mT2))
      mT2 = new_mT2;
   else
      error = 1;


   return error;
}

int CLASSNAME::solve_ewsb_one_loop()
{
   return solve_ewsb_iteratively(1);
}

int CLASSNAME::solve_ewsb()
{
   VERBOSE_MSG("\tSolving EWSB at " << ewsb_loop_order << "-loop order");

   if (ewsb_loop_order == 0)
      return solve_ewsb_tree_level();

   return solve_ewsb_iteratively(ewsb_loop_order);
}

void CLASSNAME::ewsb_initial_guess(double x_init[number_of_ewsb_equations])
{
   x_init[0] = mHd2;
   x_init[1] = mHu2;
   x_init[2] = mS2;
   x_init[3] = mT2;

}

int CLASSNAME::solve_ewsb_iteratively_with(const gsl_multiroot_fsolver_type* solver,
                                           const double x_init[number_of_ewsb_equations])
{
   Ewsb_parameters params = {this, ewsb_loop_order};
   Root_finder<number_of_ewsb_equations> root_finder(CLASSNAME::tadpole_equations,
                              &params,
                              number_of_ewsb_iterations,
                              ewsb_iteration_precision);
   root_finder.set_solver_type(solver);
   const int status = root_finder.find_root(x_init);

   return status;
}

void CLASSNAME::print(std::ostream& ostr) const
{
   ostr << "========================================\n"
           "MRSSM\n"
           "========================================\n";
   MRSSM_soft_parameters::print(ostr);
   ostr << "----------------------------------------\n"
           "tree-level DRbar masses:\n"
           "----------------------------------------\n";
   ostr << "MGlu = " << MGlu << '\n';
   ostr << "MFv = " << MFv.transpose() << '\n';
   ostr << "MSOc = " << MSOc << '\n';
   ostr << "MVZ = " << MVZ << '\n';
   ostr << "MSd = " << MSd.transpose() << '\n';
   ostr << "MSv = " << MSv.transpose() << '\n';
   ostr << "MSu = " << MSu.transpose() << '\n';
   ostr << "MSe = " << MSe.transpose() << '\n';
   ostr << "Mhh = " << Mhh.transpose() << '\n';
   ostr << "MAh = " << MAh.transpose() << '\n';
   ostr << "MRh = " << MRh.transpose() << '\n';
   ostr << "MHpm = " << MHpm.transpose() << '\n';
   ostr << "MRpm = " << MRpm.transpose() << '\n';
   ostr << "MChi = " << MChi.transpose() << '\n';
   ostr << "MCha1 = " << MCha1.transpose() << '\n';
   ostr << "MCha2 = " << MCha2.transpose() << '\n';
   ostr << "MFe = " << MFe.transpose() << '\n';
   ostr << "MFd = " << MFd.transpose() << '\n';
   ostr << "MFu = " << MFu.transpose() << '\n';
   ostr << "MVG = " << MVG << '\n';
   ostr << "MVP = " << MVP << '\n';
   ostr << "MVWm = " << MVWm << '\n';

   ostr << "----------------------------------------\n"
           "tree-level DRbar mixing matrices:\n"
           "----------------------------------------\n";
   ostr << "ZD = " << ZD << '\n';
   ostr << "ZV = " << ZV << '\n';
   ostr << "ZU = " << ZU << '\n';
   ostr << "ZE = " << ZE << '\n';
   ostr << "ZH = " << ZH << '\n';
   ostr << "ZA = " << ZA << '\n';
   ostr << "ZHR = " << ZHR << '\n';
   ostr << "ZP = " << ZP << '\n';
   ostr << "ZRP = " << ZRP << '\n';
   ostr << "ZN1 = " << ZN1 << '\n';
   ostr << "ZN2 = " << ZN2 << '\n';
   ostr << "UM1 = " << UM1 << '\n';
   ostr << "UP1 = " << UP1 << '\n';
   ostr << "UM2 = " << UM2 << '\n';
   ostr << "UP2 = " << UP2 << '\n';
   ostr << "ZEL = " << ZEL << '\n';
   ostr << "ZER = " << ZER << '\n';
   ostr << "ZDL = " << ZDL << '\n';
   ostr << "ZDR = " << ZDR << '\n';
   ostr << "ZUL = " << ZUL << '\n';
   ostr << "ZUR = " << ZUR << '\n';

   physical.print(ostr);
}
/**
 * wrapper routines for passarino Veltman functions
 */

double CLASSNAME::A0(double m) const
{
   return passarino_veltman::ReA0(m*m, Sqr(get_scale()));
}

double CLASSNAME::B0(double p, double m1, double m2) const
{
   return passarino_veltman::ReB0(p*p, m1*m1, m2*m2, Sqr(get_scale()));
}

double CLASSNAME::B1(double p, double m1, double m2) const
{
   return passarino_veltman::ReB1(p*p, m1*m1, m2*m2, Sqr(get_scale()));
}

double CLASSNAME::B00(double p, double m1, double m2) const
{
   return passarino_veltman::ReB00(p*p, m1*m1, m2*m2, Sqr(get_scale()));
}

double CLASSNAME::B22(double p, double m1, double m2) const
{
   return passarino_veltman::ReB22(p*p, m1*m1, m2*m2, Sqr(get_scale()));
}

double CLASSNAME::H0(double p, double m1, double m2) const
{
   return passarino_veltman::ReH0(p*p, m1*m1, m2*m2, Sqr(get_scale()));
}

double CLASSNAME::F0(double p, double m1, double m2) const
{
   return passarino_veltman::ReF0(p*p, m1*m1, m2*m2, Sqr(get_scale()));
}

double CLASSNAME::G0(double p, double m1, double m2) const
{
   return passarino_veltman::ReG0(p*p, m1*m1, m2*m2, Sqr(get_scale()));
}

/**
 * routine which finds the DRbar mass eigenstates and mixings.
 */
void CLASSNAME::calculate_DRbar_parameters()
{
   const auto old_mHd2 = mHd2;
   const auto old_mHu2 = mHu2;
   const auto old_mS2 = mS2;
   const auto old_mT2 = mT2;

   solve_ewsb_tree_level_via_soft_higgs_masses();

   calculate_MVZ();
   calculate_MVG();
   calculate_MVP();
   calculate_MVWm();
   calculate_MGlu();
   calculate_MFv();
   calculate_MSOc();
   calculate_MSd();
   calculate_MSv();
   calculate_MSu();
   calculate_MSe();
   calculate_Mhh();
   calculate_MAh();
   calculate_MRh();
   calculate_MHpm();
   calculate_MRpm();
   calculate_MChi();
   calculate_MCha1();
   calculate_MCha2();
   calculate_MFe();
   calculate_MFd();
   calculate_MFu();

   mHd2 = old_mHd2;
   mHu2 = old_mHu2;
   mS2 = old_mS2;
   mT2 = old_mT2;

}

/**
 * routine which finds the pole mass eigenstates and mixings.
 */
void CLASSNAME::calculate_pole_masses()
{
#ifdef ENABLE_THREADS
   thread_exception = 0;

   std::thread thread_MGlu(Thread(this, &CLASSNAME::calculate_MGlu_pole));
   std::thread thread_MSOc(Thread(this, &CLASSNAME::calculate_MSOc_pole));
   std::thread thread_MSd(Thread(this, &CLASSNAME::calculate_MSd_pole));
   std::thread thread_MSv(Thread(this, &CLASSNAME::calculate_MSv_pole));
   std::thread thread_MSu(Thread(this, &CLASSNAME::calculate_MSu_pole));
   std::thread thread_MSe(Thread(this, &CLASSNAME::calculate_MSe_pole));
   std::thread thread_Mhh(Thread(this, &CLASSNAME::calculate_Mhh_pole));
   std::thread thread_MAh(Thread(this, &CLASSNAME::calculate_MAh_pole));
   std::thread thread_MRh(Thread(this, &CLASSNAME::calculate_MRh_pole));
   std::thread thread_MHpm(Thread(this, &CLASSNAME::calculate_MHpm_pole));
   std::thread thread_MRpm(Thread(this, &CLASSNAME::calculate_MRpm_pole));
   std::thread thread_MChi(Thread(this, &CLASSNAME::calculate_MChi_pole));
   std::thread thread_MCha1(Thread(this, &CLASSNAME::calculate_MCha1_pole));
   std::thread thread_MCha2(Thread(this, &CLASSNAME::calculate_MCha2_pole));

   if (calculate_sm_pole_masses) {
      std::thread thread_MFd(Thread(this, &CLASSNAME::calculate_MFd_pole));
      std::thread thread_MFe(Thread(this, &CLASSNAME::calculate_MFe_pole));
      std::thread thread_MFu(Thread(this, &CLASSNAME::calculate_MFu_pole));
      std::thread thread_MFv(Thread(this, &CLASSNAME::calculate_MFv_pole));
      std::thread thread_MVG(Thread(this, &CLASSNAME::calculate_MVG_pole));
      std::thread thread_MVP(Thread(this, &CLASSNAME::calculate_MVP_pole));
      std::thread thread_MVWm(Thread(this, &CLASSNAME::calculate_MVWm_pole));
      std::thread thread_MVZ(Thread(this, &CLASSNAME::calculate_MVZ_pole));
      thread_MFd.join();
      thread_MFe.join();
      thread_MFu.join();
      thread_MFv.join();
      thread_MVG.join();
      thread_MVP.join();
      thread_MVWm.join();
      thread_MVZ.join();
   }

   thread_MGlu.join();
   thread_MSOc.join();
   thread_MSd.join();
   thread_MSv.join();
   thread_MSu.join();
   thread_MSe.join();
   thread_Mhh.join();
   thread_MAh.join();
   thread_MRh.join();
   thread_MHpm.join();
   thread_MRpm.join();
   thread_MChi.join();
   thread_MCha1.join();
   thread_MCha2.join();


   if (thread_exception != 0)
      std::rethrow_exception(thread_exception);
#else
   calculate_MGlu_pole();
   calculate_MSOc_pole();
   calculate_MSd_pole();
   calculate_MSv_pole();
   calculate_MSu_pole();
   calculate_MSe_pole();
   calculate_Mhh_pole();
   calculate_MAh_pole();
   calculate_MRh_pole();
   calculate_MHpm_pole();
   calculate_MRpm_pole();
   calculate_MChi_pole();
   calculate_MCha1_pole();
   calculate_MCha2_pole();

   if (calculate_sm_pole_masses) {
      calculate_MFd_pole();
      calculate_MFe_pole();
      calculate_MFu_pole();
      calculate_MFv_pole();
      calculate_MVG_pole();
      calculate_MVP_pole();
      calculate_MVWm_pole();
      calculate_MVZ_pole();
   }

#endif
}

void CLASSNAME::copy_DRbar_masses_to_pole_masses()
{
   PHYSICAL(MGlu) = MGlu;
   PHYSICAL(MFv) = MFv;
   PHYSICAL(MSOc) = MSOc;
   PHYSICAL(MVZ) = MVZ;
   PHYSICAL(MSd) = MSd;
   PHYSICAL(ZD) = ZD;
   PHYSICAL(MSv) = MSv;
   PHYSICAL(ZV) = ZV;
   PHYSICAL(MSu) = MSu;
   PHYSICAL(ZU) = ZU;
   PHYSICAL(MSe) = MSe;
   PHYSICAL(ZE) = ZE;
   PHYSICAL(Mhh) = Mhh;
   PHYSICAL(ZH) = ZH;
   PHYSICAL(MAh) = MAh;
   PHYSICAL(ZA) = ZA;
   PHYSICAL(MRh) = MRh;
   PHYSICAL(ZHR) = ZHR;
   PHYSICAL(MHpm) = MHpm;
   PHYSICAL(ZP) = ZP;
   PHYSICAL(MRpm) = MRpm;
   PHYSICAL(ZRP) = ZRP;
   PHYSICAL(MChi) = MChi;
   PHYSICAL(ZN1) = ZN1;
   PHYSICAL(ZN2) = ZN2;
   PHYSICAL(MCha1) = MCha1;
   PHYSICAL(UM1) = UM1;
   PHYSICAL(UP1) = UP1;
   PHYSICAL(MCha2) = MCha2;
   PHYSICAL(UM2) = UM2;
   PHYSICAL(UP2) = UP2;
   PHYSICAL(MFe) = MFe;
   PHYSICAL(ZEL) = ZEL;
   PHYSICAL(ZER) = ZER;
   PHYSICAL(MFd) = MFd;
   PHYSICAL(ZDL) = ZDL;
   PHYSICAL(ZDR) = ZDR;
   PHYSICAL(MFu) = MFu;
   PHYSICAL(ZUL) = ZUL;
   PHYSICAL(ZUR) = ZUR;
   PHYSICAL(MVG) = MVG;
   PHYSICAL(MVP) = MVP;
   PHYSICAL(MVWm) = MVWm;

}

/**
 * reorders DRbar masses so that golstones are placed at the index
 * specified in the model files definition of the associuated
 * gauge boson (see Z-boson definition in default particles.m file
 * in the Models directory of your SARAH distribution for example)
 */
void CLASSNAME::reorder_DRbar_masses()
{
   move_goldstone_to(0, MVZ, MAh, ZA);
   move_goldstone_to(0, MVWm, MHpm, ZP);

}

/**
 * reorders pole masses so that golstones are placed at the index
 * specified in the model files definition of the associuated
 * gauge boson (see Z-boson definition in default particles.m file
 * in the Models directory of your SARAH distribution for example)
 */
void CLASSNAME::reorder_pole_masses()
{
   move_goldstone_to(0, MVZ, PHYSICAL(MAh), PHYSICAL(ZA));
   move_goldstone_to(0, MVWm, PHYSICAL(MHpm), PHYSICAL(ZP));

}
/**
 * calculates spectrum for model once the DRbar parameters at
 * at low energies are known
 */
void CLASSNAME::calculate_spectrum()
{
   calculate_DRbar_parameters();
   if (pole_mass_loop_order > 0)
      calculate_pole_masses();

   // move goldstone bosons to the front
   reorder_DRbar_masses();
   if (pole_mass_loop_order == 0)
      copy_DRbar_masses_to_pole_masses();
   else
      reorder_pole_masses();

   if (problems.have_serious_problem()) {
      clear_DRbar_parameters();
      physical.clear();
   }
}

void CLASSNAME::clear_DRbar_parameters()
{
   MGlu = 0.0;
   MFv = Eigen::Array<double,3,1>::Zero();
   MSOc = 0.0;
   MVZ = 0.0;
   MSd = Eigen::Array<double,6,1>::Zero();
   ZD = Eigen::Matrix<double,6,6>::Zero();
   MSv = Eigen::Array<double,3,1>::Zero();
   ZV = Eigen::Matrix<double,3,3>::Zero();
   MSu = Eigen::Array<double,6,1>::Zero();
   ZU = Eigen::Matrix<double,6,6>::Zero();
   MSe = Eigen::Array<double,6,1>::Zero();
   ZE = Eigen::Matrix<double,6,6>::Zero();
   Mhh = Eigen::Array<double,4,1>::Zero();
   ZH = Eigen::Matrix<double,4,4>::Zero();
   MAh = Eigen::Array<double,4,1>::Zero();
   ZA = Eigen::Matrix<double,4,4>::Zero();
   MRh = Eigen::Array<double,2,1>::Zero();
   ZHR = Eigen::Matrix<double,2,2>::Zero();
   MHpm = Eigen::Array<double,4,1>::Zero();
   ZP = Eigen::Matrix<double,4,4>::Zero();
   MRpm = Eigen::Array<double,2,1>::Zero();
   ZRP = Eigen::Matrix<double,2,2>::Zero();
   MChi = Eigen::Array<double,4,1>::Zero();
   ZN1 = Eigen::Matrix<std::complex<double>,4,4>::Zero();
   ZN2 = Eigen::Matrix<std::complex<double>,4,4>::Zero();
   MCha1 = Eigen::Array<double,2,1>::Zero();
   UM1 = Eigen::Matrix<std::complex<double>,2,2>::Zero();
   UP1 = Eigen::Matrix<std::complex<double>,2,2>::Zero();
   MCha2 = Eigen::Array<double,2,1>::Zero();
   UM2 = Eigen::Matrix<std::complex<double>,2,2>::Zero();
   UP2 = Eigen::Matrix<std::complex<double>,2,2>::Zero();
   MFe = Eigen::Array<double,3,1>::Zero();
   ZEL = Eigen::Matrix<std::complex<double>,3,3>::Zero();
   ZER = Eigen::Matrix<std::complex<double>,3,3>::Zero();
   MFd = Eigen::Array<double,3,1>::Zero();
   ZDL = Eigen::Matrix<std::complex<double>,3,3>::Zero();
   ZDR = Eigen::Matrix<std::complex<double>,3,3>::Zero();
   MFu = Eigen::Array<double,3,1>::Zero();
   ZUL = Eigen::Matrix<std::complex<double>,3,3>::Zero();
   ZUR = Eigen::Matrix<std::complex<double>,3,3>::Zero();
   MVG = 0.0;
   MVP = 0.0;
   MVWm = 0.0;


}

void CLASSNAME::clear()
{
   MRSSM_soft_parameters::clear();
   clear_DRbar_parameters();
   physical.clear();
   problems.clear();
}

std::string CLASSNAME::name() const
{
   return "MRSSM";
}

void CLASSNAME::run_to(double scale, double eps)
{
   if (eps < 0.0)
      eps = precision;
   MRSSM_soft_parameters::run_to(scale, eps);
}
/**
 * finds the lsp and returns it's mass
 */
double CLASSNAME::get_lsp(MRSSM_info::Particles& particle_type) const
{
   double lsp_mass = std::numeric_limits<double>::max();
   double tmp_mass;
   particle_type = MRSSM_info::NUMBER_OF_PARTICLES;

   tmp_mass = Abs(PHYSICAL(MChi(0)));
   if (tmp_mass < lsp_mass) {
      lsp_mass = tmp_mass;
      particle_type = MRSSM_info::Chi;
   }

   tmp_mass = Abs(PHYSICAL(MSu(0)));
   if (tmp_mass < lsp_mass) {
      lsp_mass = tmp_mass;
      particle_type = MRSSM_info::Su;
   }

   tmp_mass = Abs(PHYSICAL(MSd(0)));
   if (tmp_mass < lsp_mass) {
      lsp_mass = tmp_mass;
      particle_type = MRSSM_info::Sd;
   }

   tmp_mass = Abs(PHYSICAL(MSe(0)));
   if (tmp_mass < lsp_mass) {
      lsp_mass = tmp_mass;
      particle_type = MRSSM_info::Se;
   }

   tmp_mass = Abs(PHYSICAL(MCha1(0)));
   if (tmp_mass < lsp_mass) {
      lsp_mass = tmp_mass;
      particle_type = MRSSM_info::Cha1;
   }

   tmp_mass = Abs(PHYSICAL(MCha2(0)));
   if (tmp_mass < lsp_mass) {
      lsp_mass = tmp_mass;
      particle_type = MRSSM_info::Cha2;
   }

   return lsp_mass;
}


void CLASSNAME::calculate_MGlu()
{
   MGlu = MDGoc;
}

void CLASSNAME::calculate_MFv()
{
   MFv.setConstant(0);
}

void CLASSNAME::calculate_MSOc()
{
   MSOc = moc2 + 2*Sqr(MDGoc);

   if (MSOc < 0.)
      problems.flag_tachyon(SOc);
   else
      problems.unflag_tachyon(SOc);

   MSOc = AbsSqrt(MSOc);
}

void CLASSNAME::calculate_MVZ()
{
   MVZ = 0.25*(Sqr(vd) + Sqr(vu))*Sqr(g2*Cos(ThetaW()) +
      0.7745966692414834*g1*Sin(ThetaW()));

   if (MVZ < 0.)
      problems.flag_tachyon(VZ);
   else
      problems.unflag_tachyon(VZ);

   MVZ = AbsSqrt(MVZ);
}

Eigen::Matrix<double,6,6> CLASSNAME::get_mass_matrix_Sd() const
{
   Eigen::Matrix<double,6,6> mass_matrix_Sd;
   mass_matrix_Sd(0,0) = 0.12909944487358055*g1*MDBS*vS - 0.5*g2*MDWBT*vT
      + 0.12909944487358055*g1*vS*Conj(MDBS) - 0.5*g2*vT*Conj(MDWBT) + mq2(0,0
      ) + 0.5*(AbsSqr(Yd(0,0)) + AbsSqr(Yd(1,0)) + AbsSqr(Yd(2,0)))*Sqr(vd) -
      0.025*Sqr(g1)*Sqr(vd) - 0.125*Sqr(g2)*Sqr(vd) + 0.025*Sqr(g1)*Sqr(vu) +
      0.125*Sqr(g2)*Sqr(vu);
   mass_matrix_Sd(0,1) = mq2(0,1) + 0.5*Sqr(vd)*(Conj(Yd(0,0))*Yd(0,1) +
      Conj(Yd(1,0))*Yd(1,1) + Conj(Yd(2,0))*Yd(2,1));
   mass_matrix_Sd(0,2) = mq2(0,2) + 0.5*Sqr(vd)*(Conj(Yd(0,0))*Yd(0,2) +
      Conj(Yd(1,0))*Yd(1,2) + Conj(Yd(2,0))*Yd(2,2));
   mass_matrix_Sd(0,3) = -0.7071067811865475*vu*Conj(Yd(0,0))*Mu;
   mass_matrix_Sd(0,4) = -0.7071067811865475*vu*Conj(Yd(1,0))*Mu;
   mass_matrix_Sd(0,5) = -0.7071067811865475*vu*Conj(Yd(2,0))*Mu;
   mass_matrix_Sd(1,0) = Conj(mass_matrix_Sd(0,1));
   mass_matrix_Sd(1,1) = 0.12909944487358055*g1*MDBS*vS - 0.5*g2*MDWBT*vT
      + 0.12909944487358055*g1*vS*Conj(MDBS) - 0.5*g2*vT*Conj(MDWBT) + mq2(1,1
      ) + 0.5*(AbsSqr(Yd(0,1)) + AbsSqr(Yd(1,1)) + AbsSqr(Yd(2,1)))*Sqr(vd) -
      0.025*Sqr(g1)*Sqr(vd) - 0.125*Sqr(g2)*Sqr(vd) + 0.025*Sqr(g1)*Sqr(vu) +
      0.125*Sqr(g2)*Sqr(vu);
   mass_matrix_Sd(1,2) = mq2(1,2) + 0.5*Sqr(vd)*(Conj(Yd(0,1))*Yd(0,2) +
      Conj(Yd(1,1))*Yd(1,2) + Conj(Yd(2,1))*Yd(2,2));
   mass_matrix_Sd(1,3) = -0.7071067811865475*vu*Conj(Yd(0,1))*Mu;
   mass_matrix_Sd(1,4) = -0.7071067811865475*vu*Conj(Yd(1,1))*Mu;
   mass_matrix_Sd(1,5) = -0.7071067811865475*vu*Conj(Yd(2,1))*Mu;
   mass_matrix_Sd(2,0) = Conj(mass_matrix_Sd(0,2));
   mass_matrix_Sd(2,1) = Conj(mass_matrix_Sd(1,2));
   mass_matrix_Sd(2,2) = 0.12909944487358055*g1*MDBS*vS - 0.5*g2*MDWBT*vT
      + 0.12909944487358055*g1*vS*Conj(MDBS) - 0.5*g2*vT*Conj(MDWBT) + mq2(2,2
      ) + 0.5*(AbsSqr(Yd(0,2)) + AbsSqr(Yd(1,2)) + AbsSqr(Yd(2,2)))*Sqr(vd) -
      0.025*Sqr(g1)*Sqr(vd) - 0.125*Sqr(g2)*Sqr(vd) + 0.025*Sqr(g1)*Sqr(vu) +
      0.125*Sqr(g2)*Sqr(vu);
   mass_matrix_Sd(2,3) = -0.7071067811865475*vu*Conj(Yd(0,2))*Mu;
   mass_matrix_Sd(2,4) = -0.7071067811865475*vu*Conj(Yd(1,2))*Mu;
   mass_matrix_Sd(2,5) = -0.7071067811865475*vu*Conj(Yd(2,2))*Mu;
   mass_matrix_Sd(3,0) = Conj(mass_matrix_Sd(0,3));
   mass_matrix_Sd(3,1) = Conj(mass_matrix_Sd(1,3));
   mass_matrix_Sd(3,2) = Conj(mass_matrix_Sd(2,3));
   mass_matrix_Sd(3,3) = 0.2581988897471611*g1*MDBS*vS +
      0.2581988897471611*g1*vS*Conj(MDBS) + md2(0,0) + 0.5*(AbsSqr(Yd(0,0)) +
      AbsSqr(Yd(0,1)) + AbsSqr(Yd(0,2)))*Sqr(vd) - 0.05*Sqr(g1)*Sqr(vd) + 0.05*
      Sqr(g1)*Sqr(vu);
   mass_matrix_Sd(3,4) = md2(0,1) + 0.5*Sqr(vd)*(Conj(Yd(1,0))*Yd(0,0) +
      Conj(Yd(1,1))*Yd(0,1) + Conj(Yd(1,2))*Yd(0,2));
   mass_matrix_Sd(3,5) = md2(0,2) + 0.5*Sqr(vd)*(Conj(Yd(2,0))*Yd(0,0) +
      Conj(Yd(2,1))*Yd(0,1) + Conj(Yd(2,2))*Yd(0,2));
   mass_matrix_Sd(4,0) = Conj(mass_matrix_Sd(0,4));
   mass_matrix_Sd(4,1) = Conj(mass_matrix_Sd(1,4));
   mass_matrix_Sd(4,2) = Conj(mass_matrix_Sd(2,4));
   mass_matrix_Sd(4,3) = Conj(mass_matrix_Sd(3,4));
   mass_matrix_Sd(4,4) = 0.2581988897471611*g1*MDBS*vS +
      0.2581988897471611*g1*vS*Conj(MDBS) + md2(1,1) + 0.5*(AbsSqr(Yd(1,0)) +
      AbsSqr(Yd(1,1)) + AbsSqr(Yd(1,2)))*Sqr(vd) - 0.05*Sqr(g1)*Sqr(vd) + 0.05*
      Sqr(g1)*Sqr(vu);
   mass_matrix_Sd(4,5) = md2(1,2) + 0.5*Sqr(vd)*(Conj(Yd(2,0))*Yd(1,0) +
      Conj(Yd(2,1))*Yd(1,1) + Conj(Yd(2,2))*Yd(1,2));
   mass_matrix_Sd(5,0) = Conj(mass_matrix_Sd(0,5));
   mass_matrix_Sd(5,1) = Conj(mass_matrix_Sd(1,5));
   mass_matrix_Sd(5,2) = Conj(mass_matrix_Sd(2,5));
   mass_matrix_Sd(5,3) = Conj(mass_matrix_Sd(3,5));
   mass_matrix_Sd(5,4) = Conj(mass_matrix_Sd(4,5));
   mass_matrix_Sd(5,5) = 0.2581988897471611*g1*MDBS*vS +
      0.2581988897471611*g1*vS*Conj(MDBS) + md2(2,2) + 0.5*(AbsSqr(Yd(2,0)) +
      AbsSqr(Yd(2,1)) + AbsSqr(Yd(2,2)))*Sqr(vd) - 0.05*Sqr(g1)*Sqr(vd) + 0.05*
      Sqr(g1)*Sqr(vu);

   return mass_matrix_Sd;
}

void CLASSNAME::calculate_MSd()
{
   const auto mass_matrix_Sd(get_mass_matrix_Sd());
   fs_diagonalize_hermitian(mass_matrix_Sd, MSd, ZD);

   if (MSd.minCoeff() < 0.)
      problems.flag_tachyon(Sd);
   else
      problems.unflag_tachyon(Sd);

   MSd = AbsSqrt(MSd);
}

Eigen::Matrix<double,3,3> CLASSNAME::get_mass_matrix_Sv() const
{
   Eigen::Matrix<double,3,3> mass_matrix_Sv;
   mass_matrix_Sv(0,0) = -0.3872983346207417*g1*MDBS*vS + 0.5*g2*MDWBT*vT
      - 0.3872983346207417*g1*vS*Conj(MDBS) + 0.5*g2*vT*Conj(MDWBT) + ml2(0,0)
      + 0.075*Sqr(g1)*Sqr(vd) + 0.125*Sqr(g2)*Sqr(vd) - 0.075*Sqr(g1)*Sqr(vu)
      - 0.125*Sqr(g2)*Sqr(vu);
   mass_matrix_Sv(0,1) = ml2(0,1);
   mass_matrix_Sv(0,2) = ml2(0,2);
   mass_matrix_Sv(1,0) = Conj(mass_matrix_Sv(0,1));
   mass_matrix_Sv(1,1) = -0.3872983346207417*g1*MDBS*vS + 0.5*g2*MDWBT*vT
      - 0.3872983346207417*g1*vS*Conj(MDBS) + 0.5*g2*vT*Conj(MDWBT) + ml2(1,1)
      + 0.075*Sqr(g1)*Sqr(vd) + 0.125*Sqr(g2)*Sqr(vd) - 0.075*Sqr(g1)*Sqr(vu)
      - 0.125*Sqr(g2)*Sqr(vu);
   mass_matrix_Sv(1,2) = ml2(1,2);
   mass_matrix_Sv(2,0) = Conj(mass_matrix_Sv(0,2));
   mass_matrix_Sv(2,1) = Conj(mass_matrix_Sv(1,2));
   mass_matrix_Sv(2,2) = -0.3872983346207417*g1*MDBS*vS + 0.5*g2*MDWBT*vT
      - 0.3872983346207417*g1*vS*Conj(MDBS) + 0.5*g2*vT*Conj(MDWBT) + ml2(2,2)
      + 0.075*Sqr(g1)*Sqr(vd) + 0.125*Sqr(g2)*Sqr(vd) - 0.075*Sqr(g1)*Sqr(vu)
      - 0.125*Sqr(g2)*Sqr(vu);

   return mass_matrix_Sv;
}

void CLASSNAME::calculate_MSv()
{
   const auto mass_matrix_Sv(get_mass_matrix_Sv());
   fs_diagonalize_hermitian(mass_matrix_Sv, MSv, ZV);

   if (MSv.minCoeff() < 0.)
      problems.flag_tachyon(Sv);
   else
      problems.unflag_tachyon(Sv);

   MSv = AbsSqrt(MSv);
}

Eigen::Matrix<double,6,6> CLASSNAME::get_mass_matrix_Su() const
{
   Eigen::Matrix<double,6,6> mass_matrix_Su;
   mass_matrix_Su(0,0) = 0.12909944487358055*g1*MDBS*vS + 0.5*g2*MDWBT*vT
      + 0.12909944487358055*g1*vS*Conj(MDBS) + 0.5*g2*vT*Conj(MDWBT) + mq2(0,0
      ) - 0.025*Sqr(g1)*Sqr(vd) + 0.125*Sqr(g2)*Sqr(vd) + 0.5*(AbsSqr(Yu(0,0))
      + AbsSqr(Yu(1,0)) + AbsSqr(Yu(2,0)))*Sqr(vu) + 0.025*Sqr(g1)*Sqr(vu) -
      0.125*Sqr(g2)*Sqr(vu);
   mass_matrix_Su(0,1) = mq2(0,1) + 0.5*Sqr(vu)*(Conj(Yu(0,0))*Yu(0,1) +
      Conj(Yu(1,0))*Yu(1,1) + Conj(Yu(2,0))*Yu(2,1));
   mass_matrix_Su(0,2) = mq2(0,2) + 0.5*Sqr(vu)*(Conj(Yu(0,0))*Yu(0,2) +
      Conj(Yu(1,0))*Yu(1,2) + Conj(Yu(2,0))*Yu(2,2));
   mass_matrix_Su(0,3) = -0.7071067811865475*vd*Conj(Yu(0,0))*Mu;
   mass_matrix_Su(0,4) = -0.7071067811865475*vd*Conj(Yu(1,0))*Mu;
   mass_matrix_Su(0,5) = -0.7071067811865475*vd*Conj(Yu(2,0))*Mu;
   mass_matrix_Su(1,0) = Conj(mass_matrix_Su(0,1));
   mass_matrix_Su(1,1) = 0.12909944487358055*g1*MDBS*vS + 0.5*g2*MDWBT*vT
      + 0.12909944487358055*g1*vS*Conj(MDBS) + 0.5*g2*vT*Conj(MDWBT) + mq2(1,1
      ) - 0.025*Sqr(g1)*Sqr(vd) + 0.125*Sqr(g2)*Sqr(vd) + 0.5*(AbsSqr(Yu(0,1))
      + AbsSqr(Yu(1,1)) + AbsSqr(Yu(2,1)))*Sqr(vu) + 0.025*Sqr(g1)*Sqr(vu) -
      0.125*Sqr(g2)*Sqr(vu);
   mass_matrix_Su(1,2) = mq2(1,2) + 0.5*Sqr(vu)*(Conj(Yu(0,1))*Yu(0,2) +
      Conj(Yu(1,1))*Yu(1,2) + Conj(Yu(2,1))*Yu(2,2));
   mass_matrix_Su(1,3) = -0.7071067811865475*vd*Conj(Yu(0,1))*Mu;
   mass_matrix_Su(1,4) = -0.7071067811865475*vd*Conj(Yu(1,1))*Mu;
   mass_matrix_Su(1,5) = -0.7071067811865475*vd*Conj(Yu(2,1))*Mu;
   mass_matrix_Su(2,0) = Conj(mass_matrix_Su(0,2));
   mass_matrix_Su(2,1) = Conj(mass_matrix_Su(1,2));
   mass_matrix_Su(2,2) = 0.12909944487358055*g1*MDBS*vS + 0.5*g2*MDWBT*vT
      + 0.12909944487358055*g1*vS*Conj(MDBS) + 0.5*g2*vT*Conj(MDWBT) + mq2(2,2
      ) - 0.025*Sqr(g1)*Sqr(vd) + 0.125*Sqr(g2)*Sqr(vd) + 0.5*(AbsSqr(Yu(0,2))
      + AbsSqr(Yu(1,2)) + AbsSqr(Yu(2,2)))*Sqr(vu) + 0.025*Sqr(g1)*Sqr(vu) -
      0.125*Sqr(g2)*Sqr(vu);
   mass_matrix_Su(2,3) = -0.7071067811865475*vd*Conj(Yu(0,2))*Mu;
   mass_matrix_Su(2,4) = -0.7071067811865475*vd*Conj(Yu(1,2))*Mu;
   mass_matrix_Su(2,5) = -0.7071067811865475*vd*Conj(Yu(2,2))*Mu;
   mass_matrix_Su(3,0) = Conj(mass_matrix_Su(0,3));
   mass_matrix_Su(3,1) = Conj(mass_matrix_Su(1,3));
   mass_matrix_Su(3,2) = Conj(mass_matrix_Su(2,3));
   mass_matrix_Su(3,3) = -0.5163977794943222*g1*MDBS*vS -
      0.5163977794943222*g1*vS*Conj(MDBS) + mu2(0,0) + 0.1*Sqr(g1)*Sqr(vd) +
      0.5*(AbsSqr(Yu(0,0)) + AbsSqr(Yu(0,1)) + AbsSqr(Yu(0,2)))*Sqr(vu) - 0.1*
      Sqr(g1)*Sqr(vu);
   mass_matrix_Su(3,4) = mu2(0,1) + 0.5*Sqr(vu)*(Conj(Yu(1,0))*Yu(0,0) +
      Conj(Yu(1,1))*Yu(0,1) + Conj(Yu(1,2))*Yu(0,2));
   mass_matrix_Su(3,5) = mu2(0,2) + 0.5*Sqr(vu)*(Conj(Yu(2,0))*Yu(0,0) +
      Conj(Yu(2,1))*Yu(0,1) + Conj(Yu(2,2))*Yu(0,2));
   mass_matrix_Su(4,0) = Conj(mass_matrix_Su(0,4));
   mass_matrix_Su(4,1) = Conj(mass_matrix_Su(1,4));
   mass_matrix_Su(4,2) = Conj(mass_matrix_Su(2,4));
   mass_matrix_Su(4,3) = Conj(mass_matrix_Su(3,4));
   mass_matrix_Su(4,4) = -0.5163977794943222*g1*MDBS*vS -
      0.5163977794943222*g1*vS*Conj(MDBS) + mu2(1,1) + 0.1*Sqr(g1)*Sqr(vd) +
      0.5*(AbsSqr(Yu(1,0)) + AbsSqr(Yu(1,1)) + AbsSqr(Yu(1,2)))*Sqr(vu) - 0.1*
      Sqr(g1)*Sqr(vu);
   mass_matrix_Su(4,5) = mu2(1,2) + 0.5*Sqr(vu)*(Conj(Yu(2,0))*Yu(1,0) +
      Conj(Yu(2,1))*Yu(1,1) + Conj(Yu(2,2))*Yu(1,2));
   mass_matrix_Su(5,0) = Conj(mass_matrix_Su(0,5));
   mass_matrix_Su(5,1) = Conj(mass_matrix_Su(1,5));
   mass_matrix_Su(5,2) = Conj(mass_matrix_Su(2,5));
   mass_matrix_Su(5,3) = Conj(mass_matrix_Su(3,5));
   mass_matrix_Su(5,4) = Conj(mass_matrix_Su(4,5));
   mass_matrix_Su(5,5) = -0.5163977794943222*g1*MDBS*vS -
      0.5163977794943222*g1*vS*Conj(MDBS) + mu2(2,2) + 0.1*Sqr(g1)*Sqr(vd) +
      0.5*(AbsSqr(Yu(2,0)) + AbsSqr(Yu(2,1)) + AbsSqr(Yu(2,2)))*Sqr(vu) - 0.1*
      Sqr(g1)*Sqr(vu);

   return mass_matrix_Su;
}

void CLASSNAME::calculate_MSu()
{
   const auto mass_matrix_Su(get_mass_matrix_Su());
   fs_diagonalize_hermitian(mass_matrix_Su, MSu, ZU);

   if (MSu.minCoeff() < 0.)
      problems.flag_tachyon(Su);
   else
      problems.unflag_tachyon(Su);

   MSu = AbsSqrt(MSu);
}

Eigen::Matrix<double,6,6> CLASSNAME::get_mass_matrix_Se() const
{
   Eigen::Matrix<double,6,6> mass_matrix_Se;
   mass_matrix_Se(0,0) = -0.3872983346207417*g1*MDBS*vS - 0.5*g2*MDWBT*vT
      - 0.3872983346207417*g1*vS*Conj(MDBS) - 0.5*g2*vT*Conj(MDWBT) + ml2(0,0)
      + 0.5*(AbsSqr(Ye(0,0)) + AbsSqr(Ye(1,0)) + AbsSqr(Ye(2,0)))*Sqr(vd) +
      0.075*Sqr(g1)*Sqr(vd) - 0.125*Sqr(g2)*Sqr(vd) - 0.075*Sqr(g1)*Sqr(vu) +
      0.125*Sqr(g2)*Sqr(vu);
   mass_matrix_Se(0,1) = ml2(0,1) + 0.5*Sqr(vd)*(Conj(Ye(0,0))*Ye(0,1) +
      Conj(Ye(1,0))*Ye(1,1) + Conj(Ye(2,0))*Ye(2,1));
   mass_matrix_Se(0,2) = ml2(0,2) + 0.5*Sqr(vd)*(Conj(Ye(0,0))*Ye(0,2) +
      Conj(Ye(1,0))*Ye(1,2) + Conj(Ye(2,0))*Ye(2,2));
   mass_matrix_Se(0,3) = -0.7071067811865475*vu*Conj(Ye(0,0))*Mu;
   mass_matrix_Se(0,4) = -0.7071067811865475*vu*Conj(Ye(1,0))*Mu;
   mass_matrix_Se(0,5) = -0.7071067811865475*vu*Conj(Ye(2,0))*Mu;
   mass_matrix_Se(1,0) = Conj(mass_matrix_Se(0,1));
   mass_matrix_Se(1,1) = -0.3872983346207417*g1*MDBS*vS - 0.5*g2*MDWBT*vT
      - 0.3872983346207417*g1*vS*Conj(MDBS) - 0.5*g2*vT*Conj(MDWBT) + ml2(1,1)
      + 0.5*(AbsSqr(Ye(0,1)) + AbsSqr(Ye(1,1)) + AbsSqr(Ye(2,1)))*Sqr(vd) +
      0.075*Sqr(g1)*Sqr(vd) - 0.125*Sqr(g2)*Sqr(vd) - 0.075*Sqr(g1)*Sqr(vu) +
      0.125*Sqr(g2)*Sqr(vu);
   mass_matrix_Se(1,2) = ml2(1,2) + 0.5*Sqr(vd)*(Conj(Ye(0,1))*Ye(0,2) +
      Conj(Ye(1,1))*Ye(1,2) + Conj(Ye(2,1))*Ye(2,2));
   mass_matrix_Se(1,3) = -0.7071067811865475*vu*Conj(Ye(0,1))*Mu;
   mass_matrix_Se(1,4) = -0.7071067811865475*vu*Conj(Ye(1,1))*Mu;
   mass_matrix_Se(1,5) = -0.7071067811865475*vu*Conj(Ye(2,1))*Mu;
   mass_matrix_Se(2,0) = Conj(mass_matrix_Se(0,2));
   mass_matrix_Se(2,1) = Conj(mass_matrix_Se(1,2));
   mass_matrix_Se(2,2) = -0.3872983346207417*g1*MDBS*vS - 0.5*g2*MDWBT*vT
      - 0.3872983346207417*g1*vS*Conj(MDBS) - 0.5*g2*vT*Conj(MDWBT) + ml2(2,2)
      + 0.5*(AbsSqr(Ye(0,2)) + AbsSqr(Ye(1,2)) + AbsSqr(Ye(2,2)))*Sqr(vd) +
      0.075*Sqr(g1)*Sqr(vd) - 0.125*Sqr(g2)*Sqr(vd) - 0.075*Sqr(g1)*Sqr(vu) +
      0.125*Sqr(g2)*Sqr(vu);
   mass_matrix_Se(2,3) = -0.7071067811865475*vu*Conj(Ye(0,2))*Mu;
   mass_matrix_Se(2,4) = -0.7071067811865475*vu*Conj(Ye(1,2))*Mu;
   mass_matrix_Se(2,5) = -0.7071067811865475*vu*Conj(Ye(2,2))*Mu;
   mass_matrix_Se(3,0) = Conj(mass_matrix_Se(0,3));
   mass_matrix_Se(3,1) = Conj(mass_matrix_Se(1,3));
   mass_matrix_Se(3,2) = Conj(mass_matrix_Se(2,3));
   mass_matrix_Se(3,3) = 0.7745966692414834*g1*MDBS*vS +
      0.7745966692414834*g1*vS*Conj(MDBS) + me2(0,0) + 0.5*(AbsSqr(Ye(0,0)) +
      AbsSqr(Ye(0,1)) + AbsSqr(Ye(0,2)))*Sqr(vd) - 0.15*Sqr(g1)*Sqr(vd) + 0.15*
      Sqr(g1)*Sqr(vu);
   mass_matrix_Se(3,4) = me2(0,1) + 0.5*Sqr(vd)*(Conj(Ye(1,0))*Ye(0,0) +
      Conj(Ye(1,1))*Ye(0,1) + Conj(Ye(1,2))*Ye(0,2));
   mass_matrix_Se(3,5) = me2(0,2) + 0.5*Sqr(vd)*(Conj(Ye(2,0))*Ye(0,0) +
      Conj(Ye(2,1))*Ye(0,1) + Conj(Ye(2,2))*Ye(0,2));
   mass_matrix_Se(4,0) = Conj(mass_matrix_Se(0,4));
   mass_matrix_Se(4,1) = Conj(mass_matrix_Se(1,4));
   mass_matrix_Se(4,2) = Conj(mass_matrix_Se(2,4));
   mass_matrix_Se(4,3) = Conj(mass_matrix_Se(3,4));
   mass_matrix_Se(4,4) = 0.7745966692414834*g1*MDBS*vS +
      0.7745966692414834*g1*vS*Conj(MDBS) + me2(1,1) + 0.5*(AbsSqr(Ye(1,0)) +
      AbsSqr(Ye(1,1)) + AbsSqr(Ye(1,2)))*Sqr(vd) - 0.15*Sqr(g1)*Sqr(vd) + 0.15*
      Sqr(g1)*Sqr(vu);
   mass_matrix_Se(4,5) = me2(1,2) + 0.5*Sqr(vd)*(Conj(Ye(2,0))*Ye(1,0) +
      Conj(Ye(2,1))*Ye(1,1) + Conj(Ye(2,2))*Ye(1,2));
   mass_matrix_Se(5,0) = Conj(mass_matrix_Se(0,5));
   mass_matrix_Se(5,1) = Conj(mass_matrix_Se(1,5));
   mass_matrix_Se(5,2) = Conj(mass_matrix_Se(2,5));
   mass_matrix_Se(5,3) = Conj(mass_matrix_Se(3,5));
   mass_matrix_Se(5,4) = Conj(mass_matrix_Se(4,5));
   mass_matrix_Se(5,5) = 0.7745966692414834*g1*MDBS*vS +
      0.7745966692414834*g1*vS*Conj(MDBS) + me2(2,2) + 0.5*(AbsSqr(Ye(2,0)) +
      AbsSqr(Ye(2,1)) + AbsSqr(Ye(2,2)))*Sqr(vd) - 0.15*Sqr(g1)*Sqr(vd) + 0.15*
      Sqr(g1)*Sqr(vu);

   return mass_matrix_Se;
}

void CLASSNAME::calculate_MSe()
{
   const auto mass_matrix_Se(get_mass_matrix_Se());
   fs_diagonalize_hermitian(mass_matrix_Se, MSe, ZE);

   if (MSe.minCoeff() < 0.)
      problems.flag_tachyon(Se);
   else
      problems.unflag_tachyon(Se);

   MSe = AbsSqrt(MSe);
}

Eigen::Matrix<double,4,4> CLASSNAME::get_mass_matrix_hh() const
{
   Eigen::Matrix<double,4,4> mass_matrix_hh;
   mass_matrix_hh(0,0) = mHd2 - 0.3872983346207417*g1*MDBS*vS + 0.5*g2*
      MDWBT*vT + AbsSqr(MuD) + AbsSqr(Mu) + 0.7071067811865475*MuD*vS*Conj(
      LamSD) + 0.35355339059327373*LamTD*vS*vT*Conj(LamSD) + 0.5*MuD*vT*Conj(
      LamTD) + 0.35355339059327373*LamSD*vS*vT*Conj(LamTD) - 0.3872983346207417
      *g1*vS*Conj(MDBS) + 0.5*g2*vT*Conj(MDWBT) + 0.7071067811865475*LamSD*vS*
      Conj(MuD) + 0.5*LamTD*vT*Conj(MuD) + 0.225*Sqr(g1)*Sqr(vd) + 0.375*Sqr(g2
      )*Sqr(vd) + 0.5*AbsSqr(LamSD)*Sqr(vS) + 0.25*AbsSqr(LamTD)*Sqr(vT) -
      0.075*Sqr(g1)*Sqr(vu) - 0.125*Sqr(g2)*Sqr(vu);
   mass_matrix_hh(0,1) = -0.5*BMu - 0.5*Conj(BMu) - 0.15*vd*vu*Sqr(g1) -
      0.25*vd*vu*Sqr(g2);
   mass_matrix_hh(0,2) = -0.3872983346207417*g1*MDBS*vd + vd*vS*AbsSqr(
      LamSD) + 0.7071067811865475*MuD*vd*Conj(LamSD) + 0.35355339059327373*
      LamTD*vd*vT*Conj(LamSD) + 0.35355339059327373*LamSD*vd*vT*Conj(LamTD) -
      0.3872983346207417*g1*vd*Conj(MDBS) + 0.7071067811865475*LamSD*vd*Conj(
      MuD);
   mass_matrix_hh(0,3) = 0.5*g2*MDWBT*vd + 0.5*vd*vT*AbsSqr(LamTD) +
      0.35355339059327373*LamTD*vd*vS*Conj(LamSD) + 0.5*MuD*vd*Conj(LamTD) +
      0.35355339059327373*LamSD*vd*vS*Conj(LamTD) + 0.5*g2*vd*Conj(MDWBT) + 0.5
      *LamTD*vd*Conj(MuD);
   mass_matrix_hh(1,0) = mass_matrix_hh(0,1);
   mass_matrix_hh(1,1) = mHu2 + 0.3872983346207417*g1*MDBS*vS - 0.5*g2*
      MDWBT*vT + AbsSqr(MuU) + AbsSqr(Mu) + 0.7071067811865475*MuU*vS*Conj(
      LamSU) - 0.35355339059327373*LamTU*vS*vT*Conj(LamSU) - 0.5*MuU*vT*Conj(
      LamTU) - 0.35355339059327373*LamSU*vS*vT*Conj(LamTU) + 0.3872983346207417
      *g1*vS*Conj(MDBS) - 0.5*g2*vT*Conj(MDWBT) + 0.7071067811865475*LamSU*vS*
      Conj(MuU) - 0.5*LamTU*vT*Conj(MuU) - 0.075*Sqr(g1)*Sqr(vd) - 0.125*Sqr(g2
      )*Sqr(vd) + 0.5*AbsSqr(LamSU)*Sqr(vS) + 0.25*AbsSqr(LamTU)*Sqr(vT) +
      0.225*Sqr(g1)*Sqr(vu) + 0.375*Sqr(g2)*Sqr(vu);
   mass_matrix_hh(1,2) = 0.3872983346207417*g1*MDBS*vu + vS*vu*AbsSqr(
      LamSU) + 0.7071067811865475*MuU*vu*Conj(LamSU) - 0.35355339059327373*
      LamTU*vT*vu*Conj(LamSU) - 0.35355339059327373*LamSU*vT*vu*Conj(LamTU) +
      0.3872983346207417*g1*vu*Conj(MDBS) + 0.7071067811865475*LamSU*vu*Conj(
      MuU);
   mass_matrix_hh(1,3) = -0.5*g2*MDWBT*vu + 0.5*vT*vu*AbsSqr(LamTU) -
      0.35355339059327373*LamTU*vS*vu*Conj(LamSU) - 0.5*MuU*vu*Conj(LamTU) -
      0.35355339059327373*LamSU*vS*vu*Conj(LamTU) - 0.5*g2*vu*Conj(MDWBT) - 0.5
      *LamTU*vu*Conj(MuU);
   mass_matrix_hh(2,0) = mass_matrix_hh(0,2);
   mass_matrix_hh(2,1) = mass_matrix_hh(1,2);
   mass_matrix_hh(2,2) = mS2 + 4*Sqr(MDBS) + 0.5*AbsSqr(LamSD)*Sqr(vd) +
      0.5*AbsSqr(LamSU)*Sqr(vu);
   mass_matrix_hh(2,3) = 0.17677669529663687*LamTD*Conj(LamSD)*Sqr(vd) +
      0.17677669529663687*LamSD*Conj(LamTD)*Sqr(vd) - 0.17677669529663687*LamTU
      *Conj(LamSU)*Sqr(vu) - 0.17677669529663687*LamSU*Conj(LamTU)*Sqr(vu);
   mass_matrix_hh(3,0) = mass_matrix_hh(0,3);
   mass_matrix_hh(3,1) = mass_matrix_hh(1,3);
   mass_matrix_hh(3,2) = mass_matrix_hh(2,3);
   mass_matrix_hh(3,3) = mT2 + 4*Sqr(MDWBT) + 0.25*AbsSqr(LamTD)*Sqr(vd)
      + 0.25*AbsSqr(LamTU)*Sqr(vu);

   return mass_matrix_hh;
}

void CLASSNAME::calculate_Mhh()
{
   const auto mass_matrix_hh(get_mass_matrix_hh());
   fs_diagonalize_hermitian(mass_matrix_hh, Mhh, ZH);

   if (Mhh.minCoeff() < 0.)
      problems.flag_tachyon(hh);
   else
      problems.unflag_tachyon(hh);

   Mhh = AbsSqrt(Mhh);
}

Eigen::Matrix<double,4,4> CLASSNAME::get_mass_matrix_Ah() const
{
   Eigen::Matrix<double,4,4> mass_matrix_Ah;
   mass_matrix_Ah(0,0) = mHd2 - 0.3872983346207417*g1*MDBS*vS + 0.5*g2*
      MDWBT*vT + AbsSqr(MuD) + AbsSqr(Mu) + 0.7071067811865475*MuD*vS*Conj(
      LamSD) + 0.35355339059327373*LamTD*vS*vT*Conj(LamSD) + 0.5*MuD*vT*Conj(
      LamTD) + 0.35355339059327373*LamSD*vS*vT*Conj(LamTD) - 0.3872983346207417
      *g1*vS*Conj(MDBS) + 0.5*g2*vT*Conj(MDWBT) + 0.7071067811865475*LamSD*vS*
      Conj(MuD) + 0.5*LamTD*vT*Conj(MuD) + 0.3872983346207417*g1*g2*Cos(ThetaW(
      ))*Sin(ThetaW())*Sqr(vd) + 0.075*Sqr(g1)*Sqr(vd) + 0.125*Sqr(g2)*Sqr(vd)
      + 0.5*AbsSqr(LamSD)*Sqr(vS) + 0.25*AbsSqr(LamTD)*Sqr(vT) - 0.075*Sqr(g1)*
      Sqr(vu) - 0.125*Sqr(g2)*Sqr(vu) + 0.25*Sqr(g2)*Sqr(vd)*Sqr(Cos(ThetaW()))
      + 0.15*Sqr(g1)*Sqr(vd)*Sqr(Sin(ThetaW()));
   mass_matrix_Ah(0,1) = 0.5*BMu + 0.5*Conj(BMu) - 0.3872983346207417*g1*
      g2*vd*vu*Cos(ThetaW())*Sin(ThetaW()) - 0.25*vd*vu*Sqr(g2)*Sqr(Cos(ThetaW(
      ))) - 0.15*vd*vu*Sqr(g1)*Sqr(Sin(ThetaW()));
   mass_matrix_Ah(0,2) = 0;
   mass_matrix_Ah(0,3) = 0;
   mass_matrix_Ah(1,0) = mass_matrix_Ah(0,1);
   mass_matrix_Ah(1,1) = mHu2 + 0.3872983346207417*g1*MDBS*vS - 0.5*g2*
      MDWBT*vT + AbsSqr(MuU) + AbsSqr(Mu) + 0.7071067811865475*MuU*vS*Conj(
      LamSU) - 0.35355339059327373*LamTU*vS*vT*Conj(LamSU) - 0.5*MuU*vT*Conj(
      LamTU) - 0.35355339059327373*LamSU*vS*vT*Conj(LamTU) + 0.3872983346207417
      *g1*vS*Conj(MDBS) - 0.5*g2*vT*Conj(MDWBT) + 0.7071067811865475*LamSU*vS*
      Conj(MuU) - 0.5*LamTU*vT*Conj(MuU) - 0.075*Sqr(g1)*Sqr(vd) - 0.125*Sqr(g2
      )*Sqr(vd) + 0.5*AbsSqr(LamSU)*Sqr(vS) + 0.25*AbsSqr(LamTU)*Sqr(vT) +
      0.3872983346207417*g1*g2*Cos(ThetaW())*Sin(ThetaW())*Sqr(vu) + 0.075*Sqr(
      g1)*Sqr(vu) + 0.125*Sqr(g2)*Sqr(vu) + 0.25*Sqr(g2)*Sqr(vu)*Sqr(Cos(ThetaW
      ())) + 0.15*Sqr(g1)*Sqr(vu)*Sqr(Sin(ThetaW()));
   mass_matrix_Ah(1,2) = 0;
   mass_matrix_Ah(1,3) = 0;
   mass_matrix_Ah(2,0) = mass_matrix_Ah(0,2);
   mass_matrix_Ah(2,1) = mass_matrix_Ah(1,2);
   mass_matrix_Ah(2,2) = mS2 + 0.5*AbsSqr(LamSD)*Sqr(vd) + 0.5*AbsSqr(
      LamSU)*Sqr(vu);
   mass_matrix_Ah(2,3) = 0.17677669529663687*LamTD*Conj(LamSD)*Sqr(vd) +
      0.17677669529663687*LamSD*Conj(LamTD)*Sqr(vd) - 0.17677669529663687*LamTU
      *Conj(LamSU)*Sqr(vu) - 0.17677669529663687*LamSU*Conj(LamTU)*Sqr(vu);
   mass_matrix_Ah(3,0) = mass_matrix_Ah(0,3);
   mass_matrix_Ah(3,1) = mass_matrix_Ah(1,3);
   mass_matrix_Ah(3,2) = mass_matrix_Ah(2,3);
   mass_matrix_Ah(3,3) = mT2 + 0.25*AbsSqr(LamTD)*Sqr(vd) + 0.25*AbsSqr(
      LamTU)*Sqr(vu);

   return mass_matrix_Ah;
}

void CLASSNAME::calculate_MAh()
{
   const auto mass_matrix_Ah(get_mass_matrix_Ah());
   fs_diagonalize_hermitian(mass_matrix_Ah, MAh, ZA);

   if (MAh.minCoeff() < 0.)
      problems.flag_tachyon(Ah);
   else
      problems.unflag_tachyon(Ah);

   MAh = AbsSqrt(MAh);
}

Eigen::Matrix<double,2,2> CLASSNAME::get_mass_matrix_Rh() const
{
   Eigen::Matrix<double,2,2> mass_matrix_Rh;
   mass_matrix_Rh(0,0) = mRd2 + 0.3872983346207417*g1*MDBS*vS - 0.5*g2*
      MDWBT*vT + AbsSqr(MuD) + 0.7071067811865475*MuD*vS*Conj(LamSD) +
      0.35355339059327373*LamTD*vS*vT*Conj(LamSD) + 0.5*MuD*vT*Conj(LamTD) +
      0.35355339059327373*LamSD*vS*vT*Conj(LamTD) + 0.3872983346207417*g1*vS*
      Conj(MDBS) - 0.5*g2*vT*Conj(MDWBT) + 0.7071067811865475*LamSD*vS*Conj(MuD
      ) + 0.5*LamTD*vT*Conj(MuD) + 0.5*AbsSqr(LamSD)*Sqr(vd) + 0.25*AbsSqr(
      LamTD)*Sqr(vd) - 0.075*Sqr(g1)*Sqr(vd) - 0.125*Sqr(g2)*Sqr(vd) + 0.5*
      AbsSqr(LamSD)*Sqr(vS) + 0.25*AbsSqr(LamTD)*Sqr(vT) + 0.075*Sqr(g1)*Sqr(vu
      ) + 0.125*Sqr(g2)*Sqr(vu);
   mass_matrix_Rh(0,1) = -0.5*LamSU*vd*vu*Conj(LamSD) + 0.25*LamTU*vd*vu*
      Conj(LamTD);
   mass_matrix_Rh(1,0) = Conj(mass_matrix_Rh(0,1));
   mass_matrix_Rh(1,1) = mRu2 - 0.3872983346207417*g1*MDBS*vS + 0.5*g2*
      MDWBT*vT + AbsSqr(MuU) + 0.7071067811865475*MuU*vS*Conj(LamSU) -
      0.35355339059327373*LamTU*vS*vT*Conj(LamSU) - 0.5*MuU*vT*Conj(LamTU) -
      0.35355339059327373*LamSU*vS*vT*Conj(LamTU) - 0.3872983346207417*g1*vS*
      Conj(MDBS) + 0.5*g2*vT*Conj(MDWBT) + 0.7071067811865475*LamSU*vS*Conj(MuU
      ) - 0.5*LamTU*vT*Conj(MuU) + 0.075*Sqr(g1)*Sqr(vd) + 0.125*Sqr(g2)*Sqr(vd
      ) + 0.5*AbsSqr(LamSU)*Sqr(vS) + 0.25*AbsSqr(LamTU)*Sqr(vT) + 0.5*AbsSqr(
      LamSU)*Sqr(vu) + 0.25*AbsSqr(LamTU)*Sqr(vu) - 0.075*Sqr(g1)*Sqr(vu) -
      0.125*Sqr(g2)*Sqr(vu);

   return mass_matrix_Rh;
}

void CLASSNAME::calculate_MRh()
{
   const auto mass_matrix_Rh(get_mass_matrix_Rh());
   fs_diagonalize_hermitian(mass_matrix_Rh, MRh, ZHR);

   if (MRh.minCoeff() < 0.)
      problems.flag_tachyon(Rh);
   else
      problems.unflag_tachyon(Rh);

   MRh = AbsSqrt(MRh);
}

Eigen::Matrix<double,4,4> CLASSNAME::get_mass_matrix_Hpm() const
{
   Eigen::Matrix<double,4,4> mass_matrix_Hpm;
   mass_matrix_Hpm(0,0) = mHd2 - 0.3872983346207417*g1*MDBS*vS - 0.5*g2*
      MDWBT*vT + AbsSqr(MuD) + AbsSqr(Mu) + 0.7071067811865475*MuD*vS*Conj(
      LamSD) - 0.35355339059327373*LamTD*vS*vT*Conj(LamSD) - 0.5*MuD*vT*Conj(
      LamTD) - 0.35355339059327373*LamSD*vS*vT*Conj(LamTD) - 0.3872983346207417
      *g1*vS*Conj(MDBS) - 0.5*g2*vT*Conj(MDWBT) + 0.7071067811865475*LamSD*vS*
      Conj(MuD) - 0.5*LamTD*vT*Conj(MuD) + 0.075*Sqr(g1)*Sqr(vd) + 0.375*Sqr(g2
      )*Sqr(vd) + 0.5*AbsSqr(LamSD)*Sqr(vS) + 0.25*AbsSqr(LamTD)*Sqr(vT) -
      0.075*Sqr(g1)*Sqr(vu) + 0.125*Sqr(g2)*Sqr(vu);
   mass_matrix_Hpm(0,1) = Conj(BMu);
   mass_matrix_Hpm(0,2) = 0.7071067811865475*g2*MDWBT*vd -
      0.35355339059327373*vd*vT*AbsSqr(LamTD) + 0.5*LamTD*vd*vS*Conj(LamSD) +
      0.7071067811865475*LamTD*vd*Conj(MuD) + 0.7071067811865475*vd*vT*Sqr(g2);
   mass_matrix_Hpm(0,3) = 0.35355339059327373*vd*vT*AbsSqr(LamTD) +
      0.7071067811865475*MuD*vd*Conj(LamTD) + 0.5*LamSD*vd*vS*Conj(LamTD) +
      0.7071067811865475*g2*vd*Conj(MDWBT);
   mass_matrix_Hpm(1,0) = BMu;
   mass_matrix_Hpm(1,1) = mHu2 + 0.3872983346207417*g1*MDBS*vS + 0.5*g2*
      MDWBT*vT + AbsSqr(MuU) + AbsSqr(Mu) + 0.7071067811865475*MuU*vS*Conj(
      LamSU) + 0.35355339059327373*LamTU*vS*vT*Conj(LamSU) + 0.5*MuU*vT*Conj(
      LamTU) + 0.35355339059327373*LamSU*vS*vT*Conj(LamTU) + 0.3872983346207417
      *g1*vS*Conj(MDBS) + 0.5*g2*vT*Conj(MDWBT) + 0.7071067811865475*LamSU*vS*
      Conj(MuU) + 0.5*LamTU*vT*Conj(MuU) - 0.075*Sqr(g1)*Sqr(vd) + 0.125*Sqr(g2
      )*Sqr(vd) + 0.5*AbsSqr(LamSU)*Sqr(vS) + 0.25*AbsSqr(LamTU)*Sqr(vT) +
      0.075*Sqr(g1)*Sqr(vu) + 0.375*Sqr(g2)*Sqr(vu);
   mass_matrix_Hpm(1,2) = 0.7071067811865475*g2*MDWBT*vu -
      0.35355339059327373*vT*vu*AbsSqr(LamTU) + 0.5*LamTU*vS*vu*Conj(LamSU) +
      0.7071067811865475*LamTU*vu*Conj(MuU);
   mass_matrix_Hpm(1,3) = 0.35355339059327373*vT*vu*AbsSqr(LamTU) +
      0.7071067811865475*MuU*vu*Conj(LamTU) + 0.5*LamSU*vS*vu*Conj(LamTU) +
      0.7071067811865475*g2*vu*Conj(MDWBT) - 0.7071067811865475*vT*vu*Sqr(g2);
   mass_matrix_Hpm(2,0) = -0.35355339059327373*vd*vT*AbsSqr(LamTD) +
      0.7071067811865475*MuD*vd*Conj(LamTD) + 0.5*LamSD*vd*vS*Conj(LamTD) +
      0.7071067811865475*g2*vd*Conj(MDWBT) + 0.7071067811865475*vd*vT*Sqr(g2);
   mass_matrix_Hpm(2,1) = -0.35355339059327373*vT*vu*AbsSqr(LamTU) +
      0.7071067811865475*MuU*vu*Conj(LamTU) + 0.5*LamSU*vS*vu*Conj(LamTU) +
      0.7071067811865475*g2*vu*Conj(MDWBT);
   mass_matrix_Hpm(2,2) = mT2 + 2*Sqr(MDWBT) + 0.5*AbsSqr(LamTD)*Sqr(vd)
      - 0.25*Sqr(g2)*Sqr(vd) + Sqr(g2)*Sqr(vT) + 0.25*Sqr(g2)*Sqr(vu);
   mass_matrix_Hpm(2,3) = 2*Sqr(MDWBT);
   mass_matrix_Hpm(3,0) = 0.7071067811865475*g2*MDWBT*vd +
      0.35355339059327373*vd*vT*AbsSqr(LamTD) + 0.5*LamTD*vd*vS*Conj(LamSD) +
      0.7071067811865475*LamTD*vd*Conj(MuD);
   mass_matrix_Hpm(3,1) = 0.7071067811865475*g2*MDWBT*vu +
      0.35355339059327373*vT*vu*AbsSqr(LamTU) + 0.5*LamTU*vS*vu*Conj(LamSU) +
      0.7071067811865475*LamTU*vu*Conj(MuU) - 0.7071067811865475*vT*vu*Sqr(g2);
   mass_matrix_Hpm(3,2) = 2*Sqr(MDWBT);
   mass_matrix_Hpm(3,3) = mT2 + 2*Sqr(MDWBT) + 0.25*Sqr(g2)*Sqr(vd) + Sqr
      (g2)*Sqr(vT) + 0.5*AbsSqr(LamTU)*Sqr(vu) - 0.25*Sqr(g2)*Sqr(vu);

   return mass_matrix_Hpm;
}

void CLASSNAME::calculate_MHpm()
{
   const auto mass_matrix_Hpm(get_mass_matrix_Hpm());
   fs_diagonalize_hermitian(mass_matrix_Hpm, MHpm, ZP);

   if (MHpm.minCoeff() < 0.)
      problems.flag_tachyon(Hpm);
   else
      problems.unflag_tachyon(Hpm);

   MHpm = AbsSqrt(MHpm);
}

Eigen::Matrix<double,2,2> CLASSNAME::get_mass_matrix_Rpm() const
{
   Eigen::Matrix<double,2,2> mass_matrix_Rpm;
   mass_matrix_Rpm(0,0) = mRu2 - 0.3872983346207417*g1*MDBS*vS - 0.5*g2*
      MDWBT*vT + AbsSqr(MuU) + 0.7071067811865475*MuU*vS*Conj(LamSU) +
      0.35355339059327373*LamTU*vS*vT*Conj(LamSU) + 0.5*MuU*vT*Conj(LamTU) +
      0.35355339059327373*LamSU*vS*vT*Conj(LamTU) - 0.3872983346207417*g1*vS*
      Conj(MDBS) - 0.5*g2*vT*Conj(MDWBT) + 0.7071067811865475*LamSU*vS*Conj(MuU
      ) + 0.5*LamTU*vT*Conj(MuU) + 0.075*Sqr(g1)*Sqr(vd) - 0.125*Sqr(g2)*Sqr(vd
      ) + 0.5*AbsSqr(LamSU)*Sqr(vS) + 0.25*AbsSqr(LamTU)*Sqr(vT) + 0.5*AbsSqr(
      LamTU)*Sqr(vu) - 0.075*Sqr(g1)*Sqr(vu) + 0.125*Sqr(g2)*Sqr(vu);
   mass_matrix_Rpm(0,1) = 0;
   mass_matrix_Rpm(1,0) = mass_matrix_Rpm(0,1);
   mass_matrix_Rpm(1,1) = mRd2 + 0.3872983346207417*g1*MDBS*vS + 0.5*g2*
      MDWBT*vT + AbsSqr(MuD) + 0.7071067811865475*MuD*vS*Conj(LamSD) -
      0.35355339059327373*LamTD*vS*vT*Conj(LamSD) - 0.5*MuD*vT*Conj(LamTD) -
      0.35355339059327373*LamSD*vS*vT*Conj(LamTD) + 0.3872983346207417*g1*vS*
      Conj(MDBS) + 0.5*g2*vT*Conj(MDWBT) + 0.7071067811865475*LamSD*vS*Conj(MuD
      ) - 0.5*LamTD*vT*Conj(MuD) + 0.5*AbsSqr(LamTD)*Sqr(vd) - 0.075*Sqr(g1)*
      Sqr(vd) + 0.125*Sqr(g2)*Sqr(vd) + 0.5*AbsSqr(LamSD)*Sqr(vS) + 0.25*AbsSqr
      (LamTD)*Sqr(vT) + 0.075*Sqr(g1)*Sqr(vu) - 0.125*Sqr(g2)*Sqr(vu);

   return mass_matrix_Rpm;
}

void CLASSNAME::calculate_MRpm()
{
   const auto mass_matrix_Rpm(get_mass_matrix_Rpm());
   fs_diagonalize_hermitian(mass_matrix_Rpm, MRpm, ZRP);

   if (MRpm.minCoeff() < 0.)
      problems.flag_tachyon(Rpm);
   else
      problems.unflag_tachyon(Rpm);

   MRpm = AbsSqrt(MRpm);
}

Eigen::Matrix<double,4,4> CLASSNAME::get_mass_matrix_Chi() const
{
   Eigen::Matrix<double,4,4> mass_matrix_Chi;
   mass_matrix_Chi(0,0) = MDBS;
   mass_matrix_Chi(0,1) = 0;
   mass_matrix_Chi(0,2) = -0.3872983346207417*g1*vd;
   mass_matrix_Chi(0,3) = 0.3872983346207417*g1*vu;
   mass_matrix_Chi(1,0) = 0;
   mass_matrix_Chi(1,1) = MDWBT;
   mass_matrix_Chi(1,2) = 0.5*g2*vd;
   mass_matrix_Chi(1,3) = -0.5*g2*vu;
   mass_matrix_Chi(2,0) = -0.7071067811865475*LamSD*vd;
   mass_matrix_Chi(2,1) = -0.5*LamTD*vd;
   mass_matrix_Chi(2,2) = -MuD - 0.7071067811865475*LamSD*vS - 0.5*LamTD*
      vT;
   mass_matrix_Chi(2,3) = 0;
   mass_matrix_Chi(3,0) = 0.7071067811865475*LamSU*vu;
   mass_matrix_Chi(3,1) = -0.5*LamTU*vu;
   mass_matrix_Chi(3,2) = 0;
   mass_matrix_Chi(3,3) = MuU + 0.7071067811865475*LamSU*vS - 0.5*LamTU*
      vT;

   return mass_matrix_Chi;
}

void CLASSNAME::calculate_MChi()
{
   const auto mass_matrix_Chi(get_mass_matrix_Chi());
   fs_svd(mass_matrix_Chi, MChi, ZN1, ZN2);
}

Eigen::Matrix<double,2,2> CLASSNAME::get_mass_matrix_Cha1() const
{
   Eigen::Matrix<double,2,2> mass_matrix_Cha1;
   mass_matrix_Cha1(0,0) = MDWBT + g2*vT;
   mass_matrix_Cha1(0,1) = 0.7071067811865475*LamTD*vd;
   mass_matrix_Cha1(1,0) = 0.7071067811865475*g2*vd;
   mass_matrix_Cha1(1,1) = MuD + 0.7071067811865475*LamSD*vS - 0.5*LamTD*
      vT;

   return mass_matrix_Cha1;
}

void CLASSNAME::calculate_MCha1()
{
   const auto mass_matrix_Cha1(get_mass_matrix_Cha1());
   fs_svd(mass_matrix_Cha1, MCha1, UM1, UP1);
}

Eigen::Matrix<double,2,2> CLASSNAME::get_mass_matrix_Cha2() const
{
   Eigen::Matrix<double,2,2> mass_matrix_Cha2;
   mass_matrix_Cha2(0,0) = MDWBT - g2*vT;
   mass_matrix_Cha2(0,1) = 0.7071067811865475*g2*vu;
   mass_matrix_Cha2(1,0) = -0.7071067811865475*LamTU*vu;
   mass_matrix_Cha2(1,1) = -MuU - 0.7071067811865475*LamSU*vS - 0.5*LamTU
      *vT;

   return mass_matrix_Cha2;
}

void CLASSNAME::calculate_MCha2()
{
   const auto mass_matrix_Cha2(get_mass_matrix_Cha2());
   fs_svd(mass_matrix_Cha2, MCha2, UM2, UP2);
}

Eigen::Matrix<double,3,3> CLASSNAME::get_mass_matrix_Fe() const
{
   Eigen::Matrix<double,3,3> mass_matrix_Fe;
   mass_matrix_Fe(0,0) = 0.7071067811865475*vd*Ye(0,0);
   mass_matrix_Fe(0,1) = 0.7071067811865475*vd*Ye(1,0);
   mass_matrix_Fe(0,2) = 0.7071067811865475*vd*Ye(2,0);
   mass_matrix_Fe(1,0) = 0.7071067811865475*vd*Ye(0,1);
   mass_matrix_Fe(1,1) = 0.7071067811865475*vd*Ye(1,1);
   mass_matrix_Fe(1,2) = 0.7071067811865475*vd*Ye(2,1);
   mass_matrix_Fe(2,0) = 0.7071067811865475*vd*Ye(0,2);
   mass_matrix_Fe(2,1) = 0.7071067811865475*vd*Ye(1,2);
   mass_matrix_Fe(2,2) = 0.7071067811865475*vd*Ye(2,2);

   return mass_matrix_Fe;
}

void CLASSNAME::calculate_MFe()
{
   const auto mass_matrix_Fe(get_mass_matrix_Fe());
   fs_svd(mass_matrix_Fe, MFe, ZEL, ZER);
}

Eigen::Matrix<double,3,3> CLASSNAME::get_mass_matrix_Fd() const
{
   Eigen::Matrix<double,3,3> mass_matrix_Fd;
   mass_matrix_Fd(0,0) = 0.7071067811865475*vd*Yd(0,0);
   mass_matrix_Fd(0,1) = 0.7071067811865475*vd*Yd(1,0);
   mass_matrix_Fd(0,2) = 0.7071067811865475*vd*Yd(2,0);
   mass_matrix_Fd(1,0) = 0.7071067811865475*vd*Yd(0,1);
   mass_matrix_Fd(1,1) = 0.7071067811865475*vd*Yd(1,1);
   mass_matrix_Fd(1,2) = 0.7071067811865475*vd*Yd(2,1);
   mass_matrix_Fd(2,0) = 0.7071067811865475*vd*Yd(0,2);
   mass_matrix_Fd(2,1) = 0.7071067811865475*vd*Yd(1,2);
   mass_matrix_Fd(2,2) = 0.7071067811865475*vd*Yd(2,2);

   return mass_matrix_Fd;
}

void CLASSNAME::calculate_MFd()
{
   const auto mass_matrix_Fd(get_mass_matrix_Fd());
   fs_svd(mass_matrix_Fd, MFd, ZDL, ZDR);
}

Eigen::Matrix<double,3,3> CLASSNAME::get_mass_matrix_Fu() const
{
   Eigen::Matrix<double,3,3> mass_matrix_Fu;
   mass_matrix_Fu(0,0) = 0.7071067811865475*vu*Yu(0,0);
   mass_matrix_Fu(0,1) = 0.7071067811865475*vu*Yu(1,0);
   mass_matrix_Fu(0,2) = 0.7071067811865475*vu*Yu(2,0);
   mass_matrix_Fu(1,0) = 0.7071067811865475*vu*Yu(0,1);
   mass_matrix_Fu(1,1) = 0.7071067811865475*vu*Yu(1,1);
   mass_matrix_Fu(1,2) = 0.7071067811865475*vu*Yu(2,1);
   mass_matrix_Fu(2,0) = 0.7071067811865475*vu*Yu(0,2);
   mass_matrix_Fu(2,1) = 0.7071067811865475*vu*Yu(1,2);
   mass_matrix_Fu(2,2) = 0.7071067811865475*vu*Yu(2,2);

   return mass_matrix_Fu;
}

void CLASSNAME::calculate_MFu()
{
   const auto mass_matrix_Fu(get_mass_matrix_Fu());
   fs_svd(mass_matrix_Fu, MFu, ZUL, ZUR);
}

void CLASSNAME::calculate_MVG()
{
   MVG = 0;
}

void CLASSNAME::calculate_MVP()
{
   MVP = 0;
}

void CLASSNAME::calculate_MVWm()
{
   MVWm = 0.25*Sqr(g2)*(Sqr(vd) + 4*Sqr(vT) + Sqr(vu));

   if (MVWm < 0.)
      problems.flag_tachyon(VWm);
   else
      problems.unflag_tachyon(VWm);

   MVWm = AbsSqrt(MVWm);
}


double CLASSNAME::get_ewsb_eq_hh_1() const
{
   double result = mHd2*vd - 0.3872983346207417*g1*MDBS*vd*vS + 0.5*g2*MDWBT*vd
      *vT + vd*AbsSqr(MuD) + vd*AbsSqr(Mu) - 0.5*vu*BMu + 0.7071067811865475*MuD*
      vd*vS*Conj(LamSD) + 0.35355339059327373*LamTD*vd*vS*vT*Conj(LamSD) + 0.5*MuD
      *vd*vT*Conj(LamTD) + 0.35355339059327373*LamSD*vd*vS*vT*Conj(LamTD) -
      0.3872983346207417*g1*vd*vS*Conj(MDBS) + 0.5*g2*vd*vT*Conj(MDWBT) +
      0.7071067811865475*LamSD*vd*vS*Conj(MuD) + 0.5*LamTD*vd*vT*Conj(MuD) - 0.5*
      vu*Conj(BMu) + 0.075*Power(vd,3)*Sqr(g1) + 0.125*Power(vd,3)*Sqr(g2) + 0.5*
      vd*AbsSqr(LamSD)*Sqr(vS) + 0.25*vd*AbsSqr(LamTD)*Sqr(vT) - 0.075*vd*Sqr(g1)*
      Sqr(vu) - 0.125*vd*Sqr(g2)*Sqr(vu);

   return result;
}

double CLASSNAME::get_ewsb_eq_hh_2() const
{
   double result = mHu2*vu + 0.3872983346207417*g1*MDBS*vS*vu - 0.5*g2*MDWBT*vT
      *vu + vu*AbsSqr(MuU) + vu*AbsSqr(Mu) - 0.5*vd*BMu + 0.7071067811865475*MuU*
      vS*vu*Conj(LamSU) - 0.35355339059327373*LamTU*vS*vT*vu*Conj(LamSU) - 0.5*MuU
      *vT*vu*Conj(LamTU) - 0.35355339059327373*LamSU*vS*vT*vu*Conj(LamTU) +
      0.3872983346207417*g1*vS*vu*Conj(MDBS) - 0.5*g2*vT*vu*Conj(MDWBT) +
      0.7071067811865475*LamSU*vS*vu*Conj(MuU) - 0.5*LamTU*vT*vu*Conj(MuU) - 0.5*
      vd*Conj(BMu) + 0.075*Power(vu,3)*Sqr(g1) + 0.125*Power(vu,3)*Sqr(g2) - 0.075
      *vu*Sqr(g1)*Sqr(vd) - 0.125*vu*Sqr(g2)*Sqr(vd) + 0.5*vu*AbsSqr(LamSU)*Sqr(vS
      ) + 0.25*vu*AbsSqr(LamTU)*Sqr(vT);

   return result;
}

double CLASSNAME::get_ewsb_eq_hh_3() const
{
   double result = mT2*vT + 4*vT*Sqr(MDWBT) + 0.25*g2*MDWBT*Sqr(vd) + 0.25*vT*
      AbsSqr(LamTD)*Sqr(vd) + 0.17677669529663687*LamTD*vS*Conj(LamSD)*Sqr(vd) +
      0.25*MuD*Conj(LamTD)*Sqr(vd) + 0.17677669529663687*LamSD*vS*Conj(LamTD)*Sqr(
      vd) + 0.25*g2*Conj(MDWBT)*Sqr(vd) + 0.25*LamTD*Conj(MuD)*Sqr(vd) - 0.25*g2*
      MDWBT*Sqr(vu) + 0.25*vT*AbsSqr(LamTU)*Sqr(vu) - 0.17677669529663687*LamTU*vS
      *Conj(LamSU)*Sqr(vu) - 0.25*MuU*Conj(LamTU)*Sqr(vu) - 0.17677669529663687*
      LamSU*vS*Conj(LamTU)*Sqr(vu) - 0.25*g2*Conj(MDWBT)*Sqr(vu) - 0.25*LamTU*Conj
      (MuU)*Sqr(vu);

   return result;
}

double CLASSNAME::get_ewsb_eq_hh_4() const
{
   double result = mS2*vS + 4*vS*Sqr(MDBS) - 0.19364916731037085*g1*MDBS*Sqr(vd
      ) + 0.5*vS*AbsSqr(LamSD)*Sqr(vd) + 0.35355339059327373*MuD*Conj(LamSD)*Sqr(
      vd) + 0.17677669529663687*LamTD*vT*Conj(LamSD)*Sqr(vd) + 0.17677669529663687
      *LamSD*vT*Conj(LamTD)*Sqr(vd) - 0.19364916731037085*g1*Conj(MDBS)*Sqr(vd) +
      0.35355339059327373*LamSD*Conj(MuD)*Sqr(vd) + 0.19364916731037085*g1*MDBS*
      Sqr(vu) + 0.5*vS*AbsSqr(LamSU)*Sqr(vu) + 0.35355339059327373*MuU*Conj(LamSU)
      *Sqr(vu) - 0.17677669529663687*LamTU*vT*Conj(LamSU)*Sqr(vu) -
      0.17677669529663687*LamSU*vT*Conj(LamTU)*Sqr(vu) + 0.19364916731037085*g1*
      Conj(MDBS)*Sqr(vu) + 0.35355339059327373*LamSU*Conj(MuU)*Sqr(vu);

   return result;
}



std::complex<double> CLASSNAME::CpUSdconjUSdVZVZ(unsigned gO1, unsigned gO2) const
{
   std::complex<double> result;

   std::complex<double> tmp_0;
   std::complex<double> tmp_1;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1 += KroneckerDelta(gO1,3 + j1)*KroneckerDelta(gO2,3 + j1);
   }
   tmp_0 += tmp_1;
   result += (0.13333333333333333*Sqr(g1)*Sqr(Sin(ThetaW()))) * tmp_0;
   if (gO1 < 3) {
      result += 0.5*KroneckerDelta(gO1,gO2)*Sqr(g2)*Sqr(Cos(ThetaW()));
   }
   if (gO1 < 3) {
      result += 0.2581988897471611*g1*g2*Cos(ThetaW())*KroneckerDelta(gO1,
         gO2)*Sin(ThetaW());
   }
   if (gO1 < 3) {
      result += 0.03333333333333333*KroneckerDelta(gO1,gO2)*Sqr(g1)*Sqr(Sin(
         ThetaW()));
   }

   return result;
}

std::complex<double> CLASSNAME::CpUSdconjUSdconjSOcSOc(unsigned gO1, unsigned gO2) const
{
   std::complex<double> result;

   std::complex<double> tmp_2;
   std::complex<double> tmp_3;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_3 += KroneckerDelta(gO1,3 + j1)*KroneckerDelta(gO2,3 + j1);
   }
   tmp_2 += tmp_3;
   result += (std::complex<double>(0,-64)*Sqr(g3)) * tmp_2;
   if (gO1 < 3) {
      result += std::complex<double>(0,64)*KroneckerDelta(gO1,gO2)*Sqr(g3);
   }

   return result;
}

double CLASSNAME::CpUSdconjUSdconjVWmVWm(unsigned gO1, unsigned gO2) const
{
   double result = 0.0;

   if (gO1 < 3) {
      result += 0.5*KroneckerDelta(gO1,gO2)*Sqr(g2);
   }

   return result;
}

std::complex<double> CLASSNAME::CpUSdconjUSdconjRhRh(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_4;
   std::complex<double> tmp_5;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_5 += KroneckerDelta(gO1,3 + j1)*KroneckerDelta(gO2,3 + j1);
   }
   tmp_4 += tmp_5;
   result += (-0.1*Sqr(g1)*ZHR(gI1,0)*ZHR(gI2,0)) * tmp_4;
   if (gO1 < 3) {
      result += -0.05*KroneckerDelta(gO1,gO2)*Sqr(g1)*ZHR(gI1,0)*ZHR(gI2,0);
   }
   if (gO1 < 3) {
      result += -0.25*KroneckerDelta(gO1,gO2)*Sqr(g2)*ZHR(gI1,0)*ZHR(gI2,0);
   }
   std::complex<double> tmp_6;
   std::complex<double> tmp_7;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_7 += KroneckerDelta(gO1,3 + j1)*KroneckerDelta(gO2,3 + j1);
   }
   tmp_6 += tmp_7;
   result += (0.1*Sqr(g1)*ZHR(gI1,1)*ZHR(gI2,1)) * tmp_6;
   if (gO1 < 3) {
      result += 0.05*KroneckerDelta(gO1,gO2)*Sqr(g1)*ZHR(gI1,1)*ZHR(gI2,1);
   }
   if (gO1 < 3) {
      result += 0.25*KroneckerDelta(gO1,gO2)*Sqr(g2)*ZHR(gI1,1)*ZHR(gI2,1);
   }

   return result;
}

std::complex<double> CLASSNAME::CpUSdconjUSdconjRpmRpm(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_8;
   std::complex<double> tmp_9;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_9 += KroneckerDelta(gO1,3 + j1)*KroneckerDelta(gO2,3 + j1);
   }
   tmp_8 += tmp_9;
   result += (0.1*Conj(ZRP(gI2,0))*Sqr(g1)*ZRP(gI1,0)) * tmp_8;
   if (gO1 < 3) {
      result += 0.05*Conj(ZRP(gI2,0))*KroneckerDelta(gO1,gO2)*Sqr(g1)*ZRP(
         gI1,0);
   }
   if (gO1 < 3) {
      result += -0.25*Conj(ZRP(gI2,0))*KroneckerDelta(gO1,gO2)*Sqr(g2)*ZRP(
         gI1,0);
   }
   std::complex<double> tmp_10;
   std::complex<double> tmp_11;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_11 += KroneckerDelta(gO1,3 + j1)*KroneckerDelta(gO2,3 + j1);
   }
   tmp_10 += tmp_11;
   result += (-0.1*Conj(ZRP(gI2,1))*Sqr(g1)*ZRP(gI1,1)) * tmp_10;
   if (gO1 < 3) {
      result += -0.05*Conj(ZRP(gI2,1))*KroneckerDelta(gO1,gO2)*Sqr(g1)*ZRP(
         gI1,1);
   }
   if (gO1 < 3) {
      result += 0.25*Conj(ZRP(gI2,1))*KroneckerDelta(gO1,gO2)*Sqr(g2)*ZRP(
         gI1,1);
   }

   return result;
}

double CLASSNAME::CpconjUSdbarCha1FuPR(unsigned , unsigned , unsigned ) const
{
   double result = 0.0;

   result = 0;

   return result;
}

std::complex<double> CLASSNAME::CpconjUSdbarCha1FuPL(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_12;
   std::complex<double> tmp_13;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_14;
      std::complex<double> tmp_15;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_15 += KroneckerDelta(gO1,3 + j1)*Yd(j1,j2);
      }
      tmp_14 += tmp_15;
      tmp_13 += (Conj(ZUL(gI2,j2))) * tmp_14;
   }
   tmp_12 += tmp_13;
   result += (Conj(UM1(gI1,1))) * tmp_12;

   return result;
}

std::complex<double> CLASSNAME::CpUSdconjUSdconjSvSv(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_16;
   std::complex<double> tmp_17;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_17 += KroneckerDelta(gO1,3 + j1)*KroneckerDelta(gO2,3 + j1);
   }
   tmp_16 += tmp_17;
   result += (0.1*KroneckerDelta(gI1,gI2)*Sqr(g1)) * tmp_16;
   if (gO1 < 3) {
      result += 0.05*KroneckerDelta(gI1,gI2)*KroneckerDelta(gO1,gO2)*Sqr(g1)
         ;
   }
   if (gO1 < 3) {
      result += 0.25*KroneckerDelta(gI1,gI2)*KroneckerDelta(gO1,gO2)*Sqr(g2)
         ;
   }

   return result;
}

std::complex<double> CLASSNAME::CpconjUSdFuCha2PR(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gO2 < 3) {
      std::complex<double> tmp_18;
      std::complex<double> tmp_19;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_19 += Conj(Yu(j1,gO2))*ZUR(gI1,j1);
      }
      tmp_18 += tmp_19;
      result += (UP2(gI2,1)) * tmp_18;
   }

   return result;
}

std::complex<double> CLASSNAME::CpconjUSdFuCha2PL(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gO1 < 3) {
      result += -(g2*Conj(UM2(gI2,0))*Conj(ZUL(gI1,gO1)));
   }

   return result;
}

std::complex<double> CLASSNAME::CpconjUSdFdChiPR(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gO2 < 3) {
      std::complex<double> tmp_20;
      std::complex<double> tmp_21;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_21 += Conj(Yd(j1,gO2))*ZDR(gI1,j1);
      }
      tmp_20 += tmp_21;
      result += (-ZN2(gI2,2)) * tmp_20;
   }

   return result;
}

std::complex<double> CLASSNAME::CpconjUSdFdChiPL(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gO1 < 3) {
      result += -0.18257418583505536*g1*Conj(ZDL(gI1,gO1))*Conj(ZN1(gI2,0));
   }
   if (gO1 < 3) {
      result += 0.7071067811865475*g2*Conj(ZDL(gI1,gO1))*Conj(ZN1(gI2,1));
   }

   return result;
}

std::complex<double> CLASSNAME::CpUSdconjUSdAhAh(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_22;
   std::complex<double> tmp_23;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_23 += KroneckerDelta(gO1,3 + j1)*KroneckerDelta(gO2,3 + j1);
   }
   tmp_22 += tmp_23;
   result += (0.1*Sqr(g1)*ZA(gI1,0)*ZA(gI2,0)) * tmp_22;
   std::complex<double> tmp_24;
   std::complex<double> tmp_25;
   for (unsigned j3 = 0; j3 < 3; ++j3) {
      std::complex<double> tmp_26;
      std::complex<double> tmp_27;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         std::complex<double> tmp_28;
         std::complex<double> tmp_29;
         for (unsigned j1 = 0; j1 < 3; ++j1) {
            tmp_29 += Conj(Yd(j3,j1))*Yd(j2,j1);
         }
         tmp_28 += tmp_29;
         tmp_27 += (KroneckerDelta(gO2,3 + j2)) * tmp_28;
      }
      tmp_26 += tmp_27;
      tmp_25 += (KroneckerDelta(gO1,3 + j3)) * tmp_26;
   }
   tmp_24 += tmp_25;
   result += (-(ZA(gI1,0)*ZA(gI2,0))) * tmp_24;
   if (gO1 < 3) {
      result += 0.05*KroneckerDelta(gO1,gO2)*Sqr(g1)*ZA(gI1,0)*ZA(gI2,0);
   }
   if (gO1 < 3) {
      result += 0.25*KroneckerDelta(gO1,gO2)*Sqr(g2)*ZA(gI1,0)*ZA(gI2,0);
   }
   if (gO1 < 3 && gO2 < 3) {
      std::complex<double> tmp_30;
      std::complex<double> tmp_31;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_31 += Conj(Yd(j1,gO2))*Yd(j1,gO1);
      }
      tmp_30 += tmp_31;
      result += (-(ZA(gI1,0)*ZA(gI2,0))) * tmp_30;
   }
   std::complex<double> tmp_32;
   std::complex<double> tmp_33;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_33 += KroneckerDelta(gO1,3 + j1)*KroneckerDelta(gO2,3 + j1);
   }
   tmp_32 += tmp_33;
   result += (-0.1*Sqr(g1)*ZA(gI1,1)*ZA(gI2,1)) * tmp_32;
   if (gO1 < 3) {
      result += -0.05*KroneckerDelta(gO1,gO2)*Sqr(g1)*ZA(gI1,1)*ZA(gI2,1);
   }
   if (gO1 < 3) {
      result += -0.25*KroneckerDelta(gO1,gO2)*Sqr(g2)*ZA(gI1,1)*ZA(gI2,1);
   }

   return result;
}

std::complex<double> CLASSNAME::CpUSdconjUSdconjHpmHpm(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_34;
   std::complex<double> tmp_35;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_35 += KroneckerDelta(gO1,3 + j1)*KroneckerDelta(gO2,3 + j1);
   }
   tmp_34 += tmp_35;
   result += (0.1*Sqr(g1)*ZP(gI1,0)*ZP(gI2,0)) * tmp_34;
   std::complex<double> tmp_36;
   std::complex<double> tmp_37;
   for (unsigned j3 = 0; j3 < 3; ++j3) {
      std::complex<double> tmp_38;
      std::complex<double> tmp_39;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         std::complex<double> tmp_40;
         std::complex<double> tmp_41;
         for (unsigned j1 = 0; j1 < 3; ++j1) {
            tmp_41 += Conj(Yd(j3,j1))*Yd(j2,j1);
         }
         tmp_40 += tmp_41;
         tmp_39 += (KroneckerDelta(gO2,3 + j2)) * tmp_40;
      }
      tmp_38 += tmp_39;
      tmp_37 += (KroneckerDelta(gO1,3 + j3)) * tmp_38;
   }
   tmp_36 += tmp_37;
   result += (-(ZP(gI1,0)*ZP(gI2,0))) * tmp_36;
   if (gO1 < 3) {
      result += 0.05*KroneckerDelta(gO1,gO2)*Sqr(g1)*ZP(gI1,0)*ZP(gI2,0);
   }
   if (gO1 < 3) {
      result += -0.25*KroneckerDelta(gO1,gO2)*Sqr(g2)*ZP(gI1,0)*ZP(gI2,0);
   }
   std::complex<double> tmp_42;
   std::complex<double> tmp_43;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_43 += KroneckerDelta(gO1,3 + j1)*KroneckerDelta(gO2,3 + j1);
   }
   tmp_42 += tmp_43;
   result += (-0.1*Sqr(g1)*ZP(gI1,1)*ZP(gI2,1)) * tmp_42;
   if (gO1 < 3) {
      result += -0.05*KroneckerDelta(gO1,gO2)*Sqr(g1)*ZP(gI1,1)*ZP(gI2,1);
   }
   if (gO1 < 3) {
      result += 0.25*KroneckerDelta(gO1,gO2)*Sqr(g2)*ZP(gI1,1)*ZP(gI2,1);
   }
   if (gO1 < 3 && gO2 < 3) {
      std::complex<double> tmp_44;
      std::complex<double> tmp_45;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_45 += Conj(Yu(j1,gO2))*Yu(j1,gO1);
      }
      tmp_44 += tmp_45;
      result += (-(ZP(gI1,1)*ZP(gI2,1))) * tmp_44;
   }
   if (gO1 < 3) {
      result += -0.5*KroneckerDelta(gO1,gO2)*Sqr(g2)*ZP(gI1,2)*ZP(gI2,2);
   }
   if (gO1 < 3) {
      result += 0.5*KroneckerDelta(gO1,gO2)*Sqr(g2)*ZP(gI1,3)*ZP(gI2,3);
   }

   return result;
}

std::complex<double> CLASSNAME::CpUSdconjUSdhhhh(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_46;
   std::complex<double> tmp_47;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_47 += KroneckerDelta(gO1,3 + j1)*KroneckerDelta(gO2,3 + j1);
   }
   tmp_46 += tmp_47;
   result += (0.1*Sqr(g1)*ZH(gI1,0)*ZH(gI2,0)) * tmp_46;
   std::complex<double> tmp_48;
   std::complex<double> tmp_49;
   for (unsigned j3 = 0; j3 < 3; ++j3) {
      std::complex<double> tmp_50;
      std::complex<double> tmp_51;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         std::complex<double> tmp_52;
         std::complex<double> tmp_53;
         for (unsigned j1 = 0; j1 < 3; ++j1) {
            tmp_53 += Conj(Yd(j3,j1))*Yd(j2,j1);
         }
         tmp_52 += tmp_53;
         tmp_51 += (KroneckerDelta(gO2,3 + j2)) * tmp_52;
      }
      tmp_50 += tmp_51;
      tmp_49 += (KroneckerDelta(gO1,3 + j3)) * tmp_50;
   }
   tmp_48 += tmp_49;
   result += (-(ZH(gI1,0)*ZH(gI2,0))) * tmp_48;
   if (gO1 < 3) {
      result += 0.05*KroneckerDelta(gO1,gO2)*Sqr(g1)*ZH(gI1,0)*ZH(gI2,0);
   }
   if (gO1 < 3) {
      result += 0.25*KroneckerDelta(gO1,gO2)*Sqr(g2)*ZH(gI1,0)*ZH(gI2,0);
   }
   if (gO1 < 3 && gO2 < 3) {
      std::complex<double> tmp_54;
      std::complex<double> tmp_55;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_55 += Conj(Yd(j1,gO2))*Yd(j1,gO1);
      }
      tmp_54 += tmp_55;
      result += (-(ZH(gI1,0)*ZH(gI2,0))) * tmp_54;
   }
   std::complex<double> tmp_56;
   std::complex<double> tmp_57;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_57 += KroneckerDelta(gO1,3 + j1)*KroneckerDelta(gO2,3 + j1);
   }
   tmp_56 += tmp_57;
   result += (-0.1*Sqr(g1)*ZH(gI1,1)*ZH(gI2,1)) * tmp_56;
   if (gO1 < 3) {
      result += -0.05*KroneckerDelta(gO1,gO2)*Sqr(g1)*ZH(gI1,1)*ZH(gI2,1);
   }
   if (gO1 < 3) {
      result += -0.25*KroneckerDelta(gO1,gO2)*Sqr(g2)*ZH(gI1,1)*ZH(gI2,1);
   }

   return result;
}

std::complex<double> CLASSNAME::CpconjUSdbarChiFdPR(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_58;
   std::complex<double> tmp_59;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_59 += KroneckerDelta(gO2,3 + j1)*ZDR(gI2,j1);
   }
   tmp_58 += tmp_59;
   result += (-0.3651483716701107*g1*ZN1(gI1,0)) * tmp_58;

   return result;
}

std::complex<double> CLASSNAME::CpconjUSdbarChiFdPL(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_60;
   std::complex<double> tmp_61;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_62;
      std::complex<double> tmp_63;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_63 += KroneckerDelta(gO1,3 + j1)*Yd(j1,j2);
      }
      tmp_62 += tmp_63;
      tmp_61 += (Conj(ZDL(gI2,j2))) * tmp_62;
   }
   tmp_60 += tmp_61;
   result += (-Conj(ZN2(gI1,2))) * tmp_60;

   return result;
}

std::complex<double> CLASSNAME::CpUSdconjUSdconjSdSd(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_64;
   std::complex<double> tmp_66;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_66 += KroneckerDelta(gO1,3 + j1)*ZD(gI1,3 + j1);
   }
   tmp_64 += tmp_66;
   std::complex<double> tmp_65;
   std::complex<double> tmp_67;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      tmp_67 += Conj(ZD(gI2,3 + j2))*KroneckerDelta(gO2,3 + j2);
   }
   tmp_65 += tmp_67;
   result += (-0.03333333333333333*Sqr(g1)) * tmp_64 * tmp_65;
   std::complex<double> tmp_68;
   std::complex<double> tmp_70;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_70 += KroneckerDelta(gO1,3 + j1)*ZD(gI1,3 + j1);
   }
   tmp_68 += tmp_70;
   std::complex<double> tmp_69;
   std::complex<double> tmp_71;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      tmp_71 += Conj(ZD(gI2,3 + j2))*KroneckerDelta(gO2,3 + j2);
   }
   tmp_69 += tmp_71;
   result += (-0.6666666666666666*Sqr(g3)) * tmp_68 * tmp_69;
   std::complex<double> tmp_72;
   std::complex<double> tmp_74;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_74 += Conj(ZD(gI2,j1))*ZD(gI1,j1);
   }
   tmp_72 += tmp_74;
   std::complex<double> tmp_73;
   std::complex<double> tmp_75;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      tmp_75 += KroneckerDelta(gO1,3 + j2)*KroneckerDelta(gO2,3 + j2);
   }
   tmp_73 += tmp_75;
   result += (-0.05*Sqr(g1)) * tmp_72 * tmp_73;
   std::complex<double> tmp_76;
   std::complex<double> tmp_78;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_78 += Conj(ZD(gI2,3 + j1))*ZD(gI1,3 + j1);
   }
   tmp_76 += tmp_78;
   std::complex<double> tmp_77;
   std::complex<double> tmp_79;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      tmp_79 += KroneckerDelta(gO1,3 + j2)*KroneckerDelta(gO2,3 + j2);
   }
   tmp_77 += tmp_79;
   result += (-0.1*Sqr(g1)) * tmp_76 * tmp_77;
   std::complex<double> tmp_80;
   std::complex<double> tmp_82;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_82 += KroneckerDelta(gO1,3 + j1)*KroneckerDelta(gO2,3 + j1);
   }
   tmp_80 += tmp_82;
   std::complex<double> tmp_81;
   std::complex<double> tmp_83;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      tmp_83 += Conj(ZD(gI2,j2))*ZD(gI1,j2);
   }
   tmp_81 += tmp_83;
   result += (-0.05*Sqr(g1)) * tmp_80 * tmp_81;
   std::complex<double> tmp_84;
   std::complex<double> tmp_86;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_86 += KroneckerDelta(gO1,3 + j1)*KroneckerDelta(gO2,3 + j1);
   }
   tmp_84 += tmp_86;
   std::complex<double> tmp_85;
   std::complex<double> tmp_87;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      tmp_87 += Conj(ZD(gI2,3 + j2))*ZD(gI1,3 + j2);
   }
   tmp_85 += tmp_87;
   result += (-0.1*Sqr(g1)) * tmp_84 * tmp_85;
   std::complex<double> tmp_88;
   std::complex<double> tmp_90;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_90 += Conj(ZD(gI2,3 + j1))*KroneckerDelta(gO2,3 + j1);
   }
   tmp_88 += tmp_90;
   std::complex<double> tmp_89;
   std::complex<double> tmp_91;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      tmp_91 += KroneckerDelta(gO1,3 + j2)*ZD(gI1,3 + j2);
   }
   tmp_89 += tmp_91;
   result += (-0.03333333333333333*Sqr(g1)) * tmp_88 * tmp_89;
   std::complex<double> tmp_92;
   std::complex<double> tmp_94;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_94 += Conj(ZD(gI2,3 + j1))*KroneckerDelta(gO2,3 + j1);
   }
   tmp_92 += tmp_94;
   std::complex<double> tmp_93;
   std::complex<double> tmp_95;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      tmp_95 += KroneckerDelta(gO1,3 + j2)*ZD(gI1,3 + j2);
   }
   tmp_93 += tmp_95;
   result += (-0.6666666666666666*Sqr(g3)) * tmp_92 * tmp_93;
   std::complex<double> tmp_96;
   std::complex<double> tmp_98;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_99;
      std::complex<double> tmp_100;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_100 += KroneckerDelta(gO2,3 + j1)*Yd(j1,j2);
      }
      tmp_99 += tmp_100;
      tmp_98 += (Conj(ZD(gI2,j2))) * tmp_99;
   }
   tmp_96 += tmp_98;
   std::complex<double> tmp_97;
   std::complex<double> tmp_101;
   for (unsigned j4 = 0; j4 < 3; ++j4) {
      std::complex<double> tmp_102;
      std::complex<double> tmp_103;
      for (unsigned j3 = 0; j3 < 3; ++j3) {
         tmp_103 += Conj(Yd(j3,j4))*KroneckerDelta(gO1,3 + j3);
      }
      tmp_102 += tmp_103;
      tmp_101 += (ZD(gI1,j4)) * tmp_102;
   }
   tmp_97 += tmp_101;
   result += (-1) * tmp_96 * tmp_97;
   if (gO1 < 3) {
      std::complex<double> tmp_104;
      std::complex<double> tmp_105;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_105 += Conj(ZD(gI2,j1))*ZD(gI1,j1);
      }
      tmp_104 += tmp_105;
      result += (-0.025*KroneckerDelta(gO1,gO2)*Sqr(g1)) * tmp_104;
   }
   if (gO1 < 3) {
      std::complex<double> tmp_106;
      std::complex<double> tmp_107;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_107 += Conj(ZD(gI2,j1))*ZD(gI1,j1);
      }
      tmp_106 += tmp_107;
      result += (-0.375*KroneckerDelta(gO1,gO2)*Sqr(g2)) * tmp_106;
   }
   if (gO1 < 3) {
      std::complex<double> tmp_108;
      std::complex<double> tmp_109;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_109 += Conj(ZD(gI2,3 + j1))*ZD(gI1,3 + j1);
      }
      tmp_108 += tmp_109;
      result += (-0.05*KroneckerDelta(gO1,gO2)*Sqr(g1)) * tmp_108;
   }
   if (gO1 < 3) {
      std::complex<double> tmp_110;
      std::complex<double> tmp_111;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         tmp_111 += Conj(ZD(gI2,j2))*ZD(gI1,j2);
      }
      tmp_110 += tmp_111;
      result += (-0.025*KroneckerDelta(gO1,gO2)*Sqr(g1)) * tmp_110;
   }
   if (gO1 < 3) {
      std::complex<double> tmp_112;
      std::complex<double> tmp_113;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         tmp_113 += Conj(ZD(gI2,j2))*ZD(gI1,j2);
      }
      tmp_112 += tmp_113;
      result += (-0.375*KroneckerDelta(gO1,gO2)*Sqr(g2)) * tmp_112;
   }
   if (gO1 < 3) {
      std::complex<double> tmp_114;
      std::complex<double> tmp_115;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         tmp_115 += Conj(ZD(gI2,3 + j2))*ZD(gI1,3 + j2);
      }
      tmp_114 += tmp_115;
      result += (-0.05*KroneckerDelta(gO1,gO2)*Sqr(g1)) * tmp_114;
   }
   if (gO1 < 3) {
      std::complex<double> tmp_116;
      std::complex<double> tmp_118;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_118 += KroneckerDelta(gO2,3 + j1)*Yd(j1,gO1);
      }
      tmp_116 += tmp_118;
      std::complex<double> tmp_117;
      std::complex<double> tmp_119;
      for (unsigned j4 = 0; j4 < 3; ++j4) {
         std::complex<double> tmp_120;
         std::complex<double> tmp_121;
         for (unsigned j3 = 0; j3 < 3; ++j3) {
            tmp_121 += Conj(Yd(j3,j4))*Conj(ZD(gI2,3 + j3));
         }
         tmp_120 += tmp_121;
         tmp_119 += (ZD(gI1,j4)) * tmp_120;
      }
      tmp_117 += tmp_119;
      result += (-3) * tmp_116 * tmp_117;
   }
   if (gO2 < 3) {
      std::complex<double> tmp_122;
      std::complex<double> tmp_123;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_123 += KroneckerDelta(gO1,3 + j1)*ZD(gI1,3 + j1);
      }
      tmp_122 += tmp_123;
      result += (-0.016666666666666666*Conj(ZD(gI2,gO2))*Sqr(g1)) * tmp_122;
   }
   if (gO2 < 3) {
      std::complex<double> tmp_124;
      std::complex<double> tmp_125;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_125 += KroneckerDelta(gO1,3 + j1)*ZD(gI1,3 + j1);
      }
      tmp_124 += tmp_125;
      result += (0.6666666666666666*Conj(ZD(gI2,gO2))*Sqr(g3)) * tmp_124;
   }
   if (gO2 < 3) {
      std::complex<double> tmp_126;
      std::complex<double> tmp_127;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         tmp_127 += KroneckerDelta(gO1,3 + j2)*ZD(gI1,3 + j2);
      }
      tmp_126 += tmp_127;
      result += (-0.016666666666666666*Conj(ZD(gI2,gO2))*Sqr(g1)) * tmp_126;
   }
   if (gO2 < 3) {
      std::complex<double> tmp_128;
      std::complex<double> tmp_129;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         tmp_129 += KroneckerDelta(gO1,3 + j2)*ZD(gI1,3 + j2);
      }
      tmp_128 += tmp_129;
      result += (0.6666666666666666*Conj(ZD(gI2,gO2))*Sqr(g3)) * tmp_128;
   }
   if (gO2 < 3) {
      std::complex<double> tmp_130;
      std::complex<double> tmp_132;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         std::complex<double> tmp_133;
         std::complex<double> tmp_134;
         for (unsigned j1 = 0; j1 < 3; ++j1) {
            tmp_134 += Yd(j1,j2)*ZD(gI1,3 + j1);
         }
         tmp_133 += tmp_134;
         tmp_132 += (Conj(ZD(gI2,j2))) * tmp_133;
      }
      tmp_130 += tmp_132;
      std::complex<double> tmp_131;
      std::complex<double> tmp_135;
      for (unsigned j3 = 0; j3 < 3; ++j3) {
         tmp_135 += Conj(Yd(j3,gO2))*KroneckerDelta(gO1,3 + j3);
      }
      tmp_131 += tmp_135;
      result += (-3) * tmp_130 * tmp_131;
   }
   if (gO1 < 3 && gO2 < 3) {
      std::complex<double> tmp_136;
      std::complex<double> tmp_138;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_138 += Yd(j1,gO1)*ZD(gI1,3 + j1);
      }
      tmp_136 += tmp_138;
      std::complex<double> tmp_137;
      std::complex<double> tmp_139;
      for (unsigned j3 = 0; j3 < 3; ++j3) {
         tmp_139 += Conj(Yd(j3,gO2))*Conj(ZD(gI2,3 + j3));
      }
      tmp_137 += tmp_139;
      result += (-1) * tmp_136 * tmp_137;
   }
   if (gO1 < 3) {
      std::complex<double> tmp_140;
      std::complex<double> tmp_141;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_141 += Conj(ZD(gI2,3 + j1))*KroneckerDelta(gO2,3 + j1);
      }
      tmp_140 += tmp_141;
      result += (-0.016666666666666666*Sqr(g1)*ZD(gI1,gO1)) * tmp_140;
   }
   if (gO1 < 3) {
      std::complex<double> tmp_142;
      std::complex<double> tmp_143;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_143 += Conj(ZD(gI2,3 + j1))*KroneckerDelta(gO2,3 + j1);
      }
      tmp_142 += tmp_143;
      result += (0.6666666666666666*Sqr(g3)*ZD(gI1,gO1)) * tmp_142;
   }
   if (gO1 < 3) {
      std::complex<double> tmp_144;
      std::complex<double> tmp_145;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         tmp_145 += Conj(ZD(gI2,3 + j2))*KroneckerDelta(gO2,3 + j2);
      }
      tmp_144 += tmp_145;
      result += (-0.016666666666666666*Sqr(g1)*ZD(gI1,gO1)) * tmp_144;
   }
   if (gO1 < 3) {
      std::complex<double> tmp_146;
      std::complex<double> tmp_147;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         tmp_147 += Conj(ZD(gI2,3 + j2))*KroneckerDelta(gO2,3 + j2);
      }
      tmp_146 += tmp_147;
      result += (0.6666666666666666*Sqr(g3)*ZD(gI1,gO1)) * tmp_146;
   }
   if (gO1 < 3 && gO2 < 3) {
      result += -0.016666666666666666*Conj(ZD(gI2,gO2))*Sqr(g1)*ZD(gI1,gO1);
   }
   if (gO1 < 3 && gO2 < 3) {
      result += -0.25*Conj(ZD(gI2,gO2))*Sqr(g2)*ZD(gI1,gO1);
   }
   if (gO1 < 3 && gO2 < 3) {
      result += -1.3333333333333333*Conj(ZD(gI2,gO2))*Sqr(g3)*ZD(gI1,gO1);
   }

   return result;
}

std::complex<double> CLASSNAME::CpUSdconjUSdconjSeSe(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_148;
   std::complex<double> tmp_150;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_150 += Conj(ZE(gI2,j1))*ZE(gI1,j1);
   }
   tmp_148 += tmp_150;
   std::complex<double> tmp_149;
   std::complex<double> tmp_151;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      tmp_151 += KroneckerDelta(gO1,3 + j2)*KroneckerDelta(gO2,3 + j2);
   }
   tmp_149 += tmp_151;
   result += (0.05*Sqr(g1)) * tmp_148 * tmp_149;
   std::complex<double> tmp_152;
   std::complex<double> tmp_154;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_154 += Conj(ZE(gI2,3 + j1))*ZE(gI1,3 + j1);
   }
   tmp_152 += tmp_154;
   std::complex<double> tmp_153;
   std::complex<double> tmp_155;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      tmp_155 += KroneckerDelta(gO1,3 + j2)*KroneckerDelta(gO2,3 + j2);
   }
   tmp_153 += tmp_155;
   result += (-0.1*Sqr(g1)) * tmp_152 * tmp_153;
   std::complex<double> tmp_156;
   std::complex<double> tmp_158;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_158 += KroneckerDelta(gO1,3 + j1)*KroneckerDelta(gO2,3 + j1);
   }
   tmp_156 += tmp_158;
   std::complex<double> tmp_157;
   std::complex<double> tmp_159;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      tmp_159 += Conj(ZE(gI2,j2))*ZE(gI1,j2);
   }
   tmp_157 += tmp_159;
   result += (0.05*Sqr(g1)) * tmp_156 * tmp_157;
   std::complex<double> tmp_160;
   std::complex<double> tmp_162;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_162 += KroneckerDelta(gO1,3 + j1)*KroneckerDelta(gO2,3 + j1);
   }
   tmp_160 += tmp_162;
   std::complex<double> tmp_161;
   std::complex<double> tmp_163;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      tmp_163 += Conj(ZE(gI2,3 + j2))*ZE(gI1,3 + j2);
   }
   tmp_161 += tmp_163;
   result += (-0.1*Sqr(g1)) * tmp_160 * tmp_161;
   if (gO1 < 3) {
      std::complex<double> tmp_164;
      std::complex<double> tmp_165;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_165 += Conj(ZE(gI2,j1))*ZE(gI1,j1);
      }
      tmp_164 += tmp_165;
      result += (0.025*KroneckerDelta(gO1,gO2)*Sqr(g1)) * tmp_164;
   }
   if (gO1 < 3) {
      std::complex<double> tmp_166;
      std::complex<double> tmp_167;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_167 += Conj(ZE(gI2,j1))*ZE(gI1,j1);
      }
      tmp_166 += tmp_167;
      result += (-0.125*KroneckerDelta(gO1,gO2)*Sqr(g2)) * tmp_166;
   }
   if (gO1 < 3) {
      std::complex<double> tmp_168;
      std::complex<double> tmp_169;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_169 += Conj(ZE(gI2,3 + j1))*ZE(gI1,3 + j1);
      }
      tmp_168 += tmp_169;
      result += (-0.05*KroneckerDelta(gO1,gO2)*Sqr(g1)) * tmp_168;
   }
   if (gO1 < 3) {
      std::complex<double> tmp_170;
      std::complex<double> tmp_171;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         tmp_171 += Conj(ZE(gI2,j2))*ZE(gI1,j2);
      }
      tmp_170 += tmp_171;
      result += (0.025*KroneckerDelta(gO1,gO2)*Sqr(g1)) * tmp_170;
   }
   if (gO1 < 3) {
      std::complex<double> tmp_172;
      std::complex<double> tmp_173;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         tmp_173 += Conj(ZE(gI2,j2))*ZE(gI1,j2);
      }
      tmp_172 += tmp_173;
      result += (-0.125*KroneckerDelta(gO1,gO2)*Sqr(g2)) * tmp_172;
   }
   if (gO1 < 3) {
      std::complex<double> tmp_174;
      std::complex<double> tmp_175;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         tmp_175 += Conj(ZE(gI2,3 + j2))*ZE(gI1,3 + j2);
      }
      tmp_174 += tmp_175;
      result += (-0.05*KroneckerDelta(gO1,gO2)*Sqr(g1)) * tmp_174;
   }
   if (gO1 < 3) {
      std::complex<double> tmp_176;
      std::complex<double> tmp_178;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_178 += KroneckerDelta(gO2,3 + j1)*Yd(j1,gO1);
      }
      tmp_176 += tmp_178;
      std::complex<double> tmp_177;
      std::complex<double> tmp_179;
      for (unsigned j4 = 0; j4 < 3; ++j4) {
         std::complex<double> tmp_180;
         std::complex<double> tmp_181;
         for (unsigned j3 = 0; j3 < 3; ++j3) {
            tmp_181 += Conj(Ye(j3,j4))*Conj(ZE(gI2,3 + j3));
         }
         tmp_180 += tmp_181;
         tmp_179 += (ZE(gI1,j4)) * tmp_180;
      }
      tmp_177 += tmp_179;
      result += (-1) * tmp_176 * tmp_177;
   }
   if (gO2 < 3) {
      std::complex<double> tmp_182;
      std::complex<double> tmp_184;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         std::complex<double> tmp_185;
         std::complex<double> tmp_186;
         for (unsigned j1 = 0; j1 < 3; ++j1) {
            tmp_186 += Ye(j1,j2)*ZE(gI1,3 + j1);
         }
         tmp_185 += tmp_186;
         tmp_184 += (Conj(ZE(gI2,j2))) * tmp_185;
      }
      tmp_182 += tmp_184;
      std::complex<double> tmp_183;
      std::complex<double> tmp_187;
      for (unsigned j3 = 0; j3 < 3; ++j3) {
         tmp_187 += Conj(Yd(j3,gO2))*KroneckerDelta(gO1,3 + j3);
      }
      tmp_183 += tmp_187;
      result += (-1) * tmp_182 * tmp_183;
   }

   return result;
}

std::complex<double> CLASSNAME::CpUSdconjUSdconjSuSu(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_188;
   std::complex<double> tmp_190;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_190 += Conj(ZU(gI2,j1))*ZU(gI1,j1);
   }
   tmp_188 += tmp_190;
   std::complex<double> tmp_189;
   std::complex<double> tmp_191;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      tmp_191 += KroneckerDelta(gO1,3 + j2)*KroneckerDelta(gO2,3 + j2);
   }
   tmp_189 += tmp_191;
   result += (-0.05*Sqr(g1)) * tmp_188 * tmp_189;
   std::complex<double> tmp_192;
   std::complex<double> tmp_194;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_194 += Conj(ZU(gI2,3 + j1))*ZU(gI1,3 + j1);
   }
   tmp_192 += tmp_194;
   std::complex<double> tmp_193;
   std::complex<double> tmp_195;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      tmp_195 += KroneckerDelta(gO1,3 + j2)*KroneckerDelta(gO2,3 + j2);
   }
   tmp_193 += tmp_195;
   result += (0.2*Sqr(g1)) * tmp_192 * tmp_193;
   std::complex<double> tmp_196;
   std::complex<double> tmp_198;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_198 += KroneckerDelta(gO1,3 + j1)*KroneckerDelta(gO2,3 + j1);
   }
   tmp_196 += tmp_198;
   std::complex<double> tmp_197;
   std::complex<double> tmp_199;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      tmp_199 += Conj(ZU(gI2,j2))*ZU(gI1,j2);
   }
   tmp_197 += tmp_199;
   result += (-0.05*Sqr(g1)) * tmp_196 * tmp_197;
   std::complex<double> tmp_200;
   std::complex<double> tmp_202;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_202 += KroneckerDelta(gO1,3 + j1)*KroneckerDelta(gO2,3 + j1);
   }
   tmp_200 += tmp_202;
   std::complex<double> tmp_201;
   std::complex<double> tmp_203;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      tmp_203 += Conj(ZU(gI2,3 + j2))*ZU(gI1,3 + j2);
   }
   tmp_201 += tmp_203;
   result += (0.2*Sqr(g1)) * tmp_200 * tmp_201;
   std::complex<double> tmp_204;
   std::complex<double> tmp_206;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_207;
      std::complex<double> tmp_208;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_208 += KroneckerDelta(gO2,3 + j1)*Yd(j1,j2);
      }
      tmp_207 += tmp_208;
      tmp_206 += (Conj(ZU(gI2,j2))) * tmp_207;
   }
   tmp_204 += tmp_206;
   std::complex<double> tmp_205;
   std::complex<double> tmp_209;
   for (unsigned j4 = 0; j4 < 3; ++j4) {
      std::complex<double> tmp_210;
      std::complex<double> tmp_211;
      for (unsigned j3 = 0; j3 < 3; ++j3) {
         tmp_211 += Conj(Yd(j3,j4))*KroneckerDelta(gO1,3 + j3);
      }
      tmp_210 += tmp_211;
      tmp_209 += (ZU(gI1,j4)) * tmp_210;
   }
   tmp_205 += tmp_209;
   result += (-1) * tmp_204 * tmp_205;
   if (gO1 < 3) {
      std::complex<double> tmp_212;
      std::complex<double> tmp_213;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_213 += Conj(ZU(gI2,j1))*ZU(gI1,j1);
      }
      tmp_212 += tmp_213;
      result += (-0.025*KroneckerDelta(gO1,gO2)*Sqr(g1)) * tmp_212;
   }
   if (gO1 < 3) {
      std::complex<double> tmp_214;
      std::complex<double> tmp_215;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_215 += Conj(ZU(gI2,j1))*ZU(gI1,j1);
      }
      tmp_214 += tmp_215;
      result += (0.375*KroneckerDelta(gO1,gO2)*Sqr(g2)) * tmp_214;
   }
   if (gO1 < 3) {
      std::complex<double> tmp_216;
      std::complex<double> tmp_217;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_217 += Conj(ZU(gI2,3 + j1))*ZU(gI1,3 + j1);
      }
      tmp_216 += tmp_217;
      result += (0.1*KroneckerDelta(gO1,gO2)*Sqr(g1)) * tmp_216;
   }
   if (gO1 < 3) {
      std::complex<double> tmp_218;
      std::complex<double> tmp_219;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         tmp_219 += Conj(ZU(gI2,j2))*ZU(gI1,j2);
      }
      tmp_218 += tmp_219;
      result += (-0.025*KroneckerDelta(gO1,gO2)*Sqr(g1)) * tmp_218;
   }
   if (gO1 < 3) {
      std::complex<double> tmp_220;
      std::complex<double> tmp_221;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         tmp_221 += Conj(ZU(gI2,j2))*ZU(gI1,j2);
      }
      tmp_220 += tmp_221;
      result += (0.375*KroneckerDelta(gO1,gO2)*Sqr(g2)) * tmp_220;
   }
   if (gO1 < 3) {
      std::complex<double> tmp_222;
      std::complex<double> tmp_223;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         tmp_223 += Conj(ZU(gI2,3 + j2))*ZU(gI1,3 + j2);
      }
      tmp_222 += tmp_223;
      result += (0.1*KroneckerDelta(gO1,gO2)*Sqr(g1)) * tmp_222;
   }
   if (gO1 < 3 && gO2 < 3) {
      std::complex<double> tmp_224;
      std::complex<double> tmp_226;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_226 += Yu(j1,gO1)*ZU(gI1,3 + j1);
      }
      tmp_224 += tmp_226;
      std::complex<double> tmp_225;
      std::complex<double> tmp_227;
      for (unsigned j3 = 0; j3 < 3; ++j3) {
         tmp_227 += Conj(Yu(j3,gO2))*Conj(ZU(gI2,3 + j3));
      }
      tmp_225 += tmp_227;
      result += (-1) * tmp_224 * tmp_225;
   }
   if (gO1 < 3 && gO2 < 3) {
      result += -0.5*Conj(ZU(gI2,gO2))*Sqr(g2)*ZU(gI1,gO1);
   }

   return result;
}

std::complex<double> CLASSNAME::CpconjUSdSdRh(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gO2 < 3) {
      std::complex<double> tmp_228;
      std::complex<double> tmp_229;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_229 += Conj(Yd(j1,gO2))*Conj(ZD(gI1,3 + j1));
      }
      tmp_228 += tmp_229;
      result += (MuD*ZHR(gI2,0)) * tmp_228;
   }
   if (gO2 < 3) {
      std::complex<double> tmp_230;
      std::complex<double> tmp_231;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_231 += Conj(Yd(j1,gO2))*Conj(ZD(gI1,3 + j1));
      }
      tmp_230 += tmp_231;
      result += (0.7071067811865475*LamSD*vS*ZHR(gI2,0)) * tmp_230;
   }
   if (gO2 < 3) {
      std::complex<double> tmp_232;
      std::complex<double> tmp_233;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_233 += Conj(Yd(j1,gO2))*Conj(ZD(gI1,3 + j1));
      }
      tmp_232 += tmp_233;
      result += (0.5*LamTD*vT*ZHR(gI2,0)) * tmp_232;
   }

   return result;
}

std::complex<double> CLASSNAME::CpconjUSdSuRpm(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_234;
   std::complex<double> tmp_235;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_236;
      std::complex<double> tmp_237;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_237 += KroneckerDelta(gO2,3 + j1)*Yd(j1,j2);
      }
      tmp_236 += tmp_237;
      tmp_235 += (Conj(ZU(gI1,j2))) * tmp_236;
   }
   tmp_234 += tmp_235;
   result += (0.7071067811865475*vS*Conj(LamSD)*Conj(ZRP(gI2,1))) * tmp_234;
   std::complex<double> tmp_238;
   std::complex<double> tmp_239;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_240;
      std::complex<double> tmp_241;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_241 += KroneckerDelta(gO2,3 + j1)*Yd(j1,j2);
      }
      tmp_240 += tmp_241;
      tmp_239 += (Conj(ZU(gI1,j2))) * tmp_240;
   }
   tmp_238 += tmp_239;
   result += (-0.5*vT*Conj(LamTD)*Conj(ZRP(gI2,1))) * tmp_238;
   std::complex<double> tmp_242;
   std::complex<double> tmp_243;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_244;
      std::complex<double> tmp_245;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_245 += KroneckerDelta(gO2,3 + j1)*Yd(j1,j2);
      }
      tmp_244 += tmp_245;
      tmp_243 += (Conj(ZU(gI1,j2))) * tmp_244;
   }
   tmp_242 += tmp_243;
   result += (Conj(MuD)*Conj(ZRP(gI2,1))) * tmp_242;
   if (gO2 < 3) {
      std::complex<double> tmp_246;
      std::complex<double> tmp_247;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_247 += Conj(Yu(j1,gO2))*Conj(ZU(gI1,3 + j1));
      }
      tmp_246 += tmp_247;
      result += (-(MuU*Conj(ZRP(gI2,0)))) * tmp_246;
   }
   if (gO2 < 3) {
      std::complex<double> tmp_248;
      std::complex<double> tmp_249;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_249 += Conj(Yu(j1,gO2))*Conj(ZU(gI1,3 + j1));
      }
      tmp_248 += tmp_249;
      result += (-0.7071067811865475*LamSU*vS*Conj(ZRP(gI2,0))) * tmp_248;
   }
   if (gO2 < 3) {
      std::complex<double> tmp_250;
      std::complex<double> tmp_251;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_251 += Conj(Yu(j1,gO2))*Conj(ZU(gI1,3 + j1));
      }
      tmp_250 += tmp_251;
      result += (-0.5*LamTU*vT*Conj(ZRP(gI2,0))) * tmp_250;
   }

   return result;
}

std::complex<double> CLASSNAME::CpconjUSdSdAh(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_252;
   std::complex<double> tmp_253;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_254;
      std::complex<double> tmp_255;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_255 += KroneckerDelta(gO2,3 + j1)*Yd(j1,j2);
      }
      tmp_254 += tmp_255;
      tmp_253 += (Conj(ZD(gI1,j2))) * tmp_254;
   }
   tmp_252 += tmp_253;
   result += (std::complex<double>(0.,-0.7071067811865475)*Conj(Mu)*ZA(gI2,1))
      * tmp_252;
   if (gO2 < 3) {
      std::complex<double> tmp_256;
      std::complex<double> tmp_257;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_257 += Conj(Yd(j1,gO2))*Conj(ZD(gI1,3 + j1));
      }
      tmp_256 += tmp_257;
      result += (std::complex<double>(0.,0.7071067811865475)*Mu*ZA(gI2,1)) *
         tmp_256;
   }
   std::complex<double> tmp_258;
   std::complex<double> tmp_259;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_259 += Conj(ZD(gI1,3 + j1))*KroneckerDelta(gO2,3 + j1);
   }
   tmp_258 += tmp_259;
   result += (std::complex<double>(0.,-0.2581988897471611)*g1*MDBS*ZA(gI2,2)) *
      tmp_258;
   std::complex<double> tmp_260;
   std::complex<double> tmp_261;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_261 += Conj(ZD(gI1,3 + j1))*KroneckerDelta(gO2,3 + j1);
   }
   tmp_260 += tmp_261;
   result += (std::complex<double>(0.,0.2581988897471611)*g1*Conj(MDBS)*ZA(gI2,
      2)) * tmp_260;
   if (gO2 < 3) {
      result += std::complex<double>(0.,-0.12909944487358055)*g1*MDBS*Conj(
         ZD(gI1,gO2))*ZA(gI2,2);
   }
   if (gO2 < 3) {
      result += std::complex<double>(0.,0.12909944487358055)*g1*Conj(MDBS)*
         Conj(ZD(gI1,gO2))*ZA(gI2,2);
   }
   if (gO2 < 3) {
      result += std::complex<double>(0,0.5)*g2*MDWBT*Conj(ZD(gI1,gO2))*ZA(
         gI2,3);
   }
   if (gO2 < 3) {
      result += std::complex<double>(0,-0.5)*g2*Conj(MDWBT)*Conj(ZD(gI1,gO2)
         )*ZA(gI2,3);
   }

   return result;
}

std::complex<double> CLASSNAME::CpconjUSdSdhh(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_262;
   std::complex<double> tmp_263;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_263 += Conj(ZD(gI1,3 + j1))*KroneckerDelta(gO2,3 + j1);
   }
   tmp_262 += tmp_263;
   result += (0.1*vd*Sqr(g1)*ZH(gI2,0)) * tmp_262;
   std::complex<double> tmp_264;
   std::complex<double> tmp_265;
   for (unsigned j3 = 0; j3 < 3; ++j3) {
      std::complex<double> tmp_266;
      std::complex<double> tmp_267;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         std::complex<double> tmp_268;
         std::complex<double> tmp_269;
         for (unsigned j1 = 0; j1 < 3; ++j1) {
            tmp_269 += Conj(Yd(j3,j1))*Yd(j2,j1);
         }
         tmp_268 += tmp_269;
         tmp_267 += (KroneckerDelta(gO2,3 + j2)) * tmp_268;
      }
      tmp_266 += tmp_267;
      tmp_265 += (Conj(ZD(gI1,3 + j3))) * tmp_266;
   }
   tmp_264 += tmp_265;
   result += (-(vd*ZH(gI2,0))) * tmp_264;
   if (gO2 < 3) {
      result += 0.05*vd*Conj(ZD(gI1,gO2))*Sqr(g1)*ZH(gI2,0);
   }
   if (gO2 < 3) {
      result += 0.25*vd*Conj(ZD(gI1,gO2))*Sqr(g2)*ZH(gI2,0);
   }
   if (gO2 < 3) {
      std::complex<double> tmp_270;
      std::complex<double> tmp_271;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         std::complex<double> tmp_272;
         std::complex<double> tmp_273;
         for (unsigned j1 = 0; j1 < 3; ++j1) {
            tmp_273 += Conj(Yd(j1,gO2))*Yd(j1,j2);
         }
         tmp_272 += tmp_273;
         tmp_271 += (Conj(ZD(gI1,j2))) * tmp_272;
      }
      tmp_270 += tmp_271;
      result += (-(vd*ZH(gI2,0))) * tmp_270;
   }
   std::complex<double> tmp_274;
   std::complex<double> tmp_275;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_275 += Conj(ZD(gI1,3 + j1))*KroneckerDelta(gO2,3 + j1);
   }
   tmp_274 += tmp_275;
   result += (-0.1*vu*Sqr(g1)*ZH(gI2,1)) * tmp_274;
   std::complex<double> tmp_276;
   std::complex<double> tmp_277;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_278;
      std::complex<double> tmp_279;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_279 += KroneckerDelta(gO2,3 + j1)*Yd(j1,j2);
      }
      tmp_278 += tmp_279;
      tmp_277 += (Conj(ZD(gI1,j2))) * tmp_278;
   }
   tmp_276 += tmp_277;
   result += (0.7071067811865475*Conj(Mu)*ZH(gI2,1)) * tmp_276;
   if (gO2 < 3) {
      result += -0.05*vu*Conj(ZD(gI1,gO2))*Sqr(g1)*ZH(gI2,1);
   }
   if (gO2 < 3) {
      result += -0.25*vu*Conj(ZD(gI1,gO2))*Sqr(g2)*ZH(gI2,1);
   }
   if (gO2 < 3) {
      std::complex<double> tmp_280;
      std::complex<double> tmp_281;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_281 += Conj(Yd(j1,gO2))*Conj(ZD(gI1,3 + j1));
      }
      tmp_280 += tmp_281;
      result += (0.7071067811865475*Mu*ZH(gI2,1)) * tmp_280;
   }
   std::complex<double> tmp_282;
   std::complex<double> tmp_283;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_283 += Conj(ZD(gI1,3 + j1))*KroneckerDelta(gO2,3 + j1);
   }
   tmp_282 += tmp_283;
   result += (-0.2581988897471611*g1*MDBS*ZH(gI2,2)) * tmp_282;
   std::complex<double> tmp_284;
   std::complex<double> tmp_285;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_285 += Conj(ZD(gI1,3 + j1))*KroneckerDelta(gO2,3 + j1);
   }
   tmp_284 += tmp_285;
   result += (-0.2581988897471611*g1*Conj(MDBS)*ZH(gI2,2)) * tmp_284;
   if (gO2 < 3) {
      result += -0.12909944487358055*g1*MDBS*Conj(ZD(gI1,gO2))*ZH(gI2,2);
   }
   if (gO2 < 3) {
      result += -0.12909944487358055*g1*Conj(MDBS)*Conj(ZD(gI1,gO2))*ZH(gI2,
         2);
   }
   if (gO2 < 3) {
      result += 0.5*g2*MDWBT*Conj(ZD(gI1,gO2))*ZH(gI2,3);
   }
   if (gO2 < 3) {
      result += 0.5*g2*Conj(MDWBT)*Conj(ZD(gI1,gO2))*ZH(gI2,3);
   }

   return result;
}

std::complex<double> CLASSNAME::CpconjUSdSuHpm(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_286;
   std::complex<double> tmp_287;
   for (unsigned j3 = 0; j3 < 3; ++j3) {
      std::complex<double> tmp_288;
      std::complex<double> tmp_289;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         std::complex<double> tmp_290;
         std::complex<double> tmp_291;
         for (unsigned j1 = 0; j1 < 3; ++j1) {
            tmp_291 += Conj(Yu(j3,j1))*Yd(j2,j1);
         }
         tmp_290 += tmp_291;
         tmp_289 += (KroneckerDelta(gO2,3 + j2)) * tmp_290;
      }
      tmp_288 += tmp_289;
      tmp_287 += (Conj(ZU(gI1,3 + j3))) * tmp_288;
   }
   tmp_286 += tmp_287;
   result += (0.7071067811865475*vu*ZP(gI2,0)) * tmp_286;
   if (gO2 < 3) {
      result += -0.35355339059327373*vd*Conj(ZU(gI1,gO2))*Sqr(g2)*ZP(gI2,0);
   }
   if (gO2 < 3) {
      std::complex<double> tmp_292;
      std::complex<double> tmp_293;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_293 += Conj(Yu(j1,gO2))*Conj(ZU(gI1,3 + j1));
      }
      tmp_292 += tmp_293;
      result += (Mu*ZP(gI2,0)) * tmp_292;
   }
   if (gO2 < 3) {
      std::complex<double> tmp_294;
      std::complex<double> tmp_295;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         std::complex<double> tmp_296;
         std::complex<double> tmp_297;
         for (unsigned j1 = 0; j1 < 3; ++j1) {
            tmp_297 += Conj(Yd(j1,gO2))*Yd(j1,j2);
         }
         tmp_296 += tmp_297;
         tmp_295 += (Conj(ZU(gI1,j2))) * tmp_296;
      }
      tmp_294 += tmp_295;
      result += (0.7071067811865475*vd*ZP(gI2,0)) * tmp_294;
   }
   std::complex<double> tmp_298;
   std::complex<double> tmp_299;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_300;
      std::complex<double> tmp_301;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_301 += KroneckerDelta(gO2,3 + j1)*Yd(j1,j2);
      }
      tmp_300 += tmp_301;
      tmp_299 += (Conj(ZU(gI1,j2))) * tmp_300;
   }
   tmp_298 += tmp_299;
   result += (Conj(Mu)*ZP(gI2,1)) * tmp_298;
   std::complex<double> tmp_302;
   std::complex<double> tmp_303;
   for (unsigned j3 = 0; j3 < 3; ++j3) {
      std::complex<double> tmp_304;
      std::complex<double> tmp_305;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         std::complex<double> tmp_306;
         std::complex<double> tmp_307;
         for (unsigned j1 = 0; j1 < 3; ++j1) {
            tmp_307 += Conj(Yu(j3,j1))*Yd(j2,j1);
         }
         tmp_306 += tmp_307;
         tmp_305 += (KroneckerDelta(gO2,3 + j2)) * tmp_306;
      }
      tmp_304 += tmp_305;
      tmp_303 += (Conj(ZU(gI1,3 + j3))) * tmp_304;
   }
   tmp_302 += tmp_303;
   result += (0.7071067811865475*vd*ZP(gI2,1)) * tmp_302;
   if (gO2 < 3) {
      result += -0.35355339059327373*vu*Conj(ZU(gI1,gO2))*Sqr(g2)*ZP(gI2,1);
   }
   if (gO2 < 3) {
      std::complex<double> tmp_308;
      std::complex<double> tmp_309;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         std::complex<double> tmp_310;
         std::complex<double> tmp_311;
         for (unsigned j1 = 0; j1 < 3; ++j1) {
            tmp_311 += Conj(Yu(j1,gO2))*Yu(j1,j2);
         }
         tmp_310 += tmp_311;
         tmp_309 += (Conj(ZU(gI1,j2))) * tmp_310;
      }
      tmp_308 += tmp_309;
      result += (0.7071067811865475*vu*ZP(gI2,1)) * tmp_308;
   }
   if (gO2 < 3) {
      result += -(g2*MDWBT*Conj(ZU(gI1,gO2))*ZP(gI2,2));
   }
   if (gO2 < 3) {
      result += -0.5*vT*Conj(ZU(gI1,gO2))*Sqr(g2)*ZP(gI2,2);
   }
   if (gO2 < 3) {
      result += 0.5*vT*Conj(ZU(gI1,gO2))*Sqr(g2)*ZP(gI2,3);
   }
   if (gO2 < 3) {
      result += -(g2*Conj(MDWBT)*Conj(ZU(gI1,gO2))*ZP(gI2,3));
   }

   return result;
}

std::complex<double> CLASSNAME::CpconjUSdbarGluFdPR(unsigned gO2, unsigned , unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_312;
   std::complex<double> tmp_313;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_313 += KroneckerDelta(gO2,3 + j1)*ZDR(gI2,j1);
   }
   tmp_312 += tmp_313;
   result += (1.4142135623730951*g3) * tmp_312;

   return result;
}

double CLASSNAME::CpconjUSdbarGluFdPL(unsigned , unsigned , unsigned ) const
{
   double result = 0.0;

   result = 0;

   return result;
}

double CLASSNAME::CpconjUSdGluFdPR(unsigned , unsigned , unsigned ) const
{
   double result = 0.0;

   result = 0;

   return result;
}

std::complex<double> CLASSNAME::CpconjUSdGluFdPL(unsigned gO1, unsigned , unsigned gI2) const
{
   std::complex<double> result;

   if (gO1 < 3) {
      result += -1.4142135623730951*g3*Conj(ZDL(gI2,gO1));
   }

   return result;
}

std::complex<double> CLASSNAME::CpconjUSdconjSOcSd(unsigned gO2, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_314;
   std::complex<double> tmp_315;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_315 += Conj(ZD(gI2,3 + j1))*KroneckerDelta(gO2,3 + j1);
   }
   tmp_314 += tmp_315;
   result += (1.4142135623730951*g3*Conj(MDGoc)) * tmp_314;
   if (gO2 < 3) {
      result += -1.4142135623730951*g3*Conj(MDGoc)*Conj(ZD(gI2,gO2));
   }

   return result;
}

std::complex<double> CLASSNAME::CpconjUSdVGSd(unsigned gO2, unsigned gI2) const
{
   std::complex<double> result;

   if (gI2 < 6) {
      result += g3*Conj(ZD(gI2,gO2));
   }

   return result;
}

std::complex<double> CLASSNAME::CpconjUSdVPSd(unsigned gO2, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_316;
   std::complex<double> tmp_317;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_317 += Conj(ZD(gI2,3 + j1))*KroneckerDelta(gO2,3 + j1);
   }
   tmp_316 += tmp_317;
   result += (-0.2581988897471611*g1*Cos(ThetaW())) * tmp_316;
   if (gO2 < 3) {
      result += 0.12909944487358055*g1*Conj(ZD(gI2,gO2))*Cos(ThetaW());
   }
   if (gO2 < 3) {
      result += -0.5*g2*Conj(ZD(gI2,gO2))*Sin(ThetaW());
   }

   return result;
}

std::complex<double> CLASSNAME::CpconjUSdVZSd(unsigned gO2, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_318;
   std::complex<double> tmp_319;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_319 += Conj(ZD(gI2,3 + j1))*KroneckerDelta(gO2,3 + j1);
   }
   tmp_318 += tmp_319;
   result += (0.2581988897471611*g1*Sin(ThetaW())) * tmp_318;
   if (gO2 < 3) {
      result += -0.5*g2*Conj(ZD(gI2,gO2))*Cos(ThetaW());
   }
   if (gO2 < 3) {
      result += -0.12909944487358055*g1*Conj(ZD(gI2,gO2))*Sin(ThetaW());
   }

   return result;
}

std::complex<double> CLASSNAME::CpconjUSdVWmSu(unsigned gO2, unsigned gI2) const
{
   std::complex<double> result;

   if (gO2 < 3) {
      result += 0.7071067811865475*g2*Conj(ZU(gI2,gO2));
   }

   return result;
}

std::complex<double> CLASSNAME::CpUSvconjUSvVZVZ(unsigned gO1, unsigned gO2) const
{
   std::complex<double> result;

   result = 0.1*KroneckerDelta(gO1,gO2)*(g1*Sin(ThetaW())*(7.745966692414834*g2
      *Cos(ThetaW()) + 3*g1*Sin(ThetaW())) + 5*Sqr(g2)*Sqr(Cos(ThetaW())));

   return result;
}

double CLASSNAME::CpUSvconjUSvconjVWmVWm(unsigned gO1, unsigned gO2) const
{
   double result = 0.0;

   result = 0.5*KroneckerDelta(gO1,gO2)*Sqr(g2);

   return result;
}

std::complex<double> CLASSNAME::CpUSvconjUSvconjRhRh(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.05*KroneckerDelta(gO1,gO2)*(3*Sqr(g1) + 5*Sqr(g2))*(ZHR(gI1,0)*
      ZHR(gI2,0) - ZHR(gI1,1)*ZHR(gI2,1));

   return result;
}

std::complex<double> CLASSNAME::CpUSvconjUSvconjRpmRpm(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = -0.05*KroneckerDelta(gO1,gO2)*(3*Sqr(g1) - 5*Sqr(g2))*(Conj(ZRP(gI2
      ,0))*ZRP(gI1,0) - Conj(ZRP(gI2,1))*ZRP(gI1,1));

   return result;
}

std::complex<double> CLASSNAME::CpconjUSvconjRpmSe(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gO2 < 3) {
      std::complex<double> tmp_320;
      std::complex<double> tmp_321;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_321 += Conj(Ye(j1,gO2))*Conj(ZE(gI2,3 + j1));
      }
      tmp_320 += tmp_321;
      result += (MuD*ZRP(gI1,1)) * tmp_320;
   }
   if (gO2 < 3) {
      std::complex<double> tmp_322;
      std::complex<double> tmp_323;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_323 += Conj(Ye(j1,gO2))*Conj(ZE(gI2,3 + j1));
      }
      tmp_322 += tmp_323;
      result += (0.7071067811865475*LamSD*vS*ZRP(gI1,1)) * tmp_322;
   }
   if (gO2 < 3) {
      std::complex<double> tmp_324;
      std::complex<double> tmp_325;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_325 += Conj(Ye(j1,gO2))*Conj(ZE(gI2,3 + j1));
      }
      tmp_324 += tmp_325;
      result += (-0.5*LamTD*vT*ZRP(gI1,1)) * tmp_324;
   }

   return result;
}

std::complex<double> CLASSNAME::CpUSvconjUSvconjSvSv(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result += -0.15*KroneckerDelta(gI1,gI2)*KroneckerDelta(gO1,gO2)*Sqr(g1);
   result += -0.25*KroneckerDelta(gI1,gI2)*KroneckerDelta(gO1,gO2)*Sqr(g2);
   if (gI1 < 3 && gI2 < 3) {
      result += -0.15*Conj(ZV(gI2,gO2))*Sqr(g1)*ZV(gI1,gO1);
   }
   if (gI1 < 3 && gI2 < 3) {
      result += -0.25*Conj(ZV(gI2,gO2))*Sqr(g2)*ZV(gI1,gO1);
   }

   return result;
}

std::complex<double> CLASSNAME::CpconjUSvFeCha1PR(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gO2 < 3) {
      std::complex<double> tmp_326;
      std::complex<double> tmp_327;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_327 += Conj(Ye(j1,gO2))*ZER(gI1,j1);
      }
      tmp_326 += tmp_327;
      result += (UM1(gI2,1)) * tmp_326;
   }

   return result;
}

std::complex<double> CLASSNAME::CpconjUSvFeCha1PL(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gO1 < 3) {
      result += -(g2*Conj(UP1(gI2,0))*Conj(ZEL(gI1,gO1)));
   }

   return result;
}

std::complex<double> CLASSNAME::CpconjUSvSvAh(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gI1 < 3) {
      result += std::complex<double>(0.,0.3872983346207417)*g1*MDBS*Conj(ZV(
         gI1,gO2))*ZA(gI2,2);
   }
   if (gI1 < 3) {
      result += std::complex<double>(0.,-0.3872983346207417)*g1*Conj(MDBS)*
         Conj(ZV(gI1,gO2))*ZA(gI2,2);
   }
   if (gI1 < 3) {
      result += std::complex<double>(0,-0.5)*g2*MDWBT*Conj(ZV(gI1,gO2))*ZA(
         gI2,3);
   }
   if (gI1 < 3) {
      result += std::complex<double>(0,0.5)*g2*Conj(MDWBT)*Conj(ZV(gI1,gO2))
         *ZA(gI2,3);
   }

   return result;
}

std::complex<double> CLASSNAME::CpconjUSvSvhh(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gI1 < 3) {
      result += -0.15*vd*Conj(ZV(gI1,gO2))*Sqr(g1)*ZH(gI2,0);
   }
   if (gI1 < 3) {
      result += -0.25*vd*Conj(ZV(gI1,gO2))*Sqr(g2)*ZH(gI2,0);
   }
   if (gI1 < 3) {
      result += 0.15*vu*Conj(ZV(gI1,gO2))*Sqr(g1)*ZH(gI2,1);
   }
   if (gI1 < 3) {
      result += 0.25*vu*Conj(ZV(gI1,gO2))*Sqr(g2)*ZH(gI2,1);
   }
   if (gI1 < 3) {
      result += 0.3872983346207417*g1*MDBS*Conj(ZV(gI1,gO2))*ZH(gI2,2);
   }
   if (gI1 < 3) {
      result += 0.3872983346207417*g1*Conj(MDBS)*Conj(ZV(gI1,gO2))*ZH(gI2,2)
         ;
   }
   if (gI1 < 3) {
      result += -0.5*g2*MDWBT*Conj(ZV(gI1,gO2))*ZH(gI2,3);
   }
   if (gI1 < 3) {
      result += -0.5*g2*Conj(MDWBT)*Conj(ZV(gI1,gO2))*ZH(gI2,3);
   }

   return result;
}

double CLASSNAME::CpconjUSvFvChiPR(unsigned , unsigned , unsigned ) const
{
   double result = 0.0;

   result = 0;

   return result;
}

std::complex<double> CLASSNAME::CpconjUSvFvChiPL(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gI1 < 3) {
      result += 0.5477225575051661*g1*Conj(ZN1(gI2,0))*KroneckerDelta(gI1,
         gO1);
   }
   if (gI1 < 3) {
      result += -0.7071067811865475*g2*Conj(ZN1(gI2,1))*KroneckerDelta(gI1,
         gO1);
   }

   return result;
}

std::complex<double> CLASSNAME::CpUSvconjUSvAhAh(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = -0.05*KroneckerDelta(gO1,gO2)*(3*Sqr(g1) + 5*Sqr(g2))*(ZA(gI1,0)*ZA
      (gI2,0) - ZA(gI1,1)*ZA(gI2,1));

   return result;
}

std::complex<double> CLASSNAME::CpUSvconjUSvconjHpmHpm(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result += -0.15*KroneckerDelta(gO1,gO2)*Sqr(g1)*ZP(gI1,0)*ZP(gI2,0);
   result += 0.25*KroneckerDelta(gO1,gO2)*Sqr(g2)*ZP(gI1,0)*ZP(gI2,0);
   if (gO1 < 3 && gO2 < 3) {
      std::complex<double> tmp_328;
      std::complex<double> tmp_329;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_329 += Conj(Ye(j1,gO2))*Ye(j1,gO1);
      }
      tmp_328 += tmp_329;
      result += (-(ZP(gI1,0)*ZP(gI2,0))) * tmp_328;
   }
   result += 0.15*KroneckerDelta(gO1,gO2)*Sqr(g1)*ZP(gI1,1)*ZP(gI2,1);
   result += -0.25*KroneckerDelta(gO1,gO2)*Sqr(g2)*ZP(gI1,1)*ZP(gI2,1);
   result += 0.5*KroneckerDelta(gO1,gO2)*Sqr(g2)*ZP(gI1,2)*ZP(gI2,2);
   result += -0.5*KroneckerDelta(gO1,gO2)*Sqr(g2)*ZP(gI1,3)*ZP(gI2,3);

   return result;
}

std::complex<double> CLASSNAME::CpUSvconjUSvhhhh(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = -0.05*KroneckerDelta(gO1,gO2)*(3*Sqr(g1) + 5*Sqr(g2))*(ZH(gI1,0)*ZH
      (gI2,0) - ZH(gI1,1)*ZH(gI2,1));

   return result;
}

std::complex<double> CLASSNAME::CpconjUSvconjHpmSe(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gO2 < 3) {
      result += -0.35355339059327373*vd*Conj(ZE(gI2,gO2))*Sqr(g2)*ZP(gI1,0);
   }
   if (gO2 < 3) {
      std::complex<double> tmp_330;
      std::complex<double> tmp_331;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         std::complex<double> tmp_332;
         std::complex<double> tmp_333;
         for (unsigned j1 = 0; j1 < 3; ++j1) {
            tmp_333 += Conj(Ye(j1,gO2))*Ye(j1,j2);
         }
         tmp_332 += tmp_333;
         tmp_331 += (Conj(ZE(gI2,j2))) * tmp_332;
      }
      tmp_330 += tmp_331;
      result += (0.7071067811865475*vd*ZP(gI1,0)) * tmp_330;
   }
   if (gO2 < 3) {
      result += -0.35355339059327373*vu*Conj(ZE(gI2,gO2))*Sqr(g2)*ZP(gI1,1);
   }
   if (gO2 < 3) {
      std::complex<double> tmp_334;
      std::complex<double> tmp_335;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_335 += Conj(Ye(j1,gO2))*Conj(ZE(gI2,3 + j1));
      }
      tmp_334 += tmp_335;
      result += (Mu*ZP(gI1,1)) * tmp_334;
   }
   if (gO2 < 3) {
      result += -0.5*vT*Conj(ZE(gI2,gO2))*Sqr(g2)*ZP(gI1,2);
   }
   if (gO2 < 3) {
      result += -(g2*Conj(MDWBT)*Conj(ZE(gI2,gO2))*ZP(gI1,2));
   }
   if (gO2 < 3) {
      result += -(g2*MDWBT*Conj(ZE(gI2,gO2))*ZP(gI1,3));
   }
   if (gO2 < 3) {
      result += 0.5*vT*Conj(ZE(gI2,gO2))*Sqr(g2)*ZP(gI1,3);
   }

   return result;
}

std::complex<double> CLASSNAME::CpUSvconjUSvconjSdSd(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_336;
   std::complex<double> tmp_337;
   std::complex<double> tmp_338;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_338 += Conj(ZD(gI2,j1))*ZD(gI1,j1);
   }
   tmp_337 += tmp_338;
   tmp_336 += (std::complex<double>(0,0.05)*KroneckerDelta(gO1,gO2)*Sqr(g1)) *
      tmp_337;
   std::complex<double> tmp_339;
   std::complex<double> tmp_340;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_340 += Conj(ZD(gI2,j1))*ZD(gI1,j1);
   }
   tmp_339 += tmp_340;
   tmp_336 += (std::complex<double>(0,0.25)*KroneckerDelta(gO1,gO2)*Sqr(g2)) *
      tmp_339;
   std::complex<double> tmp_341;
   std::complex<double> tmp_342;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_342 += Conj(ZD(gI2,3 + j1))*ZD(gI1,3 + j1);
   }
   tmp_341 += tmp_342;
   tmp_336 += (std::complex<double>(0,0.1)*KroneckerDelta(gO1,gO2)*Sqr(g1)) *
      tmp_341;
   result += (std::complex<double>(0,-1)) * tmp_336;

   return result;
}

std::complex<double> CLASSNAME::CpUSvconjUSvconjSeSe(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_343;
   std::complex<double> tmp_344;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_344 += Conj(ZE(gI2,j1))*ZE(gI1,j1);
   }
   tmp_343 += tmp_344;
   result += (-0.15*KroneckerDelta(gO1,gO2)*Sqr(g1)) * tmp_343;
   std::complex<double> tmp_345;
   std::complex<double> tmp_346;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_346 += Conj(ZE(gI2,j1))*ZE(gI1,j1);
   }
   tmp_345 += tmp_346;
   result += (0.25*KroneckerDelta(gO1,gO2)*Sqr(g2)) * tmp_345;
   std::complex<double> tmp_347;
   std::complex<double> tmp_348;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_348 += Conj(ZE(gI2,3 + j1))*ZE(gI1,3 + j1);
   }
   tmp_347 += tmp_348;
   result += (0.3*KroneckerDelta(gO1,gO2)*Sqr(g1)) * tmp_347;
   if (gO1 < 3 && gO2 < 3) {
      std::complex<double> tmp_349;
      std::complex<double> tmp_351;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_351 += Ye(j1,gO1)*ZE(gI1,3 + j1);
      }
      tmp_349 += tmp_351;
      std::complex<double> tmp_350;
      std::complex<double> tmp_352;
      for (unsigned j3 = 0; j3 < 3; ++j3) {
         tmp_352 += Conj(Ye(j3,gO2))*Conj(ZE(gI2,3 + j3));
      }
      tmp_350 += tmp_352;
      result += (-1) * tmp_349 * tmp_350;
   }
   if (gO1 < 3 && gO2 < 3) {
      result += -0.5*Conj(ZE(gI2,gO2))*Sqr(g2)*ZE(gI1,gO1);
   }

   return result;
}

std::complex<double> CLASSNAME::CpUSvconjUSvconjSuSu(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_353;
   std::complex<double> tmp_354;
   std::complex<double> tmp_355;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_355 += Conj(ZU(gI2,j1))*ZU(gI1,j1);
   }
   tmp_354 += tmp_355;
   tmp_353 += (std::complex<double>(0,0.05)*KroneckerDelta(gO1,gO2)*Sqr(g1)) *
      tmp_354;
   std::complex<double> tmp_356;
   std::complex<double> tmp_357;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_357 += Conj(ZU(gI2,j1))*ZU(gI1,j1);
   }
   tmp_356 += tmp_357;
   tmp_353 += (std::complex<double>(0,-0.25)*KroneckerDelta(gO1,gO2)*Sqr(g2)) *
      tmp_356;
   std::complex<double> tmp_358;
   std::complex<double> tmp_359;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_359 += Conj(ZU(gI2,3 + j1))*ZU(gI1,3 + j1);
   }
   tmp_358 += tmp_359;
   tmp_353 += (std::complex<double>(0,-0.2)*KroneckerDelta(gO1,gO2)*Sqr(g1)) *
      tmp_358;
   result += (std::complex<double>(0,-1)) * tmp_353;

   return result;
}

std::complex<double> CLASSNAME::CpconjUSvVZSv(unsigned gO2, unsigned gI2) const
{
   std::complex<double> result;

   if (gI2 < 3) {
      result += 0.5*g2*Conj(ZV(gI2,gO2))*Cos(ThetaW());
   }
   if (gI2 < 3) {
      result += 0.3872983346207417*g1*Conj(ZV(gI2,gO2))*Sin(ThetaW());
   }

   return result;
}

std::complex<double> CLASSNAME::CpconjUSvconjVWmSe(unsigned gO2, unsigned gI2) const
{
   std::complex<double> result;

   if (gO2 < 3) {
      result += 0.7071067811865475*g2*Conj(ZE(gI2,gO2));
   }

   return result;
}

std::complex<double> CLASSNAME::CpUSuconjUSuVZVZ(unsigned gO1, unsigned gO2) const
{
   std::complex<double> result;

   std::complex<double> tmp_360;
   std::complex<double> tmp_361;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_361 += KroneckerDelta(gO1,3 + j1)*KroneckerDelta(gO2,3 + j1);
   }
   tmp_360 += tmp_361;
   result += (0.5333333333333333*Sqr(g1)*Sqr(Sin(ThetaW()))) * tmp_360;
   if (gO1 < 3) {
      result += 0.5*KroneckerDelta(gO1,gO2)*Sqr(g2)*Sqr(Cos(ThetaW()));
   }
   if (gO1 < 3) {
      result += -0.2581988897471611*g1*g2*Cos(ThetaW())*KroneckerDelta(gO1,
         gO2)*Sin(ThetaW());
   }
   if (gO1 < 3) {
      result += 0.03333333333333333*KroneckerDelta(gO1,gO2)*Sqr(g1)*Sqr(Sin(
         ThetaW()));
   }

   return result;
}

std::complex<double> CLASSNAME::CpUSuconjUSuconjSOcSOc(unsigned gO1, unsigned gO2) const
{
   std::complex<double> result;

   std::complex<double> tmp_362;
   std::complex<double> tmp_363;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_363 += KroneckerDelta(gO1,3 + j1)*KroneckerDelta(gO2,3 + j1);
   }
   tmp_362 += tmp_363;
   result += (std::complex<double>(0,-64)*Sqr(g3)) * tmp_362;
   if (gO1 < 3) {
      result += std::complex<double>(0,64)*KroneckerDelta(gO1,gO2)*Sqr(g3);
   }

   return result;
}

double CLASSNAME::CpUSuconjUSuconjVWmVWm(unsigned gO1, unsigned gO2) const
{
   double result = 0.0;

   if (gO1 < 3) {
      result += 0.5*KroneckerDelta(gO1,gO2)*Sqr(g2);
   }

   return result;
}

std::complex<double> CLASSNAME::CpUSuconjUSuconjRhRh(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_364;
   std::complex<double> tmp_365;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_365 += KroneckerDelta(gO1,3 + j1)*KroneckerDelta(gO2,3 + j1);
   }
   tmp_364 += tmp_365;
   result += (0.2*Sqr(g1)*ZHR(gI1,0)*ZHR(gI2,0)) * tmp_364;
   if (gO1 < 3) {
      result += -0.05*KroneckerDelta(gO1,gO2)*Sqr(g1)*ZHR(gI1,0)*ZHR(gI2,0);
   }
   if (gO1 < 3) {
      result += 0.25*KroneckerDelta(gO1,gO2)*Sqr(g2)*ZHR(gI1,0)*ZHR(gI2,0);
   }
   std::complex<double> tmp_366;
   std::complex<double> tmp_367;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_367 += KroneckerDelta(gO1,3 + j1)*KroneckerDelta(gO2,3 + j1);
   }
   tmp_366 += tmp_367;
   result += (-0.2*Sqr(g1)*ZHR(gI1,1)*ZHR(gI2,1)) * tmp_366;
   if (gO1 < 3) {
      result += 0.05*KroneckerDelta(gO1,gO2)*Sqr(g1)*ZHR(gI1,1)*ZHR(gI2,1);
   }
   if (gO1 < 3) {
      result += -0.25*KroneckerDelta(gO1,gO2)*Sqr(g2)*ZHR(gI1,1)*ZHR(gI2,1);
   }

   return result;
}

std::complex<double> CLASSNAME::CpUSuconjUSuconjRpmRpm(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_368;
   std::complex<double> tmp_369;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_369 += KroneckerDelta(gO1,3 + j1)*KroneckerDelta(gO2,3 + j1);
   }
   tmp_368 += tmp_369;
   result += (-0.2*Conj(ZRP(gI2,0))*Sqr(g1)*ZRP(gI1,0)) * tmp_368;
   if (gO1 < 3) {
      result += 0.05*Conj(ZRP(gI2,0))*KroneckerDelta(gO1,gO2)*Sqr(g1)*ZRP(
         gI1,0);
   }
   if (gO1 < 3) {
      result += 0.25*Conj(ZRP(gI2,0))*KroneckerDelta(gO1,gO2)*Sqr(g2)*ZRP(
         gI1,0);
   }
   std::complex<double> tmp_370;
   std::complex<double> tmp_371;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_371 += KroneckerDelta(gO1,3 + j1)*KroneckerDelta(gO2,3 + j1);
   }
   tmp_370 += tmp_371;
   result += (0.2*Conj(ZRP(gI2,1))*Sqr(g1)*ZRP(gI1,1)) * tmp_370;
   if (gO1 < 3) {
      result += -0.05*Conj(ZRP(gI2,1))*KroneckerDelta(gO1,gO2)*Sqr(g1)*ZRP(
         gI1,1);
   }
   if (gO1 < 3) {
      result += -0.25*Conj(ZRP(gI2,1))*KroneckerDelta(gO1,gO2)*Sqr(g2)*ZRP(
         gI1,1);
   }

   return result;
}

double CLASSNAME::CpconjUSubarCha2FdPR(unsigned , unsigned , unsigned ) const
{
   double result = 0.0;

   result = 0;

   return result;
}

std::complex<double> CLASSNAME::CpconjUSubarCha2FdPL(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_372;
   std::complex<double> tmp_373;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_374;
      std::complex<double> tmp_375;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_375 += KroneckerDelta(gO1,3 + j1)*Yu(j1,j2);
      }
      tmp_374 += tmp_375;
      tmp_373 += (Conj(ZDL(gI2,j2))) * tmp_374;
   }
   tmp_372 += tmp_373;
   result += (Conj(UP2(gI1,1))) * tmp_372;

   return result;
}

std::complex<double> CLASSNAME::CpconjUSuconjRpmSd(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_376;
   std::complex<double> tmp_377;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_378;
      std::complex<double> tmp_379;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_379 += KroneckerDelta(gO2,3 + j1)*Yu(j1,j2);
      }
      tmp_378 += tmp_379;
      tmp_377 += (Conj(ZD(gI2,j2))) * tmp_378;
   }
   tmp_376 += tmp_377;
   result += (-0.7071067811865475*vS*Conj(LamSU)*ZRP(gI1,0)) * tmp_376;
   std::complex<double> tmp_380;
   std::complex<double> tmp_381;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_382;
      std::complex<double> tmp_383;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_383 += KroneckerDelta(gO2,3 + j1)*Yu(j1,j2);
      }
      tmp_382 += tmp_383;
      tmp_381 += (Conj(ZD(gI2,j2))) * tmp_382;
   }
   tmp_380 += tmp_381;
   result += (-0.5*vT*Conj(LamTU)*ZRP(gI1,0)) * tmp_380;
   std::complex<double> tmp_384;
   std::complex<double> tmp_385;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_386;
      std::complex<double> tmp_387;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_387 += KroneckerDelta(gO2,3 + j1)*Yu(j1,j2);
      }
      tmp_386 += tmp_387;
      tmp_385 += (Conj(ZD(gI2,j2))) * tmp_386;
   }
   tmp_384 += tmp_385;
   result += (-(Conj(MuU)*ZRP(gI1,0))) * tmp_384;
   if (gO2 < 3) {
      std::complex<double> tmp_388;
      std::complex<double> tmp_389;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_389 += Conj(Yd(j1,gO2))*Conj(ZD(gI2,3 + j1));
      }
      tmp_388 += tmp_389;
      result += (MuD*ZRP(gI1,1)) * tmp_388;
   }
   if (gO2 < 3) {
      std::complex<double> tmp_390;
      std::complex<double> tmp_391;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_391 += Conj(Yd(j1,gO2))*Conj(ZD(gI2,3 + j1));
      }
      tmp_390 += tmp_391;
      result += (0.7071067811865475*LamSD*vS*ZRP(gI1,1)) * tmp_390;
   }
   if (gO2 < 3) {
      std::complex<double> tmp_392;
      std::complex<double> tmp_393;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_393 += Conj(Yd(j1,gO2))*Conj(ZD(gI2,3 + j1));
      }
      tmp_392 += tmp_393;
      result += (-0.5*LamTD*vT*ZRP(gI1,1)) * tmp_392;
   }

   return result;
}

std::complex<double> CLASSNAME::CpUSuconjUSuconjSvSv(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_394;
   std::complex<double> tmp_395;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_395 += KroneckerDelta(gO1,3 + j1)*KroneckerDelta(gO2,3 + j1);
   }
   tmp_394 += tmp_395;
   result += (-0.2*KroneckerDelta(gI1,gI2)*Sqr(g1)) * tmp_394;
   if (gO1 < 3) {
      result += 0.05*KroneckerDelta(gI1,gI2)*KroneckerDelta(gO1,gO2)*Sqr(g1)
         ;
   }
   if (gO1 < 3) {
      result += -0.25*KroneckerDelta(gI1,gI2)*KroneckerDelta(gO1,gO2)*Sqr(g2
         );
   }

   return result;
}

std::complex<double> CLASSNAME::CpconjUSuFdCha1PR(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gO2 < 3) {
      std::complex<double> tmp_396;
      std::complex<double> tmp_397;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_397 += Conj(Yd(j1,gO2))*ZDR(gI1,j1);
      }
      tmp_396 += tmp_397;
      result += (UM1(gI2,1)) * tmp_396;
   }

   return result;
}

std::complex<double> CLASSNAME::CpconjUSuFdCha1PL(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gO1 < 3) {
      result += -(g2*Conj(UP1(gI2,0))*Conj(ZDL(gI1,gO1)));
   }

   return result;
}

std::complex<double> CLASSNAME::CpconjUSuFuChiPR(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gO2 < 3) {
      std::complex<double> tmp_398;
      std::complex<double> tmp_399;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_399 += Conj(Yu(j1,gO2))*ZUR(gI1,j1);
      }
      tmp_398 += tmp_399;
      result += (-ZN2(gI2,3)) * tmp_398;
   }

   return result;
}

std::complex<double> CLASSNAME::CpconjUSuFuChiPL(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gO1 < 3) {
      result += -0.18257418583505536*g1*Conj(ZN1(gI2,0))*Conj(ZUL(gI1,gO1));
   }
   if (gO1 < 3) {
      result += -0.7071067811865475*g2*Conj(ZN1(gI2,1))*Conj(ZUL(gI1,gO1));
   }

   return result;
}

std::complex<double> CLASSNAME::CpUSuconjUSuAhAh(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_400;
   std::complex<double> tmp_401;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_401 += KroneckerDelta(gO1,3 + j1)*KroneckerDelta(gO2,3 + j1);
   }
   tmp_400 += tmp_401;
   result += (-0.2*Sqr(g1)*ZA(gI1,0)*ZA(gI2,0)) * tmp_400;
   if (gO1 < 3) {
      result += 0.05*KroneckerDelta(gO1,gO2)*Sqr(g1)*ZA(gI1,0)*ZA(gI2,0);
   }
   if (gO1 < 3) {
      result += -0.25*KroneckerDelta(gO1,gO2)*Sqr(g2)*ZA(gI1,0)*ZA(gI2,0);
   }
   std::complex<double> tmp_402;
   std::complex<double> tmp_403;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_403 += KroneckerDelta(gO1,3 + j1)*KroneckerDelta(gO2,3 + j1);
   }
   tmp_402 += tmp_403;
   result += (0.2*Sqr(g1)*ZA(gI1,1)*ZA(gI2,1)) * tmp_402;
   std::complex<double> tmp_404;
   std::complex<double> tmp_405;
   for (unsigned j3 = 0; j3 < 3; ++j3) {
      std::complex<double> tmp_406;
      std::complex<double> tmp_407;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         std::complex<double> tmp_408;
         std::complex<double> tmp_409;
         for (unsigned j1 = 0; j1 < 3; ++j1) {
            tmp_409 += Conj(Yu(j3,j1))*Yu(j2,j1);
         }
         tmp_408 += tmp_409;
         tmp_407 += (KroneckerDelta(gO2,3 + j2)) * tmp_408;
      }
      tmp_406 += tmp_407;
      tmp_405 += (KroneckerDelta(gO1,3 + j3)) * tmp_406;
   }
   tmp_404 += tmp_405;
   result += (-(ZA(gI1,1)*ZA(gI2,1))) * tmp_404;
   if (gO1 < 3) {
      result += -0.05*KroneckerDelta(gO1,gO2)*Sqr(g1)*ZA(gI1,1)*ZA(gI2,1);
   }
   if (gO1 < 3) {
      result += 0.25*KroneckerDelta(gO1,gO2)*Sqr(g2)*ZA(gI1,1)*ZA(gI2,1);
   }
   if (gO1 < 3 && gO2 < 3) {
      std::complex<double> tmp_410;
      std::complex<double> tmp_411;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_411 += Conj(Yu(j1,gO2))*Yu(j1,gO1);
      }
      tmp_410 += tmp_411;
      result += (-(ZA(gI1,1)*ZA(gI2,1))) * tmp_410;
   }

   return result;
}

std::complex<double> CLASSNAME::CpUSuconjUSuconjHpmHpm(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_412;
   std::complex<double> tmp_413;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_413 += KroneckerDelta(gO1,3 + j1)*KroneckerDelta(gO2,3 + j1);
   }
   tmp_412 += tmp_413;
   result += (-0.2*Sqr(g1)*ZP(gI1,0)*ZP(gI2,0)) * tmp_412;
   if (gO1 < 3) {
      result += 0.05*KroneckerDelta(gO1,gO2)*Sqr(g1)*ZP(gI1,0)*ZP(gI2,0);
   }
   if (gO1 < 3) {
      result += 0.25*KroneckerDelta(gO1,gO2)*Sqr(g2)*ZP(gI1,0)*ZP(gI2,0);
   }
   if (gO1 < 3 && gO2 < 3) {
      std::complex<double> tmp_414;
      std::complex<double> tmp_415;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_415 += Conj(Yd(j1,gO2))*Yd(j1,gO1);
      }
      tmp_414 += tmp_415;
      result += (-(ZP(gI1,0)*ZP(gI2,0))) * tmp_414;
   }
   std::complex<double> tmp_416;
   std::complex<double> tmp_417;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_417 += KroneckerDelta(gO1,3 + j1)*KroneckerDelta(gO2,3 + j1);
   }
   tmp_416 += tmp_417;
   result += (0.2*Sqr(g1)*ZP(gI1,1)*ZP(gI2,1)) * tmp_416;
   std::complex<double> tmp_418;
   std::complex<double> tmp_419;
   for (unsigned j3 = 0; j3 < 3; ++j3) {
      std::complex<double> tmp_420;
      std::complex<double> tmp_421;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         std::complex<double> tmp_422;
         std::complex<double> tmp_423;
         for (unsigned j1 = 0; j1 < 3; ++j1) {
            tmp_423 += Conj(Yu(j3,j1))*Yu(j2,j1);
         }
         tmp_422 += tmp_423;
         tmp_421 += (KroneckerDelta(gO2,3 + j2)) * tmp_422;
      }
      tmp_420 += tmp_421;
      tmp_419 += (KroneckerDelta(gO1,3 + j3)) * tmp_420;
   }
   tmp_418 += tmp_419;
   result += (-(ZP(gI1,1)*ZP(gI2,1))) * tmp_418;
   if (gO1 < 3) {
      result += -0.05*KroneckerDelta(gO1,gO2)*Sqr(g1)*ZP(gI1,1)*ZP(gI2,1);
   }
   if (gO1 < 3) {
      result += -0.25*KroneckerDelta(gO1,gO2)*Sqr(g2)*ZP(gI1,1)*ZP(gI2,1);
   }
   if (gO1 < 3) {
      result += 0.5*KroneckerDelta(gO1,gO2)*Sqr(g2)*ZP(gI1,2)*ZP(gI2,2);
   }
   if (gO1 < 3) {
      result += -0.5*KroneckerDelta(gO1,gO2)*Sqr(g2)*ZP(gI1,3)*ZP(gI2,3);
   }

   return result;
}

std::complex<double> CLASSNAME::CpUSuconjUSuhhhh(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_424;
   std::complex<double> tmp_425;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_425 += KroneckerDelta(gO1,3 + j1)*KroneckerDelta(gO2,3 + j1);
   }
   tmp_424 += tmp_425;
   result += (-0.2*Sqr(g1)*ZH(gI1,0)*ZH(gI2,0)) * tmp_424;
   if (gO1 < 3) {
      result += 0.05*KroneckerDelta(gO1,gO2)*Sqr(g1)*ZH(gI1,0)*ZH(gI2,0);
   }
   if (gO1 < 3) {
      result += -0.25*KroneckerDelta(gO1,gO2)*Sqr(g2)*ZH(gI1,0)*ZH(gI2,0);
   }
   std::complex<double> tmp_426;
   std::complex<double> tmp_427;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_427 += KroneckerDelta(gO1,3 + j1)*KroneckerDelta(gO2,3 + j1);
   }
   tmp_426 += tmp_427;
   result += (0.2*Sqr(g1)*ZH(gI1,1)*ZH(gI2,1)) * tmp_426;
   std::complex<double> tmp_428;
   std::complex<double> tmp_429;
   for (unsigned j3 = 0; j3 < 3; ++j3) {
      std::complex<double> tmp_430;
      std::complex<double> tmp_431;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         std::complex<double> tmp_432;
         std::complex<double> tmp_433;
         for (unsigned j1 = 0; j1 < 3; ++j1) {
            tmp_433 += Conj(Yu(j3,j1))*Yu(j2,j1);
         }
         tmp_432 += tmp_433;
         tmp_431 += (KroneckerDelta(gO2,3 + j2)) * tmp_432;
      }
      tmp_430 += tmp_431;
      tmp_429 += (KroneckerDelta(gO1,3 + j3)) * tmp_430;
   }
   tmp_428 += tmp_429;
   result += (-(ZH(gI1,1)*ZH(gI2,1))) * tmp_428;
   if (gO1 < 3) {
      result += -0.05*KroneckerDelta(gO1,gO2)*Sqr(g1)*ZH(gI1,1)*ZH(gI2,1);
   }
   if (gO1 < 3) {
      result += 0.25*KroneckerDelta(gO1,gO2)*Sqr(g2)*ZH(gI1,1)*ZH(gI2,1);
   }
   if (gO1 < 3 && gO2 < 3) {
      std::complex<double> tmp_434;
      std::complex<double> tmp_435;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_435 += Conj(Yu(j1,gO2))*Yu(j1,gO1);
      }
      tmp_434 += tmp_435;
      result += (-(ZH(gI1,1)*ZH(gI2,1))) * tmp_434;
   }

   return result;
}

std::complex<double> CLASSNAME::CpconjUSubarChiFuPR(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_436;
   std::complex<double> tmp_437;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_437 += KroneckerDelta(gO2,3 + j1)*ZUR(gI2,j1);
   }
   tmp_436 += tmp_437;
   result += (0.7302967433402214*g1*ZN1(gI1,0)) * tmp_436;

   return result;
}

std::complex<double> CLASSNAME::CpconjUSubarChiFuPL(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_438;
   std::complex<double> tmp_439;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_440;
      std::complex<double> tmp_441;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_441 += KroneckerDelta(gO1,3 + j1)*Yu(j1,j2);
      }
      tmp_440 += tmp_441;
      tmp_439 += (Conj(ZUL(gI2,j2))) * tmp_440;
   }
   tmp_438 += tmp_439;
   result += (-Conj(ZN2(gI1,3))) * tmp_438;

   return result;
}

std::complex<double> CLASSNAME::CpconjUSuconjHpmSd(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_442;
   std::complex<double> tmp_443;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_444;
      std::complex<double> tmp_445;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_445 += KroneckerDelta(gO2,3 + j1)*Yu(j1,j2);
      }
      tmp_444 += tmp_445;
      tmp_443 += (Conj(ZD(gI2,j2))) * tmp_444;
   }
   tmp_442 += tmp_443;
   result += (Conj(Mu)*ZP(gI1,0)) * tmp_442;
   std::complex<double> tmp_446;
   std::complex<double> tmp_447;
   for (unsigned j3 = 0; j3 < 3; ++j3) {
      std::complex<double> tmp_448;
      std::complex<double> tmp_449;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         std::complex<double> tmp_450;
         std::complex<double> tmp_451;
         for (unsigned j1 = 0; j1 < 3; ++j1) {
            tmp_451 += Conj(Yd(j3,j1))*Yu(j2,j1);
         }
         tmp_450 += tmp_451;
         tmp_449 += (KroneckerDelta(gO2,3 + j2)) * tmp_450;
      }
      tmp_448 += tmp_449;
      tmp_447 += (Conj(ZD(gI2,3 + j3))) * tmp_448;
   }
   tmp_446 += tmp_447;
   result += (0.7071067811865475*vu*ZP(gI1,0)) * tmp_446;
   if (gO2 < 3) {
      result += -0.35355339059327373*vd*Conj(ZD(gI2,gO2))*Sqr(g2)*ZP(gI1,0);
   }
   if (gO2 < 3) {
      std::complex<double> tmp_452;
      std::complex<double> tmp_453;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         std::complex<double> tmp_454;
         std::complex<double> tmp_455;
         for (unsigned j1 = 0; j1 < 3; ++j1) {
            tmp_455 += Conj(Yd(j1,gO2))*Yd(j1,j2);
         }
         tmp_454 += tmp_455;
         tmp_453 += (Conj(ZD(gI2,j2))) * tmp_454;
      }
      tmp_452 += tmp_453;
      result += (0.7071067811865475*vd*ZP(gI1,0)) * tmp_452;
   }
   std::complex<double> tmp_456;
   std::complex<double> tmp_457;
   for (unsigned j3 = 0; j3 < 3; ++j3) {
      std::complex<double> tmp_458;
      std::complex<double> tmp_459;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         std::complex<double> tmp_460;
         std::complex<double> tmp_461;
         for (unsigned j1 = 0; j1 < 3; ++j1) {
            tmp_461 += Conj(Yd(j3,j1))*Yu(j2,j1);
         }
         tmp_460 += tmp_461;
         tmp_459 += (KroneckerDelta(gO2,3 + j2)) * tmp_460;
      }
      tmp_458 += tmp_459;
      tmp_457 += (Conj(ZD(gI2,3 + j3))) * tmp_458;
   }
   tmp_456 += tmp_457;
   result += (0.7071067811865475*vd*ZP(gI1,1)) * tmp_456;
   if (gO2 < 3) {
      result += -0.35355339059327373*vu*Conj(ZD(gI2,gO2))*Sqr(g2)*ZP(gI1,1);
   }
   if (gO2 < 3) {
      std::complex<double> tmp_462;
      std::complex<double> tmp_463;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_463 += Conj(Yd(j1,gO2))*Conj(ZD(gI2,3 + j1));
      }
      tmp_462 += tmp_463;
      result += (Mu*ZP(gI1,1)) * tmp_462;
   }
   if (gO2 < 3) {
      std::complex<double> tmp_464;
      std::complex<double> tmp_465;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         std::complex<double> tmp_466;
         std::complex<double> tmp_467;
         for (unsigned j1 = 0; j1 < 3; ++j1) {
            tmp_467 += Conj(Yu(j1,gO2))*Yu(j1,j2);
         }
         tmp_466 += tmp_467;
         tmp_465 += (Conj(ZD(gI2,j2))) * tmp_466;
      }
      tmp_464 += tmp_465;
      result += (0.7071067811865475*vu*ZP(gI1,1)) * tmp_464;
   }
   if (gO2 < 3) {
      result += -0.5*vT*Conj(ZD(gI2,gO2))*Sqr(g2)*ZP(gI1,2);
   }
   if (gO2 < 3) {
      result += -(g2*Conj(MDWBT)*Conj(ZD(gI2,gO2))*ZP(gI1,2));
   }
   if (gO2 < 3) {
      result += -(g2*MDWBT*Conj(ZD(gI2,gO2))*ZP(gI1,3));
   }
   if (gO2 < 3) {
      result += 0.5*vT*Conj(ZD(gI2,gO2))*Sqr(g2)*ZP(gI1,3);
   }

   return result;
}

std::complex<double> CLASSNAME::CpconjUSuSuSOc(unsigned gO2, unsigned gI1) const
{
   std::complex<double> result;

   std::complex<double> tmp_468;
   std::complex<double> tmp_469;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_469 += Conj(ZU(gI1,3 + j1))*KroneckerDelta(gO2,3 + j1);
   }
   tmp_468 += tmp_469;
   result += (1.4142135623730951*g3*MDGoc) * tmp_468;
   if (gO2 < 3) {
      result += -1.4142135623730951*g3*MDGoc*Conj(ZU(gI1,gO2));
   }

   return result;
}

std::complex<double> CLASSNAME::CpUSuconjUSuconjSdSd(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_470;
   std::complex<double> tmp_472;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_472 += Conj(ZD(gI2,j1))*ZD(gI1,j1);
   }
   tmp_470 += tmp_472;
   std::complex<double> tmp_471;
   std::complex<double> tmp_473;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      tmp_473 += KroneckerDelta(gO1,3 + j2)*KroneckerDelta(gO2,3 + j2);
   }
   tmp_471 += tmp_473;
   result += (0.1*Sqr(g1)) * tmp_470 * tmp_471;
   std::complex<double> tmp_474;
   std::complex<double> tmp_476;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_476 += Conj(ZD(gI2,3 + j1))*ZD(gI1,3 + j1);
   }
   tmp_474 += tmp_476;
   std::complex<double> tmp_475;
   std::complex<double> tmp_477;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      tmp_477 += KroneckerDelta(gO1,3 + j2)*KroneckerDelta(gO2,3 + j2);
   }
   tmp_475 += tmp_477;
   result += (0.2*Sqr(g1)) * tmp_474 * tmp_475;
   std::complex<double> tmp_478;
   std::complex<double> tmp_480;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_480 += KroneckerDelta(gO1,3 + j1)*KroneckerDelta(gO2,3 + j1);
   }
   tmp_478 += tmp_480;
   std::complex<double> tmp_479;
   std::complex<double> tmp_481;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      tmp_481 += Conj(ZD(gI2,j2))*ZD(gI1,j2);
   }
   tmp_479 += tmp_481;
   result += (0.1*Sqr(g1)) * tmp_478 * tmp_479;
   std::complex<double> tmp_482;
   std::complex<double> tmp_484;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_484 += KroneckerDelta(gO1,3 + j1)*KroneckerDelta(gO2,3 + j1);
   }
   tmp_482 += tmp_484;
   std::complex<double> tmp_483;
   std::complex<double> tmp_485;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      tmp_485 += Conj(ZD(gI2,3 + j2))*ZD(gI1,3 + j2);
   }
   tmp_483 += tmp_485;
   result += (0.2*Sqr(g1)) * tmp_482 * tmp_483;
   std::complex<double> tmp_486;
   std::complex<double> tmp_488;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_489;
      std::complex<double> tmp_490;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_490 += KroneckerDelta(gO2,3 + j1)*Yu(j1,j2);
      }
      tmp_489 += tmp_490;
      tmp_488 += (Conj(ZD(gI2,j2))) * tmp_489;
   }
   tmp_486 += tmp_488;
   std::complex<double> tmp_487;
   std::complex<double> tmp_491;
   for (unsigned j4 = 0; j4 < 3; ++j4) {
      std::complex<double> tmp_492;
      std::complex<double> tmp_493;
      for (unsigned j3 = 0; j3 < 3; ++j3) {
         tmp_493 += Conj(Yu(j3,j4))*KroneckerDelta(gO1,3 + j3);
      }
      tmp_492 += tmp_493;
      tmp_491 += (ZD(gI1,j4)) * tmp_492;
   }
   tmp_487 += tmp_491;
   result += (-1) * tmp_486 * tmp_487;
   if (gO1 < 3) {
      std::complex<double> tmp_494;
      std::complex<double> tmp_495;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_495 += Conj(ZD(gI2,j1))*ZD(gI1,j1);
      }
      tmp_494 += tmp_495;
      result += (-0.025*KroneckerDelta(gO1,gO2)*Sqr(g1)) * tmp_494;
   }
   if (gO1 < 3) {
      std::complex<double> tmp_496;
      std::complex<double> tmp_497;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_497 += Conj(ZD(gI2,j1))*ZD(gI1,j1);
      }
      tmp_496 += tmp_497;
      result += (0.375*KroneckerDelta(gO1,gO2)*Sqr(g2)) * tmp_496;
   }
   if (gO1 < 3) {
      std::complex<double> tmp_498;
      std::complex<double> tmp_499;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_499 += Conj(ZD(gI2,3 + j1))*ZD(gI1,3 + j1);
      }
      tmp_498 += tmp_499;
      result += (-0.05*KroneckerDelta(gO1,gO2)*Sqr(g1)) * tmp_498;
   }
   if (gO1 < 3) {
      std::complex<double> tmp_500;
      std::complex<double> tmp_501;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         tmp_501 += Conj(ZD(gI2,j2))*ZD(gI1,j2);
      }
      tmp_500 += tmp_501;
      result += (-0.025*KroneckerDelta(gO1,gO2)*Sqr(g1)) * tmp_500;
   }
   if (gO1 < 3) {
      std::complex<double> tmp_502;
      std::complex<double> tmp_503;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         tmp_503 += Conj(ZD(gI2,j2))*ZD(gI1,j2);
      }
      tmp_502 += tmp_503;
      result += (0.375*KroneckerDelta(gO1,gO2)*Sqr(g2)) * tmp_502;
   }
   if (gO1 < 3) {
      std::complex<double> tmp_504;
      std::complex<double> tmp_505;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         tmp_505 += Conj(ZD(gI2,3 + j2))*ZD(gI1,3 + j2);
      }
      tmp_504 += tmp_505;
      result += (-0.05*KroneckerDelta(gO1,gO2)*Sqr(g1)) * tmp_504;
   }
   if (gO1 < 3 && gO2 < 3) {
      std::complex<double> tmp_506;
      std::complex<double> tmp_508;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_508 += Yd(j1,gO1)*ZD(gI1,3 + j1);
      }
      tmp_506 += tmp_508;
      std::complex<double> tmp_507;
      std::complex<double> tmp_509;
      for (unsigned j3 = 0; j3 < 3; ++j3) {
         tmp_509 += Conj(Yd(j3,gO2))*Conj(ZD(gI2,3 + j3));
      }
      tmp_507 += tmp_509;
      result += (-1) * tmp_506 * tmp_507;
   }
   if (gO1 < 3 && gO2 < 3) {
      result += -0.5*Conj(ZD(gI2,gO2))*Sqr(g2)*ZD(gI1,gO1);
   }

   return result;
}

std::complex<double> CLASSNAME::CpUSuconjUSuconjSeSe(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_510;
   std::complex<double> tmp_512;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_512 += Conj(ZE(gI2,j1))*ZE(gI1,j1);
   }
   tmp_510 += tmp_512;
   std::complex<double> tmp_511;
   std::complex<double> tmp_513;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      tmp_513 += KroneckerDelta(gO1,3 + j2)*KroneckerDelta(gO2,3 + j2);
   }
   tmp_511 += tmp_513;
   result += (-0.1*Sqr(g1)) * tmp_510 * tmp_511;
   std::complex<double> tmp_514;
   std::complex<double> tmp_516;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_516 += Conj(ZE(gI2,3 + j1))*ZE(gI1,3 + j1);
   }
   tmp_514 += tmp_516;
   std::complex<double> tmp_515;
   std::complex<double> tmp_517;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      tmp_517 += KroneckerDelta(gO1,3 + j2)*KroneckerDelta(gO2,3 + j2);
   }
   tmp_515 += tmp_517;
   result += (0.2*Sqr(g1)) * tmp_514 * tmp_515;
   std::complex<double> tmp_518;
   std::complex<double> tmp_520;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_520 += KroneckerDelta(gO1,3 + j1)*KroneckerDelta(gO2,3 + j1);
   }
   tmp_518 += tmp_520;
   std::complex<double> tmp_519;
   std::complex<double> tmp_521;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      tmp_521 += Conj(ZE(gI2,j2))*ZE(gI1,j2);
   }
   tmp_519 += tmp_521;
   result += (-0.1*Sqr(g1)) * tmp_518 * tmp_519;
   std::complex<double> tmp_522;
   std::complex<double> tmp_524;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_524 += KroneckerDelta(gO1,3 + j1)*KroneckerDelta(gO2,3 + j1);
   }
   tmp_522 += tmp_524;
   std::complex<double> tmp_523;
   std::complex<double> tmp_525;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      tmp_525 += Conj(ZE(gI2,3 + j2))*ZE(gI1,3 + j2);
   }
   tmp_523 += tmp_525;
   result += (0.2*Sqr(g1)) * tmp_522 * tmp_523;
   if (gO1 < 3) {
      std::complex<double> tmp_526;
      std::complex<double> tmp_527;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_527 += Conj(ZE(gI2,j1))*ZE(gI1,j1);
      }
      tmp_526 += tmp_527;
      result += (0.025*KroneckerDelta(gO1,gO2)*Sqr(g1)) * tmp_526;
   }
   if (gO1 < 3) {
      std::complex<double> tmp_528;
      std::complex<double> tmp_529;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_529 += Conj(ZE(gI2,j1))*ZE(gI1,j1);
      }
      tmp_528 += tmp_529;
      result += (0.125*KroneckerDelta(gO1,gO2)*Sqr(g2)) * tmp_528;
   }
   if (gO1 < 3) {
      std::complex<double> tmp_530;
      std::complex<double> tmp_531;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_531 += Conj(ZE(gI2,3 + j1))*ZE(gI1,3 + j1);
      }
      tmp_530 += tmp_531;
      result += (-0.05*KroneckerDelta(gO1,gO2)*Sqr(g1)) * tmp_530;
   }
   if (gO1 < 3) {
      std::complex<double> tmp_532;
      std::complex<double> tmp_533;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         tmp_533 += Conj(ZE(gI2,j2))*ZE(gI1,j2);
      }
      tmp_532 += tmp_533;
      result += (0.025*KroneckerDelta(gO1,gO2)*Sqr(g1)) * tmp_532;
   }
   if (gO1 < 3) {
      std::complex<double> tmp_534;
      std::complex<double> tmp_535;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         tmp_535 += Conj(ZE(gI2,j2))*ZE(gI1,j2);
      }
      tmp_534 += tmp_535;
      result += (0.125*KroneckerDelta(gO1,gO2)*Sqr(g2)) * tmp_534;
   }
   if (gO1 < 3) {
      std::complex<double> tmp_536;
      std::complex<double> tmp_537;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         tmp_537 += Conj(ZE(gI2,3 + j2))*ZE(gI1,3 + j2);
      }
      tmp_536 += tmp_537;
      result += (-0.05*KroneckerDelta(gO1,gO2)*Sqr(g1)) * tmp_536;
   }

   return result;
}

std::complex<double> CLASSNAME::CpUSuconjUSuconjSuSu(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_538;
   std::complex<double> tmp_540;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_540 += KroneckerDelta(gO1,3 + j1)*ZU(gI1,3 + j1);
   }
   tmp_538 += tmp_540;
   std::complex<double> tmp_539;
   std::complex<double> tmp_541;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      tmp_541 += Conj(ZU(gI2,3 + j2))*KroneckerDelta(gO2,3 + j2);
   }
   tmp_539 += tmp_541;
   result += (-0.13333333333333333*Sqr(g1)) * tmp_538 * tmp_539;
   std::complex<double> tmp_542;
   std::complex<double> tmp_544;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_544 += KroneckerDelta(gO1,3 + j1)*ZU(gI1,3 + j1);
   }
   tmp_542 += tmp_544;
   std::complex<double> tmp_543;
   std::complex<double> tmp_545;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      tmp_545 += Conj(ZU(gI2,3 + j2))*KroneckerDelta(gO2,3 + j2);
   }
   tmp_543 += tmp_545;
   result += (-0.6666666666666666*Sqr(g3)) * tmp_542 * tmp_543;
   std::complex<double> tmp_546;
   std::complex<double> tmp_548;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_548 += Conj(ZU(gI2,j1))*ZU(gI1,j1);
   }
   tmp_546 += tmp_548;
   std::complex<double> tmp_547;
   std::complex<double> tmp_549;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      tmp_549 += KroneckerDelta(gO1,3 + j2)*KroneckerDelta(gO2,3 + j2);
   }
   tmp_547 += tmp_549;
   result += (0.1*Sqr(g1)) * tmp_546 * tmp_547;
   std::complex<double> tmp_550;
   std::complex<double> tmp_552;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_552 += Conj(ZU(gI2,3 + j1))*ZU(gI1,3 + j1);
   }
   tmp_550 += tmp_552;
   std::complex<double> tmp_551;
   std::complex<double> tmp_553;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      tmp_553 += KroneckerDelta(gO1,3 + j2)*KroneckerDelta(gO2,3 + j2);
   }
   tmp_551 += tmp_553;
   result += (-0.4*Sqr(g1)) * tmp_550 * tmp_551;
   std::complex<double> tmp_554;
   std::complex<double> tmp_556;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_556 += KroneckerDelta(gO1,3 + j1)*KroneckerDelta(gO2,3 + j1);
   }
   tmp_554 += tmp_556;
   std::complex<double> tmp_555;
   std::complex<double> tmp_557;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      tmp_557 += Conj(ZU(gI2,j2))*ZU(gI1,j2);
   }
   tmp_555 += tmp_557;
   result += (0.1*Sqr(g1)) * tmp_554 * tmp_555;
   std::complex<double> tmp_558;
   std::complex<double> tmp_560;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_560 += KroneckerDelta(gO1,3 + j1)*KroneckerDelta(gO2,3 + j1);
   }
   tmp_558 += tmp_560;
   std::complex<double> tmp_559;
   std::complex<double> tmp_561;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      tmp_561 += Conj(ZU(gI2,3 + j2))*ZU(gI1,3 + j2);
   }
   tmp_559 += tmp_561;
   result += (-0.4*Sqr(g1)) * tmp_558 * tmp_559;
   std::complex<double> tmp_562;
   std::complex<double> tmp_564;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_564 += Conj(ZU(gI2,3 + j1))*KroneckerDelta(gO2,3 + j1);
   }
   tmp_562 += tmp_564;
   std::complex<double> tmp_563;
   std::complex<double> tmp_565;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      tmp_565 += KroneckerDelta(gO1,3 + j2)*ZU(gI1,3 + j2);
   }
   tmp_563 += tmp_565;
   result += (-0.13333333333333333*Sqr(g1)) * tmp_562 * tmp_563;
   std::complex<double> tmp_566;
   std::complex<double> tmp_568;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_568 += Conj(ZU(gI2,3 + j1))*KroneckerDelta(gO2,3 + j1);
   }
   tmp_566 += tmp_568;
   std::complex<double> tmp_567;
   std::complex<double> tmp_569;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      tmp_569 += KroneckerDelta(gO1,3 + j2)*ZU(gI1,3 + j2);
   }
   tmp_567 += tmp_569;
   result += (-0.6666666666666666*Sqr(g3)) * tmp_566 * tmp_567;
   std::complex<double> tmp_570;
   std::complex<double> tmp_572;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_573;
      std::complex<double> tmp_574;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_574 += KroneckerDelta(gO2,3 + j1)*Yu(j1,j2);
      }
      tmp_573 += tmp_574;
      tmp_572 += (Conj(ZU(gI2,j2))) * tmp_573;
   }
   tmp_570 += tmp_572;
   std::complex<double> tmp_571;
   std::complex<double> tmp_575;
   for (unsigned j4 = 0; j4 < 3; ++j4) {
      std::complex<double> tmp_576;
      std::complex<double> tmp_577;
      for (unsigned j3 = 0; j3 < 3; ++j3) {
         tmp_577 += Conj(Yu(j3,j4))*KroneckerDelta(gO1,3 + j3);
      }
      tmp_576 += tmp_577;
      tmp_575 += (ZU(gI1,j4)) * tmp_576;
   }
   tmp_571 += tmp_575;
   result += (-1) * tmp_570 * tmp_571;
   if (gO1 < 3) {
      std::complex<double> tmp_578;
      std::complex<double> tmp_579;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_579 += Conj(ZU(gI2,j1))*ZU(gI1,j1);
      }
      tmp_578 += tmp_579;
      result += (-0.025*KroneckerDelta(gO1,gO2)*Sqr(g1)) * tmp_578;
   }
   if (gO1 < 3) {
      std::complex<double> tmp_580;
      std::complex<double> tmp_581;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_581 += Conj(ZU(gI2,j1))*ZU(gI1,j1);
      }
      tmp_580 += tmp_581;
      result += (-0.375*KroneckerDelta(gO1,gO2)*Sqr(g2)) * tmp_580;
   }
   if (gO1 < 3) {
      std::complex<double> tmp_582;
      std::complex<double> tmp_583;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_583 += Conj(ZU(gI2,3 + j1))*ZU(gI1,3 + j1);
      }
      tmp_582 += tmp_583;
      result += (0.1*KroneckerDelta(gO1,gO2)*Sqr(g1)) * tmp_582;
   }
   if (gO1 < 3) {
      std::complex<double> tmp_584;
      std::complex<double> tmp_585;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         tmp_585 += Conj(ZU(gI2,j2))*ZU(gI1,j2);
      }
      tmp_584 += tmp_585;
      result += (-0.025*KroneckerDelta(gO1,gO2)*Sqr(g1)) * tmp_584;
   }
   if (gO1 < 3) {
      std::complex<double> tmp_586;
      std::complex<double> tmp_587;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         tmp_587 += Conj(ZU(gI2,j2))*ZU(gI1,j2);
      }
      tmp_586 += tmp_587;
      result += (-0.375*KroneckerDelta(gO1,gO2)*Sqr(g2)) * tmp_586;
   }
   if (gO1 < 3) {
      std::complex<double> tmp_588;
      std::complex<double> tmp_589;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         tmp_589 += Conj(ZU(gI2,3 + j2))*ZU(gI1,3 + j2);
      }
      tmp_588 += tmp_589;
      result += (0.1*KroneckerDelta(gO1,gO2)*Sqr(g1)) * tmp_588;
   }
   if (gO1 < 3) {
      std::complex<double> tmp_590;
      std::complex<double> tmp_592;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_592 += KroneckerDelta(gO2,3 + j1)*Yu(j1,gO1);
      }
      tmp_590 += tmp_592;
      std::complex<double> tmp_591;
      std::complex<double> tmp_593;
      for (unsigned j4 = 0; j4 < 3; ++j4) {
         std::complex<double> tmp_594;
         std::complex<double> tmp_595;
         for (unsigned j3 = 0; j3 < 3; ++j3) {
            tmp_595 += Conj(Yu(j3,j4))*Conj(ZU(gI2,3 + j3));
         }
         tmp_594 += tmp_595;
         tmp_593 += (ZU(gI1,j4)) * tmp_594;
      }
      tmp_591 += tmp_593;
      result += (-3) * tmp_590 * tmp_591;
   }
   if (gO2 < 3) {
      std::complex<double> tmp_596;
      std::complex<double> tmp_597;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_597 += KroneckerDelta(gO1,3 + j1)*ZU(gI1,3 + j1);
      }
      tmp_596 += tmp_597;
      result += (0.03333333333333333*Conj(ZU(gI2,gO2))*Sqr(g1)) * tmp_596;
   }
   if (gO2 < 3) {
      std::complex<double> tmp_598;
      std::complex<double> tmp_599;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_599 += KroneckerDelta(gO1,3 + j1)*ZU(gI1,3 + j1);
      }
      tmp_598 += tmp_599;
      result += (0.6666666666666666*Conj(ZU(gI2,gO2))*Sqr(g3)) * tmp_598;
   }
   if (gO2 < 3) {
      std::complex<double> tmp_600;
      std::complex<double> tmp_601;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         tmp_601 += KroneckerDelta(gO1,3 + j2)*ZU(gI1,3 + j2);
      }
      tmp_600 += tmp_601;
      result += (0.03333333333333333*Conj(ZU(gI2,gO2))*Sqr(g1)) * tmp_600;
   }
   if (gO2 < 3) {
      std::complex<double> tmp_602;
      std::complex<double> tmp_603;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         tmp_603 += KroneckerDelta(gO1,3 + j2)*ZU(gI1,3 + j2);
      }
      tmp_602 += tmp_603;
      result += (0.6666666666666666*Conj(ZU(gI2,gO2))*Sqr(g3)) * tmp_602;
   }
   if (gO2 < 3) {
      std::complex<double> tmp_604;
      std::complex<double> tmp_606;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         std::complex<double> tmp_607;
         std::complex<double> tmp_608;
         for (unsigned j1 = 0; j1 < 3; ++j1) {
            tmp_608 += Yu(j1,j2)*ZU(gI1,3 + j1);
         }
         tmp_607 += tmp_608;
         tmp_606 += (Conj(ZU(gI2,j2))) * tmp_607;
      }
      tmp_604 += tmp_606;
      std::complex<double> tmp_605;
      std::complex<double> tmp_609;
      for (unsigned j3 = 0; j3 < 3; ++j3) {
         tmp_609 += Conj(Yu(j3,gO2))*KroneckerDelta(gO1,3 + j3);
      }
      tmp_605 += tmp_609;
      result += (-3) * tmp_604 * tmp_605;
   }
   if (gO1 < 3 && gO2 < 3) {
      std::complex<double> tmp_610;
      std::complex<double> tmp_612;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_612 += Yu(j1,gO1)*ZU(gI1,3 + j1);
      }
      tmp_610 += tmp_612;
      std::complex<double> tmp_611;
      std::complex<double> tmp_613;
      for (unsigned j3 = 0; j3 < 3; ++j3) {
         tmp_613 += Conj(Yu(j3,gO2))*Conj(ZU(gI2,3 + j3));
      }
      tmp_611 += tmp_613;
      result += (-1) * tmp_610 * tmp_611;
   }
   if (gO1 < 3) {
      std::complex<double> tmp_614;
      std::complex<double> tmp_615;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_615 += Conj(ZU(gI2,3 + j1))*KroneckerDelta(gO2,3 + j1);
      }
      tmp_614 += tmp_615;
      result += (0.03333333333333333*Sqr(g1)*ZU(gI1,gO1)) * tmp_614;
   }
   if (gO1 < 3) {
      std::complex<double> tmp_616;
      std::complex<double> tmp_617;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_617 += Conj(ZU(gI2,3 + j1))*KroneckerDelta(gO2,3 + j1);
      }
      tmp_616 += tmp_617;
      result += (0.6666666666666666*Sqr(g3)*ZU(gI1,gO1)) * tmp_616;
   }
   if (gO1 < 3) {
      std::complex<double> tmp_618;
      std::complex<double> tmp_619;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         tmp_619 += Conj(ZU(gI2,3 + j2))*KroneckerDelta(gO2,3 + j2);
      }
      tmp_618 += tmp_619;
      result += (0.03333333333333333*Sqr(g1)*ZU(gI1,gO1)) * tmp_618;
   }
   if (gO1 < 3) {
      std::complex<double> tmp_620;
      std::complex<double> tmp_621;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         tmp_621 += Conj(ZU(gI2,3 + j2))*KroneckerDelta(gO2,3 + j2);
      }
      tmp_620 += tmp_621;
      result += (0.6666666666666666*Sqr(g3)*ZU(gI1,gO1)) * tmp_620;
   }
   if (gO1 < 3 && gO2 < 3) {
      result += -0.016666666666666666*Conj(ZU(gI2,gO2))*Sqr(g1)*ZU(gI1,gO1);
   }
   if (gO1 < 3 && gO2 < 3) {
      result += -0.25*Conj(ZU(gI2,gO2))*Sqr(g2)*ZU(gI1,gO1);
   }
   if (gO1 < 3 && gO2 < 3) {
      result += -1.3333333333333333*Conj(ZU(gI2,gO2))*Sqr(g3)*ZU(gI1,gO1);
   }

   return result;
}

std::complex<double> CLASSNAME::CpconjUSuSuRh(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gO2 < 3) {
      std::complex<double> tmp_622;
      std::complex<double> tmp_623;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_623 += Conj(Yu(j1,gO2))*Conj(ZU(gI1,3 + j1));
      }
      tmp_622 += tmp_623;
      result += (-(MuU*ZHR(gI2,1))) * tmp_622;
   }
   if (gO2 < 3) {
      std::complex<double> tmp_624;
      std::complex<double> tmp_625;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_625 += Conj(Yu(j1,gO2))*Conj(ZU(gI1,3 + j1));
      }
      tmp_624 += tmp_625;
      result += (-0.7071067811865475*LamSU*vS*ZHR(gI2,1)) * tmp_624;
   }
   if (gO2 < 3) {
      std::complex<double> tmp_626;
      std::complex<double> tmp_627;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_627 += Conj(Yu(j1,gO2))*Conj(ZU(gI1,3 + j1));
      }
      tmp_626 += tmp_627;
      result += (0.5*LamTU*vT*ZHR(gI2,1)) * tmp_626;
   }

   return result;
}

std::complex<double> CLASSNAME::CpconjUSuSuAh(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_628;
   std::complex<double> tmp_629;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_630;
      std::complex<double> tmp_631;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_631 += KroneckerDelta(gO2,3 + j1)*Yu(j1,j2);
      }
      tmp_630 += tmp_631;
      tmp_629 += (Conj(ZU(gI1,j2))) * tmp_630;
   }
   tmp_628 += tmp_629;
   result += (std::complex<double>(0.,-0.7071067811865475)*Conj(Mu)*ZA(gI2,0))
      * tmp_628;
   if (gO2 < 3) {
      std::complex<double> tmp_632;
      std::complex<double> tmp_633;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_633 += Conj(Yu(j1,gO2))*Conj(ZU(gI1,3 + j1));
      }
      tmp_632 += tmp_633;
      result += (std::complex<double>(0.,0.7071067811865475)*Mu*ZA(gI2,0)) *
         tmp_632;
   }
   std::complex<double> tmp_634;
   std::complex<double> tmp_635;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_635 += Conj(ZU(gI1,3 + j1))*KroneckerDelta(gO2,3 + j1);
   }
   tmp_634 += tmp_635;
   result += (std::complex<double>(0.,0.5163977794943222)*g1*MDBS*ZA(gI2,2)) *
      tmp_634;
   std::complex<double> tmp_636;
   std::complex<double> tmp_637;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_637 += Conj(ZU(gI1,3 + j1))*KroneckerDelta(gO2,3 + j1);
   }
   tmp_636 += tmp_637;
   result += (std::complex<double>(0.,-0.5163977794943222)*g1*Conj(MDBS)*ZA(gI2
      ,2)) * tmp_636;
   if (gO2 < 3) {
      result += std::complex<double>(0.,-0.12909944487358055)*g1*MDBS*Conj(
         ZU(gI1,gO2))*ZA(gI2,2);
   }
   if (gO2 < 3) {
      result += std::complex<double>(0.,0.12909944487358055)*g1*Conj(MDBS)*
         Conj(ZU(gI1,gO2))*ZA(gI2,2);
   }
   if (gO2 < 3) {
      result += std::complex<double>(0,-0.5)*g2*MDWBT*Conj(ZU(gI1,gO2))*ZA(
         gI2,3);
   }
   if (gO2 < 3) {
      result += std::complex<double>(0,0.5)*g2*Conj(MDWBT)*Conj(ZU(gI1,gO2))
         *ZA(gI2,3);
   }

   return result;
}

std::complex<double> CLASSNAME::CpconjUSuSuhh(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_638;
   std::complex<double> tmp_639;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_639 += Conj(ZU(gI1,3 + j1))*KroneckerDelta(gO2,3 + j1);
   }
   tmp_638 += tmp_639;
   result += (-0.2*vd*Sqr(g1)*ZH(gI2,0)) * tmp_638;
   std::complex<double> tmp_640;
   std::complex<double> tmp_641;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_642;
      std::complex<double> tmp_643;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_643 += KroneckerDelta(gO2,3 + j1)*Yu(j1,j2);
      }
      tmp_642 += tmp_643;
      tmp_641 += (Conj(ZU(gI1,j2))) * tmp_642;
   }
   tmp_640 += tmp_641;
   result += (0.7071067811865475*Conj(Mu)*ZH(gI2,0)) * tmp_640;
   if (gO2 < 3) {
      result += 0.05*vd*Conj(ZU(gI1,gO2))*Sqr(g1)*ZH(gI2,0);
   }
   if (gO2 < 3) {
      result += -0.25*vd*Conj(ZU(gI1,gO2))*Sqr(g2)*ZH(gI2,0);
   }
   if (gO2 < 3) {
      std::complex<double> tmp_644;
      std::complex<double> tmp_645;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_645 += Conj(Yu(j1,gO2))*Conj(ZU(gI1,3 + j1));
      }
      tmp_644 += tmp_645;
      result += (0.7071067811865475*Mu*ZH(gI2,0)) * tmp_644;
   }
   std::complex<double> tmp_646;
   std::complex<double> tmp_647;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_647 += Conj(ZU(gI1,3 + j1))*KroneckerDelta(gO2,3 + j1);
   }
   tmp_646 += tmp_647;
   result += (0.2*vu*Sqr(g1)*ZH(gI2,1)) * tmp_646;
   std::complex<double> tmp_648;
   std::complex<double> tmp_649;
   for (unsigned j3 = 0; j3 < 3; ++j3) {
      std::complex<double> tmp_650;
      std::complex<double> tmp_651;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         std::complex<double> tmp_652;
         std::complex<double> tmp_653;
         for (unsigned j1 = 0; j1 < 3; ++j1) {
            tmp_653 += Conj(Yu(j3,j1))*Yu(j2,j1);
         }
         tmp_652 += tmp_653;
         tmp_651 += (KroneckerDelta(gO2,3 + j2)) * tmp_652;
      }
      tmp_650 += tmp_651;
      tmp_649 += (Conj(ZU(gI1,3 + j3))) * tmp_650;
   }
   tmp_648 += tmp_649;
   result += (-(vu*ZH(gI2,1))) * tmp_648;
   if (gO2 < 3) {
      result += -0.05*vu*Conj(ZU(gI1,gO2))*Sqr(g1)*ZH(gI2,1);
   }
   if (gO2 < 3) {
      result += 0.25*vu*Conj(ZU(gI1,gO2))*Sqr(g2)*ZH(gI2,1);
   }
   if (gO2 < 3) {
      std::complex<double> tmp_654;
      std::complex<double> tmp_655;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         std::complex<double> tmp_656;
         std::complex<double> tmp_657;
         for (unsigned j1 = 0; j1 < 3; ++j1) {
            tmp_657 += Conj(Yu(j1,gO2))*Yu(j1,j2);
         }
         tmp_656 += tmp_657;
         tmp_655 += (Conj(ZU(gI1,j2))) * tmp_656;
      }
      tmp_654 += tmp_655;
      result += (-(vu*ZH(gI2,1))) * tmp_654;
   }
   std::complex<double> tmp_658;
   std::complex<double> tmp_659;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_659 += Conj(ZU(gI1,3 + j1))*KroneckerDelta(gO2,3 + j1);
   }
   tmp_658 += tmp_659;
   result += (0.5163977794943222*g1*MDBS*ZH(gI2,2)) * tmp_658;
   std::complex<double> tmp_660;
   std::complex<double> tmp_661;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_661 += Conj(ZU(gI1,3 + j1))*KroneckerDelta(gO2,3 + j1);
   }
   tmp_660 += tmp_661;
   result += (0.5163977794943222*g1*Conj(MDBS)*ZH(gI2,2)) * tmp_660;
   if (gO2 < 3) {
      result += -0.12909944487358055*g1*MDBS*Conj(ZU(gI1,gO2))*ZH(gI2,2);
   }
   if (gO2 < 3) {
      result += -0.12909944487358055*g1*Conj(MDBS)*Conj(ZU(gI1,gO2))*ZH(gI2,
         2);
   }
   if (gO2 < 3) {
      result += -0.5*g2*MDWBT*Conj(ZU(gI1,gO2))*ZH(gI2,3);
   }
   if (gO2 < 3) {
      result += -0.5*g2*Conj(MDWBT)*Conj(ZU(gI1,gO2))*ZH(gI2,3);
   }

   return result;
}

std::complex<double> CLASSNAME::CpconjUSubarGluFuPR(unsigned gO2, unsigned , unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_662;
   std::complex<double> tmp_663;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_663 += KroneckerDelta(gO2,3 + j1)*ZUR(gI2,j1);
   }
   tmp_662 += tmp_663;
   result += (1.4142135623730951*g3) * tmp_662;

   return result;
}

double CLASSNAME::CpconjUSubarGluFuPL(unsigned , unsigned , unsigned ) const
{
   double result = 0.0;

   result = 0;

   return result;
}

double CLASSNAME::CpconjUSuGluFuPR(unsigned , unsigned , unsigned ) const
{
   double result = 0.0;

   result = 0;

   return result;
}

std::complex<double> CLASSNAME::CpconjUSuGluFuPL(unsigned gO1, unsigned , unsigned gI2) const
{
   std::complex<double> result;

   if (gO1 < 3) {
      result += -1.4142135623730951*g3*Conj(ZUL(gI2,gO1));
   }

   return result;
}

std::complex<double> CLASSNAME::CpconjUSuconjVWmSd(unsigned gO2, unsigned gI2) const
{
   std::complex<double> result;

   if (gO2 < 3) {
      result += 0.7071067811865475*g2*Conj(ZD(gI2,gO2));
   }

   return result;
}

std::complex<double> CLASSNAME::CpconjUSuVGSu(unsigned gO2, unsigned gI2) const
{
   std::complex<double> result;

   if (gI2 < 6) {
      result += g3*Conj(ZU(gI2,gO2));
   }

   return result;
}

std::complex<double> CLASSNAME::CpconjUSuVPSu(unsigned gO2, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_664;
   std::complex<double> tmp_665;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_665 += Conj(ZU(gI2,3 + j1))*KroneckerDelta(gO2,3 + j1);
   }
   tmp_664 += tmp_665;
   result += (0.5163977794943222*g1*Cos(ThetaW())) * tmp_664;
   if (gO2 < 3) {
      result += 0.12909944487358055*g1*Conj(ZU(gI2,gO2))*Cos(ThetaW());
   }
   if (gO2 < 3) {
      result += 0.5*g2*Conj(ZU(gI2,gO2))*Sin(ThetaW());
   }

   return result;
}

std::complex<double> CLASSNAME::CpconjUSuVZSu(unsigned gO2, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_666;
   std::complex<double> tmp_667;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_667 += Conj(ZU(gI2,3 + j1))*KroneckerDelta(gO2,3 + j1);
   }
   tmp_666 += tmp_667;
   result += (-0.5163977794943222*g1*Sin(ThetaW())) * tmp_666;
   if (gO2 < 3) {
      result += 0.5*g2*Conj(ZU(gI2,gO2))*Cos(ThetaW());
   }
   if (gO2 < 3) {
      result += -0.12909944487358055*g1*Conj(ZU(gI2,gO2))*Sin(ThetaW());
   }

   return result;
}

std::complex<double> CLASSNAME::CpUSeconjUSeVZVZ(unsigned gO1, unsigned gO2) const
{
   std::complex<double> result;

   std::complex<double> tmp_668;
   std::complex<double> tmp_669;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_669 += KroneckerDelta(gO1,3 + j1)*KroneckerDelta(gO2,3 + j1);
   }
   tmp_668 += tmp_669;
   result += (1.2*Sqr(g1)*Sqr(Sin(ThetaW()))) * tmp_668;
   if (gO1 < 3) {
      result += 0.5*KroneckerDelta(gO1,gO2)*Sqr(g2)*Sqr(Cos(ThetaW()));
   }
   if (gO1 < 3) {
      result += -0.7745966692414834*g1*g2*Cos(ThetaW())*KroneckerDelta(gO1,
         gO2)*Sin(ThetaW());
   }
   if (gO1 < 3) {
      result += 0.3*KroneckerDelta(gO1,gO2)*Sqr(g1)*Sqr(Sin(ThetaW()));
   }

   return result;
}

double CLASSNAME::CpUSeconjUSeconjVWmVWm(unsigned gO1, unsigned gO2) const
{
   double result = 0.0;

   if (gO1 < 3) {
      result += 0.5*KroneckerDelta(gO1,gO2)*Sqr(g2);
   }

   return result;
}

std::complex<double> CLASSNAME::CpUSeconjUSeconjRhRh(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_670;
   std::complex<double> tmp_671;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_671 += KroneckerDelta(gO1,3 + j1)*KroneckerDelta(gO2,3 + j1);
   }
   tmp_670 += tmp_671;
   result += (-0.3*Sqr(g1)*ZHR(gI1,0)*ZHR(gI2,0)) * tmp_670;
   if (gO1 < 3) {
      result += 0.15*KroneckerDelta(gO1,gO2)*Sqr(g1)*ZHR(gI1,0)*ZHR(gI2,0);
   }
   if (gO1 < 3) {
      result += -0.25*KroneckerDelta(gO1,gO2)*Sqr(g2)*ZHR(gI1,0)*ZHR(gI2,0);
   }
   std::complex<double> tmp_672;
   std::complex<double> tmp_673;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_673 += KroneckerDelta(gO1,3 + j1)*KroneckerDelta(gO2,3 + j1);
   }
   tmp_672 += tmp_673;
   result += (0.3*Sqr(g1)*ZHR(gI1,1)*ZHR(gI2,1)) * tmp_672;
   if (gO1 < 3) {
      result += -0.15*KroneckerDelta(gO1,gO2)*Sqr(g1)*ZHR(gI1,1)*ZHR(gI2,1);
   }
   if (gO1 < 3) {
      result += 0.25*KroneckerDelta(gO1,gO2)*Sqr(g2)*ZHR(gI1,1)*ZHR(gI2,1);
   }

   return result;
}

std::complex<double> CLASSNAME::CpUSeconjUSeconjRpmRpm(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_674;
   std::complex<double> tmp_675;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_675 += KroneckerDelta(gO1,3 + j1)*KroneckerDelta(gO2,3 + j1);
   }
   tmp_674 += tmp_675;
   result += (0.3*Conj(ZRP(gI2,0))*Sqr(g1)*ZRP(gI1,0)) * tmp_674;
   if (gO1 < 3) {
      result += -0.15*Conj(ZRP(gI2,0))*KroneckerDelta(gO1,gO2)*Sqr(g1)*ZRP(
         gI1,0);
   }
   if (gO1 < 3) {
      result += -0.25*Conj(ZRP(gI2,0))*KroneckerDelta(gO1,gO2)*Sqr(g2)*ZRP(
         gI1,0);
   }
   std::complex<double> tmp_676;
   std::complex<double> tmp_677;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_677 += KroneckerDelta(gO1,3 + j1)*KroneckerDelta(gO2,3 + j1);
   }
   tmp_676 += tmp_677;
   result += (-0.3*Conj(ZRP(gI2,1))*Sqr(g1)*ZRP(gI1,1)) * tmp_676;
   if (gO1 < 3) {
      result += 0.15*Conj(ZRP(gI2,1))*KroneckerDelta(gO1,gO2)*Sqr(g1)*ZRP(
         gI1,1);
   }
   if (gO1 < 3) {
      result += 0.25*Conj(ZRP(gI2,1))*KroneckerDelta(gO1,gO2)*Sqr(g2)*ZRP(
         gI1,1);
   }

   return result;
}

double CLASSNAME::CpconjUSebarCha1FvPR(unsigned , unsigned , unsigned ) const
{
   double result = 0.0;

   result = 0;

   return result;
}

std::complex<double> CLASSNAME::CpconjUSebarCha1FvPL(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_678;
   std::complex<double> tmp_679;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_679 += KroneckerDelta(gO1,3 + j1)*Ye(j1,gI2);
   }
   tmp_678 += tmp_679;
   result += (Conj(UM1(gI1,1))) * tmp_678;

   return result;
}

std::complex<double> CLASSNAME::CpUSeconjUSeconjSvSv(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_680;
   std::complex<double> tmp_681;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_681 += KroneckerDelta(gO1,3 + j1)*KroneckerDelta(gO2,3 + j1);
   }
   tmp_680 += tmp_681;
   result += (0.3*KroneckerDelta(gI1,gI2)*Sqr(g1)) * tmp_680;
   std::complex<double> tmp_682;
   std::complex<double> tmp_684;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_685;
      std::complex<double> tmp_686;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_686 += KroneckerDelta(gO2,3 + j1)*Ye(j1,j2);
      }
      tmp_685 += tmp_686;
      tmp_684 += (Conj(ZV(gI2,j2))) * tmp_685;
   }
   tmp_682 += tmp_684;
   std::complex<double> tmp_683;
   std::complex<double> tmp_687;
   for (unsigned j4 = 0; j4 < 3; ++j4) {
      std::complex<double> tmp_688;
      std::complex<double> tmp_689;
      for (unsigned j3 = 0; j3 < 3; ++j3) {
         tmp_689 += Conj(Ye(j3,j4))*KroneckerDelta(gO1,3 + j3);
      }
      tmp_688 += tmp_689;
      tmp_687 += (ZV(gI1,j4)) * tmp_688;
   }
   tmp_683 += tmp_687;
   result += (-1) * tmp_682 * tmp_683;
   if (gO1 < 3) {
      result += -0.15*KroneckerDelta(gI1,gI2)*KroneckerDelta(gO1,gO2)*Sqr(g1
         );
   }
   if (gO1 < 3) {
      result += 0.25*KroneckerDelta(gI1,gI2)*KroneckerDelta(gO1,gO2)*Sqr(g2)
         ;
   }
   if (gO1 < 3 && gO2 < 3) {
      result += -0.5*Conj(ZV(gI2,gO2))*Sqr(g2)*ZV(gI1,gO1);
   }

   return result;
}

std::complex<double> CLASSNAME::CpconjUSeSvRpm(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_690;
   std::complex<double> tmp_691;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_692;
      std::complex<double> tmp_693;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_693 += KroneckerDelta(gO2,3 + j1)*Ye(j1,j2);
      }
      tmp_692 += tmp_693;
      tmp_691 += (Conj(ZV(gI1,j2))) * tmp_692;
   }
   tmp_690 += tmp_691;
   result += (0.5*(1.4142135623730951*vS*Conj(LamSD) - vT*Conj(LamTD) + 2*Conj(
      MuD))*Conj(ZRP(gI2,1))) * tmp_690;

   return result;
}

double CLASSNAME::CpconjUSeFvCha2PR(unsigned , unsigned , unsigned ) const
{
   double result = 0.0;

   result = 0;

   return result;
}

std::complex<double> CLASSNAME::CpconjUSeFvCha2PL(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gI1 < 3) {
      result += -(g2*Conj(UM2(gI2,0))*KroneckerDelta(gI1,gO1));
   }

   return result;
}

std::complex<double> CLASSNAME::CpconjUSeSvHpm(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gO2 < 3) {
      result += -0.35355339059327373*vd*Conj(ZV(gI1,gO2))*Sqr(g2)*ZP(gI2,0);
   }
   if (gO2 < 3) {
      std::complex<double> tmp_694;
      std::complex<double> tmp_695;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         std::complex<double> tmp_696;
         std::complex<double> tmp_697;
         for (unsigned j1 = 0; j1 < 3; ++j1) {
            tmp_697 += Conj(Ye(j1,gO2))*Ye(j1,j2);
         }
         tmp_696 += tmp_697;
         tmp_695 += (Conj(ZV(gI1,j2))) * tmp_696;
      }
      tmp_694 += tmp_695;
      result += (0.7071067811865475*vd*ZP(gI2,0)) * tmp_694;
   }
   std::complex<double> tmp_698;
   std::complex<double> tmp_699;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_700;
      std::complex<double> tmp_701;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_701 += KroneckerDelta(gO2,3 + j1)*Ye(j1,j2);
      }
      tmp_700 += tmp_701;
      tmp_699 += (Conj(ZV(gI1,j2))) * tmp_700;
   }
   tmp_698 += tmp_699;
   result += (Conj(Mu)*ZP(gI2,1)) * tmp_698;
   if (gO2 < 3) {
      result += -0.35355339059327373*vu*Conj(ZV(gI1,gO2))*Sqr(g2)*ZP(gI2,1);
   }
   if (gO2 < 3) {
      result += -(g2*MDWBT*Conj(ZV(gI1,gO2))*ZP(gI2,2));
   }
   if (gO2 < 3) {
      result += -0.5*vT*Conj(ZV(gI1,gO2))*Sqr(g2)*ZP(gI2,2);
   }
   if (gO2 < 3) {
      result += 0.5*vT*Conj(ZV(gI1,gO2))*Sqr(g2)*ZP(gI2,3);
   }
   if (gO2 < 3) {
      result += -(g2*Conj(MDWBT)*Conj(ZV(gI1,gO2))*ZP(gI2,3));
   }

   return result;
}

std::complex<double> CLASSNAME::CpconjUSeFeChiPR(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gO2 < 3) {
      std::complex<double> tmp_702;
      std::complex<double> tmp_703;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_703 += Conj(Ye(j1,gO2))*ZER(gI1,j1);
      }
      tmp_702 += tmp_703;
      result += (-ZN2(gI2,2)) * tmp_702;
   }

   return result;
}

std::complex<double> CLASSNAME::CpconjUSeFeChiPL(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gO1 < 3) {
      result += 0.5477225575051661*g1*Conj(ZEL(gI1,gO1))*Conj(ZN1(gI2,0));
   }
   if (gO1 < 3) {
      result += 0.7071067811865475*g2*Conj(ZEL(gI1,gO1))*Conj(ZN1(gI2,1));
   }

   return result;
}

std::complex<double> CLASSNAME::CpUSeconjUSeAhAh(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_704;
   std::complex<double> tmp_705;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_705 += KroneckerDelta(gO1,3 + j1)*KroneckerDelta(gO2,3 + j1);
   }
   tmp_704 += tmp_705;
   result += (0.3*Sqr(g1)*ZA(gI1,0)*ZA(gI2,0)) * tmp_704;
   std::complex<double> tmp_706;
   std::complex<double> tmp_707;
   for (unsigned j3 = 0; j3 < 3; ++j3) {
      std::complex<double> tmp_708;
      std::complex<double> tmp_709;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         std::complex<double> tmp_710;
         std::complex<double> tmp_711;
         for (unsigned j1 = 0; j1 < 3; ++j1) {
            tmp_711 += Conj(Ye(j3,j1))*Ye(j2,j1);
         }
         tmp_710 += tmp_711;
         tmp_709 += (KroneckerDelta(gO2,3 + j2)) * tmp_710;
      }
      tmp_708 += tmp_709;
      tmp_707 += (KroneckerDelta(gO1,3 + j3)) * tmp_708;
   }
   tmp_706 += tmp_707;
   result += (-(ZA(gI1,0)*ZA(gI2,0))) * tmp_706;
   if (gO1 < 3) {
      result += -0.15*KroneckerDelta(gO1,gO2)*Sqr(g1)*ZA(gI1,0)*ZA(gI2,0);
   }
   if (gO1 < 3) {
      result += 0.25*KroneckerDelta(gO1,gO2)*Sqr(g2)*ZA(gI1,0)*ZA(gI2,0);
   }
   if (gO1 < 3 && gO2 < 3) {
      std::complex<double> tmp_712;
      std::complex<double> tmp_713;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_713 += Conj(Ye(j1,gO2))*Ye(j1,gO1);
      }
      tmp_712 += tmp_713;
      result += (-(ZA(gI1,0)*ZA(gI2,0))) * tmp_712;
   }
   std::complex<double> tmp_714;
   std::complex<double> tmp_715;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_715 += KroneckerDelta(gO1,3 + j1)*KroneckerDelta(gO2,3 + j1);
   }
   tmp_714 += tmp_715;
   result += (-0.3*Sqr(g1)*ZA(gI1,1)*ZA(gI2,1)) * tmp_714;
   if (gO1 < 3) {
      result += 0.15*KroneckerDelta(gO1,gO2)*Sqr(g1)*ZA(gI1,1)*ZA(gI2,1);
   }
   if (gO1 < 3) {
      result += -0.25*KroneckerDelta(gO1,gO2)*Sqr(g2)*ZA(gI1,1)*ZA(gI2,1);
   }

   return result;
}

std::complex<double> CLASSNAME::CpUSeconjUSeconjHpmHpm(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_716;
   std::complex<double> tmp_717;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_717 += KroneckerDelta(gO1,3 + j1)*KroneckerDelta(gO2,3 + j1);
   }
   tmp_716 += tmp_717;
   result += (0.3*Sqr(g1)*ZP(gI1,0)*ZP(gI2,0)) * tmp_716;
   std::complex<double> tmp_718;
   std::complex<double> tmp_719;
   for (unsigned j3 = 0; j3 < 3; ++j3) {
      std::complex<double> tmp_720;
      std::complex<double> tmp_721;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         std::complex<double> tmp_722;
         std::complex<double> tmp_723;
         for (unsigned j1 = 0; j1 < 3; ++j1) {
            tmp_723 += Conj(Ye(j3,j1))*Ye(j2,j1);
         }
         tmp_722 += tmp_723;
         tmp_721 += (KroneckerDelta(gO2,3 + j2)) * tmp_722;
      }
      tmp_720 += tmp_721;
      tmp_719 += (KroneckerDelta(gO1,3 + j3)) * tmp_720;
   }
   tmp_718 += tmp_719;
   result += (-(ZP(gI1,0)*ZP(gI2,0))) * tmp_718;
   if (gO1 < 3) {
      result += -0.15*KroneckerDelta(gO1,gO2)*Sqr(g1)*ZP(gI1,0)*ZP(gI2,0);
   }
   if (gO1 < 3) {
      result += -0.25*KroneckerDelta(gO1,gO2)*Sqr(g2)*ZP(gI1,0)*ZP(gI2,0);
   }
   std::complex<double> tmp_724;
   std::complex<double> tmp_725;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_725 += KroneckerDelta(gO1,3 + j1)*KroneckerDelta(gO2,3 + j1);
   }
   tmp_724 += tmp_725;
   result += (-0.3*Sqr(g1)*ZP(gI1,1)*ZP(gI2,1)) * tmp_724;
   if (gO1 < 3) {
      result += 0.15*KroneckerDelta(gO1,gO2)*Sqr(g1)*ZP(gI1,1)*ZP(gI2,1);
   }
   if (gO1 < 3) {
      result += 0.25*KroneckerDelta(gO1,gO2)*Sqr(g2)*ZP(gI1,1)*ZP(gI2,1);
   }
   if (gO1 < 3) {
      result += -0.5*KroneckerDelta(gO1,gO2)*Sqr(g2)*ZP(gI1,2)*ZP(gI2,2);
   }
   if (gO1 < 3) {
      result += 0.5*KroneckerDelta(gO1,gO2)*Sqr(g2)*ZP(gI1,3)*ZP(gI2,3);
   }

   return result;
}

std::complex<double> CLASSNAME::CpUSeconjUSehhhh(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_726;
   std::complex<double> tmp_727;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_727 += KroneckerDelta(gO1,3 + j1)*KroneckerDelta(gO2,3 + j1);
   }
   tmp_726 += tmp_727;
   result += (0.3*Sqr(g1)*ZH(gI1,0)*ZH(gI2,0)) * tmp_726;
   std::complex<double> tmp_728;
   std::complex<double> tmp_729;
   for (unsigned j3 = 0; j3 < 3; ++j3) {
      std::complex<double> tmp_730;
      std::complex<double> tmp_731;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         std::complex<double> tmp_732;
         std::complex<double> tmp_733;
         for (unsigned j1 = 0; j1 < 3; ++j1) {
            tmp_733 += Conj(Ye(j3,j1))*Ye(j2,j1);
         }
         tmp_732 += tmp_733;
         tmp_731 += (KroneckerDelta(gO2,3 + j2)) * tmp_732;
      }
      tmp_730 += tmp_731;
      tmp_729 += (KroneckerDelta(gO1,3 + j3)) * tmp_730;
   }
   tmp_728 += tmp_729;
   result += (-(ZH(gI1,0)*ZH(gI2,0))) * tmp_728;
   if (gO1 < 3) {
      result += -0.15*KroneckerDelta(gO1,gO2)*Sqr(g1)*ZH(gI1,0)*ZH(gI2,0);
   }
   if (gO1 < 3) {
      result += 0.25*KroneckerDelta(gO1,gO2)*Sqr(g2)*ZH(gI1,0)*ZH(gI2,0);
   }
   if (gO1 < 3 && gO2 < 3) {
      std::complex<double> tmp_734;
      std::complex<double> tmp_735;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_735 += Conj(Ye(j1,gO2))*Ye(j1,gO1);
      }
      tmp_734 += tmp_735;
      result += (-(ZH(gI1,0)*ZH(gI2,0))) * tmp_734;
   }
   std::complex<double> tmp_736;
   std::complex<double> tmp_737;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_737 += KroneckerDelta(gO1,3 + j1)*KroneckerDelta(gO2,3 + j1);
   }
   tmp_736 += tmp_737;
   result += (-0.3*Sqr(g1)*ZH(gI1,1)*ZH(gI2,1)) * tmp_736;
   if (gO1 < 3) {
      result += 0.15*KroneckerDelta(gO1,gO2)*Sqr(g1)*ZH(gI1,1)*ZH(gI2,1);
   }
   if (gO1 < 3) {
      result += -0.25*KroneckerDelta(gO1,gO2)*Sqr(g2)*ZH(gI1,1)*ZH(gI2,1);
   }

   return result;
}

std::complex<double> CLASSNAME::CpconjUSebarChiFePR(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_738;
   std::complex<double> tmp_739;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_739 += KroneckerDelta(gO2,3 + j1)*ZER(gI2,j1);
   }
   tmp_738 += tmp_739;
   result += (-1.0954451150103321*g1*ZN1(gI1,0)) * tmp_738;

   return result;
}

std::complex<double> CLASSNAME::CpconjUSebarChiFePL(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_740;
   std::complex<double> tmp_741;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_742;
      std::complex<double> tmp_743;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_743 += KroneckerDelta(gO1,3 + j1)*Ye(j1,j2);
      }
      tmp_742 += tmp_743;
      tmp_741 += (Conj(ZEL(gI2,j2))) * tmp_742;
   }
   tmp_740 += tmp_741;
   result += (-Conj(ZN2(gI1,2))) * tmp_740;

   return result;
}

std::complex<double> CLASSNAME::CpUSeconjUSeconjSdSd(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_744;
   std::complex<double> tmp_746;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_746 += Conj(ZD(gI2,j1))*ZD(gI1,j1);
   }
   tmp_744 += tmp_746;
   std::complex<double> tmp_745;
   std::complex<double> tmp_747;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      tmp_747 += KroneckerDelta(gO1,3 + j2)*KroneckerDelta(gO2,3 + j2);
   }
   tmp_745 += tmp_747;
   result += (-0.05*Sqr(g1)) * tmp_744 * tmp_745;
   std::complex<double> tmp_748;
   std::complex<double> tmp_750;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_750 += Conj(ZD(gI2,3 + j1))*ZD(gI1,3 + j1);
   }
   tmp_748 += tmp_750;
   std::complex<double> tmp_749;
   std::complex<double> tmp_751;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      tmp_751 += KroneckerDelta(gO1,3 + j2)*KroneckerDelta(gO2,3 + j2);
   }
   tmp_749 += tmp_751;
   result += (-0.1*Sqr(g1)) * tmp_748 * tmp_749;
   std::complex<double> tmp_752;
   std::complex<double> tmp_754;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_754 += KroneckerDelta(gO1,3 + j1)*KroneckerDelta(gO2,3 + j1);
   }
   tmp_752 += tmp_754;
   std::complex<double> tmp_753;
   std::complex<double> tmp_755;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      tmp_755 += Conj(ZD(gI2,j2))*ZD(gI1,j2);
   }
   tmp_753 += tmp_755;
   result += (-0.05*Sqr(g1)) * tmp_752 * tmp_753;
   std::complex<double> tmp_756;
   std::complex<double> tmp_758;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_758 += KroneckerDelta(gO1,3 + j1)*KroneckerDelta(gO2,3 + j1);
   }
   tmp_756 += tmp_758;
   std::complex<double> tmp_757;
   std::complex<double> tmp_759;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      tmp_759 += Conj(ZD(gI2,3 + j2))*ZD(gI1,3 + j2);
   }
   tmp_757 += tmp_759;
   result += (-0.1*Sqr(g1)) * tmp_756 * tmp_757;
   if (gO1 < 3) {
      std::complex<double> tmp_760;
      std::complex<double> tmp_761;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_761 += Conj(ZD(gI2,j1))*ZD(gI1,j1);
      }
      tmp_760 += tmp_761;
      result += (0.025*KroneckerDelta(gO1,gO2)*Sqr(g1)) * tmp_760;
   }
   if (gO1 < 3) {
      std::complex<double> tmp_762;
      std::complex<double> tmp_763;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_763 += Conj(ZD(gI2,j1))*ZD(gI1,j1);
      }
      tmp_762 += tmp_763;
      result += (-0.125*KroneckerDelta(gO1,gO2)*Sqr(g2)) * tmp_762;
   }
   if (gO1 < 3) {
      std::complex<double> tmp_764;
      std::complex<double> tmp_765;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_765 += Conj(ZD(gI2,3 + j1))*ZD(gI1,3 + j1);
      }
      tmp_764 += tmp_765;
      result += (0.05*KroneckerDelta(gO1,gO2)*Sqr(g1)) * tmp_764;
   }
   if (gO1 < 3) {
      std::complex<double> tmp_766;
      std::complex<double> tmp_767;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         tmp_767 += Conj(ZD(gI2,j2))*ZD(gI1,j2);
      }
      tmp_766 += tmp_767;
      result += (0.025*KroneckerDelta(gO1,gO2)*Sqr(g1)) * tmp_766;
   }
   if (gO1 < 3) {
      std::complex<double> tmp_768;
      std::complex<double> tmp_769;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         tmp_769 += Conj(ZD(gI2,j2))*ZD(gI1,j2);
      }
      tmp_768 += tmp_769;
      result += (-0.125*KroneckerDelta(gO1,gO2)*Sqr(g2)) * tmp_768;
   }
   if (gO1 < 3) {
      std::complex<double> tmp_770;
      std::complex<double> tmp_771;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         tmp_771 += Conj(ZD(gI2,3 + j2))*ZD(gI1,3 + j2);
      }
      tmp_770 += tmp_771;
      result += (0.05*KroneckerDelta(gO1,gO2)*Sqr(g1)) * tmp_770;
   }
   if (gO1 < 3) {
      std::complex<double> tmp_772;
      std::complex<double> tmp_774;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_774 += KroneckerDelta(gO2,3 + j1)*Ye(j1,gO1);
      }
      tmp_772 += tmp_774;
      std::complex<double> tmp_773;
      std::complex<double> tmp_775;
      for (unsigned j4 = 0; j4 < 3; ++j4) {
         std::complex<double> tmp_776;
         std::complex<double> tmp_777;
         for (unsigned j3 = 0; j3 < 3; ++j3) {
            tmp_777 += Conj(Yd(j3,j4))*Conj(ZD(gI2,3 + j3));
         }
         tmp_776 += tmp_777;
         tmp_775 += (ZD(gI1,j4)) * tmp_776;
      }
      tmp_773 += tmp_775;
      result += (-1) * tmp_772 * tmp_773;
   }
   if (gO2 < 3) {
      std::complex<double> tmp_778;
      std::complex<double> tmp_780;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         std::complex<double> tmp_781;
         std::complex<double> tmp_782;
         for (unsigned j1 = 0; j1 < 3; ++j1) {
            tmp_782 += Yd(j1,j2)*ZD(gI1,3 + j1);
         }
         tmp_781 += tmp_782;
         tmp_780 += (Conj(ZD(gI2,j2))) * tmp_781;
      }
      tmp_778 += tmp_780;
      std::complex<double> tmp_779;
      std::complex<double> tmp_783;
      for (unsigned j3 = 0; j3 < 3; ++j3) {
         tmp_783 += Conj(Ye(j3,gO2))*KroneckerDelta(gO1,3 + j3);
      }
      tmp_779 += tmp_783;
      result += (-1) * tmp_778 * tmp_779;
   }

   return result;
}

std::complex<double> CLASSNAME::CpUSeconjUSeconjSeSe(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_784;
   std::complex<double> tmp_786;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_786 += KroneckerDelta(gO1,3 + j1)*ZE(gI1,3 + j1);
   }
   tmp_784 += tmp_786;
   std::complex<double> tmp_785;
   std::complex<double> tmp_787;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      tmp_787 += Conj(ZE(gI2,3 + j2))*KroneckerDelta(gO2,3 + j2);
   }
   tmp_785 += tmp_787;
   result += (-0.3*Sqr(g1)) * tmp_784 * tmp_785;
   std::complex<double> tmp_788;
   std::complex<double> tmp_790;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_790 += Conj(ZE(gI2,j1))*ZE(gI1,j1);
   }
   tmp_788 += tmp_790;
   std::complex<double> tmp_789;
   std::complex<double> tmp_791;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      tmp_791 += KroneckerDelta(gO1,3 + j2)*KroneckerDelta(gO2,3 + j2);
   }
   tmp_789 += tmp_791;
   result += (0.15*Sqr(g1)) * tmp_788 * tmp_789;
   std::complex<double> tmp_792;
   std::complex<double> tmp_794;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_794 += Conj(ZE(gI2,3 + j1))*ZE(gI1,3 + j1);
   }
   tmp_792 += tmp_794;
   std::complex<double> tmp_793;
   std::complex<double> tmp_795;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      tmp_795 += KroneckerDelta(gO1,3 + j2)*KroneckerDelta(gO2,3 + j2);
   }
   tmp_793 += tmp_795;
   result += (-0.3*Sqr(g1)) * tmp_792 * tmp_793;
   std::complex<double> tmp_796;
   std::complex<double> tmp_798;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_798 += KroneckerDelta(gO1,3 + j1)*KroneckerDelta(gO2,3 + j1);
   }
   tmp_796 += tmp_798;
   std::complex<double> tmp_797;
   std::complex<double> tmp_799;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      tmp_799 += Conj(ZE(gI2,j2))*ZE(gI1,j2);
   }
   tmp_797 += tmp_799;
   result += (0.15*Sqr(g1)) * tmp_796 * tmp_797;
   std::complex<double> tmp_800;
   std::complex<double> tmp_802;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_802 += KroneckerDelta(gO1,3 + j1)*KroneckerDelta(gO2,3 + j1);
   }
   tmp_800 += tmp_802;
   std::complex<double> tmp_801;
   std::complex<double> tmp_803;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      tmp_803 += Conj(ZE(gI2,3 + j2))*ZE(gI1,3 + j2);
   }
   tmp_801 += tmp_803;
   result += (-0.3*Sqr(g1)) * tmp_800 * tmp_801;
   std::complex<double> tmp_804;
   std::complex<double> tmp_806;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_806 += Conj(ZE(gI2,3 + j1))*KroneckerDelta(gO2,3 + j1);
   }
   tmp_804 += tmp_806;
   std::complex<double> tmp_805;
   std::complex<double> tmp_807;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      tmp_807 += KroneckerDelta(gO1,3 + j2)*ZE(gI1,3 + j2);
   }
   tmp_805 += tmp_807;
   result += (-0.3*Sqr(g1)) * tmp_804 * tmp_805;
   std::complex<double> tmp_808;
   std::complex<double> tmp_810;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_811;
      std::complex<double> tmp_812;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_812 += KroneckerDelta(gO2,3 + j1)*Ye(j1,j2);
      }
      tmp_811 += tmp_812;
      tmp_810 += (Conj(ZE(gI2,j2))) * tmp_811;
   }
   tmp_808 += tmp_810;
   std::complex<double> tmp_809;
   std::complex<double> tmp_813;
   for (unsigned j4 = 0; j4 < 3; ++j4) {
      std::complex<double> tmp_814;
      std::complex<double> tmp_815;
      for (unsigned j3 = 0; j3 < 3; ++j3) {
         tmp_815 += Conj(Ye(j3,j4))*KroneckerDelta(gO1,3 + j3);
      }
      tmp_814 += tmp_815;
      tmp_813 += (ZE(gI1,j4)) * tmp_814;
   }
   tmp_809 += tmp_813;
   result += (-1) * tmp_808 * tmp_809;
   if (gO1 < 3) {
      std::complex<double> tmp_816;
      std::complex<double> tmp_817;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_817 += Conj(ZE(gI2,j1))*ZE(gI1,j1);
      }
      tmp_816 += tmp_817;
      result += (-0.075*KroneckerDelta(gO1,gO2)*Sqr(g1)) * tmp_816;
   }
   if (gO1 < 3) {
      std::complex<double> tmp_818;
      std::complex<double> tmp_819;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_819 += Conj(ZE(gI2,j1))*ZE(gI1,j1);
      }
      tmp_818 += tmp_819;
      result += (-0.125*KroneckerDelta(gO1,gO2)*Sqr(g2)) * tmp_818;
   }
   if (gO1 < 3) {
      std::complex<double> tmp_820;
      std::complex<double> tmp_821;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_821 += Conj(ZE(gI2,3 + j1))*ZE(gI1,3 + j1);
      }
      tmp_820 += tmp_821;
      result += (0.15*KroneckerDelta(gO1,gO2)*Sqr(g1)) * tmp_820;
   }
   if (gO1 < 3) {
      std::complex<double> tmp_822;
      std::complex<double> tmp_823;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         tmp_823 += Conj(ZE(gI2,j2))*ZE(gI1,j2);
      }
      tmp_822 += tmp_823;
      result += (-0.075*KroneckerDelta(gO1,gO2)*Sqr(g1)) * tmp_822;
   }
   if (gO1 < 3) {
      std::complex<double> tmp_824;
      std::complex<double> tmp_825;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         tmp_825 += Conj(ZE(gI2,j2))*ZE(gI1,j2);
      }
      tmp_824 += tmp_825;
      result += (-0.125*KroneckerDelta(gO1,gO2)*Sqr(g2)) * tmp_824;
   }
   if (gO1 < 3) {
      std::complex<double> tmp_826;
      std::complex<double> tmp_827;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         tmp_827 += Conj(ZE(gI2,3 + j2))*ZE(gI1,3 + j2);
      }
      tmp_826 += tmp_827;
      result += (0.15*KroneckerDelta(gO1,gO2)*Sqr(g1)) * tmp_826;
   }
   if (gO1 < 3) {
      std::complex<double> tmp_828;
      std::complex<double> tmp_830;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_830 += KroneckerDelta(gO2,3 + j1)*Ye(j1,gO1);
      }
      tmp_828 += tmp_830;
      std::complex<double> tmp_829;
      std::complex<double> tmp_831;
      for (unsigned j4 = 0; j4 < 3; ++j4) {
         std::complex<double> tmp_832;
         std::complex<double> tmp_833;
         for (unsigned j3 = 0; j3 < 3; ++j3) {
            tmp_833 += Conj(Ye(j3,j4))*Conj(ZE(gI2,3 + j3));
         }
         tmp_832 += tmp_833;
         tmp_831 += (ZE(gI1,j4)) * tmp_832;
      }
      tmp_829 += tmp_831;
      result += (-1) * tmp_828 * tmp_829;
   }
   if (gO2 < 3) {
      std::complex<double> tmp_834;
      std::complex<double> tmp_835;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_835 += KroneckerDelta(gO1,3 + j1)*ZE(gI1,3 + j1);
      }
      tmp_834 += tmp_835;
      result += (0.15*Conj(ZE(gI2,gO2))*Sqr(g1)) * tmp_834;
   }
   if (gO2 < 3) {
      std::complex<double> tmp_836;
      std::complex<double> tmp_837;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         tmp_837 += KroneckerDelta(gO1,3 + j2)*ZE(gI1,3 + j2);
      }
      tmp_836 += tmp_837;
      result += (0.15*Conj(ZE(gI2,gO2))*Sqr(g1)) * tmp_836;
   }
   if (gO2 < 3) {
      std::complex<double> tmp_838;
      std::complex<double> tmp_840;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         std::complex<double> tmp_841;
         std::complex<double> tmp_842;
         for (unsigned j1 = 0; j1 < 3; ++j1) {
            tmp_842 += Ye(j1,j2)*ZE(gI1,3 + j1);
         }
         tmp_841 += tmp_842;
         tmp_840 += (Conj(ZE(gI2,j2))) * tmp_841;
      }
      tmp_838 += tmp_840;
      std::complex<double> tmp_839;
      std::complex<double> tmp_843;
      for (unsigned j3 = 0; j3 < 3; ++j3) {
         tmp_843 += Conj(Ye(j3,gO2))*KroneckerDelta(gO1,3 + j3);
      }
      tmp_839 += tmp_843;
      result += (-1) * tmp_838 * tmp_839;
   }
   if (gO1 < 3 && gO2 < 3) {
      std::complex<double> tmp_844;
      std::complex<double> tmp_846;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_846 += Ye(j1,gO1)*ZE(gI1,3 + j1);
      }
      tmp_844 += tmp_846;
      std::complex<double> tmp_845;
      std::complex<double> tmp_847;
      for (unsigned j3 = 0; j3 < 3; ++j3) {
         tmp_847 += Conj(Ye(j3,gO2))*Conj(ZE(gI2,3 + j3));
      }
      tmp_845 += tmp_847;
      result += (-1) * tmp_844 * tmp_845;
   }
   if (gO1 < 3) {
      std::complex<double> tmp_848;
      std::complex<double> tmp_849;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_849 += Conj(ZE(gI2,3 + j1))*KroneckerDelta(gO2,3 + j1);
      }
      tmp_848 += tmp_849;
      result += (0.15*Sqr(g1)*ZE(gI1,gO1)) * tmp_848;
   }
   if (gO1 < 3) {
      std::complex<double> tmp_850;
      std::complex<double> tmp_851;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         tmp_851 += Conj(ZE(gI2,3 + j2))*KroneckerDelta(gO2,3 + j2);
      }
      tmp_850 += tmp_851;
      result += (0.15*Sqr(g1)*ZE(gI1,gO1)) * tmp_850;
   }
   if (gO1 < 3 && gO2 < 3) {
      result += -0.15*Conj(ZE(gI2,gO2))*Sqr(g1)*ZE(gI1,gO1);
   }
   if (gO1 < 3 && gO2 < 3) {
      result += -0.25*Conj(ZE(gI2,gO2))*Sqr(g2)*ZE(gI1,gO1);
   }

   return result;
}

std::complex<double> CLASSNAME::CpUSeconjUSeconjSuSu(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_852;
   std::complex<double> tmp_854;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_854 += Conj(ZU(gI2,j1))*ZU(gI1,j1);
   }
   tmp_852 += tmp_854;
   std::complex<double> tmp_853;
   std::complex<double> tmp_855;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      tmp_855 += KroneckerDelta(gO1,3 + j2)*KroneckerDelta(gO2,3 + j2);
   }
   tmp_853 += tmp_855;
   result += (-0.05*Sqr(g1)) * tmp_852 * tmp_853;
   std::complex<double> tmp_856;
   std::complex<double> tmp_858;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_858 += Conj(ZU(gI2,3 + j1))*ZU(gI1,3 + j1);
   }
   tmp_856 += tmp_858;
   std::complex<double> tmp_857;
   std::complex<double> tmp_859;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      tmp_859 += KroneckerDelta(gO1,3 + j2)*KroneckerDelta(gO2,3 + j2);
   }
   tmp_857 += tmp_859;
   result += (0.2*Sqr(g1)) * tmp_856 * tmp_857;
   std::complex<double> tmp_860;
   std::complex<double> tmp_862;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_862 += KroneckerDelta(gO1,3 + j1)*KroneckerDelta(gO2,3 + j1);
   }
   tmp_860 += tmp_862;
   std::complex<double> tmp_861;
   std::complex<double> tmp_863;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      tmp_863 += Conj(ZU(gI2,j2))*ZU(gI1,j2);
   }
   tmp_861 += tmp_863;
   result += (-0.05*Sqr(g1)) * tmp_860 * tmp_861;
   std::complex<double> tmp_864;
   std::complex<double> tmp_866;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_866 += KroneckerDelta(gO1,3 + j1)*KroneckerDelta(gO2,3 + j1);
   }
   tmp_864 += tmp_866;
   std::complex<double> tmp_865;
   std::complex<double> tmp_867;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      tmp_867 += Conj(ZU(gI2,3 + j2))*ZU(gI1,3 + j2);
   }
   tmp_865 += tmp_867;
   result += (0.2*Sqr(g1)) * tmp_864 * tmp_865;
   if (gO1 < 3) {
      std::complex<double> tmp_868;
      std::complex<double> tmp_869;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_869 += Conj(ZU(gI2,j1))*ZU(gI1,j1);
      }
      tmp_868 += tmp_869;
      result += (0.025*KroneckerDelta(gO1,gO2)*Sqr(g1)) * tmp_868;
   }
   if (gO1 < 3) {
      std::complex<double> tmp_870;
      std::complex<double> tmp_871;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_871 += Conj(ZU(gI2,j1))*ZU(gI1,j1);
      }
      tmp_870 += tmp_871;
      result += (0.125*KroneckerDelta(gO1,gO2)*Sqr(g2)) * tmp_870;
   }
   if (gO1 < 3) {
      std::complex<double> tmp_872;
      std::complex<double> tmp_873;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_873 += Conj(ZU(gI2,3 + j1))*ZU(gI1,3 + j1);
      }
      tmp_872 += tmp_873;
      result += (-0.1*KroneckerDelta(gO1,gO2)*Sqr(g1)) * tmp_872;
   }
   if (gO1 < 3) {
      std::complex<double> tmp_874;
      std::complex<double> tmp_875;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         tmp_875 += Conj(ZU(gI2,j2))*ZU(gI1,j2);
      }
      tmp_874 += tmp_875;
      result += (0.025*KroneckerDelta(gO1,gO2)*Sqr(g1)) * tmp_874;
   }
   if (gO1 < 3) {
      std::complex<double> tmp_876;
      std::complex<double> tmp_877;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         tmp_877 += Conj(ZU(gI2,j2))*ZU(gI1,j2);
      }
      tmp_876 += tmp_877;
      result += (0.125*KroneckerDelta(gO1,gO2)*Sqr(g2)) * tmp_876;
   }
   if (gO1 < 3) {
      std::complex<double> tmp_878;
      std::complex<double> tmp_879;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         tmp_879 += Conj(ZU(gI2,3 + j2))*ZU(gI1,3 + j2);
      }
      tmp_878 += tmp_879;
      result += (-0.1*KroneckerDelta(gO1,gO2)*Sqr(g1)) * tmp_878;
   }

   return result;
}

std::complex<double> CLASSNAME::CpconjUSeSeRh(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gO2 < 3) {
      std::complex<double> tmp_880;
      std::complex<double> tmp_881;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_881 += Conj(Ye(j1,gO2))*Conj(ZE(gI1,3 + j1));
      }
      tmp_880 += tmp_881;
      result += (MuD*ZHR(gI2,0)) * tmp_880;
   }
   if (gO2 < 3) {
      std::complex<double> tmp_882;
      std::complex<double> tmp_883;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_883 += Conj(Ye(j1,gO2))*Conj(ZE(gI1,3 + j1));
      }
      tmp_882 += tmp_883;
      result += (0.7071067811865475*LamSD*vS*ZHR(gI2,0)) * tmp_882;
   }
   if (gO2 < 3) {
      std::complex<double> tmp_884;
      std::complex<double> tmp_885;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_885 += Conj(Ye(j1,gO2))*Conj(ZE(gI1,3 + j1));
      }
      tmp_884 += tmp_885;
      result += (0.5*LamTD*vT*ZHR(gI2,0)) * tmp_884;
   }

   return result;
}

std::complex<double> CLASSNAME::CpconjUSeSeAh(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_886;
   std::complex<double> tmp_887;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_888;
      std::complex<double> tmp_889;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_889 += KroneckerDelta(gO2,3 + j1)*Ye(j1,j2);
      }
      tmp_888 += tmp_889;
      tmp_887 += (Conj(ZE(gI1,j2))) * tmp_888;
   }
   tmp_886 += tmp_887;
   result += (std::complex<double>(0.,-0.7071067811865475)*Conj(Mu)*ZA(gI2,1))
      * tmp_886;
   if (gO2 < 3) {
      std::complex<double> tmp_890;
      std::complex<double> tmp_891;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_891 += Conj(Ye(j1,gO2))*Conj(ZE(gI1,3 + j1));
      }
      tmp_890 += tmp_891;
      result += (std::complex<double>(0.,0.7071067811865475)*Mu*ZA(gI2,1)) *
         tmp_890;
   }
   std::complex<double> tmp_892;
   std::complex<double> tmp_893;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_893 += Conj(ZE(gI1,3 + j1))*KroneckerDelta(gO2,3 + j1);
   }
   tmp_892 += tmp_893;
   result += (std::complex<double>(0.,-0.7745966692414834)*g1*MDBS*ZA(gI2,2)) *
      tmp_892;
   std::complex<double> tmp_894;
   std::complex<double> tmp_895;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_895 += Conj(ZE(gI1,3 + j1))*KroneckerDelta(gO2,3 + j1);
   }
   tmp_894 += tmp_895;
   result += (std::complex<double>(0.,0.7745966692414834)*g1*Conj(MDBS)*ZA(gI2,
      2)) * tmp_894;
   if (gO2 < 3) {
      result += std::complex<double>(0.,0.3872983346207417)*g1*MDBS*Conj(ZE(
         gI1,gO2))*ZA(gI2,2);
   }
   if (gO2 < 3) {
      result += std::complex<double>(0.,-0.3872983346207417)*g1*Conj(MDBS)*
         Conj(ZE(gI1,gO2))*ZA(gI2,2);
   }
   if (gO2 < 3) {
      result += std::complex<double>(0,0.5)*g2*MDWBT*Conj(ZE(gI1,gO2))*ZA(
         gI2,3);
   }
   if (gO2 < 3) {
      result += std::complex<double>(0,-0.5)*g2*Conj(MDWBT)*Conj(ZE(gI1,gO2)
         )*ZA(gI2,3);
   }

   return result;
}

std::complex<double> CLASSNAME::CpconjUSeSehh(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_896;
   std::complex<double> tmp_897;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_897 += Conj(ZE(gI1,3 + j1))*KroneckerDelta(gO2,3 + j1);
   }
   tmp_896 += tmp_897;
   result += (0.3*vd*Sqr(g1)*ZH(gI2,0)) * tmp_896;
   std::complex<double> tmp_898;
   std::complex<double> tmp_899;
   for (unsigned j3 = 0; j3 < 3; ++j3) {
      std::complex<double> tmp_900;
      std::complex<double> tmp_901;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         std::complex<double> tmp_902;
         std::complex<double> tmp_903;
         for (unsigned j1 = 0; j1 < 3; ++j1) {
            tmp_903 += Conj(Ye(j3,j1))*Ye(j2,j1);
         }
         tmp_902 += tmp_903;
         tmp_901 += (KroneckerDelta(gO2,3 + j2)) * tmp_902;
      }
      tmp_900 += tmp_901;
      tmp_899 += (Conj(ZE(gI1,3 + j3))) * tmp_900;
   }
   tmp_898 += tmp_899;
   result += (-(vd*ZH(gI2,0))) * tmp_898;
   if (gO2 < 3) {
      result += -0.15*vd*Conj(ZE(gI1,gO2))*Sqr(g1)*ZH(gI2,0);
   }
   if (gO2 < 3) {
      result += 0.25*vd*Conj(ZE(gI1,gO2))*Sqr(g2)*ZH(gI2,0);
   }
   if (gO2 < 3) {
      std::complex<double> tmp_904;
      std::complex<double> tmp_905;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         std::complex<double> tmp_906;
         std::complex<double> tmp_907;
         for (unsigned j1 = 0; j1 < 3; ++j1) {
            tmp_907 += Conj(Ye(j1,gO2))*Ye(j1,j2);
         }
         tmp_906 += tmp_907;
         tmp_905 += (Conj(ZE(gI1,j2))) * tmp_906;
      }
      tmp_904 += tmp_905;
      result += (-(vd*ZH(gI2,0))) * tmp_904;
   }
   std::complex<double> tmp_908;
   std::complex<double> tmp_909;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_909 += Conj(ZE(gI1,3 + j1))*KroneckerDelta(gO2,3 + j1);
   }
   tmp_908 += tmp_909;
   result += (-0.3*vu*Sqr(g1)*ZH(gI2,1)) * tmp_908;
   std::complex<double> tmp_910;
   std::complex<double> tmp_911;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_912;
      std::complex<double> tmp_913;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_913 += KroneckerDelta(gO2,3 + j1)*Ye(j1,j2);
      }
      tmp_912 += tmp_913;
      tmp_911 += (Conj(ZE(gI1,j2))) * tmp_912;
   }
   tmp_910 += tmp_911;
   result += (0.7071067811865475*Conj(Mu)*ZH(gI2,1)) * tmp_910;
   if (gO2 < 3) {
      result += 0.15*vu*Conj(ZE(gI1,gO2))*Sqr(g1)*ZH(gI2,1);
   }
   if (gO2 < 3) {
      result += -0.25*vu*Conj(ZE(gI1,gO2))*Sqr(g2)*ZH(gI2,1);
   }
   if (gO2 < 3) {
      std::complex<double> tmp_914;
      std::complex<double> tmp_915;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_915 += Conj(Ye(j1,gO2))*Conj(ZE(gI1,3 + j1));
      }
      tmp_914 += tmp_915;
      result += (0.7071067811865475*Mu*ZH(gI2,1)) * tmp_914;
   }
   std::complex<double> tmp_916;
   std::complex<double> tmp_917;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_917 += Conj(ZE(gI1,3 + j1))*KroneckerDelta(gO2,3 + j1);
   }
   tmp_916 += tmp_917;
   result += (-0.7745966692414834*g1*MDBS*ZH(gI2,2)) * tmp_916;
   std::complex<double> tmp_918;
   std::complex<double> tmp_919;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_919 += Conj(ZE(gI1,3 + j1))*KroneckerDelta(gO2,3 + j1);
   }
   tmp_918 += tmp_919;
   result += (-0.7745966692414834*g1*Conj(MDBS)*ZH(gI2,2)) * tmp_918;
   if (gO2 < 3) {
      result += 0.3872983346207417*g1*MDBS*Conj(ZE(gI1,gO2))*ZH(gI2,2);
   }
   if (gO2 < 3) {
      result += 0.3872983346207417*g1*Conj(MDBS)*Conj(ZE(gI1,gO2))*ZH(gI2,2)
         ;
   }
   if (gO2 < 3) {
      result += 0.5*g2*MDWBT*Conj(ZE(gI1,gO2))*ZH(gI2,3);
   }
   if (gO2 < 3) {
      result += 0.5*g2*Conj(MDWBT)*Conj(ZE(gI1,gO2))*ZH(gI2,3);
   }

   return result;
}

std::complex<double> CLASSNAME::CpconjUSeVWmSv(unsigned gO2, unsigned gI2) const
{
   std::complex<double> result;

   if (gO2 < 3) {
      result += 0.7071067811865475*g2*Conj(ZV(gI2,gO2));
   }

   return result;
}

std::complex<double> CLASSNAME::CpconjUSeVPSe(unsigned gO2, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_920;
   std::complex<double> tmp_921;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_921 += Conj(ZE(gI2,3 + j1))*KroneckerDelta(gO2,3 + j1);
   }
   tmp_920 += tmp_921;
   result += (-0.7745966692414834*g1*Cos(ThetaW())) * tmp_920;
   if (gO2 < 3) {
      result += -0.3872983346207417*g1*Conj(ZE(gI2,gO2))*Cos(ThetaW());
   }
   if (gO2 < 3) {
      result += -0.5*g2*Conj(ZE(gI2,gO2))*Sin(ThetaW());
   }

   return result;
}

std::complex<double> CLASSNAME::CpconjUSeVZSe(unsigned gO2, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_922;
   std::complex<double> tmp_923;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_923 += Conj(ZE(gI2,3 + j1))*KroneckerDelta(gO2,3 + j1);
   }
   tmp_922 += tmp_923;
   result += (0.7745966692414834*g1*Sin(ThetaW())) * tmp_922;
   if (gO2 < 3) {
      result += -0.5*g2*Conj(ZE(gI2,gO2))*Cos(ThetaW());
   }
   if (gO2 < 3) {
      result += 0.3872983346207417*g1*Conj(ZE(gI2,gO2))*Sin(ThetaW());
   }

   return result;
}

std::complex<double> CLASSNAME::CpUhhVZVZ(unsigned gO2) const
{
   std::complex<double> result;

   result = 0.05*(vd*KroneckerDelta(0,gO2) + vu*KroneckerDelta(1,gO2))*(
      7.745966692414834*g1*g2*Sin(2*ThetaW()) + 3*Sqr(g1) + 5*Sqr(g2) + Cos(2*
      ThetaW())*(-3*Sqr(g1) + 5*Sqr(g2)));

   return result;
}

std::complex<double> CLASSNAME::CpUhhconjVWmVWm(unsigned gO2) const
{
   std::complex<double> result;

   result = 0.5*(vd*KroneckerDelta(0,gO2) + vu*KroneckerDelta(1,gO2) + 4*vT*
      KroneckerDelta(3,gO2))*Sqr(g2);

   return result;
}

std::complex<double> CLASSNAME::CpUhhbargWmgWm(unsigned gO1) const
{
   std::complex<double> result;

   result = -0.25*(vd*KroneckerDelta(0,gO1) + vu*KroneckerDelta(1,gO1) + 4*vT*
      KroneckerDelta(3,gO1))*Sqr(g2);

   return result;
}

std::complex<double> CLASSNAME::CpUhhbargWmCgWmC(unsigned gO1) const
{
   std::complex<double> result;

   result = -0.25*(vd*KroneckerDelta(0,gO1) + vu*KroneckerDelta(1,gO1) + 4*vT*
      KroneckerDelta(3,gO1))*Sqr(g2);

   return result;
}

std::complex<double> CLASSNAME::CpUhhbargZgZ(unsigned gO1) const
{
   std::complex<double> result;

   result = -0.025*(vd*KroneckerDelta(0,gO1) + vu*KroneckerDelta(1,gO1))*(
      7.745966692414834*g1*g2*Sin(2*ThetaW()) + 3*Sqr(g1) + 5*Sqr(g2) + Cos(2*
      ThetaW())*(-3*Sqr(g1) + 5*Sqr(g2)));

   return result;
}

std::complex<double> CLASSNAME::CpUhhUhhVZVZ(unsigned gO1, unsigned gO2) const
{
   std::complex<double> result;

   result = 0.05*(KroneckerDelta(0,gO1)*KroneckerDelta(0,gO2) + KroneckerDelta(
      1,gO1)*KroneckerDelta(1,gO2))*(7.745966692414834*g1*g2*Sin(2*ThetaW()) + 3*
      Sqr(g1) + 5*Sqr(g2) + Cos(2*ThetaW())*(-3*Sqr(g1) + 5*Sqr(g2)));

   return result;
}

std::complex<double> CLASSNAME::CpUhhUhhconjVWmVWm(unsigned gO1, unsigned gO2) const
{
   std::complex<double> result;

   result = 0.5*(KroneckerDelta(0,gO1)*KroneckerDelta(0,gO2) + KroneckerDelta(1
      ,gO1)*KroneckerDelta(1,gO2) + 4*KroneckerDelta(3,gO1)*KroneckerDelta(3,gO2))
      *Sqr(g2);

   return result;
}

std::complex<double> CLASSNAME::CpUhhUhhconjRhRh(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.05*(-5*(Conj(LamTD)*(1.4142135623730951*LamSD*KroneckerDelta(2,
      gO2)*KroneckerDelta(3,gO1) + (1.4142135623730951*LamSD*KroneckerDelta(2,gO1)
      + 2*LamTD*KroneckerDelta(3,gO1))*KroneckerDelta(3,gO2))*ZHR(gI1,0)*ZHR(gI2,
      0) + Conj(LamSD)*(1.4142135623730951*LamTD*KroneckerDelta(2,gO2)*
      KroneckerDelta(3,gO1) + KroneckerDelta(2,gO1)*(4*LamSD*KroneckerDelta(2,gO2)
      + 1.4142135623730951*LamTD*KroneckerDelta(3,gO2)))*ZHR(gI1,0)*ZHR(gI2,0) +
      (-(Conj(LamTU)*(1.4142135623730951*LamSU*KroneckerDelta(2,gO2)*
      KroneckerDelta(3,gO1) + (1.4142135623730951*LamSU*KroneckerDelta(2,gO1) - 2*
      LamTU*KroneckerDelta(3,gO1))*KroneckerDelta(3,gO2))) - Conj(LamSU)*(
      1.4142135623730951*LamTU*KroneckerDelta(2,gO2)*KroneckerDelta(3,gO1) +
      KroneckerDelta(2,gO1)*(-4*LamSU*KroneckerDelta(2,gO2) + 1.4142135623730951*
      LamTU*KroneckerDelta(3,gO2))))*ZHR(gI1,1)*ZHR(gI2,1)) - KroneckerDelta(1,gO1
      )*(5*KroneckerDelta(0,gO2)*(-2*LamSD*Conj(LamSU)*ZHR(gI1,1)*ZHR(gI2,0) +
      LamTD*Conj(LamTU)*ZHR(gI1,1)*ZHR(gI2,0) + (-2*LamSU*Conj(LamSD) + LamTU*Conj
      (LamTD))*ZHR(gI1,0)*ZHR(gI2,1)) + KroneckerDelta(1,gO2)*((3*Sqr(g1) + 5*Sqr(
      g2))*ZHR(gI1,0)*ZHR(gI2,0) + (20*AbsSqr(LamSU) + 10*AbsSqr(LamTU) - 3*Sqr(g1
      ) - 5*Sqr(g2))*ZHR(gI1,1)*ZHR(gI2,1))) + KroneckerDelta(0,gO1)*(5*
      KroneckerDelta(1,gO2)*(2*LamSD*Conj(LamSU)*ZHR(gI1,1)*ZHR(gI2,0) - LamTD*
      Conj(LamTU)*ZHR(gI1,1)*ZHR(gI2,0) + (2*LamSU*Conj(LamSD) - LamTU*Conj(LamTD)
      )*ZHR(gI1,0)*ZHR(gI2,1)) + KroneckerDelta(0,gO2)*((-20*AbsSqr(LamSD) - 10*
      AbsSqr(LamTD) + 3*Sqr(g1) + 5*Sqr(g2))*ZHR(gI1,0)*ZHR(gI2,0) - (3*Sqr(g1) +
      5*Sqr(g2))*ZHR(gI1,1)*ZHR(gI2,1))));

   return result;
}

std::complex<double> CLASSNAME::CpUhhUhhconjRpmRpm(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.05*(-(Conj(ZRP(gI2,0))*(5*(Conj(LamTU)*(1.4142135623730951*LamSU*
      KroneckerDelta(2,gO2)*KroneckerDelta(3,gO1) + (1.4142135623730951*LamSU*
      KroneckerDelta(2,gO1) + 2*LamTU*KroneckerDelta(3,gO1))*KroneckerDelta(3,gO2)
      ) + Conj(LamSU)*(1.4142135623730951*LamTU*KroneckerDelta(2,gO2)*
      KroneckerDelta(3,gO1) + KroneckerDelta(2,gO1)*(4*LamSU*KroneckerDelta(2,gO2)
      + 1.4142135623730951*LamTU*KroneckerDelta(3,gO2)))) + KroneckerDelta(0,gO1)
      *KroneckerDelta(0,gO2)*(3*Sqr(g1) - 5*Sqr(g2)) + KroneckerDelta(1,gO1)*
      KroneckerDelta(1,gO2)*(20*AbsSqr(LamTU) - 3*Sqr(g1) + 5*Sqr(g2)))*ZRP(gI1,0)
      ) + Conj(ZRP(gI2,1))*(5*(Conj(LamTD)*(1.4142135623730951*LamSD*
      KroneckerDelta(2,gO2)*KroneckerDelta(3,gO1) + (1.4142135623730951*LamSD*
      KroneckerDelta(2,gO1) - 2*LamTD*KroneckerDelta(3,gO1))*KroneckerDelta(3,gO2)
      ) + Conj(LamSD)*(1.4142135623730951*LamTD*KroneckerDelta(2,gO2)*
      KroneckerDelta(3,gO1) + KroneckerDelta(2,gO1)*(-4*LamSD*KroneckerDelta(2,gO2
      ) + 1.4142135623730951*LamTD*KroneckerDelta(3,gO2)))) + KroneckerDelta(0,gO1
      )*KroneckerDelta(0,gO2)*(-20*AbsSqr(LamTD) + 3*Sqr(g1) - 5*Sqr(g2)) +
      KroneckerDelta(1,gO1)*KroneckerDelta(1,gO2)*(-3*Sqr(g1) + 5*Sqr(g2)))*ZRP(
      gI1,1));

   return result;
}

std::complex<double> CLASSNAME::CpUhhconjRhRh(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.05*(-7.745966692414834*g1*MDBS*KroneckerDelta(2,gO2)*ZHR(gI1,0)*
      ZHR(gI2,0) - 20*vS*AbsSqr(LamSD)*KroneckerDelta(2,gO2)*ZHR(gI1,0)*ZHR(gI2,0)
      - 14.142135623730951*MuD*Conj(LamSD)*KroneckerDelta(2,gO2)*ZHR(gI1,0)*ZHR(
      gI2,0) - 7.0710678118654755*LamTD*vT*Conj(LamSD)*KroneckerDelta(2,gO2)*ZHR(
      gI1,0)*ZHR(gI2,0) - 7.0710678118654755*LamSD*vT*Conj(LamTD)*KroneckerDelta(2
      ,gO2)*ZHR(gI1,0)*ZHR(gI2,0) - 7.745966692414834*g1*Conj(MDBS)*KroneckerDelta
      (2,gO2)*ZHR(gI1,0)*ZHR(gI2,0) - 14.142135623730951*LamSD*Conj(MuD)*
      KroneckerDelta(2,gO2)*ZHR(gI1,0)*ZHR(gI2,0) + 10*g2*MDWBT*KroneckerDelta(3,
      gO2)*ZHR(gI1,0)*ZHR(gI2,0) - 10*vT*AbsSqr(LamTD)*KroneckerDelta(3,gO2)*ZHR(
      gI1,0)*ZHR(gI2,0) - 7.0710678118654755*LamTD*vS*Conj(LamSD)*KroneckerDelta(3
      ,gO2)*ZHR(gI1,0)*ZHR(gI2,0) - 10*MuD*Conj(LamTD)*KroneckerDelta(3,gO2)*ZHR(
      gI1,0)*ZHR(gI2,0) - 7.0710678118654755*LamSD*vS*Conj(LamTD)*KroneckerDelta(3
      ,gO2)*ZHR(gI1,0)*ZHR(gI2,0) + 10*g2*Conj(MDWBT)*KroneckerDelta(3,gO2)*ZHR(
      gI1,0)*ZHR(gI2,0) - 10*LamTD*Conj(MuD)*KroneckerDelta(3,gO2)*ZHR(gI1,0)*ZHR(
      gI2,0) + 7.745966692414834*g1*MDBS*KroneckerDelta(2,gO2)*ZHR(gI1,1)*ZHR(gI2,
      1) - 20*vS*AbsSqr(LamSU)*KroneckerDelta(2,gO2)*ZHR(gI1,1)*ZHR(gI2,1) -
      14.142135623730951*MuU*Conj(LamSU)*KroneckerDelta(2,gO2)*ZHR(gI1,1)*ZHR(gI2,
      1) + 7.0710678118654755*LamTU*vT*Conj(LamSU)*KroneckerDelta(2,gO2)*ZHR(gI1,1
      )*ZHR(gI2,1) + 7.0710678118654755*LamSU*vT*Conj(LamTU)*KroneckerDelta(2,gO2)
      *ZHR(gI1,1)*ZHR(gI2,1) + 7.745966692414834*g1*Conj(MDBS)*KroneckerDelta(2,
      gO2)*ZHR(gI1,1)*ZHR(gI2,1) - 14.142135623730951*LamSU*Conj(MuU)*
      KroneckerDelta(2,gO2)*ZHR(gI1,1)*ZHR(gI2,1) - 10*g2*MDWBT*KroneckerDelta(3,
      gO2)*ZHR(gI1,1)*ZHR(gI2,1) - 10*vT*AbsSqr(LamTU)*KroneckerDelta(3,gO2)*ZHR(
      gI1,1)*ZHR(gI2,1) + 7.0710678118654755*LamTU*vS*Conj(LamSU)*KroneckerDelta(3
      ,gO2)*ZHR(gI1,1)*ZHR(gI2,1) + 10*MuU*Conj(LamTU)*KroneckerDelta(3,gO2)*ZHR(
      gI1,1)*ZHR(gI2,1) + 7.0710678118654755*LamSU*vS*Conj(LamTU)*KroneckerDelta(3
      ,gO2)*ZHR(gI1,1)*ZHR(gI2,1) - 10*g2*Conj(MDWBT)*KroneckerDelta(3,gO2)*ZHR(
      gI1,1)*ZHR(gI2,1) + 10*LamTU*Conj(MuU)*KroneckerDelta(3,gO2)*ZHR(gI1,1)*ZHR(
      gI2,1) + KroneckerDelta(0,gO2)*(ZHR(gI1,0)*(vd*(-20*AbsSqr(LamSD) - 10*
      AbsSqr(LamTD) + 3*Sqr(g1) + 5*Sqr(g2))*ZHR(gI2,0) + 5*vu*(2*LamSU*Conj(LamSD
      ) - LamTU*Conj(LamTD))*ZHR(gI2,1)) + ZHR(gI1,1)*(10*LamSD*vu*Conj(LamSU)*ZHR
      (gI2,0) - 5*LamTD*vu*Conj(LamTU)*ZHR(gI2,0) - vd*(3*Sqr(g1) + 5*Sqr(g2))*ZHR
      (gI2,1))) - KroneckerDelta(1,gO2)*(ZHR(gI1,0)*(vu*(3*Sqr(g1) + 5*Sqr(g2))*
      ZHR(gI2,0) + 5*vd*(-2*LamSU*Conj(LamSD) + LamTU*Conj(LamTD))*ZHR(gI2,1)) +
      ZHR(gI1,1)*(-(vu*(3*Sqr(g1) + 5*Sqr(g2))*ZHR(gI2,1)) - 10*Conj(LamSU)*(LamSD
      *vd*ZHR(gI2,0) - 2*LamSU*vu*ZHR(gI2,1)) + 5*Conj(LamTU)*(LamTD*vd*ZHR(gI2,0)
      + 2*LamTU*vu*ZHR(gI2,1)))));

   return result;
}

std::complex<double> CLASSNAME::CpUhhconjRpmRpm(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.05*(-(Conj(ZRP(gI2,0))*(-7.745966692414834*g1*MDBS*KroneckerDelta
      (2,gO2) + 20*vS*AbsSqr(LamSU)*KroneckerDelta(2,gO2) + 14.142135623730951*MuU
      *Conj(LamSU)*KroneckerDelta(2,gO2) + 7.0710678118654755*LamTU*vT*Conj(LamSU)
      *KroneckerDelta(2,gO2) + 7.0710678118654755*LamSU*vT*Conj(LamTU)*
      KroneckerDelta(2,gO2) - 7.745966692414834*g1*Conj(MDBS)*KroneckerDelta(2,gO2
      ) + 14.142135623730951*LamSU*Conj(MuU)*KroneckerDelta(2,gO2) - 10*g2*MDWBT*
      KroneckerDelta(3,gO2) + 10*vT*AbsSqr(LamTU)*KroneckerDelta(3,gO2) +
      7.0710678118654755*LamTU*vS*Conj(LamSU)*KroneckerDelta(3,gO2) + 10*MuU*Conj(
      LamTU)*KroneckerDelta(3,gO2) + 7.0710678118654755*LamSU*vS*Conj(LamTU)*
      KroneckerDelta(3,gO2) - 10*g2*Conj(MDWBT)*KroneckerDelta(3,gO2) + 10*LamTU*
      Conj(MuU)*KroneckerDelta(3,gO2) + vd*KroneckerDelta(0,gO2)*(3*Sqr(g1) - 5*
      Sqr(g2)) + vu*KroneckerDelta(1,gO2)*(20*AbsSqr(LamTU) - 3*Sqr(g1) + 5*Sqr(g2
      )))*ZRP(gI1,0)) + Conj(ZRP(gI2,1))*(-7.745966692414834*g1*MDBS*
      KroneckerDelta(2,gO2) - 20*vS*AbsSqr(LamSD)*KroneckerDelta(2,gO2) -
      14.142135623730951*MuD*Conj(LamSD)*KroneckerDelta(2,gO2) +
      7.0710678118654755*LamTD*vT*Conj(LamSD)*KroneckerDelta(2,gO2) +
      7.0710678118654755*LamSD*vT*Conj(LamTD)*KroneckerDelta(2,gO2) -
      7.745966692414834*g1*Conj(MDBS)*KroneckerDelta(2,gO2) - 14.142135623730951*
      LamSD*Conj(MuD)*KroneckerDelta(2,gO2) - 10*g2*MDWBT*KroneckerDelta(3,gO2) -
      10*vT*AbsSqr(LamTD)*KroneckerDelta(3,gO2) + 7.0710678118654755*LamTD*vS*Conj
      (LamSD)*KroneckerDelta(3,gO2) + 10*MuD*Conj(LamTD)*KroneckerDelta(3,gO2) +
      7.0710678118654755*LamSD*vS*Conj(LamTD)*KroneckerDelta(3,gO2) - 10*g2*Conj(
      MDWBT)*KroneckerDelta(3,gO2) + 10*LamTD*Conj(MuD)*KroneckerDelta(3,gO2) + vd
      *KroneckerDelta(0,gO2)*(-20*AbsSqr(LamTD) + 3*Sqr(g1) - 5*Sqr(g2)) +
      KroneckerDelta(1,gO2)*(-3*vu*Sqr(g1) + 5*vu*Sqr(g2)))*ZRP(gI1,1));

   return result;
}

std::complex<double> CLASSNAME::CpUhhbarCha1Cha1PR(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.5*(KroneckerDelta(3,gO2)*(-2*g2*UM1(gI2,0)*UP1(gI1,0) + Conj(
      LamTD)*UM1(gI2,1)*UP1(gI1,1)) - 1.4142135623730951*(Conj(LamSD)*
      KroneckerDelta(2,gO2)*UM1(gI2,1)*UP1(gI1,1) + KroneckerDelta(0,gO2)*(g2*UM1(
      gI2,1)*UP1(gI1,0) + Conj(LamTD)*UM1(gI2,0)*UP1(gI1,1))));

   return result;
}

std::complex<double> CLASSNAME::CpUhhbarCha1Cha1PL(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.5*(-(Conj(UM1(gI1,0))*(1.4142135623730951*LamTD*Conj(UP1(gI2,1))*
      KroneckerDelta(0,gO1) + 2*g2*Conj(UP1(gI2,0))*KroneckerDelta(3,gO1))) - Conj
      (UM1(gI1,1))*(1.4142135623730951*g2*Conj(UP1(gI2,0))*KroneckerDelta(0,gO1) +
      Conj(UP1(gI2,1))*(1.4142135623730951*LamSD*KroneckerDelta(2,gO1) - LamTD*
      KroneckerDelta(3,gO1))));

   return result;
}

std::complex<double> CLASSNAME::CpUhhbarCha2Cha2PR(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.5*(KroneckerDelta(3,gO2)*(2*g2*UM2(gI1,0)*UP2(gI2,0) + Conj(LamTU
      )*UM2(gI1,1)*UP2(gI2,1)) + 1.4142135623730951*(Conj(LamTU)*KroneckerDelta(1,
      gO2)*UM2(gI1,1)*UP2(gI2,0) + (-(g2*KroneckerDelta(1,gO2)*UM2(gI1,0)) + Conj(
      LamSU)*KroneckerDelta(2,gO2)*UM2(gI1,1))*UP2(gI2,1)));

   return result;
}

std::complex<double> CLASSNAME::CpUhhbarCha2Cha2PL(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.5*(g2*Conj(UM2(gI2,0))*(-1.4142135623730951*Conj(UP2(gI1,1))*
      KroneckerDelta(1,gO1) + 2*Conj(UP2(gI1,0))*KroneckerDelta(3,gO1)) + Conj(UM2
      (gI2,1))*(1.4142135623730951*LamTU*Conj(UP2(gI1,0))*KroneckerDelta(1,gO1) +
      Conj(UP2(gI1,1))*(1.4142135623730951*LamSU*KroneckerDelta(2,gO1) + LamTU*
      KroneckerDelta(3,gO1))));

   return result;
}

std::complex<double> CLASSNAME::CpUhhconjRhAh(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = std::complex<double>(0,-0.25)*Mu*(2*Conj(LamSD)*(KroneckerDelta(2,
      gO2)*ZA(gI2,1) - KroneckerDelta(1,gO2)*ZA(gI2,2))*ZHR(gI1,0) +
      1.4142135623730951*Conj(LamTD)*(KroneckerDelta(3,gO2)*ZA(gI2,1) -
      KroneckerDelta(1,gO2)*ZA(gI2,3))*ZHR(gI1,0) + (Conj(LamSU)*(-2*
      KroneckerDelta(2,gO2)*ZA(gI2,0) + 2*KroneckerDelta(0,gO2)*ZA(gI2,2)) +
      1.4142135623730951*Conj(LamTU)*(KroneckerDelta(3,gO2)*ZA(gI2,0) -
      KroneckerDelta(0,gO2)*ZA(gI2,3)))*ZHR(gI1,1));

   return result;
}

std::complex<double> CLASSNAME::CpUhhconjRhhh(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = -0.25*Mu*(2*Conj(LamSD)*(KroneckerDelta(2,gO2)*ZH(gI2,1) +
      KroneckerDelta(1,gO2)*ZH(gI2,2))*ZHR(gI1,0) + 1.4142135623730951*Conj(LamTD)
      *(KroneckerDelta(3,gO2)*ZH(gI2,1) + KroneckerDelta(1,gO2)*ZH(gI2,3))*ZHR(gI1
      ,0) + (-2*Conj(LamSU)*(KroneckerDelta(2,gO2)*ZH(gI2,0) + KroneckerDelta(0,
      gO2)*ZH(gI2,2)) + 1.4142135623730951*Conj(LamTU)*(KroneckerDelta(3,gO2)*ZH(
      gI2,0) + KroneckerDelta(0,gO2)*ZH(gI2,3)))*ZHR(gI1,1));

   return result;
}

std::complex<double> CLASSNAME::CpUhhconjRpmHpm(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.5*(1.4142135623730951*Conj(LamSU)*KroneckerDelta(2,gO2)*Mu*ZP(gI2
      ,0)*ZRP(gI1,0) + Conj(LamTU)*Mu*(KroneckerDelta(3,gO2)*ZP(gI2,0) -
      1.4142135623730951*KroneckerDelta(0,gO2)*ZP(gI2,3))*ZRP(gI1,0) + Conj(Mu)*(
      -1.4142135623730951*LamSD*KroneckerDelta(2,gO2)*ZP(gI2,1) + LamTD*
      KroneckerDelta(3,gO2)*ZP(gI2,1) + 1.4142135623730951*LamTD*KroneckerDelta(1,
      gO2)*ZP(gI2,2))*ZRP(gI1,1));

   return result;
}

std::complex<double> CLASSNAME::CpUhhUhhconjSvSv(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = -0.05*(KroneckerDelta(0,gO1)*KroneckerDelta(0,gO2) - KroneckerDelta
      (1,gO1)*KroneckerDelta(1,gO2))*KroneckerDelta(gI1,gI2)*(3*Sqr(g1) + 5*Sqr(g2
      ));

   return result;
}

std::complex<double> CLASSNAME::CpUhhconjSvSv(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.05*KroneckerDelta(gI1,gI2)*(2*(3.872983346207417*g1*(MDBS + Conj(
      MDBS))*KroneckerDelta(2,gO2) - 5*g2*(MDWBT + Conj(MDWBT))*KroneckerDelta(3,
      gO2)) - vd*KroneckerDelta(0,gO2)*(3*Sqr(g1) + 5*Sqr(g2)) + vu*KroneckerDelta
      (1,gO2)*(3*Sqr(g1) + 5*Sqr(g2)));

   return result;
}

std::complex<double> CLASSNAME::CpUhhbarFdFdPR(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_924;
   std::complex<double> tmp_925;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_926;
      std::complex<double> tmp_927;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_927 += Conj(Yd(j1,j2))*ZDR(gI2,j1);
      }
      tmp_926 += tmp_927;
      tmp_925 += (ZDL(gI1,j2)) * tmp_926;
   }
   tmp_924 += tmp_925;
   result += (-0.7071067811865475*KroneckerDelta(0,gO2)) * tmp_924;

   return result;
}

std::complex<double> CLASSNAME::CpUhhbarFdFdPL(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_928;
   std::complex<double> tmp_929;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_930;
      std::complex<double> tmp_931;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_931 += Conj(ZDR(gI1,j1))*Yd(j1,j2);
      }
      tmp_930 += tmp_931;
      tmp_929 += (Conj(ZDL(gI2,j2))) * tmp_930;
   }
   tmp_928 += tmp_929;
   result += (-0.7071067811865475*KroneckerDelta(0,gO1)) * tmp_928;

   return result;
}

std::complex<double> CLASSNAME::CpUhhbarFeFePR(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_932;
   std::complex<double> tmp_933;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_934;
      std::complex<double> tmp_935;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_935 += Conj(Ye(j1,j2))*ZER(gI2,j1);
      }
      tmp_934 += tmp_935;
      tmp_933 += (ZEL(gI1,j2)) * tmp_934;
   }
   tmp_932 += tmp_933;
   result += (-0.7071067811865475*KroneckerDelta(0,gO2)) * tmp_932;

   return result;
}

std::complex<double> CLASSNAME::CpUhhbarFeFePL(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_936;
   std::complex<double> tmp_937;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_938;
      std::complex<double> tmp_939;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_939 += Conj(ZER(gI1,j1))*Ye(j1,j2);
      }
      tmp_938 += tmp_939;
      tmp_937 += (Conj(ZEL(gI2,j2))) * tmp_938;
   }
   tmp_936 += tmp_937;
   result += (-0.7071067811865475*KroneckerDelta(0,gO1)) * tmp_936;

   return result;
}

std::complex<double> CLASSNAME::CpUhhbarFuFuPR(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_940;
   std::complex<double> tmp_941;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_942;
      std::complex<double> tmp_943;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_943 += Conj(Yu(j1,j2))*ZUR(gI2,j1);
      }
      tmp_942 += tmp_943;
      tmp_941 += (ZUL(gI1,j2)) * tmp_942;
   }
   tmp_940 += tmp_941;
   result += (-0.7071067811865475*KroneckerDelta(1,gO2)) * tmp_940;

   return result;
}

std::complex<double> CLASSNAME::CpUhhbarFuFuPL(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_944;
   std::complex<double> tmp_945;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_946;
      std::complex<double> tmp_947;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_947 += Conj(ZUR(gI1,j1))*Yu(j1,j2);
      }
      tmp_946 += tmp_947;
      tmp_945 += (Conj(ZUL(gI2,j2))) * tmp_946;
   }
   tmp_944 += tmp_945;
   result += (-0.7071067811865475*KroneckerDelta(1,gO1)) * tmp_944;

   return result;
}

std::complex<double> CLASSNAME::CpUhhUhhAhAh(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.05*(-5*(Conj(LamTD)*(1.4142135623730951*LamSD*KroneckerDelta(2,
      gO2)*KroneckerDelta(3,gO1) + (1.4142135623730951*LamSD*KroneckerDelta(2,gO1)
      + 2*LamTD*KroneckerDelta(3,gO1))*KroneckerDelta(3,gO2))*ZA(gI1,0)*ZA(gI2,0)
      + Conj(LamSD)*(1.4142135623730951*LamTD*KroneckerDelta(2,gO2)*
      KroneckerDelta(3,gO1) + KroneckerDelta(2,gO1)*(4*LamSD*KroneckerDelta(2,gO2)
      + 1.4142135623730951*LamTD*KroneckerDelta(3,gO2)))*ZA(gI1,0)*ZA(gI2,0) + (-
      (Conj(LamTU)*(1.4142135623730951*LamSU*KroneckerDelta(2,gO2)*KroneckerDelta(
      3,gO1) + (1.4142135623730951*LamSU*KroneckerDelta(2,gO1) - 2*LamTU*
      KroneckerDelta(3,gO1))*KroneckerDelta(3,gO2))) - Conj(LamSU)*(
      1.4142135623730951*LamTU*KroneckerDelta(2,gO2)*KroneckerDelta(3,gO1) +
      KroneckerDelta(2,gO1)*(-4*LamSU*KroneckerDelta(2,gO2) + 1.4142135623730951*
      LamTU*KroneckerDelta(3,gO2))))*ZA(gI1,1)*ZA(gI2,1)) - KroneckerDelta(0,gO1)*
      KroneckerDelta(0,gO2)*((3*Sqr(g1) + 5*Sqr(g2))*ZA(gI1,0)*ZA(gI2,0) - (3*Sqr(
      g1) + 5*Sqr(g2))*ZA(gI1,1)*ZA(gI2,1) + 5*(Conj(LamSD)*(1.4142135623730951*
      LamTD*ZA(gI1,3)*ZA(gI2,2) + ZA(gI1,2)*(4*LamSD*ZA(gI2,2) +
      1.4142135623730951*LamTD*ZA(gI2,3))) + Conj(LamTD)*(1.4142135623730951*LamSD
      *ZA(gI1,2)*ZA(gI2,3) + ZA(gI1,3)*(1.4142135623730951*LamSD*ZA(gI2,2) + 2*
      LamTD*ZA(gI2,3))))) + KroneckerDelta(1,gO1)*KroneckerDelta(1,gO2)*((3*Sqr(g1
      ) + 5*Sqr(g2))*ZA(gI1,0)*ZA(gI2,0) - (3*Sqr(g1) + 5*Sqr(g2))*ZA(gI1,1)*ZA(
      gI2,1) + 5*(Conj(LamTU)*(1.4142135623730951*LamSU*ZA(gI1,2)*ZA(gI2,3) + ZA(
      gI1,3)*(1.4142135623730951*LamSU*ZA(gI2,2) - 2*LamTU*ZA(gI2,3))) + Conj(
      LamSU)*(1.4142135623730951*LamTU*ZA(gI1,3)*ZA(gI2,2) + ZA(gI1,2)*(-4*LamSU*
      ZA(gI2,2) + 1.4142135623730951*LamTU*ZA(gI2,3))))));

   return result;
}

std::complex<double> CLASSNAME::CpUhhUhhconjHpmHpm(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.05*(-5*(1.4142135623730951*KroneckerDelta(0,gO2)*KroneckerDelta(3
      ,gO1)*Sqr(g2)*ZP(gI1,2)*ZP(gI2,0) - 1.4142135623730951*KroneckerDelta(0,gO2)
      *KroneckerDelta(3,gO1)*Sqr(g2)*ZP(gI1,3)*ZP(gI2,0) + 4*AbsSqr(LamSU)*
      KroneckerDelta(2,gO1)*KroneckerDelta(2,gO2)*ZP(gI1,1)*ZP(gI2,1) +
      1.4142135623730951*LamTU*Conj(LamSU)*KroneckerDelta(2,gO2)*KroneckerDelta(3,
      gO1)*ZP(gI1,1)*ZP(gI2,1) + 1.4142135623730951*LamSU*Conj(LamTU)*
      KroneckerDelta(2,gO2)*KroneckerDelta(3,gO1)*ZP(gI1,1)*ZP(gI2,1) +
      1.4142135623730951*LamTU*Conj(LamSU)*KroneckerDelta(2,gO1)*KroneckerDelta(3,
      gO2)*ZP(gI1,1)*ZP(gI2,1) + 1.4142135623730951*LamSU*Conj(LamTU)*
      KroneckerDelta(2,gO1)*KroneckerDelta(3,gO2)*ZP(gI1,1)*ZP(gI2,1) + 2*AbsSqr(
      LamTU)*KroneckerDelta(3,gO1)*KroneckerDelta(3,gO2)*ZP(gI1,1)*ZP(gI2,1) + 2*
      LamSU*Conj(LamTU)*KroneckerDelta(1,gO2)*KroneckerDelta(2,gO1)*ZP(gI1,2)*ZP(
      gI2,1) - 1.4142135623730951*AbsSqr(LamTU)*KroneckerDelta(1,gO2)*
      KroneckerDelta(3,gO1)*ZP(gI1,2)*ZP(gI2,1) + 1.4142135623730951*
      KroneckerDelta(1,gO2)*KroneckerDelta(3,gO1)*Sqr(g2)*ZP(gI1,2)*ZP(gI2,1) + 2*
      LamTU*Conj(LamSU)*KroneckerDelta(1,gO2)*KroneckerDelta(2,gO1)*ZP(gI1,3)*ZP(
      gI2,1) + 1.4142135623730951*AbsSqr(LamTU)*KroneckerDelta(1,gO2)*
      KroneckerDelta(3,gO1)*ZP(gI1,3)*ZP(gI2,1) - 1.4142135623730951*
      KroneckerDelta(1,gO2)*KroneckerDelta(3,gO1)*Sqr(g2)*ZP(gI1,3)*ZP(gI2,1) +
      1.4142135623730951*KroneckerDelta(0,gO2)*KroneckerDelta(3,gO1)*Sqr(g2)*ZP(
      gI1,0)*ZP(gI2,2) + 2*LamTU*Conj(LamSU)*KroneckerDelta(1,gO2)*KroneckerDelta(
      2,gO1)*ZP(gI1,1)*ZP(gI2,2) - 1.4142135623730951*AbsSqr(LamTU)*KroneckerDelta
      (1,gO2)*KroneckerDelta(3,gO1)*ZP(gI1,1)*ZP(gI2,2) + 1.4142135623730951*
      KroneckerDelta(1,gO2)*KroneckerDelta(3,gO1)*Sqr(g2)*ZP(gI1,1)*ZP(gI2,2) + 4*
      KroneckerDelta(3,gO1)*KroneckerDelta(3,gO2)*Sqr(g2)*ZP(gI1,2)*ZP(gI2,2) - 4*
      KroneckerDelta(3,gO1)*KroneckerDelta(3,gO2)*Sqr(g2)*ZP(gI1,3)*ZP(gI2,2) +
      Conj(LamSD)*(-1.4142135623730951*LamTD*KroneckerDelta(2,gO2)*KroneckerDelta(
      3,gO1)*ZP(gI1,0)*ZP(gI2,0) + KroneckerDelta(2,gO1)*(4*LamSD*KroneckerDelta(2
      ,gO2)*ZP(gI1,0)*ZP(gI2,0) + LamTD*(-1.4142135623730951*KroneckerDelta(3,gO2)
      *ZP(gI1,0)*ZP(gI2,0) + 2*KroneckerDelta(0,gO2)*(ZP(gI1,3)*ZP(gI2,0) + ZP(gI1
      ,0)*ZP(gI2,2))))) - 1.4142135623730951*KroneckerDelta(0,gO2)*KroneckerDelta(
      3,gO1)*Sqr(g2)*ZP(gI1,0)*ZP(gI2,3) + 2*LamSU*Conj(LamTU)*KroneckerDelta(1,
      gO2)*KroneckerDelta(2,gO1)*ZP(gI1,1)*ZP(gI2,3) + 1.4142135623730951*AbsSqr(
      LamTU)*KroneckerDelta(1,gO2)*KroneckerDelta(3,gO1)*ZP(gI1,1)*ZP(gI2,3) -
      1.4142135623730951*KroneckerDelta(1,gO2)*KroneckerDelta(3,gO1)*Sqr(g2)*ZP(
      gI1,1)*ZP(gI2,3) - 4*KroneckerDelta(3,gO1)*KroneckerDelta(3,gO2)*Sqr(g2)*ZP(
      gI1,2)*ZP(gI2,3) + 4*KroneckerDelta(3,gO1)*KroneckerDelta(3,gO2)*Sqr(g2)*ZP(
      gI1,3)*ZP(gI2,3) + Conj(LamTD)*(-1.4142135623730951*LamSD*KroneckerDelta(2,
      gO2)*KroneckerDelta(3,gO1)*ZP(gI1,0)*ZP(gI2,0) + LamSD*KroneckerDelta(2,gO1)
      *(-1.4142135623730951*KroneckerDelta(3,gO2)*ZP(gI1,0)*ZP(gI2,0) + 2*
      KroneckerDelta(0,gO2)*(ZP(gI1,2)*ZP(gI2,0) + ZP(gI1,0)*ZP(gI2,3))) + LamTD*
      KroneckerDelta(3,gO1)*(2*KroneckerDelta(3,gO2)*ZP(gI1,0)*ZP(gI2,0) +
      1.4142135623730951*KroneckerDelta(0,gO2)*(-(ZP(gI1,2)*ZP(gI2,0)) + ZP(gI1,3)
      *ZP(gI2,0) + ZP(gI1,0)*(-ZP(gI2,2) + ZP(gI2,3)))))) - KroneckerDelta(0,gO1)*
      (KroneckerDelta(0,gO2)*((3*Sqr(g1) + 5*Sqr(g2))*ZP(gI1,0)*ZP(gI2,0) + (-3*
      Sqr(g1) + 5*Sqr(g2))*ZP(gI1,1)*ZP(gI2,1) + 10*(-((-2*AbsSqr(LamTD) + Sqr(g2)
      )*ZP(gI1,2)*ZP(gI2,2)) + Sqr(g2)*ZP(gI1,3)*ZP(gI2,3))) + 5*(
      1.4142135623730951*KroneckerDelta(3,gO2)*Sqr(g2)*ZP(gI1,2)*ZP(gI2,0) + 2*
      LamTD*Conj(LamSD)*KroneckerDelta(2,gO2)*ZP(gI1,3)*ZP(gI2,0) -
      1.4142135623730951*KroneckerDelta(3,gO2)*Sqr(g2)*ZP(gI1,3)*ZP(gI2,0) +
      KroneckerDelta(1,gO2)*Sqr(g2)*(ZP(gI1,1)*ZP(gI2,0) + ZP(gI1,0)*ZP(gI2,1)) +
      2*LamTD*Conj(LamSD)*KroneckerDelta(2,gO2)*ZP(gI1,0)*ZP(gI2,2) +
      1.4142135623730951*KroneckerDelta(3,gO2)*Sqr(g2)*ZP(gI1,0)*ZP(gI2,2) -
      1.4142135623730951*KroneckerDelta(3,gO2)*Sqr(g2)*ZP(gI1,0)*ZP(gI2,3) + Conj(
      LamTD)*(2*LamSD*KroneckerDelta(2,gO2)*(ZP(gI1,2)*ZP(gI2,0) + ZP(gI1,0)*ZP(
      gI2,3)) + 1.4142135623730951*LamTD*KroneckerDelta(3,gO2)*(-(ZP(gI1,2)*ZP(gI2
      ,0)) + ZP(gI1,3)*ZP(gI2,0) + ZP(gI1,0)*(-ZP(gI2,2) + ZP(gI2,3)))))) +
      KroneckerDelta(1,gO1)*(KroneckerDelta(1,gO2)*((3*Sqr(g1) - 5*Sqr(g2))*ZP(gI1
      ,0)*ZP(gI2,0) - (3*Sqr(g1) + 5*Sqr(g2))*ZP(gI1,1)*ZP(gI2,1) - 10*(Sqr(g2)*ZP
      (gI1,2)*ZP(gI2,2) - (-2*AbsSqr(LamTU) + Sqr(g2))*ZP(gI1,3)*ZP(gI2,3))) - 5*(
      1.4142135623730951*KroneckerDelta(3,gO2)*Sqr(g2)*ZP(gI1,2)*ZP(gI2,1) + 2*
      LamTU*Conj(LamSU)*KroneckerDelta(2,gO2)*ZP(gI1,3)*ZP(gI2,1) -
      1.4142135623730951*KroneckerDelta(3,gO2)*Sqr(g2)*ZP(gI1,3)*ZP(gI2,1) +
      KroneckerDelta(0,gO2)*Sqr(g2)*(ZP(gI1,1)*ZP(gI2,0) + ZP(gI1,0)*ZP(gI2,1)) +
      2*LamTU*Conj(LamSU)*KroneckerDelta(2,gO2)*ZP(gI1,1)*ZP(gI2,2) +
      1.4142135623730951*KroneckerDelta(3,gO2)*Sqr(g2)*ZP(gI1,1)*ZP(gI2,2) -
      1.4142135623730951*KroneckerDelta(3,gO2)*Sqr(g2)*ZP(gI1,1)*ZP(gI2,3) + Conj(
      LamTU)*(2*LamSU*KroneckerDelta(2,gO2)*(ZP(gI1,2)*ZP(gI2,1) + ZP(gI1,1)*ZP(
      gI2,3)) + 1.4142135623730951*LamTU*KroneckerDelta(3,gO2)*(-(ZP(gI1,2)*ZP(gI2
      ,1)) + ZP(gI1,3)*ZP(gI2,1) + ZP(gI1,1)*(-ZP(gI2,2) + ZP(gI2,3)))))));

   return result;
}

std::complex<double> CLASSNAME::CpUhhUhhhhhh(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.05*(-5*(4*AbsSqr(LamSU)*KroneckerDelta(2,gO1)*KroneckerDelta(2,
      gO2)*ZH(gI1,1)*ZH(gI2,1) - 1.4142135623730951*LamTU*Conj(LamSU)*
      KroneckerDelta(2,gO2)*KroneckerDelta(3,gO1)*ZH(gI1,1)*ZH(gI2,1) -
      1.4142135623730951*LamSU*Conj(LamTU)*KroneckerDelta(2,gO2)*KroneckerDelta(3,
      gO1)*ZH(gI1,1)*ZH(gI2,1) - 1.4142135623730951*LamTU*Conj(LamSU)*
      KroneckerDelta(2,gO1)*KroneckerDelta(3,gO2)*ZH(gI1,1)*ZH(gI2,1) -
      1.4142135623730951*LamSU*Conj(LamTU)*KroneckerDelta(2,gO1)*KroneckerDelta(3,
      gO2)*ZH(gI1,1)*ZH(gI2,1) + 2*AbsSqr(LamTU)*KroneckerDelta(3,gO1)*
      KroneckerDelta(3,gO2)*ZH(gI1,1)*ZH(gI2,1) + 4*AbsSqr(LamSU)*KroneckerDelta(1
      ,gO2)*KroneckerDelta(2,gO1)*ZH(gI1,2)*ZH(gI2,1) - 1.4142135623730951*LamTU*
      Conj(LamSU)*KroneckerDelta(1,gO2)*KroneckerDelta(3,gO1)*ZH(gI1,2)*ZH(gI2,1)
      - 1.4142135623730951*LamSU*Conj(LamTU)*KroneckerDelta(1,gO2)*KroneckerDelta(
      3,gO1)*ZH(gI1,2)*ZH(gI2,1) - 1.4142135623730951*LamTU*Conj(LamSU)*
      KroneckerDelta(1,gO2)*KroneckerDelta(2,gO1)*ZH(gI1,3)*ZH(gI2,1) -
      1.4142135623730951*LamSU*Conj(LamTU)*KroneckerDelta(1,gO2)*KroneckerDelta(2,
      gO1)*ZH(gI1,3)*ZH(gI2,1) + 2*AbsSqr(LamTU)*KroneckerDelta(1,gO2)*
      KroneckerDelta(3,gO1)*ZH(gI1,3)*ZH(gI2,1) + 4*AbsSqr(LamSU)*KroneckerDelta(1
      ,gO2)*KroneckerDelta(2,gO1)*ZH(gI1,1)*ZH(gI2,2) - 1.4142135623730951*LamTU*
      Conj(LamSU)*KroneckerDelta(1,gO2)*KroneckerDelta(3,gO1)*ZH(gI1,1)*ZH(gI2,2)
      - 1.4142135623730951*LamSU*Conj(LamTU)*KroneckerDelta(1,gO2)*KroneckerDelta(
      3,gO1)*ZH(gI1,1)*ZH(gI2,2) - 1.4142135623730951*LamTU*Conj(LamSU)*
      KroneckerDelta(1,gO2)*KroneckerDelta(2,gO1)*ZH(gI1,1)*ZH(gI2,3) -
      1.4142135623730951*LamSU*Conj(LamTU)*KroneckerDelta(1,gO2)*KroneckerDelta(2,
      gO1)*ZH(gI1,1)*ZH(gI2,3) + 2*AbsSqr(LamTU)*KroneckerDelta(1,gO2)*
      KroneckerDelta(3,gO1)*ZH(gI1,1)*ZH(gI2,3) + Conj(LamSD)*(1.4142135623730951*
      LamTD*KroneckerDelta(3,gO1)*(KroneckerDelta(2,gO2)*ZH(gI1,0)*ZH(gI2,0) +
      KroneckerDelta(0,gO2)*(ZH(gI1,2)*ZH(gI2,0) + ZH(gI1,0)*ZH(gI2,2))) +
      KroneckerDelta(2,gO1)*(4*LamSD*KroneckerDelta(2,gO2)*ZH(gI1,0)*ZH(gI2,0) +
      1.4142135623730951*LamTD*KroneckerDelta(3,gO2)*ZH(gI1,0)*ZH(gI2,0) +
      KroneckerDelta(0,gO2)*(4*LamSD*ZH(gI1,2)*ZH(gI2,0) + 1.4142135623730951*
      LamTD*ZH(gI1,3)*ZH(gI2,0) + ZH(gI1,0)*(4*LamSD*ZH(gI2,2) +
      1.4142135623730951*LamTD*ZH(gI2,3))))) + Conj(LamTD)*(1.4142135623730951*
      LamSD*KroneckerDelta(2,gO2)*KroneckerDelta(3,gO1)*ZH(gI1,0)*ZH(gI2,0) +
      1.4142135623730951*LamSD*KroneckerDelta(2,gO1)*(KroneckerDelta(3,gO2)*ZH(gI1
      ,0)*ZH(gI2,0) + KroneckerDelta(0,gO2)*(ZH(gI1,3)*ZH(gI2,0) + ZH(gI1,0)*ZH(
      gI2,3))) + KroneckerDelta(3,gO1)*(2*LamTD*KroneckerDelta(3,gO2)*ZH(gI1,0)*ZH
      (gI2,0) + KroneckerDelta(0,gO2)*(1.4142135623730951*LamSD*ZH(gI1,2)*ZH(gI2,0
      ) + 2*LamTD*ZH(gI1,3)*ZH(gI2,0) + ZH(gI1,0)*(1.4142135623730951*LamSD*ZH(gI2
      ,2) + 2*LamTD*ZH(gI2,3)))))) - KroneckerDelta(0,gO1)*(-(KroneckerDelta(1,gO2
      )*(3*Sqr(g1) + 5*Sqr(g2))*(ZH(gI1,1)*ZH(gI2,0) + ZH(gI1,0)*ZH(gI2,1))) + 5*(
      Conj(LamSD)*(1.4142135623730951*LamTD*KroneckerDelta(3,gO2)*(ZH(gI1,2)*ZH(
      gI2,0) + ZH(gI1,0)*ZH(gI2,2)) + KroneckerDelta(2,gO2)*(4*LamSD*ZH(gI1,2)*ZH(
      gI2,0) + 1.4142135623730951*LamTD*ZH(gI1,3)*ZH(gI2,0) + ZH(gI1,0)*(4*LamSD*
      ZH(gI2,2) + 1.4142135623730951*LamTD*ZH(gI2,3)))) + Conj(LamTD)*(
      1.4142135623730951*LamSD*KroneckerDelta(2,gO2)*(ZH(gI1,3)*ZH(gI2,0) + ZH(gI1
      ,0)*ZH(gI2,3)) + KroneckerDelta(3,gO2)*(1.4142135623730951*LamSD*ZH(gI1,2)*
      ZH(gI2,0) + 2*LamTD*ZH(gI1,3)*ZH(gI2,0) + ZH(gI1,0)*(1.4142135623730951*
      LamSD*ZH(gI2,2) + 2*LamTD*ZH(gI2,3))))) + KroneckerDelta(0,gO2)*(3*(3*Sqr(g1
      ) + 5*Sqr(g2))*ZH(gI1,0)*ZH(gI2,0) - (3*Sqr(g1) + 5*Sqr(g2))*ZH(gI1,1)*ZH(
      gI2,1) + 5*(Conj(LamSD)*(1.4142135623730951*LamTD*ZH(gI1,3)*ZH(gI2,2) + ZH(
      gI1,2)*(4*LamSD*ZH(gI2,2) + 1.4142135623730951*LamTD*ZH(gI2,3))) + Conj(
      LamTD)*(1.4142135623730951*LamSD*ZH(gI1,2)*ZH(gI2,3) + ZH(gI1,3)*(
      1.4142135623730951*LamSD*ZH(gI2,2) + 2*LamTD*ZH(gI2,3)))))) + KroneckerDelta
      (1,gO1)*(KroneckerDelta(0,gO2)*(3*Sqr(g1) + 5*Sqr(g2))*(ZH(gI1,1)*ZH(gI2,0)
      + ZH(gI1,0)*ZH(gI2,1)) + 5*(Conj(LamTU)*(1.4142135623730951*LamSU*
      KroneckerDelta(2,gO2)*(ZH(gI1,3)*ZH(gI2,1) + ZH(gI1,1)*ZH(gI2,3)) +
      KroneckerDelta(3,gO2)*(1.4142135623730951*LamSU*ZH(gI1,2)*ZH(gI2,1) - 2*
      LamTU*ZH(gI1,3)*ZH(gI2,1) + ZH(gI1,1)*(1.4142135623730951*LamSU*ZH(gI2,2) -
      2*LamTU*ZH(gI2,3)))) + Conj(LamSU)*(1.4142135623730951*LamTU*KroneckerDelta(
      3,gO2)*(ZH(gI1,2)*ZH(gI2,1) + ZH(gI1,1)*ZH(gI2,2)) + KroneckerDelta(2,gO2)*(
      -4*LamSU*ZH(gI1,2)*ZH(gI2,1) + 1.4142135623730951*LamTU*ZH(gI1,3)*ZH(gI2,1)
      + ZH(gI1,1)*(-4*LamSU*ZH(gI2,2) + 1.4142135623730951*LamTU*ZH(gI2,3))))) +
      KroneckerDelta(1,gO2)*((3*Sqr(g1) + 5*Sqr(g2))*ZH(gI1,0)*ZH(gI2,0) - 3*(3*
      Sqr(g1) + 5*Sqr(g2))*ZH(gI1,1)*ZH(gI2,1) + 5*(Conj(LamTU)*(
      1.4142135623730951*LamSU*ZH(gI1,2)*ZH(gI2,3) + ZH(gI1,3)*(1.4142135623730951
      *LamSU*ZH(gI2,2) - 2*LamTU*ZH(gI2,3))) + Conj(LamSU)*(1.4142135623730951*
      LamTU*ZH(gI1,3)*ZH(gI2,2) + ZH(gI1,2)*(-4*LamSU*ZH(gI2,2) +
      1.4142135623730951*LamTU*ZH(gI2,3)))))));

   return result;
}

std::complex<double> CLASSNAME::CpUhhAhAh(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.05*(7.745966692414834*g1*MDBS*KroneckerDelta(2,gO2)*ZA(gI1,0)*ZA(
      gI2,0) - 20*vS*AbsSqr(LamSD)*KroneckerDelta(2,gO2)*ZA(gI1,0)*ZA(gI2,0) -
      14.142135623730951*MuD*Conj(LamSD)*KroneckerDelta(2,gO2)*ZA(gI1,0)*ZA(gI2,0)
      - 7.0710678118654755*LamTD*vT*Conj(LamSD)*KroneckerDelta(2,gO2)*ZA(gI1,0)*
      ZA(gI2,0) - 7.0710678118654755*LamSD*vT*Conj(LamTD)*KroneckerDelta(2,gO2)*ZA
      (gI1,0)*ZA(gI2,0) + 7.745966692414834*g1*Conj(MDBS)*KroneckerDelta(2,gO2)*ZA
      (gI1,0)*ZA(gI2,0) - 14.142135623730951*LamSD*Conj(MuD)*KroneckerDelta(2,gO2)
      *ZA(gI1,0)*ZA(gI2,0) - 10*g2*MDWBT*KroneckerDelta(3,gO2)*ZA(gI1,0)*ZA(gI2,0)
      - 10*vT*AbsSqr(LamTD)*KroneckerDelta(3,gO2)*ZA(gI1,0)*ZA(gI2,0) -
      7.0710678118654755*LamTD*vS*Conj(LamSD)*KroneckerDelta(3,gO2)*ZA(gI1,0)*ZA(
      gI2,0) - 10*MuD*Conj(LamTD)*KroneckerDelta(3,gO2)*ZA(gI1,0)*ZA(gI2,0) -
      7.0710678118654755*LamSD*vS*Conj(LamTD)*KroneckerDelta(3,gO2)*ZA(gI1,0)*ZA(
      gI2,0) - 10*g2*Conj(MDWBT)*KroneckerDelta(3,gO2)*ZA(gI1,0)*ZA(gI2,0) - 10*
      LamTD*Conj(MuD)*KroneckerDelta(3,gO2)*ZA(gI1,0)*ZA(gI2,0) -
      7.745966692414834*g1*MDBS*KroneckerDelta(2,gO2)*ZA(gI1,1)*ZA(gI2,1) - 20*vS*
      AbsSqr(LamSU)*KroneckerDelta(2,gO2)*ZA(gI1,1)*ZA(gI2,1) - 14.142135623730951
      *MuU*Conj(LamSU)*KroneckerDelta(2,gO2)*ZA(gI1,1)*ZA(gI2,1) +
      7.0710678118654755*LamTU*vT*Conj(LamSU)*KroneckerDelta(2,gO2)*ZA(gI1,1)*ZA(
      gI2,1) + 7.0710678118654755*LamSU*vT*Conj(LamTU)*KroneckerDelta(2,gO2)*ZA(
      gI1,1)*ZA(gI2,1) - 7.745966692414834*g1*Conj(MDBS)*KroneckerDelta(2,gO2)*ZA(
      gI1,1)*ZA(gI2,1) - 14.142135623730951*LamSU*Conj(MuU)*KroneckerDelta(2,gO2)*
      ZA(gI1,1)*ZA(gI2,1) + 10*g2*MDWBT*KroneckerDelta(3,gO2)*ZA(gI1,1)*ZA(gI2,1)
      - 10*vT*AbsSqr(LamTU)*KroneckerDelta(3,gO2)*ZA(gI1,1)*ZA(gI2,1) +
      7.0710678118654755*LamTU*vS*Conj(LamSU)*KroneckerDelta(3,gO2)*ZA(gI1,1)*ZA(
      gI2,1) + 10*MuU*Conj(LamTU)*KroneckerDelta(3,gO2)*ZA(gI1,1)*ZA(gI2,1) +
      7.0710678118654755*LamSU*vS*Conj(LamTU)*KroneckerDelta(3,gO2)*ZA(gI1,1)*ZA(
      gI2,1) + 10*g2*Conj(MDWBT)*KroneckerDelta(3,gO2)*ZA(gI1,1)*ZA(gI2,1) + 10*
      LamTU*Conj(MuU)*KroneckerDelta(3,gO2)*ZA(gI1,1)*ZA(gI2,1) - vd*
      KroneckerDelta(0,gO2)*((3*Sqr(g1) + 5*Sqr(g2))*ZA(gI1,0)*ZA(gI2,0) - (3*Sqr(
      g1) + 5*Sqr(g2))*ZA(gI1,1)*ZA(gI2,1) + 5*(Conj(LamSD)*(1.4142135623730951*
      LamTD*ZA(gI1,3)*ZA(gI2,2) + ZA(gI1,2)*(4*LamSD*ZA(gI2,2) +
      1.4142135623730951*LamTD*ZA(gI2,3))) + Conj(LamTD)*(1.4142135623730951*LamSD
      *ZA(gI1,2)*ZA(gI2,3) + ZA(gI1,3)*(1.4142135623730951*LamSD*ZA(gI2,2) + 2*
      LamTD*ZA(gI2,3))))) + vu*KroneckerDelta(1,gO2)*((3*Sqr(g1) + 5*Sqr(g2))*ZA(
      gI1,0)*ZA(gI2,0) - (3*Sqr(g1) + 5*Sqr(g2))*ZA(gI1,1)*ZA(gI2,1) + 5*(Conj(
      LamTU)*(1.4142135623730951*LamSU*ZA(gI1,2)*ZA(gI2,3) + ZA(gI1,3)*(
      1.4142135623730951*LamSU*ZA(gI2,2) - 2*LamTU*ZA(gI2,3))) + Conj(LamSU)*(
      1.4142135623730951*LamTU*ZA(gI1,3)*ZA(gI2,2) + ZA(gI1,2)*(-4*LamSU*ZA(gI2,2)
      + 1.4142135623730951*LamTU*ZA(gI2,3))))));

   return result;
}

std::complex<double> CLASSNAME::CpUhhconjHpmHpm(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.05*(7.745966692414834*g1*MDBS*KroneckerDelta(2,gO2)*ZP(gI1,0)*ZP(
      gI2,0) - 20*vS*AbsSqr(LamSD)*KroneckerDelta(2,gO2)*ZP(gI1,0)*ZP(gI2,0) -
      14.142135623730951*MuD*Conj(LamSD)*KroneckerDelta(2,gO2)*ZP(gI1,0)*ZP(gI2,0)
      + 7.0710678118654755*LamTD*vT*Conj(LamSD)*KroneckerDelta(2,gO2)*ZP(gI1,0)*
      ZP(gI2,0) + 7.0710678118654755*LamSD*vT*Conj(LamTD)*KroneckerDelta(2,gO2)*ZP
      (gI1,0)*ZP(gI2,0) + 7.745966692414834*g1*Conj(MDBS)*KroneckerDelta(2,gO2)*ZP
      (gI1,0)*ZP(gI2,0) - 14.142135623730951*LamSD*Conj(MuD)*KroneckerDelta(2,gO2)
      *ZP(gI1,0)*ZP(gI2,0) + 10*g2*MDWBT*KroneckerDelta(3,gO2)*ZP(gI1,0)*ZP(gI2,0)
      - 10*vT*AbsSqr(LamTD)*KroneckerDelta(3,gO2)*ZP(gI1,0)*ZP(gI2,0) +
      7.0710678118654755*LamTD*vS*Conj(LamSD)*KroneckerDelta(3,gO2)*ZP(gI1,0)*ZP(
      gI2,0) + 10*MuD*Conj(LamTD)*KroneckerDelta(3,gO2)*ZP(gI1,0)*ZP(gI2,0) +
      7.0710678118654755*LamSD*vS*Conj(LamTD)*KroneckerDelta(3,gO2)*ZP(gI1,0)*ZP(
      gI2,0) + 10*g2*Conj(MDWBT)*KroneckerDelta(3,gO2)*ZP(gI1,0)*ZP(gI2,0) + 10*
      LamTD*Conj(MuD)*KroneckerDelta(3,gO2)*ZP(gI1,0)*ZP(gI2,0) - 10*LamSD*vd*Conj
      (LamTD)*KroneckerDelta(2,gO2)*ZP(gI1,2)*ZP(gI2,0) + 7.0710678118654755*vd*
      AbsSqr(LamTD)*KroneckerDelta(3,gO2)*ZP(gI1,2)*ZP(gI2,0) - 7.0710678118654755
      *vd*KroneckerDelta(3,gO2)*Sqr(g2)*ZP(gI1,2)*ZP(gI2,0) - 10*LamTD*vd*Conj(
      LamSD)*KroneckerDelta(2,gO2)*ZP(gI1,3)*ZP(gI2,0) - 7.0710678118654755*vd*
      AbsSqr(LamTD)*KroneckerDelta(3,gO2)*ZP(gI1,3)*ZP(gI2,0) + 7.0710678118654755
      *vd*KroneckerDelta(3,gO2)*Sqr(g2)*ZP(gI1,3)*ZP(gI2,0) - 7.745966692414834*g1
      *MDBS*KroneckerDelta(2,gO2)*ZP(gI1,1)*ZP(gI2,1) - 20*vS*AbsSqr(LamSU)*
      KroneckerDelta(2,gO2)*ZP(gI1,1)*ZP(gI2,1) - 14.142135623730951*MuU*Conj(
      LamSU)*KroneckerDelta(2,gO2)*ZP(gI1,1)*ZP(gI2,1) - 7.0710678118654755*LamTU*
      vT*Conj(LamSU)*KroneckerDelta(2,gO2)*ZP(gI1,1)*ZP(gI2,1) -
      7.0710678118654755*LamSU*vT*Conj(LamTU)*KroneckerDelta(2,gO2)*ZP(gI1,1)*ZP(
      gI2,1) - 7.745966692414834*g1*Conj(MDBS)*KroneckerDelta(2,gO2)*ZP(gI1,1)*ZP(
      gI2,1) - 14.142135623730951*LamSU*Conj(MuU)*KroneckerDelta(2,gO2)*ZP(gI1,1)*
      ZP(gI2,1) - 10*g2*MDWBT*KroneckerDelta(3,gO2)*ZP(gI1,1)*ZP(gI2,1) - 10*vT*
      AbsSqr(LamTU)*KroneckerDelta(3,gO2)*ZP(gI1,1)*ZP(gI2,1) - 7.0710678118654755
      *LamTU*vS*Conj(LamSU)*KroneckerDelta(3,gO2)*ZP(gI1,1)*ZP(gI2,1) - 10*MuU*
      Conj(LamTU)*KroneckerDelta(3,gO2)*ZP(gI1,1)*ZP(gI2,1) - 7.0710678118654755*
      LamSU*vS*Conj(LamTU)*KroneckerDelta(3,gO2)*ZP(gI1,1)*ZP(gI2,1) - 10*g2*Conj(
      MDWBT)*KroneckerDelta(3,gO2)*ZP(gI1,1)*ZP(gI2,1) - 10*LamTU*Conj(MuU)*
      KroneckerDelta(3,gO2)*ZP(gI1,1)*ZP(gI2,1) - 10*LamSU*vu*Conj(LamTU)*
      KroneckerDelta(2,gO2)*ZP(gI1,2)*ZP(gI2,1) + 7.0710678118654755*vu*AbsSqr(
      LamTU)*KroneckerDelta(3,gO2)*ZP(gI1,2)*ZP(gI2,1) - 7.0710678118654755*vu*
      KroneckerDelta(3,gO2)*Sqr(g2)*ZP(gI1,2)*ZP(gI2,1) - 10*LamTU*vu*Conj(LamSU)*
      KroneckerDelta(2,gO2)*ZP(gI1,3)*ZP(gI2,1) - 7.0710678118654755*vu*AbsSqr(
      LamTU)*KroneckerDelta(3,gO2)*ZP(gI1,3)*ZP(gI2,1) + 7.0710678118654755*vu*
      KroneckerDelta(3,gO2)*Sqr(g2)*ZP(gI1,3)*ZP(gI2,1) - 10*LamTD*vd*Conj(LamSD)*
      KroneckerDelta(2,gO2)*ZP(gI1,0)*ZP(gI2,2) + 7.0710678118654755*vd*AbsSqr(
      LamTD)*KroneckerDelta(3,gO2)*ZP(gI1,0)*ZP(gI2,2) - 7.0710678118654755*vd*
      KroneckerDelta(3,gO2)*Sqr(g2)*ZP(gI1,0)*ZP(gI2,2) - 10*LamTU*vu*Conj(LamSU)*
      KroneckerDelta(2,gO2)*ZP(gI1,1)*ZP(gI2,2) + 7.0710678118654755*vu*AbsSqr(
      LamTU)*KroneckerDelta(3,gO2)*ZP(gI1,1)*ZP(gI2,2) - 7.0710678118654755*vu*
      KroneckerDelta(3,gO2)*Sqr(g2)*ZP(gI1,1)*ZP(gI2,2) - 20*vT*KroneckerDelta(3,
      gO2)*Sqr(g2)*ZP(gI1,2)*ZP(gI2,2) + 20*vT*KroneckerDelta(3,gO2)*Sqr(g2)*ZP(
      gI1,3)*ZP(gI2,2) - 10*LamSD*vd*Conj(LamTD)*KroneckerDelta(2,gO2)*ZP(gI1,0)*
      ZP(gI2,3) - 7.0710678118654755*vd*AbsSqr(LamTD)*KroneckerDelta(3,gO2)*ZP(gI1
      ,0)*ZP(gI2,3) + 7.0710678118654755*vd*KroneckerDelta(3,gO2)*Sqr(g2)*ZP(gI1,0
      )*ZP(gI2,3) - 10*LamSU*vu*Conj(LamTU)*KroneckerDelta(2,gO2)*ZP(gI1,1)*ZP(gI2
      ,3) - 7.0710678118654755*vu*AbsSqr(LamTU)*KroneckerDelta(3,gO2)*ZP(gI1,1)*ZP
      (gI2,3) + 7.0710678118654755*vu*KroneckerDelta(3,gO2)*Sqr(g2)*ZP(gI1,1)*ZP(
      gI2,3) + 20*vT*KroneckerDelta(3,gO2)*Sqr(g2)*ZP(gI1,2)*ZP(gI2,3) - 20*vT*
      KroneckerDelta(3,gO2)*Sqr(g2)*ZP(gI1,3)*ZP(gI2,3) - KroneckerDelta(0,gO2)*(
      ZP(gI1,1)*(5*vu*Sqr(g2)*ZP(gI2,0) + vd*(-3*Sqr(g1) + 5*Sqr(g2))*ZP(gI2,1)) +
      ZP(gI1,0)*(vd*(3*Sqr(g1) + 5*Sqr(g2))*ZP(gI2,0) + 5*(vu*Sqr(g2)*ZP(gI2,1) +
      (2*LamTD*vS*Conj(LamSD) + 1.4142135623730951*(2*g2*MDWBT - vT*AbsSqr(LamTD)
      + 2*LamTD*Conj(MuD) + vT*Sqr(g2)))*ZP(gI2,2) + ((2.8284271247461903*MuD + 2
      *LamSD*vS + 1.4142135623730951*LamTD*vT)*Conj(LamTD) + 1.4142135623730951*g2
      *(-(g2*vT) + 2*Conj(MDWBT)))*ZP(gI2,3))) + 5*(ZP(gI1,2)*(((
      2.8284271247461903*MuD + 2*LamSD*vS - 1.4142135623730951*LamTD*vT)*Conj(
      LamTD) + 1.4142135623730951*g2*(g2*vT + 2*Conj(MDWBT)))*ZP(gI2,0) - 2*vd*(-2
      *AbsSqr(LamTD) + Sqr(g2))*ZP(gI2,2)) + ZP(gI1,3)*((2*LamTD*vS*Conj(LamSD) +
      1.4142135623730951*(2*g2*MDWBT + vT*AbsSqr(LamTD) + 2*LamTD*Conj(MuD) - vT*
      Sqr(g2)))*ZP(gI2,0) + 2*vd*Sqr(g2)*ZP(gI2,3)))) - KroneckerDelta(1,gO2)*(ZP(
      gI1,0)*((-3*vu*Sqr(g1) + 5*vu*Sqr(g2))*ZP(gI2,0) + 5*vd*Sqr(g2)*ZP(gI2,1)) +
      ZP(gI1,1)*(5*vd*Sqr(g2)*ZP(gI2,0) + vu*(3*Sqr(g1) + 5*Sqr(g2))*ZP(gI2,1) +
      5*((2*LamTU*vS*Conj(LamSU) + 1.4142135623730951*(2*g2*MDWBT - vT*AbsSqr(
      LamTU) + 2*LamTU*Conj(MuU) + vT*Sqr(g2)))*ZP(gI2,2) + ((2.8284271247461903*
      MuU + 2*LamSU*vS + 1.4142135623730951*LamTU*vT)*Conj(LamTU) +
      1.4142135623730951*g2*(-(g2*vT) + 2*Conj(MDWBT)))*ZP(gI2,3))) + 5*(ZP(gI1,2)
      *(((2.8284271247461903*MuU + 2*LamSU*vS - 1.4142135623730951*LamTU*vT)*Conj(
      LamTU) + 1.4142135623730951*g2*(g2*vT + 2*Conj(MDWBT)))*ZP(gI2,1) + 2*vu*Sqr
      (g2)*ZP(gI2,2)) + ZP(gI1,3)*((2*LamTU*vS*Conj(LamSU) + 1.4142135623730951*(2
      *g2*MDWBT + vT*AbsSqr(LamTU) + 2*LamTU*Conj(MuU) - vT*Sqr(g2)))*ZP(gI2,1) -
      2*vu*(-2*AbsSqr(LamTU) + Sqr(g2))*ZP(gI2,3)))));

   return result;
}

std::complex<double> CLASSNAME::CpUhhhhAh(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = std::complex<double>(0,0.05)*(-7.0710678118654755*LamSD*vd*Conj(
      LamTD)*KroneckerDelta(3,gO2)*ZA(gI2,2)*ZH(gI1,0) + 7.0710678118654755*LamSD*
      vd*Conj(LamTD)*KroneckerDelta(2,gO2)*ZA(gI2,3)*ZH(gI1,0) +
      7.0710678118654755*LamTD*vd*Conj(LamSD)*(KroneckerDelta(3,gO2)*ZA(gI2,2) -
      KroneckerDelta(2,gO2)*ZA(gI2,3))*ZH(gI1,0) - 7.745966692414834*g1*MDBS*
      KroneckerDelta(1,gO2)*ZA(gI2,2)*ZH(gI1,1) + 14.142135623730951*MuU*Conj(
      LamSU)*KroneckerDelta(1,gO2)*ZA(gI2,2)*ZH(gI1,1) - 7.0710678118654755*LamTU*
      vT*Conj(LamSU)*KroneckerDelta(1,gO2)*ZA(gI2,2)*ZH(gI1,1) +
      7.0710678118654755*LamSU*vT*Conj(LamTU)*KroneckerDelta(1,gO2)*ZA(gI2,2)*ZH(
      gI1,1) + 7.745966692414834*g1*Conj(MDBS)*KroneckerDelta(1,gO2)*ZA(gI2,2)*ZH(
      gI1,1) - 14.142135623730951*LamSU*Conj(MuU)*KroneckerDelta(1,gO2)*ZA(gI2,2)*
      ZH(gI1,1) - 7.0710678118654755*LamTU*vu*Conj(LamSU)*KroneckerDelta(3,gO2)*ZA
      (gI2,2)*ZH(gI1,1) + 7.0710678118654755*LamSU*vu*Conj(LamTU)*KroneckerDelta(3
      ,gO2)*ZA(gI2,2)*ZH(gI1,1) + 10*g2*MDWBT*KroneckerDelta(1,gO2)*ZA(gI2,3)*ZH(
      gI1,1) + 7.0710678118654755*LamTU*vS*Conj(LamSU)*KroneckerDelta(1,gO2)*ZA(
      gI2,3)*ZH(gI1,1) - 10*MuU*Conj(LamTU)*KroneckerDelta(1,gO2)*ZA(gI2,3)*ZH(gI1
      ,1) - 7.0710678118654755*LamSU*vS*Conj(LamTU)*KroneckerDelta(1,gO2)*ZA(gI2,3
      )*ZH(gI1,1) - 10*g2*Conj(MDWBT)*KroneckerDelta(1,gO2)*ZA(gI2,3)*ZH(gI1,1) +
      10*LamTU*Conj(MuU)*KroneckerDelta(1,gO2)*ZA(gI2,3)*ZH(gI1,1) +
      7.0710678118654755*LamTU*vu*Conj(LamSU)*KroneckerDelta(2,gO2)*ZA(gI2,3)*ZH(
      gI1,1) - 7.0710678118654755*LamSU*vu*Conj(LamTU)*KroneckerDelta(2,gO2)*ZA(
      gI2,3)*ZH(gI1,1) + 7.0710678118654755*LamTU*vu*Conj(LamSU)*KroneckerDelta(1,
      gO2)*ZA(gI2,3)*ZH(gI1,2) - 7.0710678118654755*LamSU*vu*Conj(LamTU)*
      KroneckerDelta(1,gO2)*ZA(gI2,3)*ZH(gI1,2) - 7.0710678118654755*LamTU*vu*Conj
      (LamSU)*KroneckerDelta(1,gO2)*ZA(gI2,2)*ZH(gI1,3) + 7.0710678118654755*LamSU
      *vu*Conj(LamTU)*KroneckerDelta(1,gO2)*ZA(gI2,2)*ZH(gI1,3) + KroneckerDelta(0
      ,gO2)*(-5*ZA(gI2,3)*((2*g2*MDWBT + 1.4142135623730951*LamTD*vS*Conj(LamSD) -
      2*MuD*Conj(LamTD) - 1.4142135623730951*LamSD*vS*Conj(LamTD) - 2*g2*Conj(
      MDWBT) + 2*LamTD*Conj(MuD))*ZH(gI1,0) + 1.4142135623730951*vd*(LamTD*Conj(
      LamSD) - LamSD*Conj(LamTD))*ZH(gI1,2)) + ZA(gI2,2)*((7.745966692414834*g1*
      MDBS + 7.0710678118654755*(2*MuD + LamTD*vT)*Conj(LamSD) -
      7.0710678118654755*LamSD*vT*Conj(LamTD) - 7.745966692414834*g1*Conj(MDBS) -
      14.142135623730951*LamSD*Conj(MuD))*ZH(gI1,0) + 7.0710678118654755*vd*(LamTD
      *Conj(LamSD) - LamSD*Conj(LamTD))*ZH(gI1,3))));

   return result;
}

std::complex<double> CLASSNAME::CpUhhhhhh(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.05*(7.745966692414834*g1*MDBS*KroneckerDelta(2,gO2)*ZH(gI1,0)*ZH(
      gI2,0) - 20*vS*AbsSqr(LamSD)*KroneckerDelta(2,gO2)*ZH(gI1,0)*ZH(gI2,0) -
      14.142135623730951*MuD*Conj(LamSD)*KroneckerDelta(2,gO2)*ZH(gI1,0)*ZH(gI2,0)
      - 7.0710678118654755*LamTD*vT*Conj(LamSD)*KroneckerDelta(2,gO2)*ZH(gI1,0)*
      ZH(gI2,0) - 7.0710678118654755*LamSD*vT*Conj(LamTD)*KroneckerDelta(2,gO2)*ZH
      (gI1,0)*ZH(gI2,0) + 7.745966692414834*g1*Conj(MDBS)*KroneckerDelta(2,gO2)*ZH
      (gI1,0)*ZH(gI2,0) - 14.142135623730951*LamSD*Conj(MuD)*KroneckerDelta(2,gO2)
      *ZH(gI1,0)*ZH(gI2,0) - 10*g2*MDWBT*KroneckerDelta(3,gO2)*ZH(gI1,0)*ZH(gI2,0)
      - 10*vT*AbsSqr(LamTD)*KroneckerDelta(3,gO2)*ZH(gI1,0)*ZH(gI2,0) -
      7.0710678118654755*LamTD*vS*Conj(LamSD)*KroneckerDelta(3,gO2)*ZH(gI1,0)*ZH(
      gI2,0) - 10*MuD*Conj(LamTD)*KroneckerDelta(3,gO2)*ZH(gI1,0)*ZH(gI2,0) -
      7.0710678118654755*LamSD*vS*Conj(LamTD)*KroneckerDelta(3,gO2)*ZH(gI1,0)*ZH(
      gI2,0) - 10*g2*Conj(MDWBT)*KroneckerDelta(3,gO2)*ZH(gI1,0)*ZH(gI2,0) - 10*
      LamTD*Conj(MuD)*KroneckerDelta(3,gO2)*ZH(gI1,0)*ZH(gI2,0) - 20*vd*AbsSqr(
      LamSD)*KroneckerDelta(2,gO2)*ZH(gI1,2)*ZH(gI2,0) - 7.0710678118654755*LamTD*
      vd*Conj(LamSD)*KroneckerDelta(3,gO2)*ZH(gI1,2)*ZH(gI2,0) -
      7.0710678118654755*LamSD*vd*Conj(LamTD)*KroneckerDelta(3,gO2)*ZH(gI1,2)*ZH(
      gI2,0) - 7.0710678118654755*LamTD*vd*Conj(LamSD)*KroneckerDelta(2,gO2)*ZH(
      gI1,3)*ZH(gI2,0) - 7.0710678118654755*LamSD*vd*Conj(LamTD)*KroneckerDelta(2,
      gO2)*ZH(gI1,3)*ZH(gI2,0) - 10*vd*AbsSqr(LamTD)*KroneckerDelta(3,gO2)*ZH(gI1,
      3)*ZH(gI2,0) - 7.745966692414834*g1*MDBS*KroneckerDelta(2,gO2)*ZH(gI1,1)*ZH(
      gI2,1) - 20*vS*AbsSqr(LamSU)*KroneckerDelta(2,gO2)*ZH(gI1,1)*ZH(gI2,1) -
      14.142135623730951*MuU*Conj(LamSU)*KroneckerDelta(2,gO2)*ZH(gI1,1)*ZH(gI2,1)
      + 7.0710678118654755*LamTU*vT*Conj(LamSU)*KroneckerDelta(2,gO2)*ZH(gI1,1)*
      ZH(gI2,1) + 7.0710678118654755*LamSU*vT*Conj(LamTU)*KroneckerDelta(2,gO2)*ZH
      (gI1,1)*ZH(gI2,1) - 7.745966692414834*g1*Conj(MDBS)*KroneckerDelta(2,gO2)*ZH
      (gI1,1)*ZH(gI2,1) - 14.142135623730951*LamSU*Conj(MuU)*KroneckerDelta(2,gO2)
      *ZH(gI1,1)*ZH(gI2,1) + 10*g2*MDWBT*KroneckerDelta(3,gO2)*ZH(gI1,1)*ZH(gI2,1)
      - 10*vT*AbsSqr(LamTU)*KroneckerDelta(3,gO2)*ZH(gI1,1)*ZH(gI2,1) +
      7.0710678118654755*LamTU*vS*Conj(LamSU)*KroneckerDelta(3,gO2)*ZH(gI1,1)*ZH(
      gI2,1) + 10*MuU*Conj(LamTU)*KroneckerDelta(3,gO2)*ZH(gI1,1)*ZH(gI2,1) +
      7.0710678118654755*LamSU*vS*Conj(LamTU)*KroneckerDelta(3,gO2)*ZH(gI1,1)*ZH(
      gI2,1) + 10*g2*Conj(MDWBT)*KroneckerDelta(3,gO2)*ZH(gI1,1)*ZH(gI2,1) + 10*
      LamTU*Conj(MuU)*KroneckerDelta(3,gO2)*ZH(gI1,1)*ZH(gI2,1) - 20*vu*AbsSqr(
      LamSU)*KroneckerDelta(2,gO2)*ZH(gI1,2)*ZH(gI2,1) + 7.0710678118654755*LamTU*
      vu*Conj(LamSU)*KroneckerDelta(3,gO2)*ZH(gI1,2)*ZH(gI2,1) +
      7.0710678118654755*LamSU*vu*Conj(LamTU)*KroneckerDelta(3,gO2)*ZH(gI1,2)*ZH(
      gI2,1) + 7.0710678118654755*LamTU*vu*Conj(LamSU)*KroneckerDelta(2,gO2)*ZH(
      gI1,3)*ZH(gI2,1) + 7.0710678118654755*LamSU*vu*Conj(LamTU)*KroneckerDelta(2,
      gO2)*ZH(gI1,3)*ZH(gI2,1) - 10*vu*AbsSqr(LamTU)*KroneckerDelta(3,gO2)*ZH(gI1,
      3)*ZH(gI2,1) - 20*vd*AbsSqr(LamSD)*KroneckerDelta(2,gO2)*ZH(gI1,0)*ZH(gI2,2)
      - 7.0710678118654755*LamTD*vd*Conj(LamSD)*KroneckerDelta(3,gO2)*ZH(gI1,0)*
      ZH(gI2,2) - 7.0710678118654755*LamSD*vd*Conj(LamTD)*KroneckerDelta(3,gO2)*ZH
      (gI1,0)*ZH(gI2,2) - 20*vu*AbsSqr(LamSU)*KroneckerDelta(2,gO2)*ZH(gI1,1)*ZH(
      gI2,2) + 7.0710678118654755*LamTU*vu*Conj(LamSU)*KroneckerDelta(3,gO2)*ZH(
      gI1,1)*ZH(gI2,2) + 7.0710678118654755*LamSU*vu*Conj(LamTU)*KroneckerDelta(3,
      gO2)*ZH(gI1,1)*ZH(gI2,2) - 7.0710678118654755*LamTD*vd*Conj(LamSD)*
      KroneckerDelta(2,gO2)*ZH(gI1,0)*ZH(gI2,3) - 7.0710678118654755*LamSD*vd*Conj
      (LamTD)*KroneckerDelta(2,gO2)*ZH(gI1,0)*ZH(gI2,3) - 10*vd*AbsSqr(LamTD)*
      KroneckerDelta(3,gO2)*ZH(gI1,0)*ZH(gI2,3) + 7.0710678118654755*LamTU*vu*Conj
      (LamSU)*KroneckerDelta(2,gO2)*ZH(gI1,1)*ZH(gI2,3) + 7.0710678118654755*LamSU
      *vu*Conj(LamTU)*KroneckerDelta(2,gO2)*ZH(gI1,1)*ZH(gI2,3) - 10*vu*AbsSqr(
      LamTU)*KroneckerDelta(3,gO2)*ZH(gI1,1)*ZH(gI2,3) - KroneckerDelta(0,gO2)*(
      -7.745966692414834*g1*MDBS*ZH(gI1,2)*ZH(gI2,0) + 20*vS*AbsSqr(LamSD)*ZH(gI1,
      2)*ZH(gI2,0) + 14.142135623730951*MuD*Conj(LamSD)*ZH(gI1,2)*ZH(gI2,0) +
      7.0710678118654755*LamTD*vT*Conj(LamSD)*ZH(gI1,2)*ZH(gI2,0) +
      7.0710678118654755*LamSD*vT*Conj(LamTD)*ZH(gI1,2)*ZH(gI2,0) -
      7.745966692414834*g1*Conj(MDBS)*ZH(gI1,2)*ZH(gI2,0) + 14.142135623730951*
      LamSD*Conj(MuD)*ZH(gI1,2)*ZH(gI2,0) + 10*g2*MDWBT*ZH(gI1,3)*ZH(gI2,0) + 10*
      vT*AbsSqr(LamTD)*ZH(gI1,3)*ZH(gI2,0) + 7.0710678118654755*LamTD*vS*Conj(
      LamSD)*ZH(gI1,3)*ZH(gI2,0) + 10*MuD*Conj(LamTD)*ZH(gI1,3)*ZH(gI2,0) +
      7.0710678118654755*LamSD*vS*Conj(LamTD)*ZH(gI1,3)*ZH(gI2,0) + 10*g2*Conj(
      MDWBT)*ZH(gI1,3)*ZH(gI2,0) + 10*LamTD*Conj(MuD)*ZH(gI1,3)*ZH(gI2,0) - (3*Sqr
      (g1) + 5*Sqr(g2))*ZH(gI1,1)*(vu*ZH(gI2,0) + vd*ZH(gI2,1)) + 20*vd*AbsSqr(
      LamSD)*ZH(gI1,2)*ZH(gI2,2) + 7.0710678118654755*LamTD*vd*Conj(LamSD)*ZH(gI1,
      3)*ZH(gI2,2) + 7.0710678118654755*LamSD*vd*Conj(LamTD)*ZH(gI1,3)*ZH(gI2,2) +
      7.0710678118654755*LamTD*vd*Conj(LamSD)*ZH(gI1,2)*ZH(gI2,3) +
      7.0710678118654755*LamSD*vd*Conj(LamTD)*ZH(gI1,2)*ZH(gI2,3) + 10*vd*AbsSqr(
      LamTD)*ZH(gI1,3)*ZH(gI2,3) + ZH(gI1,0)*(3*vd*(3*Sqr(g1) + 5*Sqr(g2))*ZH(gI2,
      0) - vu*(3*Sqr(g1) + 5*Sqr(g2))*ZH(gI2,1) - 7.745966692414834*g1*MDBS*ZH(gI2
      ,2) + 20*vS*AbsSqr(LamSD)*ZH(gI2,2) + 14.142135623730951*MuD*Conj(LamSD)*ZH(
      gI2,2) + 7.0710678118654755*LamTD*vT*Conj(LamSD)*ZH(gI2,2) +
      7.0710678118654755*LamSD*vT*Conj(LamTD)*ZH(gI2,2) - 7.745966692414834*g1*
      Conj(MDBS)*ZH(gI2,2) + 14.142135623730951*LamSD*Conj(MuD)*ZH(gI2,2) + 10*g2*
      MDWBT*ZH(gI2,3) + 10*vT*AbsSqr(LamTD)*ZH(gI2,3) + 7.0710678118654755*LamTD*
      vS*Conj(LamSD)*ZH(gI2,3) + 10*MuD*Conj(LamTD)*ZH(gI2,3) + 7.0710678118654755
      *LamSD*vS*Conj(LamTD)*ZH(gI2,3) + 10*g2*Conj(MDWBT)*ZH(gI2,3) + 10*LamTD*
      Conj(MuD)*ZH(gI2,3))) + KroneckerDelta(1,gO2)*(-7.745966692414834*g1*MDBS*ZH
      (gI1,2)*ZH(gI2,1) - 20*vS*AbsSqr(LamSU)*ZH(gI1,2)*ZH(gI2,1) -
      14.142135623730951*MuU*Conj(LamSU)*ZH(gI1,2)*ZH(gI2,1) + 7.0710678118654755*
      LamTU*vT*Conj(LamSU)*ZH(gI1,2)*ZH(gI2,1) + 7.0710678118654755*LamSU*vT*Conj(
      LamTU)*ZH(gI1,2)*ZH(gI2,1) - 7.745966692414834*g1*Conj(MDBS)*ZH(gI1,2)*ZH(
      gI2,1) - 14.142135623730951*LamSU*Conj(MuU)*ZH(gI1,2)*ZH(gI2,1) + 10*g2*
      MDWBT*ZH(gI1,3)*ZH(gI2,1) - 10*vT*AbsSqr(LamTU)*ZH(gI1,3)*ZH(gI2,1) +
      7.0710678118654755*LamTU*vS*Conj(LamSU)*ZH(gI1,3)*ZH(gI2,1) + 10*MuU*Conj(
      LamTU)*ZH(gI1,3)*ZH(gI2,1) + 7.0710678118654755*LamSU*vS*Conj(LamTU)*ZH(gI1,
      3)*ZH(gI2,1) + 10*g2*Conj(MDWBT)*ZH(gI1,3)*ZH(gI2,1) + 10*LamTU*Conj(MuU)*ZH
      (gI1,3)*ZH(gI2,1) + (3*Sqr(g1) + 5*Sqr(g2))*ZH(gI1,0)*(vu*ZH(gI2,0) + vd*ZH(
      gI2,1)) - 20*vu*AbsSqr(LamSU)*ZH(gI1,2)*ZH(gI2,2) + 7.0710678118654755*LamTU
      *vu*Conj(LamSU)*ZH(gI1,3)*ZH(gI2,2) + 7.0710678118654755*LamSU*vu*Conj(LamTU
      )*ZH(gI1,3)*ZH(gI2,2) + 7.0710678118654755*LamTU*vu*Conj(LamSU)*ZH(gI1,2)*ZH
      (gI2,3) + 7.0710678118654755*LamSU*vu*Conj(LamTU)*ZH(gI1,2)*ZH(gI2,3) - 10*
      vu*AbsSqr(LamTU)*ZH(gI1,3)*ZH(gI2,3) + ZH(gI1,1)*(vd*(3*Sqr(g1) + 5*Sqr(g2))
      *ZH(gI2,0) - 3*vu*(3*Sqr(g1) + 5*Sqr(g2))*ZH(gI2,1) - 7.745966692414834*g1*
      MDBS*ZH(gI2,2) - 20*vS*AbsSqr(LamSU)*ZH(gI2,2) - 14.142135623730951*MuU*Conj
      (LamSU)*ZH(gI2,2) + 7.0710678118654755*LamTU*vT*Conj(LamSU)*ZH(gI2,2) +
      7.0710678118654755*LamSU*vT*Conj(LamTU)*ZH(gI2,2) - 7.745966692414834*g1*
      Conj(MDBS)*ZH(gI2,2) - 14.142135623730951*LamSU*Conj(MuU)*ZH(gI2,2) + 10*g2*
      MDWBT*ZH(gI2,3) - 10*vT*AbsSqr(LamTU)*ZH(gI2,3) + 7.0710678118654755*LamTU*
      vS*Conj(LamSU)*ZH(gI2,3) + 10*MuU*Conj(LamTU)*ZH(gI2,3) + 7.0710678118654755
      *LamSU*vS*Conj(LamTU)*ZH(gI2,3) + 10*g2*Conj(MDWBT)*ZH(gI2,3) + 10*LamTU*
      Conj(MuU)*ZH(gI2,3))));

   return result;
}

std::complex<double> CLASSNAME::CpUhhbarChiChiPR(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.1*(5*Conj(LamTD)*KroneckerDelta(0,gO2)*ZN1(gI1,2)*ZN2(gI2,1) + 5*
      Conj(LamTU)*KroneckerDelta(1,gO2)*ZN1(gI1,3)*ZN2(gI2,1) + 3.872983346207417*
      g1*KroneckerDelta(0,gO2)*ZN1(gI1,0)*ZN2(gI2,2) - 5*g2*KroneckerDelta(0,gO2)*
      ZN1(gI1,1)*ZN2(gI2,2) + 5*Conj(LamTD)*KroneckerDelta(3,gO2)*ZN1(gI1,2)*ZN2(
      gI2,2) + 7.0710678118654755*Conj(LamSD)*ZN1(gI1,2)*(KroneckerDelta(0,gO2)*
      ZN2(gI2,0) + KroneckerDelta(2,gO2)*ZN2(gI2,2)) - 3.872983346207417*g1*
      KroneckerDelta(1,gO2)*ZN1(gI1,0)*ZN2(gI2,3) + 5*g2*KroneckerDelta(1,gO2)*ZN1
      (gI1,1)*ZN2(gI2,3) + 5*Conj(LamTU)*KroneckerDelta(3,gO2)*ZN1(gI1,3)*ZN2(gI2,
      3) - 7.0710678118654755*Conj(LamSU)*ZN1(gI1,3)*(KroneckerDelta(1,gO2)*ZN2(
      gI2,0) + KroneckerDelta(2,gO2)*ZN2(gI2,3)));

   return result;
}

std::complex<double> CLASSNAME::CpUhhbarChiChiPL(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.1*(3.872983346207417*g1*Conj(ZN1(gI2,0))*(Conj(ZN2(gI1,2))*
      KroneckerDelta(0,gO1) - Conj(ZN2(gI1,3))*KroneckerDelta(1,gO1)) + 5*Conj(ZN1
      (gI2,2))*(1.4142135623730951*LamSD*Conj(ZN2(gI1,0))*KroneckerDelta(0,gO1) +
      LamTD*Conj(ZN2(gI1,1))*KroneckerDelta(0,gO1) + Conj(ZN2(gI1,2))*(
      1.4142135623730951*LamSD*KroneckerDelta(2,gO1) + LamTD*KroneckerDelta(3,gO1)
      )) + 5*(Conj(ZN1(gI2,1))*(-(g2*Conj(ZN2(gI1,2))*KroneckerDelta(0,gO1)) + g2*
      Conj(ZN2(gI1,3))*KroneckerDelta(1,gO1)) + Conj(ZN1(gI2,3))*(
      -1.4142135623730951*LamSU*Conj(ZN2(gI1,0))*KroneckerDelta(1,gO1) + LamTU*
      Conj(ZN2(gI1,1))*KroneckerDelta(1,gO1) + Conj(ZN2(gI1,3))*(
      -1.4142135623730951*LamSU*KroneckerDelta(2,gO1) + LamTU*KroneckerDelta(3,gO1
      )))));

   return result;
}

std::complex<double> CLASSNAME::CpUhhUhhconjSdSd(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_948;
   std::complex<double> tmp_949;
   std::complex<double> tmp_950;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_950 += Conj(ZD(gI2,j1))*ZD(gI1,j1);
   }
   tmp_949 += tmp_950;
   tmp_948 += (std::complex<double>(0,0.05)*KroneckerDelta(0,gO1)*
      KroneckerDelta(0,gO2)*Sqr(g1)) * tmp_949;
   std::complex<double> tmp_951;
   std::complex<double> tmp_952;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_952 += Conj(ZD(gI2,j1))*ZD(gI1,j1);
   }
   tmp_951 += tmp_952;
   tmp_948 += (std::complex<double>(0,0.25)*KroneckerDelta(0,gO1)*
      KroneckerDelta(0,gO2)*Sqr(g2)) * tmp_951;
   std::complex<double> tmp_953;
   std::complex<double> tmp_954;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_954 += Conj(ZD(gI2,j1))*ZD(gI1,j1);
   }
   tmp_953 += tmp_954;
   tmp_948 += (std::complex<double>(0,-0.05)*KroneckerDelta(1,gO1)*
      KroneckerDelta(1,gO2)*Sqr(g1)) * tmp_953;
   std::complex<double> tmp_955;
   std::complex<double> tmp_956;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_956 += Conj(ZD(gI2,j1))*ZD(gI1,j1);
   }
   tmp_955 += tmp_956;
   tmp_948 += (std::complex<double>(0,-0.25)*KroneckerDelta(1,gO1)*
      KroneckerDelta(1,gO2)*Sqr(g2)) * tmp_955;
   std::complex<double> tmp_957;
   std::complex<double> tmp_958;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_958 += Conj(ZD(gI2,3 + j1))*ZD(gI1,3 + j1);
   }
   tmp_957 += tmp_958;
   tmp_948 += (std::complex<double>(0,0.1)*KroneckerDelta(0,gO1)*KroneckerDelta
      (0,gO2)*Sqr(g1)) * tmp_957;
   std::complex<double> tmp_959;
   std::complex<double> tmp_960;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_960 += Conj(ZD(gI2,3 + j1))*ZD(gI1,3 + j1);
   }
   tmp_959 += tmp_960;
   tmp_948 += (std::complex<double>(0,-0.1)*KroneckerDelta(1,gO1)*
      KroneckerDelta(1,gO2)*Sqr(g1)) * tmp_959;
   std::complex<double> tmp_961;
   std::complex<double> tmp_962;
   for (unsigned j3 = 0; j3 < 3; ++j3) {
      std::complex<double> tmp_963;
      std::complex<double> tmp_964;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         std::complex<double> tmp_965;
         std::complex<double> tmp_966;
         for (unsigned j1 = 0; j1 < 3; ++j1) {
            tmp_966 += Conj(Yd(j3,j1))*Yd(j2,j1);
         }
         tmp_965 += tmp_966;
         tmp_964 += (ZD(gI1,3 + j2)) * tmp_965;
      }
      tmp_963 += tmp_964;
      tmp_962 += (Conj(ZD(gI2,3 + j3))) * tmp_963;
   }
   tmp_961 += tmp_962;
   tmp_948 += (std::complex<double>(0,-1)*KroneckerDelta(0,gO1)*KroneckerDelta(
      0,gO2)) * tmp_961;
   std::complex<double> tmp_967;
   std::complex<double> tmp_968;
   for (unsigned j3 = 0; j3 < 3; ++j3) {
      std::complex<double> tmp_969;
      std::complex<double> tmp_970;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         std::complex<double> tmp_971;
         std::complex<double> tmp_972;
         for (unsigned j1 = 0; j1 < 3; ++j1) {
            tmp_972 += Conj(Yd(j1,j3))*Yd(j1,j2);
         }
         tmp_971 += tmp_972;
         tmp_970 += (Conj(ZD(gI2,j2))) * tmp_971;
      }
      tmp_969 += tmp_970;
      tmp_968 += (ZD(gI1,j3)) * tmp_969;
   }
   tmp_967 += tmp_968;
   tmp_948 += (std::complex<double>(0,-1)*KroneckerDelta(0,gO1)*KroneckerDelta(
      0,gO2)) * tmp_967;
   result += (std::complex<double>(0,-1)) * tmp_948;

   return result;
}

std::complex<double> CLASSNAME::CpUhhUhhconjSeSe(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_973;
   std::complex<double> tmp_974;
   std::complex<double> tmp_975;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_975 += Conj(ZE(gI2,j1))*ZE(gI1,j1);
   }
   tmp_974 += tmp_975;
   tmp_973 += (std::complex<double>(0,-0.15)*KroneckerDelta(0,gO1)*
      KroneckerDelta(0,gO2)*Sqr(g1)) * tmp_974;
   std::complex<double> tmp_976;
   std::complex<double> tmp_977;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_977 += Conj(ZE(gI2,j1))*ZE(gI1,j1);
   }
   tmp_976 += tmp_977;
   tmp_973 += (std::complex<double>(0,0.25)*KroneckerDelta(0,gO1)*
      KroneckerDelta(0,gO2)*Sqr(g2)) * tmp_976;
   std::complex<double> tmp_978;
   std::complex<double> tmp_979;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_979 += Conj(ZE(gI2,j1))*ZE(gI1,j1);
   }
   tmp_978 += tmp_979;
   tmp_973 += (std::complex<double>(0,0.15)*KroneckerDelta(1,gO1)*
      KroneckerDelta(1,gO2)*Sqr(g1)) * tmp_978;
   std::complex<double> tmp_980;
   std::complex<double> tmp_981;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_981 += Conj(ZE(gI2,j1))*ZE(gI1,j1);
   }
   tmp_980 += tmp_981;
   tmp_973 += (std::complex<double>(0,-0.25)*KroneckerDelta(1,gO1)*
      KroneckerDelta(1,gO2)*Sqr(g2)) * tmp_980;
   std::complex<double> tmp_982;
   std::complex<double> tmp_983;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_983 += Conj(ZE(gI2,3 + j1))*ZE(gI1,3 + j1);
   }
   tmp_982 += tmp_983;
   tmp_973 += (std::complex<double>(0,0.3)*KroneckerDelta(0,gO1)*KroneckerDelta
      (0,gO2)*Sqr(g1)) * tmp_982;
   std::complex<double> tmp_984;
   std::complex<double> tmp_985;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_985 += Conj(ZE(gI2,3 + j1))*ZE(gI1,3 + j1);
   }
   tmp_984 += tmp_985;
   tmp_973 += (std::complex<double>(0,-0.3)*KroneckerDelta(1,gO1)*
      KroneckerDelta(1,gO2)*Sqr(g1)) * tmp_984;
   std::complex<double> tmp_986;
   std::complex<double> tmp_987;
   for (unsigned j3 = 0; j3 < 3; ++j3) {
      std::complex<double> tmp_988;
      std::complex<double> tmp_989;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         std::complex<double> tmp_990;
         std::complex<double> tmp_991;
         for (unsigned j1 = 0; j1 < 3; ++j1) {
            tmp_991 += Conj(Ye(j3,j1))*Ye(j2,j1);
         }
         tmp_990 += tmp_991;
         tmp_989 += (ZE(gI1,3 + j2)) * tmp_990;
      }
      tmp_988 += tmp_989;
      tmp_987 += (Conj(ZE(gI2,3 + j3))) * tmp_988;
   }
   tmp_986 += tmp_987;
   tmp_973 += (std::complex<double>(0,-1)*KroneckerDelta(0,gO1)*KroneckerDelta(
      0,gO2)) * tmp_986;
   std::complex<double> tmp_992;
   std::complex<double> tmp_993;
   for (unsigned j3 = 0; j3 < 3; ++j3) {
      std::complex<double> tmp_994;
      std::complex<double> tmp_995;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         std::complex<double> tmp_996;
         std::complex<double> tmp_997;
         for (unsigned j1 = 0; j1 < 3; ++j1) {
            tmp_997 += Conj(Ye(j1,j3))*Ye(j1,j2);
         }
         tmp_996 += tmp_997;
         tmp_995 += (Conj(ZE(gI2,j2))) * tmp_996;
      }
      tmp_994 += tmp_995;
      tmp_993 += (ZE(gI1,j3)) * tmp_994;
   }
   tmp_992 += tmp_993;
   tmp_973 += (std::complex<double>(0,-1)*KroneckerDelta(0,gO1)*KroneckerDelta(
      0,gO2)) * tmp_992;
   result += (std::complex<double>(0,-1)) * tmp_973;

   return result;
}

std::complex<double> CLASSNAME::CpUhhUhhconjSuSu(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_998;
   std::complex<double> tmp_999;
   std::complex<double> tmp_1000;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1000 += Conj(ZU(gI2,j1))*ZU(gI1,j1);
   }
   tmp_999 += tmp_1000;
   tmp_998 += (std::complex<double>(0,0.05)*KroneckerDelta(0,gO1)*
      KroneckerDelta(0,gO2)*Sqr(g1)) * tmp_999;
   std::complex<double> tmp_1001;
   std::complex<double> tmp_1002;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1002 += Conj(ZU(gI2,j1))*ZU(gI1,j1);
   }
   tmp_1001 += tmp_1002;
   tmp_998 += (std::complex<double>(0,-0.25)*KroneckerDelta(0,gO1)*
      KroneckerDelta(0,gO2)*Sqr(g2)) * tmp_1001;
   std::complex<double> tmp_1003;
   std::complex<double> tmp_1004;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1004 += Conj(ZU(gI2,j1))*ZU(gI1,j1);
   }
   tmp_1003 += tmp_1004;
   tmp_998 += (std::complex<double>(0,-0.05)*KroneckerDelta(1,gO1)*
      KroneckerDelta(1,gO2)*Sqr(g1)) * tmp_1003;
   std::complex<double> tmp_1005;
   std::complex<double> tmp_1006;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1006 += Conj(ZU(gI2,j1))*ZU(gI1,j1);
   }
   tmp_1005 += tmp_1006;
   tmp_998 += (std::complex<double>(0,0.25)*KroneckerDelta(1,gO1)*
      KroneckerDelta(1,gO2)*Sqr(g2)) * tmp_1005;
   std::complex<double> tmp_1007;
   std::complex<double> tmp_1008;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1008 += Conj(ZU(gI2,3 + j1))*ZU(gI1,3 + j1);
   }
   tmp_1007 += tmp_1008;
   tmp_998 += (std::complex<double>(0,-0.2)*KroneckerDelta(0,gO1)*
      KroneckerDelta(0,gO2)*Sqr(g1)) * tmp_1007;
   std::complex<double> tmp_1009;
   std::complex<double> tmp_1010;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1010 += Conj(ZU(gI2,3 + j1))*ZU(gI1,3 + j1);
   }
   tmp_1009 += tmp_1010;
   tmp_998 += (std::complex<double>(0,0.2)*KroneckerDelta(1,gO1)*KroneckerDelta
      (1,gO2)*Sqr(g1)) * tmp_1009;
   std::complex<double> tmp_1011;
   std::complex<double> tmp_1012;
   for (unsigned j3 = 0; j3 < 3; ++j3) {
      std::complex<double> tmp_1013;
      std::complex<double> tmp_1014;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         std::complex<double> tmp_1015;
         std::complex<double> tmp_1016;
         for (unsigned j1 = 0; j1 < 3; ++j1) {
            tmp_1016 += Conj(Yu(j3,j1))*Yu(j2,j1);
         }
         tmp_1015 += tmp_1016;
         tmp_1014 += (ZU(gI1,3 + j2)) * tmp_1015;
      }
      tmp_1013 += tmp_1014;
      tmp_1012 += (Conj(ZU(gI2,3 + j3))) * tmp_1013;
   }
   tmp_1011 += tmp_1012;
   tmp_998 += (std::complex<double>(0,-1)*KroneckerDelta(1,gO1)*KroneckerDelta(
      1,gO2)) * tmp_1011;
   std::complex<double> tmp_1017;
   std::complex<double> tmp_1018;
   for (unsigned j3 = 0; j3 < 3; ++j3) {
      std::complex<double> tmp_1019;
      std::complex<double> tmp_1020;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         std::complex<double> tmp_1021;
         std::complex<double> tmp_1022;
         for (unsigned j1 = 0; j1 < 3; ++j1) {
            tmp_1022 += Conj(Yu(j1,j3))*Yu(j1,j2);
         }
         tmp_1021 += tmp_1022;
         tmp_1020 += (Conj(ZU(gI2,j2))) * tmp_1021;
      }
      tmp_1019 += tmp_1020;
      tmp_1018 += (ZU(gI1,j3)) * tmp_1019;
   }
   tmp_1017 += tmp_1018;
   tmp_998 += (std::complex<double>(0,-1)*KroneckerDelta(1,gO1)*KroneckerDelta(
      1,gO2)) * tmp_1017;
   result += (std::complex<double>(0,-1)) * tmp_998;

   return result;
}

std::complex<double> CLASSNAME::CpUhhconjSdSd(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1023;
   std::complex<double> tmp_1024;
   std::complex<double> tmp_1025;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1025 += Conj(ZD(gI2,j1))*ZD(gI1,j1);
   }
   tmp_1024 += tmp_1025;
   tmp_1023 += (std::complex<double>(0,0.05)*vd*KroneckerDelta(0,gO2)*Sqr(g1))
      * tmp_1024;
   std::complex<double> tmp_1026;
   std::complex<double> tmp_1027;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1027 += Conj(ZD(gI2,j1))*ZD(gI1,j1);
   }
   tmp_1026 += tmp_1027;
   tmp_1023 += (std::complex<double>(0,0.25)*vd*KroneckerDelta(0,gO2)*Sqr(g2))
      * tmp_1026;
   std::complex<double> tmp_1028;
   std::complex<double> tmp_1029;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1029 += Conj(ZD(gI2,j1))*ZD(gI1,j1);
   }
   tmp_1028 += tmp_1029;
   tmp_1023 += (std::complex<double>(0,-0.05)*vu*KroneckerDelta(1,gO2)*Sqr(g1))
      * tmp_1028;
   std::complex<double> tmp_1030;
   std::complex<double> tmp_1031;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1031 += Conj(ZD(gI2,j1))*ZD(gI1,j1);
   }
   tmp_1030 += tmp_1031;
   tmp_1023 += (std::complex<double>(0,-0.25)*vu*KroneckerDelta(1,gO2)*Sqr(g2))
      * tmp_1030;
   std::complex<double> tmp_1032;
   std::complex<double> tmp_1033;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1033 += Conj(ZD(gI2,j1))*ZD(gI1,j1);
   }
   tmp_1032 += tmp_1033;
   tmp_1023 += (std::complex<double>(0.,-0.12909944487358055)*g1*MDBS*
      KroneckerDelta(2,gO2)) * tmp_1032;
   std::complex<double> tmp_1034;
   std::complex<double> tmp_1035;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1035 += Conj(ZD(gI2,j1))*ZD(gI1,j1);
   }
   tmp_1034 += tmp_1035;
   tmp_1023 += (std::complex<double>(0.,-0.12909944487358055)*g1*Conj(MDBS)*
      KroneckerDelta(2,gO2)) * tmp_1034;
   std::complex<double> tmp_1036;
   std::complex<double> tmp_1037;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1037 += Conj(ZD(gI2,j1))*ZD(gI1,j1);
   }
   tmp_1036 += tmp_1037;
   tmp_1023 += (std::complex<double>(0,0.5)*g2*MDWBT*KroneckerDelta(3,gO2)) *
      tmp_1036;
   std::complex<double> tmp_1038;
   std::complex<double> tmp_1039;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1039 += Conj(ZD(gI2,j1))*ZD(gI1,j1);
   }
   tmp_1038 += tmp_1039;
   tmp_1023 += (std::complex<double>(0,0.5)*g2*Conj(MDWBT)*KroneckerDelta(3,gO2
      )) * tmp_1038;
   std::complex<double> tmp_1040;
   std::complex<double> tmp_1041;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1041 += Conj(ZD(gI2,3 + j1))*ZD(gI1,3 + j1);
   }
   tmp_1040 += tmp_1041;
   tmp_1023 += (std::complex<double>(0,0.1)*vd*KroneckerDelta(0,gO2)*Sqr(g1)) *
      tmp_1040;
   std::complex<double> tmp_1042;
   std::complex<double> tmp_1043;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1043 += Conj(ZD(gI2,3 + j1))*ZD(gI1,3 + j1);
   }
   tmp_1042 += tmp_1043;
   tmp_1023 += (std::complex<double>(0,-0.1)*vu*KroneckerDelta(1,gO2)*Sqr(g1))
      * tmp_1042;
   std::complex<double> tmp_1044;
   std::complex<double> tmp_1045;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1045 += Conj(ZD(gI2,3 + j1))*ZD(gI1,3 + j1);
   }
   tmp_1044 += tmp_1045;
   tmp_1023 += (std::complex<double>(0.,-0.2581988897471611)*g1*MDBS*
      KroneckerDelta(2,gO2)) * tmp_1044;
   std::complex<double> tmp_1046;
   std::complex<double> tmp_1047;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1047 += Conj(ZD(gI2,3 + j1))*ZD(gI1,3 + j1);
   }
   tmp_1046 += tmp_1047;
   tmp_1023 += (std::complex<double>(0.,-0.2581988897471611)*g1*Conj(MDBS)*
      KroneckerDelta(2,gO2)) * tmp_1046;
   std::complex<double> tmp_1048;
   std::complex<double> tmp_1049;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_1050;
      std::complex<double> tmp_1051;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1051 += Yd(j1,j2)*ZD(gI1,3 + j1);
      }
      tmp_1050 += tmp_1051;
      tmp_1049 += (Conj(ZD(gI2,j2))) * tmp_1050;
   }
   tmp_1048 += tmp_1049;
   tmp_1023 += (std::complex<double>(0.,0.7071067811865475)*Conj(Mu)*
      KroneckerDelta(1,gO2)) * tmp_1048;
   std::complex<double> tmp_1052;
   std::complex<double> tmp_1053;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_1054;
      std::complex<double> tmp_1055;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1055 += Conj(Yd(j1,j2))*Conj(ZD(gI2,3 + j1));
      }
      tmp_1054 += tmp_1055;
      tmp_1053 += (ZD(gI1,j2)) * tmp_1054;
   }
   tmp_1052 += tmp_1053;
   tmp_1023 += (std::complex<double>(0.,0.7071067811865475)*KroneckerDelta(1,
      gO2)*Mu) * tmp_1052;
   std::complex<double> tmp_1056;
   std::complex<double> tmp_1057;
   for (unsigned j3 = 0; j3 < 3; ++j3) {
      std::complex<double> tmp_1058;
      std::complex<double> tmp_1059;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         std::complex<double> tmp_1060;
         std::complex<double> tmp_1061;
         for (unsigned j1 = 0; j1 < 3; ++j1) {
            tmp_1061 += Conj(Yd(j3,j1))*Yd(j2,j1);
         }
         tmp_1060 += tmp_1061;
         tmp_1059 += (ZD(gI1,3 + j2)) * tmp_1060;
      }
      tmp_1058 += tmp_1059;
      tmp_1057 += (Conj(ZD(gI2,3 + j3))) * tmp_1058;
   }
   tmp_1056 += tmp_1057;
   tmp_1023 += (std::complex<double>(0,-1)*vd*KroneckerDelta(0,gO2)) * tmp_1056
      ;
   std::complex<double> tmp_1062;
   std::complex<double> tmp_1063;
   for (unsigned j3 = 0; j3 < 3; ++j3) {
      std::complex<double> tmp_1064;
      std::complex<double> tmp_1065;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         std::complex<double> tmp_1066;
         std::complex<double> tmp_1067;
         for (unsigned j1 = 0; j1 < 3; ++j1) {
            tmp_1067 += Conj(Yd(j1,j3))*Yd(j1,j2);
         }
         tmp_1066 += tmp_1067;
         tmp_1065 += (Conj(ZD(gI2,j2))) * tmp_1066;
      }
      tmp_1064 += tmp_1065;
      tmp_1063 += (ZD(gI1,j3)) * tmp_1064;
   }
   tmp_1062 += tmp_1063;
   tmp_1023 += (std::complex<double>(0,-1)*vd*KroneckerDelta(0,gO2)) * tmp_1062
      ;
   result += (std::complex<double>(0,-1)) * tmp_1023;

   return result;
}

std::complex<double> CLASSNAME::CpUhhconjSeSe(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1068;
   std::complex<double> tmp_1069;
   std::complex<double> tmp_1070;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1070 += Conj(ZE(gI2,j1))*ZE(gI1,j1);
   }
   tmp_1069 += tmp_1070;
   tmp_1068 += (std::complex<double>(0,-0.15)*vd*KroneckerDelta(0,gO2)*Sqr(g1))
      * tmp_1069;
   std::complex<double> tmp_1071;
   std::complex<double> tmp_1072;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1072 += Conj(ZE(gI2,j1))*ZE(gI1,j1);
   }
   tmp_1071 += tmp_1072;
   tmp_1068 += (std::complex<double>(0,0.25)*vd*KroneckerDelta(0,gO2)*Sqr(g2))
      * tmp_1071;
   std::complex<double> tmp_1073;
   std::complex<double> tmp_1074;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1074 += Conj(ZE(gI2,j1))*ZE(gI1,j1);
   }
   tmp_1073 += tmp_1074;
   tmp_1068 += (std::complex<double>(0,0.15)*vu*KroneckerDelta(1,gO2)*Sqr(g1))
      * tmp_1073;
   std::complex<double> tmp_1075;
   std::complex<double> tmp_1076;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1076 += Conj(ZE(gI2,j1))*ZE(gI1,j1);
   }
   tmp_1075 += tmp_1076;
   tmp_1068 += (std::complex<double>(0,-0.25)*vu*KroneckerDelta(1,gO2)*Sqr(g2))
      * tmp_1075;
   std::complex<double> tmp_1077;
   std::complex<double> tmp_1078;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1078 += Conj(ZE(gI2,j1))*ZE(gI1,j1);
   }
   tmp_1077 += tmp_1078;
   tmp_1068 += (std::complex<double>(0.,0.3872983346207417)*g1*MDBS*
      KroneckerDelta(2,gO2)) * tmp_1077;
   std::complex<double> tmp_1079;
   std::complex<double> tmp_1080;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1080 += Conj(ZE(gI2,j1))*ZE(gI1,j1);
   }
   tmp_1079 += tmp_1080;
   tmp_1068 += (std::complex<double>(0.,0.3872983346207417)*g1*Conj(MDBS)*
      KroneckerDelta(2,gO2)) * tmp_1079;
   std::complex<double> tmp_1081;
   std::complex<double> tmp_1082;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1082 += Conj(ZE(gI2,j1))*ZE(gI1,j1);
   }
   tmp_1081 += tmp_1082;
   tmp_1068 += (std::complex<double>(0,0.5)*g2*MDWBT*KroneckerDelta(3,gO2)) *
      tmp_1081;
   std::complex<double> tmp_1083;
   std::complex<double> tmp_1084;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1084 += Conj(ZE(gI2,j1))*ZE(gI1,j1);
   }
   tmp_1083 += tmp_1084;
   tmp_1068 += (std::complex<double>(0,0.5)*g2*Conj(MDWBT)*KroneckerDelta(3,gO2
      )) * tmp_1083;
   std::complex<double> tmp_1085;
   std::complex<double> tmp_1086;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1086 += Conj(ZE(gI2,3 + j1))*ZE(gI1,3 + j1);
   }
   tmp_1085 += tmp_1086;
   tmp_1068 += (std::complex<double>(0,0.3)*vd*KroneckerDelta(0,gO2)*Sqr(g1)) *
      tmp_1085;
   std::complex<double> tmp_1087;
   std::complex<double> tmp_1088;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1088 += Conj(ZE(gI2,3 + j1))*ZE(gI1,3 + j1);
   }
   tmp_1087 += tmp_1088;
   tmp_1068 += (std::complex<double>(0,-0.3)*vu*KroneckerDelta(1,gO2)*Sqr(g1))
      * tmp_1087;
   std::complex<double> tmp_1089;
   std::complex<double> tmp_1090;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1090 += Conj(ZE(gI2,3 + j1))*ZE(gI1,3 + j1);
   }
   tmp_1089 += tmp_1090;
   tmp_1068 += (std::complex<double>(0.,-0.7745966692414834)*g1*MDBS*
      KroneckerDelta(2,gO2)) * tmp_1089;
   std::complex<double> tmp_1091;
   std::complex<double> tmp_1092;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1092 += Conj(ZE(gI2,3 + j1))*ZE(gI1,3 + j1);
   }
   tmp_1091 += tmp_1092;
   tmp_1068 += (std::complex<double>(0.,-0.7745966692414834)*g1*Conj(MDBS)*
      KroneckerDelta(2,gO2)) * tmp_1091;
   std::complex<double> tmp_1093;
   std::complex<double> tmp_1094;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_1095;
      std::complex<double> tmp_1096;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1096 += Ye(j1,j2)*ZE(gI1,3 + j1);
      }
      tmp_1095 += tmp_1096;
      tmp_1094 += (Conj(ZE(gI2,j2))) * tmp_1095;
   }
   tmp_1093 += tmp_1094;
   tmp_1068 += (std::complex<double>(0.,0.7071067811865475)*Conj(Mu)*
      KroneckerDelta(1,gO2)) * tmp_1093;
   std::complex<double> tmp_1097;
   std::complex<double> tmp_1098;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_1099;
      std::complex<double> tmp_1100;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1100 += Conj(Ye(j1,j2))*Conj(ZE(gI2,3 + j1));
      }
      tmp_1099 += tmp_1100;
      tmp_1098 += (ZE(gI1,j2)) * tmp_1099;
   }
   tmp_1097 += tmp_1098;
   tmp_1068 += (std::complex<double>(0.,0.7071067811865475)*KroneckerDelta(1,
      gO2)*Mu) * tmp_1097;
   std::complex<double> tmp_1101;
   std::complex<double> tmp_1102;
   for (unsigned j3 = 0; j3 < 3; ++j3) {
      std::complex<double> tmp_1103;
      std::complex<double> tmp_1104;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         std::complex<double> tmp_1105;
         std::complex<double> tmp_1106;
         for (unsigned j1 = 0; j1 < 3; ++j1) {
            tmp_1106 += Conj(Ye(j3,j1))*Ye(j2,j1);
         }
         tmp_1105 += tmp_1106;
         tmp_1104 += (ZE(gI1,3 + j2)) * tmp_1105;
      }
      tmp_1103 += tmp_1104;
      tmp_1102 += (Conj(ZE(gI2,3 + j3))) * tmp_1103;
   }
   tmp_1101 += tmp_1102;
   tmp_1068 += (std::complex<double>(0,-1)*vd*KroneckerDelta(0,gO2)) * tmp_1101
      ;
   std::complex<double> tmp_1107;
   std::complex<double> tmp_1108;
   for (unsigned j3 = 0; j3 < 3; ++j3) {
      std::complex<double> tmp_1109;
      std::complex<double> tmp_1110;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         std::complex<double> tmp_1111;
         std::complex<double> tmp_1112;
         for (unsigned j1 = 0; j1 < 3; ++j1) {
            tmp_1112 += Conj(Ye(j1,j3))*Ye(j1,j2);
         }
         tmp_1111 += tmp_1112;
         tmp_1110 += (Conj(ZE(gI2,j2))) * tmp_1111;
      }
      tmp_1109 += tmp_1110;
      tmp_1108 += (ZE(gI1,j3)) * tmp_1109;
   }
   tmp_1107 += tmp_1108;
   tmp_1068 += (std::complex<double>(0,-1)*vd*KroneckerDelta(0,gO2)) * tmp_1107
      ;
   result += (std::complex<double>(0,-1)) * tmp_1068;

   return result;
}

std::complex<double> CLASSNAME::CpUhhconjSuSu(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1113;
   std::complex<double> tmp_1114;
   std::complex<double> tmp_1115;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1115 += Conj(ZU(gI2,j1))*ZU(gI1,j1);
   }
   tmp_1114 += tmp_1115;
   tmp_1113 += (std::complex<double>(0,0.05)*vd*KroneckerDelta(0,gO2)*Sqr(g1))
      * tmp_1114;
   std::complex<double> tmp_1116;
   std::complex<double> tmp_1117;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1117 += Conj(ZU(gI2,j1))*ZU(gI1,j1);
   }
   tmp_1116 += tmp_1117;
   tmp_1113 += (std::complex<double>(0,-0.25)*vd*KroneckerDelta(0,gO2)*Sqr(g2))
      * tmp_1116;
   std::complex<double> tmp_1118;
   std::complex<double> tmp_1119;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1119 += Conj(ZU(gI2,j1))*ZU(gI1,j1);
   }
   tmp_1118 += tmp_1119;
   tmp_1113 += (std::complex<double>(0,-0.05)*vu*KroneckerDelta(1,gO2)*Sqr(g1))
      * tmp_1118;
   std::complex<double> tmp_1120;
   std::complex<double> tmp_1121;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1121 += Conj(ZU(gI2,j1))*ZU(gI1,j1);
   }
   tmp_1120 += tmp_1121;
   tmp_1113 += (std::complex<double>(0,0.25)*vu*KroneckerDelta(1,gO2)*Sqr(g2))
      * tmp_1120;
   std::complex<double> tmp_1122;
   std::complex<double> tmp_1123;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1123 += Conj(ZU(gI2,j1))*ZU(gI1,j1);
   }
   tmp_1122 += tmp_1123;
   tmp_1113 += (std::complex<double>(0.,-0.12909944487358055)*g1*MDBS*
      KroneckerDelta(2,gO2)) * tmp_1122;
   std::complex<double> tmp_1124;
   std::complex<double> tmp_1125;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1125 += Conj(ZU(gI2,j1))*ZU(gI1,j1);
   }
   tmp_1124 += tmp_1125;
   tmp_1113 += (std::complex<double>(0.,-0.12909944487358055)*g1*Conj(MDBS)*
      KroneckerDelta(2,gO2)) * tmp_1124;
   std::complex<double> tmp_1126;
   std::complex<double> tmp_1127;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1127 += Conj(ZU(gI2,j1))*ZU(gI1,j1);
   }
   tmp_1126 += tmp_1127;
   tmp_1113 += (std::complex<double>(0,-0.5)*g2*MDWBT*KroneckerDelta(3,gO2)) *
      tmp_1126;
   std::complex<double> tmp_1128;
   std::complex<double> tmp_1129;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1129 += Conj(ZU(gI2,j1))*ZU(gI1,j1);
   }
   tmp_1128 += tmp_1129;
   tmp_1113 += (std::complex<double>(0,-0.5)*g2*Conj(MDWBT)*KroneckerDelta(3,
      gO2)) * tmp_1128;
   std::complex<double> tmp_1130;
   std::complex<double> tmp_1131;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1131 += Conj(ZU(gI2,3 + j1))*ZU(gI1,3 + j1);
   }
   tmp_1130 += tmp_1131;
   tmp_1113 += (std::complex<double>(0,-0.2)*vd*KroneckerDelta(0,gO2)*Sqr(g1))
      * tmp_1130;
   std::complex<double> tmp_1132;
   std::complex<double> tmp_1133;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1133 += Conj(ZU(gI2,3 + j1))*ZU(gI1,3 + j1);
   }
   tmp_1132 += tmp_1133;
   tmp_1113 += (std::complex<double>(0,0.2)*vu*KroneckerDelta(1,gO2)*Sqr(g1)) *
      tmp_1132;
   std::complex<double> tmp_1134;
   std::complex<double> tmp_1135;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1135 += Conj(ZU(gI2,3 + j1))*ZU(gI1,3 + j1);
   }
   tmp_1134 += tmp_1135;
   tmp_1113 += (std::complex<double>(0.,0.5163977794943222)*g1*MDBS*
      KroneckerDelta(2,gO2)) * tmp_1134;
   std::complex<double> tmp_1136;
   std::complex<double> tmp_1137;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1137 += Conj(ZU(gI2,3 + j1))*ZU(gI1,3 + j1);
   }
   tmp_1136 += tmp_1137;
   tmp_1113 += (std::complex<double>(0.,0.5163977794943222)*g1*Conj(MDBS)*
      KroneckerDelta(2,gO2)) * tmp_1136;
   std::complex<double> tmp_1138;
   std::complex<double> tmp_1139;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_1140;
      std::complex<double> tmp_1141;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1141 += Yu(j1,j2)*ZU(gI1,3 + j1);
      }
      tmp_1140 += tmp_1141;
      tmp_1139 += (Conj(ZU(gI2,j2))) * tmp_1140;
   }
   tmp_1138 += tmp_1139;
   tmp_1113 += (std::complex<double>(0.,0.7071067811865475)*Conj(Mu)*
      KroneckerDelta(0,gO2)) * tmp_1138;
   std::complex<double> tmp_1142;
   std::complex<double> tmp_1143;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_1144;
      std::complex<double> tmp_1145;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1145 += Conj(Yu(j1,j2))*Conj(ZU(gI2,3 + j1));
      }
      tmp_1144 += tmp_1145;
      tmp_1143 += (ZU(gI1,j2)) * tmp_1144;
   }
   tmp_1142 += tmp_1143;
   tmp_1113 += (std::complex<double>(0.,0.7071067811865475)*KroneckerDelta(0,
      gO2)*Mu) * tmp_1142;
   std::complex<double> tmp_1146;
   std::complex<double> tmp_1147;
   for (unsigned j3 = 0; j3 < 3; ++j3) {
      std::complex<double> tmp_1148;
      std::complex<double> tmp_1149;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         std::complex<double> tmp_1150;
         std::complex<double> tmp_1151;
         for (unsigned j1 = 0; j1 < 3; ++j1) {
            tmp_1151 += Conj(Yu(j3,j1))*Yu(j2,j1);
         }
         tmp_1150 += tmp_1151;
         tmp_1149 += (ZU(gI1,3 + j2)) * tmp_1150;
      }
      tmp_1148 += tmp_1149;
      tmp_1147 += (Conj(ZU(gI2,3 + j3))) * tmp_1148;
   }
   tmp_1146 += tmp_1147;
   tmp_1113 += (std::complex<double>(0,-1)*vu*KroneckerDelta(1,gO2)) * tmp_1146
      ;
   std::complex<double> tmp_1152;
   std::complex<double> tmp_1153;
   for (unsigned j3 = 0; j3 < 3; ++j3) {
      std::complex<double> tmp_1154;
      std::complex<double> tmp_1155;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         std::complex<double> tmp_1156;
         std::complex<double> tmp_1157;
         for (unsigned j1 = 0; j1 < 3; ++j1) {
            tmp_1157 += Conj(Yu(j1,j3))*Yu(j1,j2);
         }
         tmp_1156 += tmp_1157;
         tmp_1155 += (Conj(ZU(gI2,j2))) * tmp_1156;
      }
      tmp_1154 += tmp_1155;
      tmp_1153 += (ZU(gI1,j3)) * tmp_1154;
   }
   tmp_1152 += tmp_1153;
   tmp_1113 += (std::complex<double>(0,-1)*vu*KroneckerDelta(1,gO2)) * tmp_1152
      ;
   result += (std::complex<double>(0,-1)) * tmp_1113;

   return result;
}

std::complex<double> CLASSNAME::CpUhhVZAh(unsigned gO2, unsigned gI2) const
{
   std::complex<double> result;

   result = std::complex<double>(0,-0.1)*(5*g2*Cos(ThetaW()) +
      3.872983346207417*g1*Sin(ThetaW()))*(KroneckerDelta(0,gO2)*ZA(gI2,0) -
      KroneckerDelta(1,gO2)*ZA(gI2,1));

   return result;
}

std::complex<double> CLASSNAME::CpUhhconjVWmHpm(unsigned gO2, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.5*g2*(KroneckerDelta(0,gO2)*ZP(gI2,0) - KroneckerDelta(1,gO2)*ZP(
      gI2,1) + 1.4142135623730951*KroneckerDelta(3,gO2)*(ZP(gI2,2) + ZP(gI2,3)));

   return result;
}

std::complex<double> CLASSNAME::CpUAhbargWmgWm(unsigned gO1) const
{
   std::complex<double> result;

   result = std::complex<double>(0,-0.25)*(vd*KroneckerDelta(0,gO1) - vu*
      KroneckerDelta(1,gO1))*Sqr(g2);

   return result;
}

std::complex<double> CLASSNAME::CpUAhbargWmCgWmC(unsigned gO1) const
{
   std::complex<double> result;

   result = std::complex<double>(0,0.25)*(vd*KroneckerDelta(0,gO1) - vu*
      KroneckerDelta(1,gO1))*Sqr(g2);

   return result;
}

std::complex<double> CLASSNAME::CpUAhUAhVZVZ(unsigned gO1, unsigned gO2) const
{
   std::complex<double> result;

   result = 0.05*(KroneckerDelta(0,gO1)*KroneckerDelta(0,gO2) + KroneckerDelta(
      1,gO1)*KroneckerDelta(1,gO2))*(7.745966692414834*g1*g2*Sin(2*ThetaW()) + 3*
      Sqr(g1) + 5*Sqr(g2) + Cos(2*ThetaW())*(-3*Sqr(g1) + 5*Sqr(g2)));

   return result;
}

std::complex<double> CLASSNAME::CpUAhUAhconjVWmVWm(unsigned gO1, unsigned gO2) const
{
   std::complex<double> result;

   result = 0.5*(KroneckerDelta(0,gO1)*KroneckerDelta(0,gO2) + KroneckerDelta(1
      ,gO1)*KroneckerDelta(1,gO2) + 4*KroneckerDelta(3,gO1)*KroneckerDelta(3,gO2))
      *Sqr(g2);

   return result;
}

std::complex<double> CLASSNAME::CpUAhUAhconjRhRh(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.05*(-5*(Conj(LamTD)*(1.4142135623730951*LamSD*KroneckerDelta(2,
      gO2)*KroneckerDelta(3,gO1) + (1.4142135623730951*LamSD*KroneckerDelta(2,gO1)
      + 2*LamTD*KroneckerDelta(3,gO1))*KroneckerDelta(3,gO2))*ZHR(gI1,0)*ZHR(gI2,
      0) + Conj(LamSD)*(1.4142135623730951*LamTD*KroneckerDelta(2,gO2)*
      KroneckerDelta(3,gO1) + KroneckerDelta(2,gO1)*(4*LamSD*KroneckerDelta(2,gO2)
      + 1.4142135623730951*LamTD*KroneckerDelta(3,gO2)))*ZHR(gI1,0)*ZHR(gI2,0) +
      (-(Conj(LamTU)*(1.4142135623730951*LamSU*KroneckerDelta(2,gO2)*
      KroneckerDelta(3,gO1) + (1.4142135623730951*LamSU*KroneckerDelta(2,gO1) - 2*
      LamTU*KroneckerDelta(3,gO1))*KroneckerDelta(3,gO2))) - Conj(LamSU)*(
      1.4142135623730951*LamTU*KroneckerDelta(2,gO2)*KroneckerDelta(3,gO1) +
      KroneckerDelta(2,gO1)*(-4*LamSU*KroneckerDelta(2,gO2) + 1.4142135623730951*
      LamTU*KroneckerDelta(3,gO2))))*ZHR(gI1,1)*ZHR(gI2,1)) - KroneckerDelta(1,gO1
      )*(5*KroneckerDelta(0,gO2)*(-2*LamSD*Conj(LamSU)*ZHR(gI1,1)*ZHR(gI2,0) +
      LamTD*Conj(LamTU)*ZHR(gI1,1)*ZHR(gI2,0) + (-2*LamSU*Conj(LamSD) + LamTU*Conj
      (LamTD))*ZHR(gI1,0)*ZHR(gI2,1)) + KroneckerDelta(1,gO2)*((3*Sqr(g1) + 5*Sqr(
      g2))*ZHR(gI1,0)*ZHR(gI2,0) + (20*AbsSqr(LamSU) + 10*AbsSqr(LamTU) - 3*Sqr(g1
      ) - 5*Sqr(g2))*ZHR(gI1,1)*ZHR(gI2,1))) + KroneckerDelta(0,gO1)*(5*
      KroneckerDelta(1,gO2)*(2*LamSD*Conj(LamSU)*ZHR(gI1,1)*ZHR(gI2,0) - LamTD*
      Conj(LamTU)*ZHR(gI1,1)*ZHR(gI2,0) + (2*LamSU*Conj(LamSD) - LamTU*Conj(LamTD)
      )*ZHR(gI1,0)*ZHR(gI2,1)) + KroneckerDelta(0,gO2)*((-20*AbsSqr(LamSD) - 10*
      AbsSqr(LamTD) + 3*Sqr(g1) + 5*Sqr(g2))*ZHR(gI1,0)*ZHR(gI2,0) - (3*Sqr(g1) +
      5*Sqr(g2))*ZHR(gI1,1)*ZHR(gI2,1))));

   return result;
}

std::complex<double> CLASSNAME::CpUAhUAhconjRpmRpm(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.05*(-(Conj(ZRP(gI2,0))*(5*(Conj(LamTU)*(1.4142135623730951*LamSU*
      KroneckerDelta(2,gO2)*KroneckerDelta(3,gO1) + (1.4142135623730951*LamSU*
      KroneckerDelta(2,gO1) + 2*LamTU*KroneckerDelta(3,gO1))*KroneckerDelta(3,gO2)
      ) + Conj(LamSU)*(1.4142135623730951*LamTU*KroneckerDelta(2,gO2)*
      KroneckerDelta(3,gO1) + KroneckerDelta(2,gO1)*(4*LamSU*KroneckerDelta(2,gO2)
      + 1.4142135623730951*LamTU*KroneckerDelta(3,gO2)))) + KroneckerDelta(0,gO1)
      *KroneckerDelta(0,gO2)*(3*Sqr(g1) - 5*Sqr(g2)) + KroneckerDelta(1,gO1)*
      KroneckerDelta(1,gO2)*(20*AbsSqr(LamTU) - 3*Sqr(g1) + 5*Sqr(g2)))*ZRP(gI1,0)
      ) + Conj(ZRP(gI2,1))*(5*(Conj(LamTD)*(1.4142135623730951*LamSD*
      KroneckerDelta(2,gO2)*KroneckerDelta(3,gO1) + (1.4142135623730951*LamSD*
      KroneckerDelta(2,gO1) - 2*LamTD*KroneckerDelta(3,gO1))*KroneckerDelta(3,gO2)
      ) + Conj(LamSD)*(1.4142135623730951*LamTD*KroneckerDelta(2,gO2)*
      KroneckerDelta(3,gO1) + KroneckerDelta(2,gO1)*(-4*LamSD*KroneckerDelta(2,gO2
      ) + 1.4142135623730951*LamTD*KroneckerDelta(3,gO2)))) + KroneckerDelta(0,gO1
      )*KroneckerDelta(0,gO2)*(-20*AbsSqr(LamTD) + 3*Sqr(g1) - 5*Sqr(g2)) +
      KroneckerDelta(1,gO1)*KroneckerDelta(1,gO2)*(-3*Sqr(g1) + 5*Sqr(g2)))*ZRP(
      gI1,1));

   return result;
}

std::complex<double> CLASSNAME::CpUAhconjRhRh(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = std::complex<double>(0,-0.05)*(KroneckerDelta(2,gO2)*((
      7.745966692414834*g1*MDBS - 7.0710678118654755*(2*MuD + LamTD*vT)*Conj(LamSD
      ) + 7.0710678118654755*LamSD*vT*Conj(LamTD) - 7.745966692414834*g1*Conj(MDBS
      ) + 14.142135623730951*LamSD*Conj(MuD))*ZHR(gI1,0)*ZHR(gI2,0) + (
      -7.745966692414834*g1*MDBS + 7.0710678118654755*(-2*MuU + LamTU*vT)*Conj(
      LamSU) - 7.0710678118654755*LamSU*vT*Conj(LamTU) + 7.745966692414834*g1*Conj
      (MDBS) + 14.142135623730951*LamSU*Conj(MuU))*ZHR(gI1,1)*ZHR(gI2,1)) - 5*((vu
      *KroneckerDelta(0,gO2) - vd*KroneckerDelta(1,gO2))*(2*LamSD*Conj(LamSU)*ZHR(
      gI1,1)*ZHR(gI2,0) - LamTD*Conj(LamTU)*ZHR(gI1,1)*ZHR(gI2,0) + (-2*LamSU*Conj
      (LamSD) + LamTU*Conj(LamTD))*ZHR(gI1,0)*ZHR(gI2,1)) + KroneckerDelta(3,gO2)*
      ((2*g2*MDWBT - 1.4142135623730951*LamTD*vS*Conj(LamSD) + (2*MuD +
      1.4142135623730951*LamSD*vS)*Conj(LamTD) - 2*g2*Conj(MDWBT) - 2*LamTD*Conj(
      MuD))*ZHR(gI1,0)*ZHR(gI2,0) + (-2*g2*MDWBT + 1.4142135623730951*LamTU*vS*
      Conj(LamSU) - (2*MuU + 1.4142135623730951*LamSU*vS)*Conj(LamTU) + 2*g2*Conj(
      MDWBT) + 2*LamTU*Conj(MuU))*ZHR(gI1,1)*ZHR(gI2,1))));

   return result;
}

std::complex<double> CLASSNAME::CpUAhconjRpmRpm(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = std::complex<double>(0,0.05)*(Conj(ZRP(gI2,0))*((7.745966692414834*
      g1*MDBS + 7.0710678118654755*(2*MuU + LamTU*vT)*Conj(LamSU) -
      7.0710678118654755*LamSU*vT*Conj(LamTU) - 7.745966692414834*g1*Conj(MDBS) -
      14.142135623730951*LamSU*Conj(MuU))*KroneckerDelta(2,gO2) + 5*(2*g2*MDWBT -
      1.4142135623730951*LamTU*vS*Conj(LamSU) + 2*MuU*Conj(LamTU) +
      1.4142135623730951*LamSU*vS*Conj(LamTU) - 2*g2*Conj(MDWBT) - 2*LamTU*Conj(
      MuU))*KroneckerDelta(3,gO2))*ZRP(gI1,0) + Conj(ZRP(gI2,1))*((
      -7.745966692414834*g1*MDBS + 7.0710678118654755*(2*MuD - LamTD*vT)*Conj(
      LamSD) + 7.0710678118654755*LamSD*vT*Conj(LamTD) + 7.745966692414834*g1*Conj
      (MDBS) - 14.142135623730951*LamSD*Conj(MuD))*KroneckerDelta(2,gO2) - 5*(2*g2
      *MDWBT - 1.4142135623730951*LamTD*vS*Conj(LamSD) + 2*MuD*Conj(LamTD) +
      1.4142135623730951*LamSD*vS*Conj(LamTD) - 2*g2*Conj(MDWBT) - 2*LamTD*Conj(
      MuD))*KroneckerDelta(3,gO2))*ZRP(gI1,1));

   return result;
}

std::complex<double> CLASSNAME::CpUAhbarCha1Cha1PR(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = std::complex<double>(0,-0.5)*(KroneckerDelta(3,gO2)*(2*g2*UM1(gI2,0
      )*UP1(gI1,0) + Conj(LamTD)*UM1(gI2,1)*UP1(gI1,1)) + 1.4142135623730951*(-(
      Conj(LamSD)*KroneckerDelta(2,gO2)*UM1(gI2,1)*UP1(gI1,1)) + KroneckerDelta(0,
      gO2)*(g2*UM1(gI2,1)*UP1(gI1,0) - Conj(LamTD)*UM1(gI2,0)*UP1(gI1,1))));

   return result;
}

std::complex<double> CLASSNAME::CpUAhbarCha1Cha1PL(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = std::complex<double>(0,0.5)*(Conj(UM1(gI1,0))*(-1.4142135623730951*
      LamTD*Conj(UP1(gI2,1))*KroneckerDelta(0,gO1) + 2*g2*Conj(UP1(gI2,0))*
      KroneckerDelta(3,gO1)) + Conj(UM1(gI1,1))*(1.4142135623730951*g2*Conj(UP1(
      gI2,0))*KroneckerDelta(0,gO1) + Conj(UP1(gI2,1))*(-1.4142135623730951*LamSD*
      KroneckerDelta(2,gO1) + LamTD*KroneckerDelta(3,gO1))));

   return result;
}

std::complex<double> CLASSNAME::CpUAhbarCha2Cha2PR(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = std::complex<double>(0,0.5)*(KroneckerDelta(3,gO2)*(2*g2*UM2(gI1,0)
      *UP2(gI2,0) - Conj(LamTU)*UM2(gI1,1)*UP2(gI2,1)) - 1.4142135623730951*(Conj(
      LamTU)*KroneckerDelta(1,gO2)*UM2(gI1,1)*UP2(gI2,0) + (g2*KroneckerDelta(1,
      gO2)*UM2(gI1,0) + Conj(LamSU)*KroneckerDelta(2,gO2)*UM2(gI1,1))*UP2(gI2,1)))
      ;

   return result;
}

std::complex<double> CLASSNAME::CpUAhbarCha2Cha2PL(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = std::complex<double>(0,0.5)*(g2*Conj(UM2(gI2,0))*(
      1.4142135623730951*Conj(UP2(gI1,1))*KroneckerDelta(1,gO1) - 2*Conj(UP2(gI1,0
      ))*KroneckerDelta(3,gO1)) + Conj(UM2(gI2,1))*(1.4142135623730951*LamTU*Conj(
      UP2(gI1,0))*KroneckerDelta(1,gO1) + Conj(UP2(gI1,1))*(1.4142135623730951*
      LamSU*KroneckerDelta(2,gO1) + LamTU*KroneckerDelta(3,gO1))));

   return result;
}

std::complex<double> CLASSNAME::CpUAhconjRhAh(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = -0.25*Mu*(2*Conj(LamSD)*(KroneckerDelta(2,gO2)*ZA(gI2,1) +
      KroneckerDelta(1,gO2)*ZA(gI2,2))*ZHR(gI1,0) + 1.4142135623730951*Conj(LamTD)
      *(KroneckerDelta(3,gO2)*ZA(gI2,1) + KroneckerDelta(1,gO2)*ZA(gI2,3))*ZHR(gI1
      ,0) + (-2*Conj(LamSU)*(KroneckerDelta(2,gO2)*ZA(gI2,0) + KroneckerDelta(0,
      gO2)*ZA(gI2,2)) + 1.4142135623730951*Conj(LamTU)*(KroneckerDelta(3,gO2)*ZA(
      gI2,0) + KroneckerDelta(0,gO2)*ZA(gI2,3)))*ZHR(gI1,1));

   return result;
}

std::complex<double> CLASSNAME::CpUAhconjRhhh(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = std::complex<double>(0,0.25)*Mu*(2*Conj(LamSD)*(KroneckerDelta(2,
      gO2)*ZH(gI2,1) - KroneckerDelta(1,gO2)*ZH(gI2,2))*ZHR(gI1,0) +
      1.4142135623730951*Conj(LamTD)*(KroneckerDelta(3,gO2)*ZH(gI2,1) -
      KroneckerDelta(1,gO2)*ZH(gI2,3))*ZHR(gI1,0) + (Conj(LamSU)*(-2*
      KroneckerDelta(2,gO2)*ZH(gI2,0) + 2*KroneckerDelta(0,gO2)*ZH(gI2,2)) +
      1.4142135623730951*Conj(LamTU)*(KroneckerDelta(3,gO2)*ZH(gI2,0) -
      KroneckerDelta(0,gO2)*ZH(gI2,3)))*ZHR(gI1,1));

   return result;
}

std::complex<double> CLASSNAME::CpUAhconjRpmHpm(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = std::complex<double>(0,-0.5)*(1.4142135623730951*Conj(LamSU)*
      KroneckerDelta(2,gO2)*Mu*ZP(gI2,0)*ZRP(gI1,0) + Conj(LamTU)*Mu*(
      KroneckerDelta(3,gO2)*ZP(gI2,0) + 1.4142135623730951*KroneckerDelta(0,gO2)*
      ZP(gI2,3))*ZRP(gI1,0) + Conj(Mu)*(1.4142135623730951*LamSD*KroneckerDelta(2,
      gO2)*ZP(gI2,1) - LamTD*KroneckerDelta(3,gO2)*ZP(gI2,1) + 1.4142135623730951*
      LamTD*KroneckerDelta(1,gO2)*ZP(gI2,2))*ZRP(gI1,1));

   return result;
}

std::complex<double> CLASSNAME::CpUAhUAhconjSvSv(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = -0.05*(KroneckerDelta(0,gO1)*KroneckerDelta(0,gO2) - KroneckerDelta
      (1,gO1)*KroneckerDelta(1,gO2))*KroneckerDelta(gI1,gI2)*(3*Sqr(g1) + 5*Sqr(g2
      ));

   return result;
}

std::complex<double> CLASSNAME::CpUAhconjSvSv(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = std::complex<double>(0,0.1)*(3.872983346207417*g1*(MDBS - Conj(MDBS
      ))*KroneckerDelta(2,gO2) + 5*g2*(-MDWBT + Conj(MDWBT))*KroneckerDelta(3,gO2)
      )*KroneckerDelta(gI1,gI2);

   return result;
}

std::complex<double> CLASSNAME::CpUAhbarFdFdPR(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1158;
   std::complex<double> tmp_1159;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_1160;
      std::complex<double> tmp_1161;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1161 += Conj(Yd(j1,j2))*ZDR(gI2,j1);
      }
      tmp_1160 += tmp_1161;
      tmp_1159 += (ZDL(gI1,j2)) * tmp_1160;
   }
   tmp_1158 += tmp_1159;
   result += (std::complex<double>(0.,0.7071067811865475)*KroneckerDelta(0,gO2)
      ) * tmp_1158;

   return result;
}

std::complex<double> CLASSNAME::CpUAhbarFdFdPL(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1162;
   std::complex<double> tmp_1163;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_1164;
      std::complex<double> tmp_1165;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1165 += Conj(ZDR(gI1,j1))*Yd(j1,j2);
      }
      tmp_1164 += tmp_1165;
      tmp_1163 += (Conj(ZDL(gI2,j2))) * tmp_1164;
   }
   tmp_1162 += tmp_1163;
   result += (std::complex<double>(0.,-0.7071067811865475)*KroneckerDelta(0,gO1
      )) * tmp_1162;

   return result;
}

std::complex<double> CLASSNAME::CpUAhbarFeFePR(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1166;
   std::complex<double> tmp_1167;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_1168;
      std::complex<double> tmp_1169;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1169 += Conj(Ye(j1,j2))*ZER(gI2,j1);
      }
      tmp_1168 += tmp_1169;
      tmp_1167 += (ZEL(gI1,j2)) * tmp_1168;
   }
   tmp_1166 += tmp_1167;
   result += (std::complex<double>(0.,0.7071067811865475)*KroneckerDelta(0,gO2)
      ) * tmp_1166;

   return result;
}

std::complex<double> CLASSNAME::CpUAhbarFeFePL(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1170;
   std::complex<double> tmp_1171;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_1172;
      std::complex<double> tmp_1173;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1173 += Conj(ZER(gI1,j1))*Ye(j1,j2);
      }
      tmp_1172 += tmp_1173;
      tmp_1171 += (Conj(ZEL(gI2,j2))) * tmp_1172;
   }
   tmp_1170 += tmp_1171;
   result += (std::complex<double>(0.,-0.7071067811865475)*KroneckerDelta(0,gO1
      )) * tmp_1170;

   return result;
}

std::complex<double> CLASSNAME::CpUAhbarFuFuPR(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1174;
   std::complex<double> tmp_1175;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_1176;
      std::complex<double> tmp_1177;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1177 += Conj(Yu(j1,j2))*ZUR(gI2,j1);
      }
      tmp_1176 += tmp_1177;
      tmp_1175 += (ZUL(gI1,j2)) * tmp_1176;
   }
   tmp_1174 += tmp_1175;
   result += (std::complex<double>(0.,0.7071067811865475)*KroneckerDelta(1,gO2)
      ) * tmp_1174;

   return result;
}

std::complex<double> CLASSNAME::CpUAhbarFuFuPL(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1178;
   std::complex<double> tmp_1179;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_1180;
      std::complex<double> tmp_1181;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1181 += Conj(ZUR(gI1,j1))*Yu(j1,j2);
      }
      tmp_1180 += tmp_1181;
      tmp_1179 += (Conj(ZUL(gI2,j2))) * tmp_1180;
   }
   tmp_1178 += tmp_1179;
   result += (std::complex<double>(0.,-0.7071067811865475)*KroneckerDelta(1,gO1
      )) * tmp_1178;

   return result;
}

std::complex<double> CLASSNAME::CpUAhUAhAhAh(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.05*(-5*(4*AbsSqr(LamSU)*KroneckerDelta(2,gO1)*KroneckerDelta(2,
      gO2)*ZA(gI1,1)*ZA(gI2,1) - 1.4142135623730951*LamTU*Conj(LamSU)*
      KroneckerDelta(2,gO2)*KroneckerDelta(3,gO1)*ZA(gI1,1)*ZA(gI2,1) -
      1.4142135623730951*LamSU*Conj(LamTU)*KroneckerDelta(2,gO2)*KroneckerDelta(3,
      gO1)*ZA(gI1,1)*ZA(gI2,1) - 1.4142135623730951*LamTU*Conj(LamSU)*
      KroneckerDelta(2,gO1)*KroneckerDelta(3,gO2)*ZA(gI1,1)*ZA(gI2,1) -
      1.4142135623730951*LamSU*Conj(LamTU)*KroneckerDelta(2,gO1)*KroneckerDelta(3,
      gO2)*ZA(gI1,1)*ZA(gI2,1) + 2*AbsSqr(LamTU)*KroneckerDelta(3,gO1)*
      KroneckerDelta(3,gO2)*ZA(gI1,1)*ZA(gI2,1) + 4*AbsSqr(LamSU)*KroneckerDelta(1
      ,gO2)*KroneckerDelta(2,gO1)*ZA(gI1,2)*ZA(gI2,1) - 1.4142135623730951*LamTU*
      Conj(LamSU)*KroneckerDelta(1,gO2)*KroneckerDelta(3,gO1)*ZA(gI1,2)*ZA(gI2,1)
      - 1.4142135623730951*LamSU*Conj(LamTU)*KroneckerDelta(1,gO2)*KroneckerDelta(
      3,gO1)*ZA(gI1,2)*ZA(gI2,1) - 1.4142135623730951*LamTU*Conj(LamSU)*
      KroneckerDelta(1,gO2)*KroneckerDelta(2,gO1)*ZA(gI1,3)*ZA(gI2,1) -
      1.4142135623730951*LamSU*Conj(LamTU)*KroneckerDelta(1,gO2)*KroneckerDelta(2,
      gO1)*ZA(gI1,3)*ZA(gI2,1) + 2*AbsSqr(LamTU)*KroneckerDelta(1,gO2)*
      KroneckerDelta(3,gO1)*ZA(gI1,3)*ZA(gI2,1) + 4*AbsSqr(LamSU)*KroneckerDelta(1
      ,gO2)*KroneckerDelta(2,gO1)*ZA(gI1,1)*ZA(gI2,2) - 1.4142135623730951*LamTU*
      Conj(LamSU)*KroneckerDelta(1,gO2)*KroneckerDelta(3,gO1)*ZA(gI1,1)*ZA(gI2,2)
      - 1.4142135623730951*LamSU*Conj(LamTU)*KroneckerDelta(1,gO2)*KroneckerDelta(
      3,gO1)*ZA(gI1,1)*ZA(gI2,2) - 1.4142135623730951*LamTU*Conj(LamSU)*
      KroneckerDelta(1,gO2)*KroneckerDelta(2,gO1)*ZA(gI1,1)*ZA(gI2,3) -
      1.4142135623730951*LamSU*Conj(LamTU)*KroneckerDelta(1,gO2)*KroneckerDelta(2,
      gO1)*ZA(gI1,1)*ZA(gI2,3) + 2*AbsSqr(LamTU)*KroneckerDelta(1,gO2)*
      KroneckerDelta(3,gO1)*ZA(gI1,1)*ZA(gI2,3) + Conj(LamSD)*(1.4142135623730951*
      LamTD*KroneckerDelta(3,gO1)*(KroneckerDelta(2,gO2)*ZA(gI1,0)*ZA(gI2,0) +
      KroneckerDelta(0,gO2)*(ZA(gI1,2)*ZA(gI2,0) + ZA(gI1,0)*ZA(gI2,2))) +
      KroneckerDelta(2,gO1)*(4*LamSD*KroneckerDelta(2,gO2)*ZA(gI1,0)*ZA(gI2,0) +
      1.4142135623730951*LamTD*KroneckerDelta(3,gO2)*ZA(gI1,0)*ZA(gI2,0) +
      KroneckerDelta(0,gO2)*(4*LamSD*ZA(gI1,2)*ZA(gI2,0) + 1.4142135623730951*
      LamTD*ZA(gI1,3)*ZA(gI2,0) + ZA(gI1,0)*(4*LamSD*ZA(gI2,2) +
      1.4142135623730951*LamTD*ZA(gI2,3))))) + Conj(LamTD)*(1.4142135623730951*
      LamSD*KroneckerDelta(2,gO2)*KroneckerDelta(3,gO1)*ZA(gI1,0)*ZA(gI2,0) +
      1.4142135623730951*LamSD*KroneckerDelta(2,gO1)*(KroneckerDelta(3,gO2)*ZA(gI1
      ,0)*ZA(gI2,0) + KroneckerDelta(0,gO2)*(ZA(gI1,3)*ZA(gI2,0) + ZA(gI1,0)*ZA(
      gI2,3))) + KroneckerDelta(3,gO1)*(2*LamTD*KroneckerDelta(3,gO2)*ZA(gI1,0)*ZA
      (gI2,0) + KroneckerDelta(0,gO2)*(1.4142135623730951*LamSD*ZA(gI1,2)*ZA(gI2,0
      ) + 2*LamTD*ZA(gI1,3)*ZA(gI2,0) + ZA(gI1,0)*(1.4142135623730951*LamSD*ZA(gI2
      ,2) + 2*LamTD*ZA(gI2,3)))))) - KroneckerDelta(0,gO1)*(-(KroneckerDelta(1,gO2
      )*(3*Sqr(g1) + 5*Sqr(g2))*(ZA(gI1,1)*ZA(gI2,0) + ZA(gI1,0)*ZA(gI2,1))) + 5*(
      Conj(LamSD)*(1.4142135623730951*LamTD*KroneckerDelta(3,gO2)*(ZA(gI1,2)*ZA(
      gI2,0) + ZA(gI1,0)*ZA(gI2,2)) + KroneckerDelta(2,gO2)*(4*LamSD*ZA(gI1,2)*ZA(
      gI2,0) + 1.4142135623730951*LamTD*ZA(gI1,3)*ZA(gI2,0) + ZA(gI1,0)*(4*LamSD*
      ZA(gI2,2) + 1.4142135623730951*LamTD*ZA(gI2,3)))) + Conj(LamTD)*(
      1.4142135623730951*LamSD*KroneckerDelta(2,gO2)*(ZA(gI1,3)*ZA(gI2,0) + ZA(gI1
      ,0)*ZA(gI2,3)) + KroneckerDelta(3,gO2)*(1.4142135623730951*LamSD*ZA(gI1,2)*
      ZA(gI2,0) + 2*LamTD*ZA(gI1,3)*ZA(gI2,0) + ZA(gI1,0)*(1.4142135623730951*
      LamSD*ZA(gI2,2) + 2*LamTD*ZA(gI2,3))))) + KroneckerDelta(0,gO2)*(3*(3*Sqr(g1
      ) + 5*Sqr(g2))*ZA(gI1,0)*ZA(gI2,0) - (3*Sqr(g1) + 5*Sqr(g2))*ZA(gI1,1)*ZA(
      gI2,1) + 5*(Conj(LamSD)*(1.4142135623730951*LamTD*ZA(gI1,3)*ZA(gI2,2) + ZA(
      gI1,2)*(4*LamSD*ZA(gI2,2) + 1.4142135623730951*LamTD*ZA(gI2,3))) + Conj(
      LamTD)*(1.4142135623730951*LamSD*ZA(gI1,2)*ZA(gI2,3) + ZA(gI1,3)*(
      1.4142135623730951*LamSD*ZA(gI2,2) + 2*LamTD*ZA(gI2,3)))))) + KroneckerDelta
      (1,gO1)*(KroneckerDelta(0,gO2)*(3*Sqr(g1) + 5*Sqr(g2))*(ZA(gI1,1)*ZA(gI2,0)
      + ZA(gI1,0)*ZA(gI2,1)) + 5*(Conj(LamTU)*(1.4142135623730951*LamSU*
      KroneckerDelta(2,gO2)*(ZA(gI1,3)*ZA(gI2,1) + ZA(gI1,1)*ZA(gI2,3)) +
      KroneckerDelta(3,gO2)*(1.4142135623730951*LamSU*ZA(gI1,2)*ZA(gI2,1) - 2*
      LamTU*ZA(gI1,3)*ZA(gI2,1) + ZA(gI1,1)*(1.4142135623730951*LamSU*ZA(gI2,2) -
      2*LamTU*ZA(gI2,3)))) + Conj(LamSU)*(1.4142135623730951*LamTU*KroneckerDelta(
      3,gO2)*(ZA(gI1,2)*ZA(gI2,1) + ZA(gI1,1)*ZA(gI2,2)) + KroneckerDelta(2,gO2)*(
      -4*LamSU*ZA(gI1,2)*ZA(gI2,1) + 1.4142135623730951*LamTU*ZA(gI1,3)*ZA(gI2,1)
      + ZA(gI1,1)*(-4*LamSU*ZA(gI2,2) + 1.4142135623730951*LamTU*ZA(gI2,3))))) +
      KroneckerDelta(1,gO2)*((3*Sqr(g1) + 5*Sqr(g2))*ZA(gI1,0)*ZA(gI2,0) - 3*(3*
      Sqr(g1) + 5*Sqr(g2))*ZA(gI1,1)*ZA(gI2,1) + 5*(Conj(LamTU)*(
      1.4142135623730951*LamSU*ZA(gI1,2)*ZA(gI2,3) + ZA(gI1,3)*(1.4142135623730951
      *LamSU*ZA(gI2,2) - 2*LamTU*ZA(gI2,3))) + Conj(LamSU)*(1.4142135623730951*
      LamTU*ZA(gI1,3)*ZA(gI2,2) + ZA(gI1,2)*(-4*LamSU*ZA(gI2,2) +
      1.4142135623730951*LamTU*ZA(gI2,3)))))));

   return result;
}

std::complex<double> CLASSNAME::CpUAhUAhconjHpmHpm(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.05*(-5*(1.4142135623730951*KroneckerDelta(0,gO2)*KroneckerDelta(3
      ,gO1)*Sqr(g2)*ZP(gI1,2)*ZP(gI2,0) + 1.4142135623730951*KroneckerDelta(0,gO2)
      *KroneckerDelta(3,gO1)*Sqr(g2)*ZP(gI1,3)*ZP(gI2,0) + 4*AbsSqr(LamSU)*
      KroneckerDelta(2,gO1)*KroneckerDelta(2,gO2)*ZP(gI1,1)*ZP(gI2,1) +
      1.4142135623730951*LamTU*Conj(LamSU)*KroneckerDelta(2,gO2)*KroneckerDelta(3,
      gO1)*ZP(gI1,1)*ZP(gI2,1) + 1.4142135623730951*LamSU*Conj(LamTU)*
      KroneckerDelta(2,gO2)*KroneckerDelta(3,gO1)*ZP(gI1,1)*ZP(gI2,1) +
      1.4142135623730951*LamTU*Conj(LamSU)*KroneckerDelta(2,gO1)*KroneckerDelta(3,
      gO2)*ZP(gI1,1)*ZP(gI2,1) + 1.4142135623730951*LamSU*Conj(LamTU)*
      KroneckerDelta(2,gO1)*KroneckerDelta(3,gO2)*ZP(gI1,1)*ZP(gI2,1) + 2*AbsSqr(
      LamTU)*KroneckerDelta(3,gO1)*KroneckerDelta(3,gO2)*ZP(gI1,1)*ZP(gI2,1) - 2*
      LamSU*Conj(LamTU)*KroneckerDelta(1,gO2)*KroneckerDelta(2,gO1)*ZP(gI1,2)*ZP(
      gI2,1) + 1.4142135623730951*AbsSqr(LamTU)*KroneckerDelta(1,gO2)*
      KroneckerDelta(3,gO1)*ZP(gI1,2)*ZP(gI2,1) - 1.4142135623730951*
      KroneckerDelta(1,gO2)*KroneckerDelta(3,gO1)*Sqr(g2)*ZP(gI1,2)*ZP(gI2,1) + 2*
      LamTU*Conj(LamSU)*KroneckerDelta(1,gO2)*KroneckerDelta(2,gO1)*ZP(gI1,3)*ZP(
      gI2,1) + 1.4142135623730951*AbsSqr(LamTU)*KroneckerDelta(1,gO2)*
      KroneckerDelta(3,gO1)*ZP(gI1,3)*ZP(gI2,1) - 1.4142135623730951*
      KroneckerDelta(1,gO2)*KroneckerDelta(3,gO1)*Sqr(g2)*ZP(gI1,3)*ZP(gI2,1) +
      1.4142135623730951*KroneckerDelta(0,gO2)*KroneckerDelta(3,gO1)*Sqr(g2)*ZP(
      gI1,0)*ZP(gI2,2) - 2*LamTU*Conj(LamSU)*KroneckerDelta(1,gO2)*KroneckerDelta(
      2,gO1)*ZP(gI1,1)*ZP(gI2,2) + 1.4142135623730951*AbsSqr(LamTU)*KroneckerDelta
      (1,gO2)*KroneckerDelta(3,gO1)*ZP(gI1,1)*ZP(gI2,2) - 1.4142135623730951*
      KroneckerDelta(1,gO2)*KroneckerDelta(3,gO1)*Sqr(g2)*ZP(gI1,1)*ZP(gI2,2) + 4*
      KroneckerDelta(3,gO1)*KroneckerDelta(3,gO2)*Sqr(g2)*ZP(gI1,2)*ZP(gI2,2) + 4*
      KroneckerDelta(3,gO1)*KroneckerDelta(3,gO2)*Sqr(g2)*ZP(gI1,3)*ZP(gI2,2) +
      Conj(LamSD)*(-1.4142135623730951*LamTD*KroneckerDelta(2,gO2)*KroneckerDelta(
      3,gO1)*ZP(gI1,0)*ZP(gI2,0) + KroneckerDelta(2,gO1)*(4*LamSD*KroneckerDelta(2
      ,gO2)*ZP(gI1,0)*ZP(gI2,0) - LamTD*(1.4142135623730951*KroneckerDelta(3,gO2)*
      ZP(gI1,0)*ZP(gI2,0) + 2*KroneckerDelta(0,gO2)*(ZP(gI1,3)*ZP(gI2,0) - ZP(gI1,
      0)*ZP(gI2,2))))) + 1.4142135623730951*KroneckerDelta(0,gO2)*KroneckerDelta(3
      ,gO1)*Sqr(g2)*ZP(gI1,0)*ZP(gI2,3) + 2*LamSU*Conj(LamTU)*KroneckerDelta(1,gO2
      )*KroneckerDelta(2,gO1)*ZP(gI1,1)*ZP(gI2,3) + 1.4142135623730951*AbsSqr(
      LamTU)*KroneckerDelta(1,gO2)*KroneckerDelta(3,gO1)*ZP(gI1,1)*ZP(gI2,3) -
      1.4142135623730951*KroneckerDelta(1,gO2)*KroneckerDelta(3,gO1)*Sqr(g2)*ZP(
      gI1,1)*ZP(gI2,3) + 4*KroneckerDelta(3,gO1)*KroneckerDelta(3,gO2)*Sqr(g2)*ZP(
      gI1,2)*ZP(gI2,3) + 4*KroneckerDelta(3,gO1)*KroneckerDelta(3,gO2)*Sqr(g2)*ZP(
      gI1,3)*ZP(gI2,3) - Conj(LamTD)*(1.4142135623730951*LamSD*KroneckerDelta(2,
      gO2)*KroneckerDelta(3,gO1)*ZP(gI1,0)*ZP(gI2,0) + LamSD*KroneckerDelta(2,gO1)
      *(1.4142135623730951*KroneckerDelta(3,gO2)*ZP(gI1,0)*ZP(gI2,0) + 2*
      KroneckerDelta(0,gO2)*(-(ZP(gI1,2)*ZP(gI2,0)) + ZP(gI1,0)*ZP(gI2,3))) +
      LamTD*KroneckerDelta(3,gO1)*(-2*KroneckerDelta(3,gO2)*ZP(gI1,0)*ZP(gI2,0) +
      1.4142135623730951*KroneckerDelta(0,gO2)*(ZP(gI1,2)*ZP(gI2,0) + ZP(gI1,3)*ZP
      (gI2,0) + ZP(gI1,0)*(ZP(gI2,2) + ZP(gI2,3)))))) + KroneckerDelta(0,gO1)*(-(
      KroneckerDelta(0,gO2)*((3*Sqr(g1) + 5*Sqr(g2))*ZP(gI1,0)*ZP(gI2,0) + (-3*Sqr
      (g1) + 5*Sqr(g2))*ZP(gI1,1)*ZP(gI2,1) + 10*(-((-2*AbsSqr(LamTD) + Sqr(g2))*
      ZP(gI1,2)*ZP(gI2,2)) + Sqr(g2)*ZP(gI1,3)*ZP(gI2,3)))) + 5*(
      -1.4142135623730951*KroneckerDelta(3,gO2)*Sqr(g2)*ZP(gI1,2)*ZP(gI2,0) + 2*
      LamTD*Conj(LamSD)*KroneckerDelta(2,gO2)*ZP(gI1,3)*ZP(gI2,0) -
      1.4142135623730951*KroneckerDelta(3,gO2)*Sqr(g2)*ZP(gI1,3)*ZP(gI2,0) +
      KroneckerDelta(1,gO2)*Sqr(g2)*(ZP(gI1,1)*ZP(gI2,0) + ZP(gI1,0)*ZP(gI2,1)) -
      2*LamTD*Conj(LamSD)*KroneckerDelta(2,gO2)*ZP(gI1,0)*ZP(gI2,2) -
      1.4142135623730951*KroneckerDelta(3,gO2)*Sqr(g2)*ZP(gI1,0)*ZP(gI2,2) -
      1.4142135623730951*KroneckerDelta(3,gO2)*Sqr(g2)*ZP(gI1,0)*ZP(gI2,3) + Conj(
      LamTD)*(KroneckerDelta(2,gO2)*(-2*LamSD*ZP(gI1,2)*ZP(gI2,0) + 2*LamSD*ZP(gI1
      ,0)*ZP(gI2,3)) + 1.4142135623730951*LamTD*KroneckerDelta(3,gO2)*(ZP(gI1,2)*
      ZP(gI2,0) + ZP(gI1,3)*ZP(gI2,0) + ZP(gI1,0)*(ZP(gI2,2) + ZP(gI2,3)))))) +
      KroneckerDelta(1,gO1)*(KroneckerDelta(1,gO2)*((3*Sqr(g1) - 5*Sqr(g2))*ZP(gI1
      ,0)*ZP(gI2,0) - (3*Sqr(g1) + 5*Sqr(g2))*ZP(gI1,1)*ZP(gI2,1) - 10*(Sqr(g2)*ZP
      (gI1,2)*ZP(gI2,2) - (-2*AbsSqr(LamTU) + Sqr(g2))*ZP(gI1,3)*ZP(gI2,3))) + 5*(
      1.4142135623730951*KroneckerDelta(3,gO2)*Sqr(g2)*ZP(gI1,2)*ZP(gI2,1) - 2*
      LamTU*Conj(LamSU)*KroneckerDelta(2,gO2)*ZP(gI1,3)*ZP(gI2,1) +
      1.4142135623730951*KroneckerDelta(3,gO2)*Sqr(g2)*ZP(gI1,3)*ZP(gI2,1) +
      KroneckerDelta(0,gO2)*Sqr(g2)*(ZP(gI1,1)*ZP(gI2,0) + ZP(gI1,0)*ZP(gI2,1)) +
      2*LamTU*Conj(LamSU)*KroneckerDelta(2,gO2)*ZP(gI1,1)*ZP(gI2,2) +
      1.4142135623730951*KroneckerDelta(3,gO2)*Sqr(g2)*ZP(gI1,1)*ZP(gI2,2) +
      1.4142135623730951*KroneckerDelta(3,gO2)*Sqr(g2)*ZP(gI1,1)*ZP(gI2,3) + Conj(
      LamTU)*(2*LamSU*KroneckerDelta(2,gO2)*(ZP(gI1,2)*ZP(gI2,1) - ZP(gI1,1)*ZP(
      gI2,3)) - 1.4142135623730951*LamTU*KroneckerDelta(3,gO2)*(ZP(gI1,2)*ZP(gI2,1
      ) + ZP(gI1,3)*ZP(gI2,1) + ZP(gI1,1)*(ZP(gI2,2) + ZP(gI2,3)))))));

   return result;
}

std::complex<double> CLASSNAME::CpUAhUAhhhhh(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.05*(-5*(Conj(LamTD)*(1.4142135623730951*LamSD*KroneckerDelta(2,
      gO2)*KroneckerDelta(3,gO1) + (1.4142135623730951*LamSD*KroneckerDelta(2,gO1)
      + 2*LamTD*KroneckerDelta(3,gO1))*KroneckerDelta(3,gO2))*ZH(gI1,0)*ZH(gI2,0)
      + Conj(LamSD)*(1.4142135623730951*LamTD*KroneckerDelta(2,gO2)*
      KroneckerDelta(3,gO1) + KroneckerDelta(2,gO1)*(4*LamSD*KroneckerDelta(2,gO2)
      + 1.4142135623730951*LamTD*KroneckerDelta(3,gO2)))*ZH(gI1,0)*ZH(gI2,0) + (-
      (Conj(LamTU)*(1.4142135623730951*LamSU*KroneckerDelta(2,gO2)*KroneckerDelta(
      3,gO1) + (1.4142135623730951*LamSU*KroneckerDelta(2,gO1) - 2*LamTU*
      KroneckerDelta(3,gO1))*KroneckerDelta(3,gO2))) - Conj(LamSU)*(
      1.4142135623730951*LamTU*KroneckerDelta(2,gO2)*KroneckerDelta(3,gO1) +
      KroneckerDelta(2,gO1)*(-4*LamSU*KroneckerDelta(2,gO2) + 1.4142135623730951*
      LamTU*KroneckerDelta(3,gO2))))*ZH(gI1,1)*ZH(gI2,1)) - KroneckerDelta(0,gO1)*
      KroneckerDelta(0,gO2)*((3*Sqr(g1) + 5*Sqr(g2))*ZH(gI1,0)*ZH(gI2,0) - (3*Sqr(
      g1) + 5*Sqr(g2))*ZH(gI1,1)*ZH(gI2,1) + 5*(Conj(LamSD)*(1.4142135623730951*
      LamTD*ZH(gI1,3)*ZH(gI2,2) + ZH(gI1,2)*(4*LamSD*ZH(gI2,2) +
      1.4142135623730951*LamTD*ZH(gI2,3))) + Conj(LamTD)*(1.4142135623730951*LamSD
      *ZH(gI1,2)*ZH(gI2,3) + ZH(gI1,3)*(1.4142135623730951*LamSD*ZH(gI2,2) + 2*
      LamTD*ZH(gI2,3))))) + KroneckerDelta(1,gO1)*KroneckerDelta(1,gO2)*((3*Sqr(g1
      ) + 5*Sqr(g2))*ZH(gI1,0)*ZH(gI2,0) - (3*Sqr(g1) + 5*Sqr(g2))*ZH(gI1,1)*ZH(
      gI2,1) + 5*(Conj(LamTU)*(1.4142135623730951*LamSU*ZH(gI1,2)*ZH(gI2,3) + ZH(
      gI1,3)*(1.4142135623730951*LamSU*ZH(gI2,2) - 2*LamTU*ZH(gI2,3))) + Conj(
      LamSU)*(1.4142135623730951*LamTU*ZH(gI1,3)*ZH(gI2,2) + ZH(gI1,2)*(-4*LamSU*
      ZH(gI2,2) + 1.4142135623730951*LamTU*ZH(gI2,3))))));

   return result;
}

std::complex<double> CLASSNAME::CpUAhAhAh(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = std::complex<double>(0,0.05)*(7.745966692414834*g1*MDBS*
      KroneckerDelta(0,gO2)*ZA(gI1,2)*ZA(gI2,0) + 14.142135623730951*MuD*Conj(
      LamSD)*KroneckerDelta(0,gO2)*ZA(gI1,2)*ZA(gI2,0) + 7.0710678118654755*LamTD*
      vT*Conj(LamSD)*KroneckerDelta(0,gO2)*ZA(gI1,2)*ZA(gI2,0) -
      7.0710678118654755*LamSD*vT*Conj(LamTD)*KroneckerDelta(0,gO2)*ZA(gI1,2)*ZA(
      gI2,0) - 7.745966692414834*g1*Conj(MDBS)*KroneckerDelta(0,gO2)*ZA(gI1,2)*ZA(
      gI2,0) - 14.142135623730951*LamSD*Conj(MuD)*KroneckerDelta(0,gO2)*ZA(gI1,2)*
      ZA(gI2,0) - 10*g2*MDWBT*KroneckerDelta(0,gO2)*ZA(gI1,3)*ZA(gI2,0) -
      7.0710678118654755*LamTD*vS*Conj(LamSD)*KroneckerDelta(0,gO2)*ZA(gI1,3)*ZA(
      gI2,0) + 10*MuD*Conj(LamTD)*KroneckerDelta(0,gO2)*ZA(gI1,3)*ZA(gI2,0) +
      7.0710678118654755*LamSD*vS*Conj(LamTD)*KroneckerDelta(0,gO2)*ZA(gI1,3)*ZA(
      gI2,0) + 10*g2*Conj(MDWBT)*KroneckerDelta(0,gO2)*ZA(gI1,3)*ZA(gI2,0) - 10*
      LamTD*Conj(MuD)*KroneckerDelta(0,gO2)*ZA(gI1,3)*ZA(gI2,0) -
      7.745966692414834*g1*MDBS*KroneckerDelta(1,gO2)*ZA(gI1,2)*ZA(gI2,1) +
      14.142135623730951*MuU*Conj(LamSU)*KroneckerDelta(1,gO2)*ZA(gI1,2)*ZA(gI2,1)
      - 7.0710678118654755*LamTU*vT*Conj(LamSU)*KroneckerDelta(1,gO2)*ZA(gI1,2)*
      ZA(gI2,1) + 7.0710678118654755*LamSU*vT*Conj(LamTU)*KroneckerDelta(1,gO2)*ZA
      (gI1,2)*ZA(gI2,1) + 7.745966692414834*g1*Conj(MDBS)*KroneckerDelta(1,gO2)*ZA
      (gI1,2)*ZA(gI2,1) - 14.142135623730951*LamSU*Conj(MuU)*KroneckerDelta(1,gO2)
      *ZA(gI1,2)*ZA(gI2,1) + 10*g2*MDWBT*KroneckerDelta(1,gO2)*ZA(gI1,3)*ZA(gI2,1)
      + 7.0710678118654755*LamTU*vS*Conj(LamSU)*KroneckerDelta(1,gO2)*ZA(gI1,3)*
      ZA(gI2,1) - 10*MuU*Conj(LamTU)*KroneckerDelta(1,gO2)*ZA(gI1,3)*ZA(gI2,1) -
      7.0710678118654755*LamSU*vS*Conj(LamTU)*KroneckerDelta(1,gO2)*ZA(gI1,3)*ZA(
      gI2,1) - 10*g2*Conj(MDWBT)*KroneckerDelta(1,gO2)*ZA(gI1,3)*ZA(gI2,1) + 10*
      LamTU*Conj(MuU)*KroneckerDelta(1,gO2)*ZA(gI1,3)*ZA(gI2,1) + KroneckerDelta(2
      ,gO2)*((7.745966692414834*g1*MDBS + 7.0710678118654755*(2*MuD + LamTD*vT)*
      Conj(LamSD) - 7.0710678118654755*LamSD*vT*Conj(LamTD) - 7.745966692414834*g1
      *Conj(MDBS) - 14.142135623730951*LamSD*Conj(MuD))*ZA(gI1,0)*ZA(gI2,0) + (
      -7.745966692414834*g1*MDBS + 7.0710678118654755*(2*MuU - LamTU*vT)*Conj(
      LamSU) + 7.0710678118654755*LamSU*vT*Conj(LamTU) + 7.745966692414834*g1*Conj
      (MDBS) - 14.142135623730951*LamSU*Conj(MuU))*ZA(gI1,1)*ZA(gI2,1)) - 5*
      KroneckerDelta(3,gO2)*((2*g2*MDWBT + 1.4142135623730951*LamTD*vS*Conj(LamSD)
      - 2*MuD*Conj(LamTD) - 1.4142135623730951*LamSD*vS*Conj(LamTD) - 2*g2*Conj(
      MDWBT) + 2*LamTD*Conj(MuD))*ZA(gI1,0)*ZA(gI2,0) + (-2*g2*MDWBT -
      1.4142135623730951*LamTU*vS*Conj(LamSU) + 2*MuU*Conj(LamTU) +
      1.4142135623730951*LamSU*vS*Conj(LamTU) + 2*g2*Conj(MDWBT) - 2*LamTU*Conj(
      MuU))*ZA(gI1,1)*ZA(gI2,1)) + 7.745966692414834*g1*MDBS*KroneckerDelta(0,gO2)
      *ZA(gI1,0)*ZA(gI2,2) + 14.142135623730951*MuD*Conj(LamSD)*KroneckerDelta(0,
      gO2)*ZA(gI1,0)*ZA(gI2,2) + 7.0710678118654755*LamTD*vT*Conj(LamSD)*
      KroneckerDelta(0,gO2)*ZA(gI1,0)*ZA(gI2,2) - 7.0710678118654755*LamSD*vT*Conj
      (LamTD)*KroneckerDelta(0,gO2)*ZA(gI1,0)*ZA(gI2,2) - 7.745966692414834*g1*
      Conj(MDBS)*KroneckerDelta(0,gO2)*ZA(gI1,0)*ZA(gI2,2) - 14.142135623730951*
      LamSD*Conj(MuD)*KroneckerDelta(0,gO2)*ZA(gI1,0)*ZA(gI2,2) -
      7.745966692414834*g1*MDBS*KroneckerDelta(1,gO2)*ZA(gI1,1)*ZA(gI2,2) +
      14.142135623730951*MuU*Conj(LamSU)*KroneckerDelta(1,gO2)*ZA(gI1,1)*ZA(gI2,2)
      - 7.0710678118654755*LamTU*vT*Conj(LamSU)*KroneckerDelta(1,gO2)*ZA(gI1,1)*
      ZA(gI2,2) + 7.0710678118654755*LamSU*vT*Conj(LamTU)*KroneckerDelta(1,gO2)*ZA
      (gI1,1)*ZA(gI2,2) + 7.745966692414834*g1*Conj(MDBS)*KroneckerDelta(1,gO2)*ZA
      (gI1,1)*ZA(gI2,2) - 14.142135623730951*LamSU*Conj(MuU)*KroneckerDelta(1,gO2)
      *ZA(gI1,1)*ZA(gI2,2) - 10*g2*MDWBT*KroneckerDelta(0,gO2)*ZA(gI1,0)*ZA(gI2,3)
      - 7.0710678118654755*LamTD*vS*Conj(LamSD)*KroneckerDelta(0,gO2)*ZA(gI1,0)*
      ZA(gI2,3) + 10*MuD*Conj(LamTD)*KroneckerDelta(0,gO2)*ZA(gI1,0)*ZA(gI2,3) +
      7.0710678118654755*LamSD*vS*Conj(LamTD)*KroneckerDelta(0,gO2)*ZA(gI1,0)*ZA(
      gI2,3) + 10*g2*Conj(MDWBT)*KroneckerDelta(0,gO2)*ZA(gI1,0)*ZA(gI2,3) - 10*
      LamTD*Conj(MuD)*KroneckerDelta(0,gO2)*ZA(gI1,0)*ZA(gI2,3) + 10*g2*MDWBT*
      KroneckerDelta(1,gO2)*ZA(gI1,1)*ZA(gI2,3) + 7.0710678118654755*LamTU*vS*Conj
      (LamSU)*KroneckerDelta(1,gO2)*ZA(gI1,1)*ZA(gI2,3) - 10*MuU*Conj(LamTU)*
      KroneckerDelta(1,gO2)*ZA(gI1,1)*ZA(gI2,3) - 7.0710678118654755*LamSU*vS*Conj
      (LamTU)*KroneckerDelta(1,gO2)*ZA(gI1,1)*ZA(gI2,3) - 10*g2*Conj(MDWBT)*
      KroneckerDelta(1,gO2)*ZA(gI1,1)*ZA(gI2,3) + 10*LamTU*Conj(MuU)*
      KroneckerDelta(1,gO2)*ZA(gI1,1)*ZA(gI2,3));

   return result;
}

std::complex<double> CLASSNAME::CpUAhconjHpmHpm(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = std::complex<double>(0,0.05)*(KroneckerDelta(2,gO2)*(-10*LamSD*vd*
      Conj(LamTD)*ZP(gI1,2)*ZP(gI2,0) + 10*LamTD*vd*Conj(LamSD)*ZP(gI1,3)*ZP(gI2,0
      ) - 7.745966692414834*g1*MDBS*ZP(gI1,1)*ZP(gI2,1) + 14.142135623730951*MuU*
      Conj(LamSU)*ZP(gI1,1)*ZP(gI2,1) + 7.0710678118654755*LamTU*vT*Conj(LamSU)*ZP
      (gI1,1)*ZP(gI2,1) - 7.0710678118654755*LamSU*vT*Conj(LamTU)*ZP(gI1,1)*ZP(gI2
      ,1) + 7.745966692414834*g1*Conj(MDBS)*ZP(gI1,1)*ZP(gI2,1) -
      14.142135623730951*LamSU*Conj(MuU)*ZP(gI1,1)*ZP(gI2,1) - 10*LamSU*vu*Conj(
      LamTU)*ZP(gI1,2)*ZP(gI2,1) + 10*LamTU*vu*Conj(LamSU)*ZP(gI1,3)*ZP(gI2,1) +
      10*LamTU*vu*Conj(LamSU)*ZP(gI1,1)*ZP(gI2,2) - 10*LamSU*vu*Conj(LamTU)*ZP(gI1
      ,1)*ZP(gI2,3) + ZP(gI1,0)*((7.745966692414834*g1*MDBS + 7.0710678118654755*(
      2*MuD - LamTD*vT)*Conj(LamSD) + 7.0710678118654755*LamSD*vT*Conj(LamTD) -
      7.745966692414834*g1*Conj(MDBS) - 14.142135623730951*LamSD*Conj(MuD))*ZP(gI2
      ,0) + 10*vd*(LamTD*Conj(LamSD)*ZP(gI2,2) - LamSD*Conj(LamTD)*ZP(gI2,3)))) +
      5*(KroneckerDelta(0,gO2)*(vu*Sqr(g2)*ZP(gI1,1)*ZP(gI2,0) + ((
      2.8284271247461903*MuD + 2*LamSD*vS - 1.4142135623730951*LamTD*vT)*Conj(
      LamTD) + 1.4142135623730951*g2*(g2*vT + 2*Conj(MDWBT)))*ZP(gI1,2)*ZP(gI2,0)
      + 2.8284271247461903*g2*MDWBT*ZP(gI1,3)*ZP(gI2,0) + 1.4142135623730951*vT*
      AbsSqr(LamTD)*ZP(gI1,3)*ZP(gI2,0) + 2*LamTD*vS*Conj(LamSD)*ZP(gI1,3)*ZP(gI2,
      0) + 2.8284271247461903*LamTD*Conj(MuD)*ZP(gI1,3)*ZP(gI2,0) -
      1.4142135623730951*vT*Sqr(g2)*ZP(gI1,3)*ZP(gI2,0) - vu*Sqr(g2)*ZP(gI1,0)*ZP(
      gI2,1) - 2.8284271247461903*g2*MDWBT*ZP(gI1,0)*ZP(gI2,2) +
      1.4142135623730951*vT*AbsSqr(LamTD)*ZP(gI1,0)*ZP(gI2,2) - 2*LamTD*vS*Conj(
      LamSD)*ZP(gI1,0)*ZP(gI2,2) - 2.8284271247461903*LamTD*Conj(MuD)*ZP(gI1,0)*ZP
      (gI2,2) - 1.4142135623730951*vT*Sqr(g2)*ZP(gI1,0)*ZP(gI2,2) -
      1.4142135623730951*vT*AbsSqr(LamTD)*ZP(gI1,0)*ZP(gI2,3) - 2.8284271247461903
      *MuD*Conj(LamTD)*ZP(gI1,0)*ZP(gI2,3) - 2*LamSD*vS*Conj(LamTD)*ZP(gI1,0)*ZP(
      gI2,3) - 2.8284271247461903*g2*Conj(MDWBT)*ZP(gI1,0)*ZP(gI2,3) +
      1.4142135623730951*vT*Sqr(g2)*ZP(gI1,0)*ZP(gI2,3)) + KroneckerDelta(1,gO2)*(
      -((vd*Sqr(g2)*ZP(gI1,0) + ((2.8284271247461903*MuU + 2*LamSU*vS -
      1.4142135623730951*LamTU*vT)*Conj(LamTU) + 1.4142135623730951*g2*(g2*vT + 2*
      Conj(MDWBT)))*ZP(gI1,2) + (2*LamTU*vS*Conj(LamSU) + 1.4142135623730951*(2*g2
      *MDWBT + vT*AbsSqr(LamTU) + 2*LamTU*Conj(MuU) - vT*Sqr(g2)))*ZP(gI1,3))*ZP(
      gI2,1)) + ZP(gI1,1)*(vd*Sqr(g2)*ZP(gI2,0) + (2*LamTU*vS*Conj(LamSU) +
      1.4142135623730951*(2*g2*MDWBT - vT*AbsSqr(LamTU) + 2*LamTU*Conj(MuU) + vT*
      Sqr(g2)))*ZP(gI2,2) + ((2.8284271247461903*MuU + 2*LamSU*vS +
      1.4142135623730951*LamTU*vT)*Conj(LamTU) + 1.4142135623730951*g2*(-(g2*vT) +
      2*Conj(MDWBT)))*ZP(gI2,3))) + KroneckerDelta(3,gO2)*(1.4142135623730951*vd*
      AbsSqr(LamTD)*ZP(gI1,3)*ZP(gI2,0) - 1.4142135623730951*vd*Sqr(g2)*ZP(gI1,3)*
      ZP(gI2,0) - 2*g2*MDWBT*ZP(gI1,1)*ZP(gI2,1) - 1.4142135623730951*LamTU*vS*
      Conj(LamSU)*ZP(gI1,1)*ZP(gI2,1) + 2*MuU*Conj(LamTU)*ZP(gI1,1)*ZP(gI2,1) +
      1.4142135623730951*LamSU*vS*Conj(LamTU)*ZP(gI1,1)*ZP(gI2,1) + 2*g2*Conj(
      MDWBT)*ZP(gI1,1)*ZP(gI2,1) - 2*LamTU*Conj(MuU)*ZP(gI1,1)*ZP(gI2,1) +
      1.4142135623730951*vu*AbsSqr(LamTU)*ZP(gI1,3)*ZP(gI2,1) - 1.4142135623730951
      *vu*Sqr(g2)*ZP(gI1,3)*ZP(gI2,1) - 1.4142135623730951*vu*AbsSqr(LamTU)*ZP(gI1
      ,1)*ZP(gI2,2) + 1.4142135623730951*vu*Sqr(g2)*ZP(gI1,1)*ZP(gI2,2) - 4*vT*Sqr
      (g2)*ZP(gI1,3)*ZP(gI2,2) - 1.4142135623730951*vu*AbsSqr(LamTU)*ZP(gI1,1)*ZP(
      gI2,3) + 1.4142135623730951*vu*Sqr(g2)*ZP(gI1,1)*ZP(gI2,3) + ZP(gI1,2)*(
      1.4142135623730951*vd*(AbsSqr(LamTD) - Sqr(g2))*ZP(gI2,0) +
      1.4142135623730951*vu*(AbsSqr(LamTU) - Sqr(g2))*ZP(gI2,1) + 4*vT*Sqr(g2)*ZP(
      gI2,3)) + ZP(gI1,0)*((2*g2*MDWBT + 1.4142135623730951*LamTD*vS*Conj(LamSD) -
      2*MuD*Conj(LamTD) - 1.4142135623730951*LamSD*vS*Conj(LamTD) - 2*g2*Conj(
      MDWBT) + 2*LamTD*Conj(MuD))*ZP(gI2,0) + 1.4142135623730951*vd*(-AbsSqr(LamTD
      ) + Sqr(g2))*(ZP(gI2,2) + ZP(gI2,3))))));

   return result;
}

std::complex<double> CLASSNAME::CpUAhhhAh(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.05*(-5*(vd*Conj(LamSD)*(1.4142135623730951*LamTD*KroneckerDelta(3
      ,gO2)*ZA(gI2,2) + KroneckerDelta(2,gO2)*(4*LamSD*ZA(gI2,2) +
      1.4142135623730951*LamTD*ZA(gI2,3)))*ZH(gI1,0) + vd*Conj(LamTD)*(
      1.4142135623730951*LamSD*KroneckerDelta(2,gO2)*ZA(gI2,3) + KroneckerDelta(3,
      gO2)*(1.4142135623730951*LamSD*ZA(gI2,2) + 2*LamTD*ZA(gI2,3)))*ZH(gI1,0) +
      vu*(-(Conj(LamTU)*(1.4142135623730951*LamSU*KroneckerDelta(2,gO2)*ZA(gI2,3)
      + KroneckerDelta(3,gO2)*(1.4142135623730951*LamSU*ZA(gI2,2) - 2*LamTU*ZA(gI2
      ,3)))) - Conj(LamSU)*(1.4142135623730951*LamTU*KroneckerDelta(3,gO2)*ZA(gI2,
      2) + KroneckerDelta(2,gO2)*(-4*LamSU*ZA(gI2,2) + 1.4142135623730951*LamTU*ZA
      (gI2,3))))*ZH(gI1,1)) - KroneckerDelta(0,gO2)*ZA(gI2,0)*(vd*(3*Sqr(g1) + 5*
      Sqr(g2))*ZH(gI1,0) - vu*(3*Sqr(g1) + 5*Sqr(g2))*ZH(gI1,1) -
      7.745966692414834*g1*MDBS*ZH(gI1,2) + 20*vS*AbsSqr(LamSD)*ZH(gI1,2) +
      14.142135623730951*MuD*Conj(LamSD)*ZH(gI1,2) + 7.0710678118654755*LamTD*vT*
      Conj(LamSD)*ZH(gI1,2) + 7.0710678118654755*LamSD*vT*Conj(LamTD)*ZH(gI1,2) -
      7.745966692414834*g1*Conj(MDBS)*ZH(gI1,2) + 14.142135623730951*LamSD*Conj(
      MuD)*ZH(gI1,2) + 10*g2*MDWBT*ZH(gI1,3) + 10*vT*AbsSqr(LamTD)*ZH(gI1,3) +
      7.0710678118654755*LamTD*vS*Conj(LamSD)*ZH(gI1,3) + 10*MuD*Conj(LamTD)*ZH(
      gI1,3) + 7.0710678118654755*LamSD*vS*Conj(LamTD)*ZH(gI1,3) + 10*g2*Conj(
      MDWBT)*ZH(gI1,3) + 10*LamTD*Conj(MuD)*ZH(gI1,3)) + KroneckerDelta(1,gO2)*ZA(
      gI2,1)*(vd*(3*Sqr(g1) + 5*Sqr(g2))*ZH(gI1,0) - vu*(3*Sqr(g1) + 5*Sqr(g2))*ZH
      (gI1,1) - 7.745966692414834*g1*MDBS*ZH(gI1,2) - 20*vS*AbsSqr(LamSU)*ZH(gI1,2
      ) - 14.142135623730951*MuU*Conj(LamSU)*ZH(gI1,2) + 7.0710678118654755*LamTU*
      vT*Conj(LamSU)*ZH(gI1,2) + 7.0710678118654755*LamSU*vT*Conj(LamTU)*ZH(gI1,2)
      - 7.745966692414834*g1*Conj(MDBS)*ZH(gI1,2) - 14.142135623730951*LamSU*Conj
      (MuU)*ZH(gI1,2) + 10*g2*MDWBT*ZH(gI1,3) - 10*vT*AbsSqr(LamTU)*ZH(gI1,3) +
      7.0710678118654755*LamTU*vS*Conj(LamSU)*ZH(gI1,3) + 10*MuU*Conj(LamTU)*ZH(
      gI1,3) + 7.0710678118654755*LamSU*vS*Conj(LamTU)*ZH(gI1,3) + 10*g2*Conj(
      MDWBT)*ZH(gI1,3) + 10*LamTU*Conj(MuU)*ZH(gI1,3)));

   return result;
}

std::complex<double> CLASSNAME::CpUAhhhhh(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = std::complex<double>(0,0.05)*(-5*KroneckerDelta(3,gO2)*(
      1.4142135623730951*LamTD*vd*Conj(LamSD)*ZH(gI1,2)*ZH(gI2,0) -
      1.4142135623730951*LamSD*vd*Conj(LamTD)*ZH(gI1,2)*ZH(gI2,0) - 2*g2*MDWBT*ZH(
      gI1,1)*ZH(gI2,1) - 1.4142135623730951*LamTU*vS*Conj(LamSU)*ZH(gI1,1)*ZH(gI2,
      1) + 2*MuU*Conj(LamTU)*ZH(gI1,1)*ZH(gI2,1) + 1.4142135623730951*LamSU*vS*
      Conj(LamTU)*ZH(gI1,1)*ZH(gI2,1) + 2*g2*Conj(MDWBT)*ZH(gI1,1)*ZH(gI2,1) - 2*
      LamTU*Conj(MuU)*ZH(gI1,1)*ZH(gI2,1) - 1.4142135623730951*LamTU*vu*Conj(LamSU
      )*ZH(gI1,2)*ZH(gI2,1) + 1.4142135623730951*LamSU*vu*Conj(LamTU)*ZH(gI1,2)*ZH
      (gI2,1) - 1.4142135623730951*LamTU*vu*Conj(LamSU)*ZH(gI1,1)*ZH(gI2,2) +
      1.4142135623730951*LamSU*vu*Conj(LamTU)*ZH(gI1,1)*ZH(gI2,2) + ZH(gI1,0)*((2*
      g2*MDWBT + 1.4142135623730951*LamTD*vS*Conj(LamSD) - 2*MuD*Conj(LamTD) -
      1.4142135623730951*LamSD*vS*Conj(LamTD) - 2*g2*Conj(MDWBT) + 2*LamTD*Conj(
      MuD))*ZH(gI2,0) + 1.4142135623730951*vd*(LamTD*Conj(LamSD) - LamSD*Conj(
      LamTD))*ZH(gI2,2))) + KroneckerDelta(2,gO2)*(7.0710678118654755*LamTD*vd*
      Conj(LamSD)*ZH(gI1,3)*ZH(gI2,0) - 7.0710678118654755*LamSD*vd*Conj(LamTD)*ZH
      (gI1,3)*ZH(gI2,0) - 7.745966692414834*g1*MDBS*ZH(gI1,1)*ZH(gI2,1) +
      14.142135623730951*MuU*Conj(LamSU)*ZH(gI1,1)*ZH(gI2,1) - 7.0710678118654755*
      LamTU*vT*Conj(LamSU)*ZH(gI1,1)*ZH(gI2,1) + 7.0710678118654755*LamSU*vT*Conj(
      LamTU)*ZH(gI1,1)*ZH(gI2,1) + 7.745966692414834*g1*Conj(MDBS)*ZH(gI1,1)*ZH(
      gI2,1) - 14.142135623730951*LamSU*Conj(MuU)*ZH(gI1,1)*ZH(gI2,1) -
      7.0710678118654755*LamTU*vu*Conj(LamSU)*ZH(gI1,3)*ZH(gI2,1) +
      7.0710678118654755*LamSU*vu*Conj(LamTU)*ZH(gI1,3)*ZH(gI2,1) -
      7.0710678118654755*LamTU*vu*Conj(LamSU)*ZH(gI1,1)*ZH(gI2,3) +
      7.0710678118654755*LamSU*vu*Conj(LamTU)*ZH(gI1,1)*ZH(gI2,3) + ZH(gI1,0)*((
      7.745966692414834*g1*MDBS + 7.0710678118654755*(2*MuD + LamTD*vT)*Conj(LamSD
      ) - 7.0710678118654755*LamSD*vT*Conj(LamTD) - 7.745966692414834*g1*Conj(MDBS
      ) - 14.142135623730951*LamSD*Conj(MuD))*ZH(gI2,0) + 7.0710678118654755*vd*(
      LamTD*Conj(LamSD) - LamSD*Conj(LamTD))*ZH(gI2,3))));

   return result;
}

std::complex<double> CLASSNAME::CpUAhbarChiChiPR(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = std::complex<double>(0,-0.1)*(5*Conj(LamTD)*KroneckerDelta(0,gO2)*
      ZN1(gI1,2)*ZN2(gI2,1) + 5*Conj(LamTU)*KroneckerDelta(1,gO2)*ZN1(gI1,3)*ZN2(
      gI2,1) - 3.872983346207417*g1*KroneckerDelta(0,gO2)*ZN1(gI1,0)*ZN2(gI2,2) +
      5*g2*KroneckerDelta(0,gO2)*ZN1(gI1,1)*ZN2(gI2,2) + 5*Conj(LamTD)*
      KroneckerDelta(3,gO2)*ZN1(gI1,2)*ZN2(gI2,2) + 7.0710678118654755*Conj(LamSD)
      *ZN1(gI1,2)*(KroneckerDelta(0,gO2)*ZN2(gI2,0) + KroneckerDelta(2,gO2)*ZN2(
      gI2,2)) + 3.872983346207417*g1*KroneckerDelta(1,gO2)*ZN1(gI1,0)*ZN2(gI2,3) -
      5*g2*KroneckerDelta(1,gO2)*ZN1(gI1,1)*ZN2(gI2,3) + 5*Conj(LamTU)*
      KroneckerDelta(3,gO2)*ZN1(gI1,3)*ZN2(gI2,3) - 7.0710678118654755*Conj(LamSU)
      *ZN1(gI1,3)*(KroneckerDelta(1,gO2)*ZN2(gI2,0) + KroneckerDelta(2,gO2)*ZN2(
      gI2,3)));

   return result;
}

std::complex<double> CLASSNAME::CpUAhbarChiChiPL(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = std::complex<double>(0,0.1)*(3.872983346207417*g1*Conj(ZN1(gI2,0))*
      (-(Conj(ZN2(gI1,2))*KroneckerDelta(0,gO1)) + Conj(ZN2(gI1,3))*KroneckerDelta
      (1,gO1)) + 5*Conj(ZN1(gI2,2))*(1.4142135623730951*LamSD*Conj(ZN2(gI1,0))*
      KroneckerDelta(0,gO1) + LamTD*Conj(ZN2(gI1,1))*KroneckerDelta(0,gO1) + Conj(
      ZN2(gI1,2))*(1.4142135623730951*LamSD*KroneckerDelta(2,gO1) + LamTD*
      KroneckerDelta(3,gO1))) + 5*(g2*Conj(ZN1(gI2,1))*(Conj(ZN2(gI1,2))*
      KroneckerDelta(0,gO1) - Conj(ZN2(gI1,3))*KroneckerDelta(1,gO1)) + Conj(ZN1(
      gI2,3))*(-1.4142135623730951*LamSU*Conj(ZN2(gI1,0))*KroneckerDelta(1,gO1) +
      LamTU*Conj(ZN2(gI1,1))*KroneckerDelta(1,gO1) + Conj(ZN2(gI1,3))*(
      -1.4142135623730951*LamSU*KroneckerDelta(2,gO1) + LamTU*KroneckerDelta(3,gO1
      )))));

   return result;
}

std::complex<double> CLASSNAME::CpUAhUAhconjSdSd(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1182;
   std::complex<double> tmp_1183;
   std::complex<double> tmp_1184;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1184 += Conj(ZD(gI2,j1))*ZD(gI1,j1);
   }
   tmp_1183 += tmp_1184;
   tmp_1182 += (std::complex<double>(0,0.05)*KroneckerDelta(0,gO1)*
      KroneckerDelta(0,gO2)*Sqr(g1)) * tmp_1183;
   std::complex<double> tmp_1185;
   std::complex<double> tmp_1186;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1186 += Conj(ZD(gI2,j1))*ZD(gI1,j1);
   }
   tmp_1185 += tmp_1186;
   tmp_1182 += (std::complex<double>(0,0.25)*KroneckerDelta(0,gO1)*
      KroneckerDelta(0,gO2)*Sqr(g2)) * tmp_1185;
   std::complex<double> tmp_1187;
   std::complex<double> tmp_1188;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1188 += Conj(ZD(gI2,j1))*ZD(gI1,j1);
   }
   tmp_1187 += tmp_1188;
   tmp_1182 += (std::complex<double>(0,-0.05)*KroneckerDelta(1,gO1)*
      KroneckerDelta(1,gO2)*Sqr(g1)) * tmp_1187;
   std::complex<double> tmp_1189;
   std::complex<double> tmp_1190;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1190 += Conj(ZD(gI2,j1))*ZD(gI1,j1);
   }
   tmp_1189 += tmp_1190;
   tmp_1182 += (std::complex<double>(0,-0.25)*KroneckerDelta(1,gO1)*
      KroneckerDelta(1,gO2)*Sqr(g2)) * tmp_1189;
   std::complex<double> tmp_1191;
   std::complex<double> tmp_1192;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1192 += Conj(ZD(gI2,3 + j1))*ZD(gI1,3 + j1);
   }
   tmp_1191 += tmp_1192;
   tmp_1182 += (std::complex<double>(0,0.1)*KroneckerDelta(0,gO1)*
      KroneckerDelta(0,gO2)*Sqr(g1)) * tmp_1191;
   std::complex<double> tmp_1193;
   std::complex<double> tmp_1194;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1194 += Conj(ZD(gI2,3 + j1))*ZD(gI1,3 + j1);
   }
   tmp_1193 += tmp_1194;
   tmp_1182 += (std::complex<double>(0,-0.1)*KroneckerDelta(1,gO1)*
      KroneckerDelta(1,gO2)*Sqr(g1)) * tmp_1193;
   std::complex<double> tmp_1195;
   std::complex<double> tmp_1196;
   for (unsigned j3 = 0; j3 < 3; ++j3) {
      std::complex<double> tmp_1197;
      std::complex<double> tmp_1198;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         std::complex<double> tmp_1199;
         std::complex<double> tmp_1200;
         for (unsigned j1 = 0; j1 < 3; ++j1) {
            tmp_1200 += Conj(Yd(j3,j1))*Yd(j2,j1);
         }
         tmp_1199 += tmp_1200;
         tmp_1198 += (ZD(gI1,3 + j2)) * tmp_1199;
      }
      tmp_1197 += tmp_1198;
      tmp_1196 += (Conj(ZD(gI2,3 + j3))) * tmp_1197;
   }
   tmp_1195 += tmp_1196;
   tmp_1182 += (std::complex<double>(0,-1)*KroneckerDelta(0,gO1)*KroneckerDelta
      (0,gO2)) * tmp_1195;
   std::complex<double> tmp_1201;
   std::complex<double> tmp_1202;
   for (unsigned j3 = 0; j3 < 3; ++j3) {
      std::complex<double> tmp_1203;
      std::complex<double> tmp_1204;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         std::complex<double> tmp_1205;
         std::complex<double> tmp_1206;
         for (unsigned j1 = 0; j1 < 3; ++j1) {
            tmp_1206 += Conj(Yd(j1,j3))*Yd(j1,j2);
         }
         tmp_1205 += tmp_1206;
         tmp_1204 += (Conj(ZD(gI2,j2))) * tmp_1205;
      }
      tmp_1203 += tmp_1204;
      tmp_1202 += (ZD(gI1,j3)) * tmp_1203;
   }
   tmp_1201 += tmp_1202;
   tmp_1182 += (std::complex<double>(0,-1)*KroneckerDelta(0,gO1)*KroneckerDelta
      (0,gO2)) * tmp_1201;
   result += (std::complex<double>(0,-1)) * tmp_1182;

   return result;
}

std::complex<double> CLASSNAME::CpUAhUAhconjSeSe(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1207;
   std::complex<double> tmp_1208;
   std::complex<double> tmp_1209;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1209 += Conj(ZE(gI2,j1))*ZE(gI1,j1);
   }
   tmp_1208 += tmp_1209;
   tmp_1207 += (std::complex<double>(0,-0.15)*KroneckerDelta(0,gO1)*
      KroneckerDelta(0,gO2)*Sqr(g1)) * tmp_1208;
   std::complex<double> tmp_1210;
   std::complex<double> tmp_1211;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1211 += Conj(ZE(gI2,j1))*ZE(gI1,j1);
   }
   tmp_1210 += tmp_1211;
   tmp_1207 += (std::complex<double>(0,0.25)*KroneckerDelta(0,gO1)*
      KroneckerDelta(0,gO2)*Sqr(g2)) * tmp_1210;
   std::complex<double> tmp_1212;
   std::complex<double> tmp_1213;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1213 += Conj(ZE(gI2,j1))*ZE(gI1,j1);
   }
   tmp_1212 += tmp_1213;
   tmp_1207 += (std::complex<double>(0,0.15)*KroneckerDelta(1,gO1)*
      KroneckerDelta(1,gO2)*Sqr(g1)) * tmp_1212;
   std::complex<double> tmp_1214;
   std::complex<double> tmp_1215;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1215 += Conj(ZE(gI2,j1))*ZE(gI1,j1);
   }
   tmp_1214 += tmp_1215;
   tmp_1207 += (std::complex<double>(0,-0.25)*KroneckerDelta(1,gO1)*
      KroneckerDelta(1,gO2)*Sqr(g2)) * tmp_1214;
   std::complex<double> tmp_1216;
   std::complex<double> tmp_1217;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1217 += Conj(ZE(gI2,3 + j1))*ZE(gI1,3 + j1);
   }
   tmp_1216 += tmp_1217;
   tmp_1207 += (std::complex<double>(0,0.3)*KroneckerDelta(0,gO1)*
      KroneckerDelta(0,gO2)*Sqr(g1)) * tmp_1216;
   std::complex<double> tmp_1218;
   std::complex<double> tmp_1219;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1219 += Conj(ZE(gI2,3 + j1))*ZE(gI1,3 + j1);
   }
   tmp_1218 += tmp_1219;
   tmp_1207 += (std::complex<double>(0,-0.3)*KroneckerDelta(1,gO1)*
      KroneckerDelta(1,gO2)*Sqr(g1)) * tmp_1218;
   std::complex<double> tmp_1220;
   std::complex<double> tmp_1221;
   for (unsigned j3 = 0; j3 < 3; ++j3) {
      std::complex<double> tmp_1222;
      std::complex<double> tmp_1223;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         std::complex<double> tmp_1224;
         std::complex<double> tmp_1225;
         for (unsigned j1 = 0; j1 < 3; ++j1) {
            tmp_1225 += Conj(Ye(j3,j1))*Ye(j2,j1);
         }
         tmp_1224 += tmp_1225;
         tmp_1223 += (ZE(gI1,3 + j2)) * tmp_1224;
      }
      tmp_1222 += tmp_1223;
      tmp_1221 += (Conj(ZE(gI2,3 + j3))) * tmp_1222;
   }
   tmp_1220 += tmp_1221;
   tmp_1207 += (std::complex<double>(0,-1)*KroneckerDelta(0,gO1)*KroneckerDelta
      (0,gO2)) * tmp_1220;
   std::complex<double> tmp_1226;
   std::complex<double> tmp_1227;
   for (unsigned j3 = 0; j3 < 3; ++j3) {
      std::complex<double> tmp_1228;
      std::complex<double> tmp_1229;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         std::complex<double> tmp_1230;
         std::complex<double> tmp_1231;
         for (unsigned j1 = 0; j1 < 3; ++j1) {
            tmp_1231 += Conj(Ye(j1,j3))*Ye(j1,j2);
         }
         tmp_1230 += tmp_1231;
         tmp_1229 += (Conj(ZE(gI2,j2))) * tmp_1230;
      }
      tmp_1228 += tmp_1229;
      tmp_1227 += (ZE(gI1,j3)) * tmp_1228;
   }
   tmp_1226 += tmp_1227;
   tmp_1207 += (std::complex<double>(0,-1)*KroneckerDelta(0,gO1)*KroneckerDelta
      (0,gO2)) * tmp_1226;
   result += (std::complex<double>(0,-1)) * tmp_1207;

   return result;
}

std::complex<double> CLASSNAME::CpUAhUAhconjSuSu(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1232;
   std::complex<double> tmp_1233;
   std::complex<double> tmp_1234;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1234 += Conj(ZU(gI2,j1))*ZU(gI1,j1);
   }
   tmp_1233 += tmp_1234;
   tmp_1232 += (std::complex<double>(0,0.05)*KroneckerDelta(0,gO1)*
      KroneckerDelta(0,gO2)*Sqr(g1)) * tmp_1233;
   std::complex<double> tmp_1235;
   std::complex<double> tmp_1236;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1236 += Conj(ZU(gI2,j1))*ZU(gI1,j1);
   }
   tmp_1235 += tmp_1236;
   tmp_1232 += (std::complex<double>(0,-0.25)*KroneckerDelta(0,gO1)*
      KroneckerDelta(0,gO2)*Sqr(g2)) * tmp_1235;
   std::complex<double> tmp_1237;
   std::complex<double> tmp_1238;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1238 += Conj(ZU(gI2,j1))*ZU(gI1,j1);
   }
   tmp_1237 += tmp_1238;
   tmp_1232 += (std::complex<double>(0,-0.05)*KroneckerDelta(1,gO1)*
      KroneckerDelta(1,gO2)*Sqr(g1)) * tmp_1237;
   std::complex<double> tmp_1239;
   std::complex<double> tmp_1240;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1240 += Conj(ZU(gI2,j1))*ZU(gI1,j1);
   }
   tmp_1239 += tmp_1240;
   tmp_1232 += (std::complex<double>(0,0.25)*KroneckerDelta(1,gO1)*
      KroneckerDelta(1,gO2)*Sqr(g2)) * tmp_1239;
   std::complex<double> tmp_1241;
   std::complex<double> tmp_1242;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1242 += Conj(ZU(gI2,3 + j1))*ZU(gI1,3 + j1);
   }
   tmp_1241 += tmp_1242;
   tmp_1232 += (std::complex<double>(0,-0.2)*KroneckerDelta(0,gO1)*
      KroneckerDelta(0,gO2)*Sqr(g1)) * tmp_1241;
   std::complex<double> tmp_1243;
   std::complex<double> tmp_1244;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1244 += Conj(ZU(gI2,3 + j1))*ZU(gI1,3 + j1);
   }
   tmp_1243 += tmp_1244;
   tmp_1232 += (std::complex<double>(0,0.2)*KroneckerDelta(1,gO1)*
      KroneckerDelta(1,gO2)*Sqr(g1)) * tmp_1243;
   std::complex<double> tmp_1245;
   std::complex<double> tmp_1246;
   for (unsigned j3 = 0; j3 < 3; ++j3) {
      std::complex<double> tmp_1247;
      std::complex<double> tmp_1248;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         std::complex<double> tmp_1249;
         std::complex<double> tmp_1250;
         for (unsigned j1 = 0; j1 < 3; ++j1) {
            tmp_1250 += Conj(Yu(j3,j1))*Yu(j2,j1);
         }
         tmp_1249 += tmp_1250;
         tmp_1248 += (ZU(gI1,3 + j2)) * tmp_1249;
      }
      tmp_1247 += tmp_1248;
      tmp_1246 += (Conj(ZU(gI2,3 + j3))) * tmp_1247;
   }
   tmp_1245 += tmp_1246;
   tmp_1232 += (std::complex<double>(0,-1)*KroneckerDelta(1,gO1)*KroneckerDelta
      (1,gO2)) * tmp_1245;
   std::complex<double> tmp_1251;
   std::complex<double> tmp_1252;
   for (unsigned j3 = 0; j3 < 3; ++j3) {
      std::complex<double> tmp_1253;
      std::complex<double> tmp_1254;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         std::complex<double> tmp_1255;
         std::complex<double> tmp_1256;
         for (unsigned j1 = 0; j1 < 3; ++j1) {
            tmp_1256 += Conj(Yu(j1,j3))*Yu(j1,j2);
         }
         tmp_1255 += tmp_1256;
         tmp_1254 += (Conj(ZU(gI2,j2))) * tmp_1255;
      }
      tmp_1253 += tmp_1254;
      tmp_1252 += (ZU(gI1,j3)) * tmp_1253;
   }
   tmp_1251 += tmp_1252;
   tmp_1232 += (std::complex<double>(0,-1)*KroneckerDelta(1,gO1)*KroneckerDelta
      (1,gO2)) * tmp_1251;
   result += (std::complex<double>(0,-1)) * tmp_1232;

   return result;
}

std::complex<double> CLASSNAME::CpUAhconjSdSd(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1257;
   std::complex<double> tmp_1258;
   std::complex<double> tmp_1259;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1259 += Conj(ZD(gI2,j1))*ZD(gI1,j1);
   }
   tmp_1258 += tmp_1259;
   tmp_1257 += (0.12909944487358055*g1*MDBS*KroneckerDelta(2,gO2)) * tmp_1258;
   std::complex<double> tmp_1260;
   std::complex<double> tmp_1261;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1261 += Conj(ZD(gI2,j1))*ZD(gI1,j1);
   }
   tmp_1260 += tmp_1261;
   tmp_1257 += (-0.12909944487358055*g1*Conj(MDBS)*KroneckerDelta(2,gO2)) *
      tmp_1260;
   std::complex<double> tmp_1262;
   std::complex<double> tmp_1263;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1263 += Conj(ZD(gI2,j1))*ZD(gI1,j1);
   }
   tmp_1262 += tmp_1263;
   tmp_1257 += (-0.5*g2*MDWBT*KroneckerDelta(3,gO2)) * tmp_1262;
   std::complex<double> tmp_1264;
   std::complex<double> tmp_1265;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1265 += Conj(ZD(gI2,j1))*ZD(gI1,j1);
   }
   tmp_1264 += tmp_1265;
   tmp_1257 += (0.5*g2*Conj(MDWBT)*KroneckerDelta(3,gO2)) * tmp_1264;
   std::complex<double> tmp_1266;
   std::complex<double> tmp_1267;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1267 += Conj(ZD(gI2,3 + j1))*ZD(gI1,3 + j1);
   }
   tmp_1266 += tmp_1267;
   tmp_1257 += (0.2581988897471611*g1*MDBS*KroneckerDelta(2,gO2)) * tmp_1266;
   std::complex<double> tmp_1268;
   std::complex<double> tmp_1269;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1269 += Conj(ZD(gI2,3 + j1))*ZD(gI1,3 + j1);
   }
   tmp_1268 += tmp_1269;
   tmp_1257 += (-0.2581988897471611*g1*Conj(MDBS)*KroneckerDelta(2,gO2)) *
      tmp_1268;
   std::complex<double> tmp_1270;
   std::complex<double> tmp_1271;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_1272;
      std::complex<double> tmp_1273;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1273 += Yd(j1,j2)*ZD(gI1,3 + j1);
      }
      tmp_1272 += tmp_1273;
      tmp_1271 += (Conj(ZD(gI2,j2))) * tmp_1272;
   }
   tmp_1270 += tmp_1271;
   tmp_1257 += (0.7071067811865475*Conj(Mu)*KroneckerDelta(1,gO2)) * tmp_1270;
   std::complex<double> tmp_1274;
   std::complex<double> tmp_1275;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_1276;
      std::complex<double> tmp_1277;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1277 += Conj(Yd(j1,j2))*Conj(ZD(gI2,3 + j1));
      }
      tmp_1276 += tmp_1277;
      tmp_1275 += (ZD(gI1,j2)) * tmp_1276;
   }
   tmp_1274 += tmp_1275;
   tmp_1257 += (-0.7071067811865475*KroneckerDelta(1,gO2)*Mu) * tmp_1274;
   result += (std::complex<double>(0,-1)) * tmp_1257;

   return result;
}

std::complex<double> CLASSNAME::CpUAhconjSeSe(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1278;
   std::complex<double> tmp_1279;
   std::complex<double> tmp_1280;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1280 += Conj(ZE(gI2,j1))*ZE(gI1,j1);
   }
   tmp_1279 += tmp_1280;
   tmp_1278 += (-0.3872983346207417*g1*MDBS*KroneckerDelta(2,gO2)) * tmp_1279;
   std::complex<double> tmp_1281;
   std::complex<double> tmp_1282;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1282 += Conj(ZE(gI2,j1))*ZE(gI1,j1);
   }
   tmp_1281 += tmp_1282;
   tmp_1278 += (0.3872983346207417*g1*Conj(MDBS)*KroneckerDelta(2,gO2)) *
      tmp_1281;
   std::complex<double> tmp_1283;
   std::complex<double> tmp_1284;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1284 += Conj(ZE(gI2,j1))*ZE(gI1,j1);
   }
   tmp_1283 += tmp_1284;
   tmp_1278 += (-0.5*g2*MDWBT*KroneckerDelta(3,gO2)) * tmp_1283;
   std::complex<double> tmp_1285;
   std::complex<double> tmp_1286;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1286 += Conj(ZE(gI2,j1))*ZE(gI1,j1);
   }
   tmp_1285 += tmp_1286;
   tmp_1278 += (0.5*g2*Conj(MDWBT)*KroneckerDelta(3,gO2)) * tmp_1285;
   std::complex<double> tmp_1287;
   std::complex<double> tmp_1288;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1288 += Conj(ZE(gI2,3 + j1))*ZE(gI1,3 + j1);
   }
   tmp_1287 += tmp_1288;
   tmp_1278 += (0.7745966692414834*g1*MDBS*KroneckerDelta(2,gO2)) * tmp_1287;
   std::complex<double> tmp_1289;
   std::complex<double> tmp_1290;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1290 += Conj(ZE(gI2,3 + j1))*ZE(gI1,3 + j1);
   }
   tmp_1289 += tmp_1290;
   tmp_1278 += (-0.7745966692414834*g1*Conj(MDBS)*KroneckerDelta(2,gO2)) *
      tmp_1289;
   std::complex<double> tmp_1291;
   std::complex<double> tmp_1292;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_1293;
      std::complex<double> tmp_1294;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1294 += Ye(j1,j2)*ZE(gI1,3 + j1);
      }
      tmp_1293 += tmp_1294;
      tmp_1292 += (Conj(ZE(gI2,j2))) * tmp_1293;
   }
   tmp_1291 += tmp_1292;
   tmp_1278 += (0.7071067811865475*Conj(Mu)*KroneckerDelta(1,gO2)) * tmp_1291;
   std::complex<double> tmp_1295;
   std::complex<double> tmp_1296;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_1297;
      std::complex<double> tmp_1298;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1298 += Conj(Ye(j1,j2))*Conj(ZE(gI2,3 + j1));
      }
      tmp_1297 += tmp_1298;
      tmp_1296 += (ZE(gI1,j2)) * tmp_1297;
   }
   tmp_1295 += tmp_1296;
   tmp_1278 += (-0.7071067811865475*KroneckerDelta(1,gO2)*Mu) * tmp_1295;
   result += (std::complex<double>(0,-1)) * tmp_1278;

   return result;
}

std::complex<double> CLASSNAME::CpUAhconjSuSu(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1299;
   std::complex<double> tmp_1300;
   std::complex<double> tmp_1301;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1301 += Conj(ZU(gI2,j1))*ZU(gI1,j1);
   }
   tmp_1300 += tmp_1301;
   tmp_1299 += (0.12909944487358055*g1*MDBS*KroneckerDelta(2,gO2)) * tmp_1300;
   std::complex<double> tmp_1302;
   std::complex<double> tmp_1303;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1303 += Conj(ZU(gI2,j1))*ZU(gI1,j1);
   }
   tmp_1302 += tmp_1303;
   tmp_1299 += (-0.12909944487358055*g1*Conj(MDBS)*KroneckerDelta(2,gO2)) *
      tmp_1302;
   std::complex<double> tmp_1304;
   std::complex<double> tmp_1305;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1305 += Conj(ZU(gI2,j1))*ZU(gI1,j1);
   }
   tmp_1304 += tmp_1305;
   tmp_1299 += (0.5*g2*MDWBT*KroneckerDelta(3,gO2)) * tmp_1304;
   std::complex<double> tmp_1306;
   std::complex<double> tmp_1307;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1307 += Conj(ZU(gI2,j1))*ZU(gI1,j1);
   }
   tmp_1306 += tmp_1307;
   tmp_1299 += (-0.5*g2*Conj(MDWBT)*KroneckerDelta(3,gO2)) * tmp_1306;
   std::complex<double> tmp_1308;
   std::complex<double> tmp_1309;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1309 += Conj(ZU(gI2,3 + j1))*ZU(gI1,3 + j1);
   }
   tmp_1308 += tmp_1309;
   tmp_1299 += (-0.5163977794943222*g1*MDBS*KroneckerDelta(2,gO2)) * tmp_1308;
   std::complex<double> tmp_1310;
   std::complex<double> tmp_1311;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1311 += Conj(ZU(gI2,3 + j1))*ZU(gI1,3 + j1);
   }
   tmp_1310 += tmp_1311;
   tmp_1299 += (0.5163977794943222*g1*Conj(MDBS)*KroneckerDelta(2,gO2)) *
      tmp_1310;
   std::complex<double> tmp_1312;
   std::complex<double> tmp_1313;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_1314;
      std::complex<double> tmp_1315;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1315 += Yu(j1,j2)*ZU(gI1,3 + j1);
      }
      tmp_1314 += tmp_1315;
      tmp_1313 += (Conj(ZU(gI2,j2))) * tmp_1314;
   }
   tmp_1312 += tmp_1313;
   tmp_1299 += (0.7071067811865475*Conj(Mu)*KroneckerDelta(0,gO2)) * tmp_1312;
   std::complex<double> tmp_1316;
   std::complex<double> tmp_1317;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_1318;
      std::complex<double> tmp_1319;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1319 += Conj(Yu(j1,j2))*Conj(ZU(gI2,3 + j1));
      }
      tmp_1318 += tmp_1319;
      tmp_1317 += (ZU(gI1,j2)) * tmp_1318;
   }
   tmp_1316 += tmp_1317;
   tmp_1299 += (-0.7071067811865475*KroneckerDelta(0,gO2)*Mu) * tmp_1316;
   result += (std::complex<double>(0,-1)) * tmp_1299;

   return result;
}

std::complex<double> CLASSNAME::CpUAhVZhh(unsigned gO2, unsigned gI2) const
{
   std::complex<double> result;

   result = std::complex<double>(0,-0.1)*(5*g2*Cos(ThetaW()) +
      3.872983346207417*g1*Sin(ThetaW()))*(KroneckerDelta(0,gO2)*ZH(gI2,0) -
      KroneckerDelta(1,gO2)*ZH(gI2,1));

   return result;
}

std::complex<double> CLASSNAME::CpUAhconjVWmHpm(unsigned gO2, unsigned gI2) const
{
   std::complex<double> result;

   result = std::complex<double>(0,-0.5)*g2*(KroneckerDelta(0,gO2)*ZP(gI2,0) +
      KroneckerDelta(1,gO2)*ZP(gI2,1) + 1.4142135623730951*KroneckerDelta(3,gO2)*(
      ZP(gI2,2) - ZP(gI2,3)));

   return result;
}

std::complex<double> CLASSNAME::CpURhconjURhVZVZ(unsigned gO1, unsigned gO2) const
{
   std::complex<double> result;

   result = 0.05*(KroneckerDelta(0,gO1)*KroneckerDelta(0,gO2) + KroneckerDelta(
      1,gO1)*KroneckerDelta(1,gO2))*(7.745966692414834*g1*g2*Sin(2*ThetaW()) + 3*
      Sqr(g1) + 5*Sqr(g2) + Cos(2*ThetaW())*(-3*Sqr(g1) + 5*Sqr(g2)));

   return result;
}

std::complex<double> CLASSNAME::CpURhconjURhconjVWmVWm(unsigned gO1, unsigned gO2) const
{
   std::complex<double> result;

   result = 0.5*(KroneckerDelta(0,gO1)*KroneckerDelta(0,gO2) + KroneckerDelta(1
      ,gO1)*KroneckerDelta(1,gO2))*Sqr(g2);

   return result;
}

std::complex<double> CLASSNAME::CpURhconjURhconjRhRh(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.05*(3*Sqr(g1) + 5*Sqr(g2))*(KroneckerDelta(1,gO1)*(KroneckerDelta
      (0,gO2)*ZHR(gI1,1)*ZHR(gI2,0) + KroneckerDelta(1,gO2)*(ZHR(gI1,0)*ZHR(gI2,0)
      - 2*ZHR(gI1,1)*ZHR(gI2,1))) + KroneckerDelta(0,gO1)*(KroneckerDelta(1,gO2)*
      ZHR(gI1,0)*ZHR(gI2,1) + KroneckerDelta(0,gO2)*(-2*ZHR(gI1,0)*ZHR(gI2,0) +
      ZHR(gI1,1)*ZHR(gI2,1))));

   return result;
}

std::complex<double> CLASSNAME::CpURhconjURhconjRpmRpm(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.05*(Conj(ZRP(gI2,0))*(KroneckerDelta(0,gO1)*KroneckerDelta(0,gO2)
      *(3*Sqr(g1) - 5*Sqr(g2)) - KroneckerDelta(1,gO1)*KroneckerDelta(1,gO2)*(3*
      Sqr(g1) + 5*Sqr(g2)))*ZRP(gI1,0) - Conj(ZRP(gI2,1))*(KroneckerDelta(1,gO1)*
      KroneckerDelta(1,gO2)*(-3*Sqr(g1) + 5*Sqr(g2)) + KroneckerDelta(0,gO1)*
      KroneckerDelta(0,gO2)*(3*Sqr(g1) + 5*Sqr(g2)))*ZRP(gI1,1));

   return result;
}

std::complex<double> CLASSNAME::CpconjURhconjRpmVWm(unsigned gO2, unsigned gI1) const
{
   std::complex<double> result;

   result = 0.7071067811865475*g2*KroneckerDelta(0,gO2)*ZRP(gI1,1);

   return result;
}

std::complex<double> CLASSNAME::CpconjURhCha2Cha1PR(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = Conj(LamTD)*KroneckerDelta(0,gO2)*UM1(gI2,1)*UP2(gI1,0) - Conj(
      LamTU)*KroneckerDelta(1,gO2)*UM1(gI2,0)*UP2(gI1,1);

   return result;
}

std::complex<double> CLASSNAME::CpconjURhCha2Cha1PL(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = -(g2*(Conj(UM2(gI1,0))*Conj(UP1(gI2,1))*KroneckerDelta(0,gO1) +
      Conj(UM2(gI1,1))*Conj(UP1(gI2,0))*KroneckerDelta(1,gO1)));

   return result;
}

std::complex<double> CLASSNAME::CpconjURhconjRpmHpm(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = -0.25*(1.4142135623730951*KroneckerDelta(1,gO2)*(2*LamSD*vu*Conj(
      LamSU)*ZP(gI2,0) + LamTD*Conj(LamTU)*(vu*ZP(gI2,0) + 2*vd*ZP(gI2,1))) +
      KroneckerDelta(0,gO2)*(1.4142135623730951*vd*(-2*AbsSqr(LamSD) + AbsSqr(
      LamTD) + Sqr(g2))*ZP(gI2,0) + 1.4142135623730951*vu*Sqr(g2)*ZP(gI2,1) + 4*g2
      *MDWBT*ZP(gI2,2) - 2*vT*AbsSqr(LamTD)*ZP(gI2,2) - 2.8284271247461903*LamTD*
      vS*Conj(LamSD)*ZP(gI2,2) - 4*LamTD*Conj(MuD)*ZP(gI2,2) + 2*vT*Sqr(g2)*ZP(gI2
      ,2) + 2*vT*AbsSqr(LamTD)*ZP(gI2,3) - 4*MuD*Conj(LamTD)*ZP(gI2,3) -
      2.8284271247461903*LamSD*vS*Conj(LamTD)*ZP(gI2,3) + 4*g2*Conj(MDWBT)*ZP(gI2,
      3) - 2*vT*Sqr(g2)*ZP(gI2,3)))*ZRP(gI1,1);

   return result;
}

std::complex<double> CLASSNAME::CpconjURhRhAh(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = std::complex<double>(0,0.05)*(-7.745966692414834*g1*MDBS*
      KroneckerDelta(0,gO2)*ZA(gI2,2)*ZHR(gI1,0) + 14.142135623730951*MuD*Conj(
      LamSD)*KroneckerDelta(0,gO2)*ZA(gI2,2)*ZHR(gI1,0) + 7.0710678118654755*LamTD
      *vT*Conj(LamSD)*KroneckerDelta(0,gO2)*ZA(gI2,2)*ZHR(gI1,0) -
      7.0710678118654755*LamSD*vT*Conj(LamTD)*KroneckerDelta(0,gO2)*ZA(gI2,2)*ZHR(
      gI1,0) + 7.745966692414834*g1*Conj(MDBS)*KroneckerDelta(0,gO2)*ZA(gI2,2)*ZHR
      (gI1,0) - 14.142135623730951*LamSD*Conj(MuD)*KroneckerDelta(0,gO2)*ZA(gI2,2)
      *ZHR(gI1,0) + 10*g2*MDWBT*KroneckerDelta(0,gO2)*ZA(gI2,3)*ZHR(gI1,0) -
      7.0710678118654755*LamTD*vS*Conj(LamSD)*KroneckerDelta(0,gO2)*ZA(gI2,3)*ZHR(
      gI1,0) + 10*MuD*Conj(LamTD)*KroneckerDelta(0,gO2)*ZA(gI2,3)*ZHR(gI1,0) +
      7.0710678118654755*LamSD*vS*Conj(LamTD)*KroneckerDelta(0,gO2)*ZA(gI2,3)*ZHR(
      gI1,0) - 10*g2*Conj(MDWBT)*KroneckerDelta(0,gO2)*ZA(gI2,3)*ZHR(gI1,0) - 10*
      LamTD*Conj(MuD)*KroneckerDelta(0,gO2)*ZA(gI2,3)*ZHR(gI1,0) - 10*LamSU*vu*
      Conj(LamSD)*KroneckerDelta(0,gO2)*ZA(gI2,0)*ZHR(gI1,1) + 5*LamTU*vu*Conj(
      LamTD)*KroneckerDelta(0,gO2)*ZA(gI2,0)*ZHR(gI1,1) + 10*LamSU*vd*Conj(LamSD)*
      KroneckerDelta(0,gO2)*ZA(gI2,1)*ZHR(gI1,1) - 5*LamTU*vd*Conj(LamTD)*
      KroneckerDelta(0,gO2)*ZA(gI2,1)*ZHR(gI1,1) + 7.745966692414834*g1*MDBS*
      KroneckerDelta(1,gO2)*ZA(gI2,2)*ZHR(gI1,1) - 7.745966692414834*g1*Conj(MDBS)
      *KroneckerDelta(1,gO2)*ZA(gI2,2)*ZHR(gI1,1) - 14.142135623730951*LamSU*Conj(
      MuU)*KroneckerDelta(1,gO2)*ZA(gI2,2)*ZHR(gI1,1) - 10*g2*MDWBT*KroneckerDelta
      (1,gO2)*ZA(gI2,3)*ZHR(gI1,1) + 10*g2*Conj(MDWBT)*KroneckerDelta(1,gO2)*ZA(
      gI2,3)*ZHR(gI1,1) + 10*LamTU*Conj(MuU)*KroneckerDelta(1,gO2)*ZA(gI2,3)*ZHR(
      gI1,1) + 5*Conj(LamSU)*KroneckerDelta(1,gO2)*(2*LamSD*vu*ZA(gI2,0)*ZHR(gI1,0
      ) - 2*LamSD*vd*ZA(gI2,1)*ZHR(gI1,0) + 1.4142135623730951*((2*MuU - LamTU*vT)
      *ZA(gI2,2) + LamTU*vS*ZA(gI2,3))*ZHR(gI1,1)) - 5*Conj(LamTU)*KroneckerDelta(
      1,gO2)*(LamTD*vu*ZA(gI2,0)*ZHR(gI1,0) - LamTD*vd*ZA(gI2,1)*ZHR(gI1,0) + (
      -1.4142135623730951*LamSU*vT*ZA(gI2,2) + (2*MuU + 1.4142135623730951*LamSU*
      vS)*ZA(gI2,3))*ZHR(gI1,1)));

   return result;
}

std::complex<double> CLASSNAME::CpconjURhRhhh(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.05*(KroneckerDelta(0,gO2)*(-(((5*(2.8284271247461903*MuD + 4*
      LamSD*vS + 1.4142135623730951*LamTD*vT)*Conj(LamSD) + 7.0710678118654755*
      LamSD*vT*Conj(LamTD) + 2*(3.872983346207417*g1*MDBS + 3.872983346207417*g1*
      Conj(MDBS) + 7.0710678118654755*LamSD*Conj(MuD)))*ZH(gI2,2) + 5*(
      1.4142135623730951*LamTD*vS*Conj(LamSD) + (2*MuD + 1.4142135623730951*LamSD*
      vS + 2*LamTD*vT)*Conj(LamTD) - 2*(g2*MDWBT + g2*Conj(MDWBT) - LamTD*Conj(MuD
      )))*ZH(gI2,3))*ZHR(gI1,0)) + ZH(gI2,0)*(vd*(-20*AbsSqr(LamSD) - 10*AbsSqr(
      LamTD) + 3*Sqr(g1) + 5*Sqr(g2))*ZHR(gI1,0) + 5*vu*(2*LamSU*Conj(LamSD) -
      LamTU*Conj(LamTD))*ZHR(gI1,1)) - ZH(gI2,1)*(vu*(3*Sqr(g1) + 5*Sqr(g2))*ZHR(
      gI1,0) + 5*vd*(-2*LamSU*Conj(LamSD) + LamTU*Conj(LamTD))*ZHR(gI1,1))) +
      KroneckerDelta(1,gO2)*((-(vd*(3*Sqr(g1) + 5*Sqr(g2))*ZH(gI2,0)) + vu*(3*Sqr(
      g1) + 5*Sqr(g2))*ZH(gI2,1) + 2*((3.872983346207417*g1*MDBS +
      3.872983346207417*g1*Conj(MDBS) - 7.0710678118654755*LamSU*Conj(MuU))*ZH(gI2
      ,2) - 5*(g2*MDWBT + g2*Conj(MDWBT) - LamTU*Conj(MuU))*ZH(gI2,3)))*ZHR(gI1,1)
      + 5*Conj(LamSU)*(2*LamSD*vu*ZH(gI2,0)*ZHR(gI1,0) + ((-2.8284271247461903*
      MuU - 4*LamSU*vS + 1.4142135623730951*LamTU*vT)*ZH(gI2,2) +
      1.4142135623730951*LamTU*vS*ZH(gI2,3))*ZHR(gI1,1) + 2*ZH(gI2,1)*(LamSD*vd*
      ZHR(gI1,0) - 2*LamSU*vu*ZHR(gI1,1))) - 5*Conj(LamTU)*(LamTD*vu*ZH(gI2,0)*ZHR
      (gI1,0) - (1.4142135623730951*LamSU*vT*ZH(gI2,2) + (2*MuU +
      1.4142135623730951*LamSU*vS - 2*LamTU*vT)*ZH(gI2,3))*ZHR(gI1,1) + ZH(gI2,1)*
      (LamTD*vd*ZHR(gI1,0) + 2*LamTU*vu*ZHR(gI1,1)))));

   return result;
}

std::complex<double> CLASSNAME::CpURhconjURhconjSvSv(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.05*(KroneckerDelta(0,gO1)*KroneckerDelta(0,gO2) - KroneckerDelta(
      1,gO1)*KroneckerDelta(1,gO2))*KroneckerDelta(gI1,gI2)*(3*Sqr(g1) + 5*Sqr(g2)
      );

   return result;
}

std::complex<double> CLASSNAME::CpURhconjURhAhAh(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.05*(KroneckerDelta(0,gO1)*(5*(2*LamSD*Conj(LamSU) - LamTD*Conj(
      LamTU))*KroneckerDelta(1,gO2)*(ZA(gI1,1)*ZA(gI2,0) + ZA(gI1,0)*ZA(gI2,1)) +
      KroneckerDelta(0,gO2)*((-20*AbsSqr(LamSD) - 10*AbsSqr(LamTD) + 3*Sqr(g1) + 5
      *Sqr(g2))*ZA(gI1,0)*ZA(gI2,0) - (3*Sqr(g1) + 5*Sqr(g2))*ZA(gI1,1)*ZA(gI2,1)
      - 5*(Conj(LamSD)*(1.4142135623730951*LamTD*ZA(gI1,3)*ZA(gI2,2) + ZA(gI1,2)*(
      4*LamSD*ZA(gI2,2) + 1.4142135623730951*LamTD*ZA(gI2,3))) + Conj(LamTD)*(
      1.4142135623730951*LamSD*ZA(gI1,2)*ZA(gI2,3) + ZA(gI1,3)*(1.4142135623730951
      *LamSD*ZA(gI2,2) + 2*LamTD*ZA(gI2,3)))))) + KroneckerDelta(1,gO1)*(5*(2*
      LamSU*Conj(LamSD) - LamTU*Conj(LamTD))*KroneckerDelta(0,gO2)*(ZA(gI1,1)*ZA(
      gI2,0) + ZA(gI1,0)*ZA(gI2,1)) + KroneckerDelta(1,gO2)*(-((3*Sqr(g1) + 5*Sqr(
      g2))*ZA(gI1,0)*ZA(gI2,0)) + (-20*AbsSqr(LamSU) - 10*AbsSqr(LamTU) + 3*Sqr(g1
      ) + 5*Sqr(g2))*ZA(gI1,1)*ZA(gI2,1) + 5*(Conj(LamTU)*(1.4142135623730951*
      LamSU*ZA(gI1,2)*ZA(gI2,3) + ZA(gI1,3)*(1.4142135623730951*LamSU*ZA(gI2,2) -
      2*LamTU*ZA(gI2,3))) + Conj(LamSU)*(1.4142135623730951*LamTU*ZA(gI1,3)*ZA(gI2
      ,2) + ZA(gI1,2)*(-4*LamSU*ZA(gI2,2) + 1.4142135623730951*LamTU*ZA(gI2,3)))))
      ));

   return result;
}

std::complex<double> CLASSNAME::CpURhconjURhconjHpmHpm(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.05*(-(KroneckerDelta(1,gO1)*KroneckerDelta(1,gO2)*((3*Sqr(g1) - 5
      *Sqr(g2))*ZP(gI1,0)*ZP(gI2,0) + (20*AbsSqr(LamTU) - 3*Sqr(g1) + 5*Sqr(g2))*
      ZP(gI1,1)*ZP(gI2,1) + 10*(-((-2*AbsSqr(LamTU) + Sqr(g2))*ZP(gI1,2)*ZP(gI2,2)
      ) + Sqr(g2)*ZP(gI1,3)*ZP(gI2,3)))) + KroneckerDelta(0,gO1)*KroneckerDelta(0,
      gO2)*((-20*AbsSqr(LamTD) + 3*Sqr(g1) - 5*Sqr(g2))*ZP(gI1,0)*ZP(gI2,0) + (-3*
      Sqr(g1) + 5*Sqr(g2))*ZP(gI1,1)*ZP(gI2,1) - 10*(Sqr(g2)*ZP(gI1,2)*ZP(gI2,2) -
      (-2*AbsSqr(LamTD) + Sqr(g2))*ZP(gI1,3)*ZP(gI2,3))));

   return result;
}

std::complex<double> CLASSNAME::CpURhconjURhhhhh(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.05*(KroneckerDelta(0,gO1)*(5*(2*LamSD*Conj(LamSU) - LamTD*Conj(
      LamTU))*KroneckerDelta(1,gO2)*(ZH(gI1,1)*ZH(gI2,0) + ZH(gI1,0)*ZH(gI2,1)) +
      KroneckerDelta(0,gO2)*((-20*AbsSqr(LamSD) - 10*AbsSqr(LamTD) + 3*Sqr(g1) + 5
      *Sqr(g2))*ZH(gI1,0)*ZH(gI2,0) - (3*Sqr(g1) + 5*Sqr(g2))*ZH(gI1,1)*ZH(gI2,1)
      - 5*(Conj(LamSD)*(1.4142135623730951*LamTD*ZH(gI1,3)*ZH(gI2,2) + ZH(gI1,2)*(
      4*LamSD*ZH(gI2,2) + 1.4142135623730951*LamTD*ZH(gI2,3))) + Conj(LamTD)*(
      1.4142135623730951*LamSD*ZH(gI1,2)*ZH(gI2,3) + ZH(gI1,3)*(1.4142135623730951
      *LamSD*ZH(gI2,2) + 2*LamTD*ZH(gI2,3)))))) + KroneckerDelta(1,gO1)*(5*(2*
      LamSU*Conj(LamSD) - LamTU*Conj(LamTD))*KroneckerDelta(0,gO2)*(ZH(gI1,1)*ZH(
      gI2,0) + ZH(gI1,0)*ZH(gI2,1)) + KroneckerDelta(1,gO2)*(-((3*Sqr(g1) + 5*Sqr(
      g2))*ZH(gI1,0)*ZH(gI2,0)) + (-20*AbsSqr(LamSU) - 10*AbsSqr(LamTU) + 3*Sqr(g1
      ) + 5*Sqr(g2))*ZH(gI1,1)*ZH(gI2,1) + 5*(Conj(LamTU)*(1.4142135623730951*
      LamSU*ZH(gI1,2)*ZH(gI2,3) + ZH(gI1,3)*(1.4142135623730951*LamSU*ZH(gI2,2) -
      2*LamTU*ZH(gI2,3))) + Conj(LamSU)*(1.4142135623730951*LamTU*ZH(gI1,3)*ZH(gI2
      ,2) + ZH(gI1,2)*(-4*LamSU*ZH(gI2,2) + 1.4142135623730951*LamTU*ZH(gI2,3)))))
      ));

   return result;
}

std::complex<double> CLASSNAME::CpconjURhconjHpmRpm(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = -0.25*Conj(ZRP(gI2,0))*(2.8284271247461903*LamSU*vd*Conj(LamSD)*
      KroneckerDelta(0,gO2)*ZP(gI1,1) + 1.4142135623730951*LamTU*Conj(LamTD)*
      KroneckerDelta(0,gO2)*(2*vu*ZP(gI1,0) + vd*ZP(gI1,1)) + KroneckerDelta(1,gO2
      )*(1.4142135623730951*vd*Sqr(g2)*ZP(gI1,0) + 1.4142135623730951*vu*(-2*
      AbsSqr(LamSU) + AbsSqr(LamTU) + Sqr(g2))*ZP(gI1,1) + 2*((-((2*MuU +
      1.4142135623730951*LamSU*vS + LamTU*vT)*Conj(LamTU)) + g2*(g2*vT + 2*Conj(
      MDWBT)))*ZP(gI1,2) - (-2*g2*MDWBT - vT*AbsSqr(LamTU) + 1.4142135623730951*
      LamTU*vS*Conj(LamSU) + 2*LamTU*Conj(MuU) + vT*Sqr(g2))*ZP(gI1,3))));

   return result;
}

std::complex<double> CLASSNAME::CpconjURhAhAh(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.25*Mu*(2*Conj(LamSU)*KroneckerDelta(1,gO2)*(ZA(gI1,2)*ZA(gI2,0) +
      ZA(gI1,0)*ZA(gI2,2)) - 1.4142135623730951*Conj(LamTU)*KroneckerDelta(1,gO2)
      *(ZA(gI1,3)*ZA(gI2,0) + ZA(gI1,0)*ZA(gI2,3)) - KroneckerDelta(0,gO2)*(2*Conj
      (LamSD)*(ZA(gI1,2)*ZA(gI2,1) + ZA(gI1,1)*ZA(gI2,2)) + 1.4142135623730951*
      Conj(LamTD)*(ZA(gI1,3)*ZA(gI2,1) + ZA(gI1,1)*ZA(gI2,3))));

   return result;
}

std::complex<double> CLASSNAME::CpconjURhconjHpmHpm(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = -(Conj(LamTU)*KroneckerDelta(1,gO2)*Mu*ZP(gI1,2)*ZP(gI2,0)) + Conj(
      LamTD)*KroneckerDelta(0,gO2)*Mu*ZP(gI1,1)*ZP(gI2,3);

   return result;
}

std::complex<double> CLASSNAME::CpconjURhhhAh(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = std::complex<double>(0,-0.25)*Mu*(2*Conj(LamSU)*KroneckerDelta(1,
      gO2)*(ZA(gI2,2)*ZH(gI1,0) - ZA(gI2,0)*ZH(gI1,2)) + 1.4142135623730951*Conj(
      LamTU)*KroneckerDelta(1,gO2)*(-(ZA(gI2,3)*ZH(gI1,0)) + ZA(gI2,0)*ZH(gI1,3))
      + KroneckerDelta(0,gO2)*(Conj(LamSD)*(-2*ZA(gI2,2)*ZH(gI1,1) + 2*ZA(gI2,1)*
      ZH(gI1,2)) + 1.4142135623730951*Conj(LamTD)*(-(ZA(gI2,3)*ZH(gI1,1)) + ZA(gI2
      ,1)*ZH(gI1,3))));

   return result;
}

std::complex<double> CLASSNAME::CpconjURhhhhh(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.25*Mu*(2*Conj(LamSU)*KroneckerDelta(1,gO2)*(ZH(gI1,2)*ZH(gI2,0) +
      ZH(gI1,0)*ZH(gI2,2)) - 1.4142135623730951*Conj(LamTU)*KroneckerDelta(1,gO2)
      *(ZH(gI1,3)*ZH(gI2,0) + ZH(gI1,0)*ZH(gI2,3)) - KroneckerDelta(0,gO2)*(2*Conj
      (LamSD)*(ZH(gI1,2)*ZH(gI2,1) + ZH(gI1,1)*ZH(gI2,2)) + 1.4142135623730951*
      Conj(LamTD)*(ZH(gI1,3)*ZH(gI2,1) + ZH(gI1,1)*ZH(gI2,3))));

   return result;
}

std::complex<double> CLASSNAME::CpconjURhChiChiPR(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = Conj(LamSD)*KroneckerDelta(0,gO2)*(ZN2(gI1,2)*ZN2(gI2,0) + ZN2(gI1,
      0)*ZN2(gI2,2)) + 0.5*(-2*Conj(LamSU)*KroneckerDelta(1,gO2)*(ZN2(gI1,3)*ZN2(
      gI2,0) + ZN2(gI1,0)*ZN2(gI2,3)) + 1.4142135623730951*(Conj(LamTD)*
      KroneckerDelta(0,gO2)*(ZN2(gI1,2)*ZN2(gI2,1) + ZN2(gI1,1)*ZN2(gI2,2)) + Conj
      (LamTU)*KroneckerDelta(1,gO2)*(ZN2(gI1,3)*ZN2(gI2,1) + ZN2(gI1,1)*ZN2(gI2,3)
      )));

   return result;
}

std::complex<double> CLASSNAME::CpconjURhChiChiPL(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.1414213562373095*(Conj(ZN1(gI1,2))*(-3.872983346207417*g1*Conj(
      ZN1(gI2,0)) + 5*g2*Conj(ZN1(gI2,1)))*KroneckerDelta(0,gO1) + 5*g2*Conj(ZN1(
      gI1,1))*Conj(ZN1(gI2,2))*KroneckerDelta(0,gO1) + 3.872983346207417*g1*Conj(
      ZN1(gI1,3))*Conj(ZN1(gI2,0))*KroneckerDelta(1,gO1) - 5*g2*Conj(ZN1(gI1,3))*
      Conj(ZN1(gI2,1))*KroneckerDelta(1,gO1) - 5*g2*Conj(ZN1(gI1,1))*Conj(ZN1(gI2,
      3))*KroneckerDelta(1,gO1) + 3.872983346207417*g1*Conj(ZN1(gI1,0))*(-(Conj(
      ZN1(gI2,2))*KroneckerDelta(0,gO1)) + Conj(ZN1(gI2,3))*KroneckerDelta(1,gO1))
      );

   return result;
}

std::complex<double> CLASSNAME::CpURhconjURhconjSdSd(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1320;
   std::complex<double> tmp_1321;
   std::complex<double> tmp_1322;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1322 += Conj(ZD(gI2,j1))*ZD(gI1,j1);
   }
   tmp_1321 += tmp_1322;
   tmp_1320 += (std::complex<double>(0,-0.05)*KroneckerDelta(0,gO1)*
      KroneckerDelta(0,gO2)*Sqr(g1)) * tmp_1321;
   std::complex<double> tmp_1323;
   std::complex<double> tmp_1324;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1324 += Conj(ZD(gI2,j1))*ZD(gI1,j1);
   }
   tmp_1323 += tmp_1324;
   tmp_1320 += (std::complex<double>(0,-0.25)*KroneckerDelta(0,gO1)*
      KroneckerDelta(0,gO2)*Sqr(g2)) * tmp_1323;
   std::complex<double> tmp_1325;
   std::complex<double> tmp_1326;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1326 += Conj(ZD(gI2,j1))*ZD(gI1,j1);
   }
   tmp_1325 += tmp_1326;
   tmp_1320 += (std::complex<double>(0,0.05)*KroneckerDelta(1,gO1)*
      KroneckerDelta(1,gO2)*Sqr(g1)) * tmp_1325;
   std::complex<double> tmp_1327;
   std::complex<double> tmp_1328;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1328 += Conj(ZD(gI2,j1))*ZD(gI1,j1);
   }
   tmp_1327 += tmp_1328;
   tmp_1320 += (std::complex<double>(0,0.25)*KroneckerDelta(1,gO1)*
      KroneckerDelta(1,gO2)*Sqr(g2)) * tmp_1327;
   std::complex<double> tmp_1329;
   std::complex<double> tmp_1330;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1330 += Conj(ZD(gI2,3 + j1))*ZD(gI1,3 + j1);
   }
   tmp_1329 += tmp_1330;
   tmp_1320 += (std::complex<double>(0,-0.1)*KroneckerDelta(0,gO1)*
      KroneckerDelta(0,gO2)*Sqr(g1)) * tmp_1329;
   std::complex<double> tmp_1331;
   std::complex<double> tmp_1332;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1332 += Conj(ZD(gI2,3 + j1))*ZD(gI1,3 + j1);
   }
   tmp_1331 += tmp_1332;
   tmp_1320 += (std::complex<double>(0,0.1)*KroneckerDelta(1,gO1)*
      KroneckerDelta(1,gO2)*Sqr(g1)) * tmp_1331;
   result += (std::complex<double>(0,-1)) * tmp_1320;

   return result;
}

std::complex<double> CLASSNAME::CpURhconjURhconjSeSe(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1333;
   std::complex<double> tmp_1334;
   std::complex<double> tmp_1335;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1335 += Conj(ZE(gI2,j1))*ZE(gI1,j1);
   }
   tmp_1334 += tmp_1335;
   tmp_1333 += (std::complex<double>(0,0.15)*KroneckerDelta(0,gO1)*
      KroneckerDelta(0,gO2)*Sqr(g1)) * tmp_1334;
   std::complex<double> tmp_1336;
   std::complex<double> tmp_1337;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1337 += Conj(ZE(gI2,j1))*ZE(gI1,j1);
   }
   tmp_1336 += tmp_1337;
   tmp_1333 += (std::complex<double>(0,-0.25)*KroneckerDelta(0,gO1)*
      KroneckerDelta(0,gO2)*Sqr(g2)) * tmp_1336;
   std::complex<double> tmp_1338;
   std::complex<double> tmp_1339;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1339 += Conj(ZE(gI2,j1))*ZE(gI1,j1);
   }
   tmp_1338 += tmp_1339;
   tmp_1333 += (std::complex<double>(0,-0.15)*KroneckerDelta(1,gO1)*
      KroneckerDelta(1,gO2)*Sqr(g1)) * tmp_1338;
   std::complex<double> tmp_1340;
   std::complex<double> tmp_1341;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1341 += Conj(ZE(gI2,j1))*ZE(gI1,j1);
   }
   tmp_1340 += tmp_1341;
   tmp_1333 += (std::complex<double>(0,0.25)*KroneckerDelta(1,gO1)*
      KroneckerDelta(1,gO2)*Sqr(g2)) * tmp_1340;
   std::complex<double> tmp_1342;
   std::complex<double> tmp_1343;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1343 += Conj(ZE(gI2,3 + j1))*ZE(gI1,3 + j1);
   }
   tmp_1342 += tmp_1343;
   tmp_1333 += (std::complex<double>(0,-0.3)*KroneckerDelta(0,gO1)*
      KroneckerDelta(0,gO2)*Sqr(g1)) * tmp_1342;
   std::complex<double> tmp_1344;
   std::complex<double> tmp_1345;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1345 += Conj(ZE(gI2,3 + j1))*ZE(gI1,3 + j1);
   }
   tmp_1344 += tmp_1345;
   tmp_1333 += (std::complex<double>(0,0.3)*KroneckerDelta(1,gO1)*
      KroneckerDelta(1,gO2)*Sqr(g1)) * tmp_1344;
   result += (std::complex<double>(0,-1)) * tmp_1333;

   return result;
}

std::complex<double> CLASSNAME::CpURhconjURhconjSuSu(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1346;
   std::complex<double> tmp_1347;
   std::complex<double> tmp_1348;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1348 += Conj(ZU(gI2,j1))*ZU(gI1,j1);
   }
   tmp_1347 += tmp_1348;
   tmp_1346 += (std::complex<double>(0,-0.05)*KroneckerDelta(0,gO1)*
      KroneckerDelta(0,gO2)*Sqr(g1)) * tmp_1347;
   std::complex<double> tmp_1349;
   std::complex<double> tmp_1350;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1350 += Conj(ZU(gI2,j1))*ZU(gI1,j1);
   }
   tmp_1349 += tmp_1350;
   tmp_1346 += (std::complex<double>(0,0.25)*KroneckerDelta(0,gO1)*
      KroneckerDelta(0,gO2)*Sqr(g2)) * tmp_1349;
   std::complex<double> tmp_1351;
   std::complex<double> tmp_1352;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1352 += Conj(ZU(gI2,j1))*ZU(gI1,j1);
   }
   tmp_1351 += tmp_1352;
   tmp_1346 += (std::complex<double>(0,0.05)*KroneckerDelta(1,gO1)*
      KroneckerDelta(1,gO2)*Sqr(g1)) * tmp_1351;
   std::complex<double> tmp_1353;
   std::complex<double> tmp_1354;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1354 += Conj(ZU(gI2,j1))*ZU(gI1,j1);
   }
   tmp_1353 += tmp_1354;
   tmp_1346 += (std::complex<double>(0,-0.25)*KroneckerDelta(1,gO1)*
      KroneckerDelta(1,gO2)*Sqr(g2)) * tmp_1353;
   std::complex<double> tmp_1355;
   std::complex<double> tmp_1356;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1356 += Conj(ZU(gI2,3 + j1))*ZU(gI1,3 + j1);
   }
   tmp_1355 += tmp_1356;
   tmp_1346 += (std::complex<double>(0,0.2)*KroneckerDelta(0,gO1)*
      KroneckerDelta(0,gO2)*Sqr(g1)) * tmp_1355;
   std::complex<double> tmp_1357;
   std::complex<double> tmp_1358;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1358 += Conj(ZU(gI2,3 + j1))*ZU(gI1,3 + j1);
   }
   tmp_1357 += tmp_1358;
   tmp_1346 += (std::complex<double>(0,-0.2)*KroneckerDelta(1,gO1)*
      KroneckerDelta(1,gO2)*Sqr(g1)) * tmp_1357;
   result += (std::complex<double>(0,-1)) * tmp_1346;

   return result;
}

std::complex<double> CLASSNAME::CpconjURhconjSdSd(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1359;
   std::complex<double> tmp_1360;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_1361;
      std::complex<double> tmp_1362;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1362 += Yd(j1,j2)*ZD(gI1,3 + j1);
      }
      tmp_1361 += tmp_1362;
      tmp_1360 += (Conj(ZD(gI2,j2))) * tmp_1361;
   }
   tmp_1359 += tmp_1360;
   result += (0.5*(1.4142135623730951*vS*Conj(LamSD) + vT*Conj(LamTD) + 2*Conj(
      MuD))*KroneckerDelta(0,gO2)) * tmp_1359;

   return result;
}

std::complex<double> CLASSNAME::CpconjURhconjSeSe(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1363;
   std::complex<double> tmp_1364;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_1365;
      std::complex<double> tmp_1366;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1366 += Ye(j1,j2)*ZE(gI1,3 + j1);
      }
      tmp_1365 += tmp_1366;
      tmp_1364 += (Conj(ZE(gI2,j2))) * tmp_1365;
   }
   tmp_1363 += tmp_1364;
   result += (0.5*(1.4142135623730951*vS*Conj(LamSD) + vT*Conj(LamTD) + 2*Conj(
      MuD))*KroneckerDelta(0,gO2)) * tmp_1363;

   return result;
}

std::complex<double> CLASSNAME::CpconjURhconjSuSu(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1367;
   std::complex<double> tmp_1368;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_1369;
      std::complex<double> tmp_1370;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1370 += Yu(j1,j2)*ZU(gI1,3 + j1);
      }
      tmp_1369 += tmp_1370;
      tmp_1368 += (Conj(ZU(gI2,j2))) * tmp_1369;
   }
   tmp_1367 += tmp_1368;
   result += (-0.5*(1.4142135623730951*vS*Conj(LamSU) - vT*Conj(LamTU) + 2*Conj
      (MuU))*KroneckerDelta(1,gO2)) * tmp_1367;

   return result;
}

std::complex<double> CLASSNAME::CpconjURhVZRh(unsigned gO2, unsigned gI2) const
{
   std::complex<double> result;

   result = -0.1*(5*g2*Cos(ThetaW()) + 3.872983346207417*g1*Sin(ThetaW()))*(
      KroneckerDelta(0,gO2)*ZHR(gI2,0) - KroneckerDelta(1,gO2)*ZHR(gI2,1));

   return result;
}

std::complex<double> CLASSNAME::CpconjURhconjVWmRpm(unsigned gO2, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.7071067811865475*g2*Conj(ZRP(gI2,0))*KroneckerDelta(1,gO2);

   return result;
}

std::complex<double> CLASSNAME::CpconjUHpmVWmVP(unsigned gO2) const
{
   std::complex<double> result;

   result = -0.1*g2*(3.872983346207417*g1*vd*Cos(ThetaW())*KroneckerDelta(0,gO2
      ) - 3.872983346207417*g1*vu*Cos(ThetaW())*KroneckerDelta(1,gO2) +
      7.0710678118654755*g2*vT*(KroneckerDelta(2,gO2) + KroneckerDelta(3,gO2))*Sin
      (ThetaW()));

   return result;
}

std::complex<double> CLASSNAME::CpconjUHpmVZVWm(unsigned gO2) const
{
   std::complex<double> result;

   result = -0.1*g2*(7.0710678118654755*g2*vT*Cos(ThetaW())*KroneckerDelta(2,
      gO2) + 7.0710678118654755*g2*vT*Cos(ThetaW())*KroneckerDelta(3,gO2) +
      3.872983346207417*g1*(-(vd*KroneckerDelta(0,gO2)) + vu*KroneckerDelta(1,gO2)
      )*Sin(ThetaW()));

   return result;
}

std::complex<double> CLASSNAME::CpconjUHpmbargWmCgZ(unsigned gO1) const
{
   std::complex<double> result;

   result = 0.05*g2*(14.142135623730951*g2*vT*Cos(ThetaW())*(KroneckerDelta(2,
      gO1) + KroneckerDelta(3,gO1)) + vd*KroneckerDelta(0,gO1)*(5*g2*Cos(ThetaW())
      - 3.872983346207417*g1*Sin(ThetaW())) + KroneckerDelta(1,gO1)*(-5*g2*vu*Cos
      (ThetaW()) + 3.872983346207417*g1*vu*Sin(ThetaW())));

   return result;
}

std::complex<double> CLASSNAME::CpUHpmgWmCbargZ(unsigned gO2) const
{
   std::complex<double> result;

   result = -0.05*g2*(vd*KroneckerDelta(0,gO2) - vu*KroneckerDelta(1,gO2))*(5*
      g2*Cos(ThetaW()) + 3.872983346207417*g1*Sin(ThetaW()));

   return result;
}

std::complex<double> CLASSNAME::CpconjUHpmbargZgWm(unsigned gO1) const
{
   std::complex<double> result;

   result = -0.05*g2*(vd*KroneckerDelta(0,gO1) - vu*KroneckerDelta(1,gO1))*(5*
      g2*Cos(ThetaW()) + 3.872983346207417*g1*Sin(ThetaW()));

   return result;
}

std::complex<double> CLASSNAME::CpUHpmgZbargWm(unsigned gO2) const
{
   std::complex<double> result;

   result = 0.05*g2*(14.142135623730951*g2*vT*Cos(ThetaW())*(KroneckerDelta(2,
      gO2) + KroneckerDelta(3,gO2)) + vd*KroneckerDelta(0,gO2)*(5*g2*Cos(ThetaW())
      - 3.872983346207417*g1*Sin(ThetaW())) + KroneckerDelta(1,gO2)*(-5*g2*vu*Cos
      (ThetaW()) + 3.872983346207417*g1*vu*Sin(ThetaW())));

   return result;
}

std::complex<double> CLASSNAME::CpUHpmconjUHpmVZVZ(unsigned gO1, unsigned gO2) const
{
   std::complex<double> result;

   result = 0.1*(20*(KroneckerDelta(2,gO1)*KroneckerDelta(2,gO2) +
      KroneckerDelta(3,gO1)*KroneckerDelta(3,gO2))*Sqr(g2)*Sqr(Cos(ThetaW())) +
      KroneckerDelta(0,gO1)*KroneckerDelta(0,gO2)*(-7.745966692414834*g1*g2*Cos(
      ThetaW())*Sin(ThetaW()) + 5*Sqr(g2)*Sqr(Cos(ThetaW())) + 3*Sqr(g1)*Sqr(Sin(
      ThetaW()))) + KroneckerDelta(1,gO1)*KroneckerDelta(1,gO2)*(
      -7.745966692414834*g1*g2*Cos(ThetaW())*Sin(ThetaW()) + 5*Sqr(g2)*Sqr(Cos(
      ThetaW())) + 3*Sqr(g1)*Sqr(Sin(ThetaW()))));

   return result;
}

std::complex<double> CLASSNAME::CpUHpmconjUHpmconjVWmVWm(unsigned gO1, unsigned gO2) const
{
   std::complex<double> result;

   result = 0.5*(KroneckerDelta(0,gO1)*KroneckerDelta(0,gO2) + KroneckerDelta(1
      ,gO1)*KroneckerDelta(1,gO2) + 2*KroneckerDelta(2,gO1)*KroneckerDelta(2,gO2)
      + 2*KroneckerDelta(3,gO1)*KroneckerDelta(3,gO2))*Sqr(g2);

   return result;
}

std::complex<double> CLASSNAME::CpUHpmconjUHpmconjRhRh(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.05*(KroneckerDelta(1,gO1)*KroneckerDelta(1,gO2)*((-3*Sqr(g1) + 5*
      Sqr(g2))*ZHR(gI1,0)*ZHR(gI2,0) + (-20*AbsSqr(LamTU) + 3*Sqr(g1) - 5*Sqr(g2))
      *ZHR(gI1,1)*ZHR(gI2,1)) + KroneckerDelta(0,gO1)*KroneckerDelta(0,gO2)*((-20*
      AbsSqr(LamTD) + 3*Sqr(g1) - 5*Sqr(g2))*ZHR(gI1,0)*ZHR(gI2,0) + (-3*Sqr(g1) +
      5*Sqr(g2))*ZHR(gI1,1)*ZHR(gI2,1)) - 10*(KroneckerDelta(3,gO1)*
      KroneckerDelta(3,gO2)*(-((-2*AbsSqr(LamTD) + Sqr(g2))*ZHR(gI1,0)*ZHR(gI2,0))
      + Sqr(g2)*ZHR(gI1,1)*ZHR(gI2,1)) + KroneckerDelta(2,gO1)*KroneckerDelta(2,
      gO2)*(Sqr(g2)*ZHR(gI1,0)*ZHR(gI2,0) - (-2*AbsSqr(LamTU) + Sqr(g2))*ZHR(gI1,1
      )*ZHR(gI2,1))));

   return result;
}

std::complex<double> CLASSNAME::CpUHpmconjUHpmconjRpmRpm(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.05*(-(Conj(ZRP(gI2,0))*(KroneckerDelta(1,gO1)*KroneckerDelta(1,
      gO2)*(20*AbsSqr(LamSU) + 10*AbsSqr(LamTU) - 3*Sqr(g1) - 5*Sqr(g2)) +
      KroneckerDelta(0,gO1)*KroneckerDelta(0,gO2)*(3*Sqr(g1) + 5*Sqr(g2)) + 10*(
      KroneckerDelta(2,gO1)*KroneckerDelta(2,gO2)*Sqr(g2) - KroneckerDelta(3,gO1)*
      KroneckerDelta(3,gO2)*(-2*AbsSqr(LamTU) + Sqr(g2))))*ZRP(gI1,0)) + Conj(ZRP(
      gI2,1))*(-(KroneckerDelta(1,gO1)*KroneckerDelta(1,gO2)*(3*Sqr(g1) + 5*Sqr(g2
      ))) + KroneckerDelta(0,gO1)*KroneckerDelta(0,gO2)*(-20*AbsSqr(LamSD) - 10*
      AbsSqr(LamTD) + 3*Sqr(g1) + 5*Sqr(g2)) + 10*(-(KroneckerDelta(3,gO1)*
      KroneckerDelta(3,gO2)*Sqr(g2)) + KroneckerDelta(2,gO1)*KroneckerDelta(2,gO2)
      *(-2*AbsSqr(LamTD) + Sqr(g2))))*ZRP(gI1,1));

   return result;
}

std::complex<double> CLASSNAME::CpconjUHpmconjRhRpm(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = -0.25*Conj(ZRP(gI2,0))*(2.8284271247461903*LamSU*vd*Conj(LamSD)*
      KroneckerDelta(1,gO2)*ZHR(gI1,0) + 1.4142135623730951*LamTU*Conj(LamTD)*(2*
      vu*KroneckerDelta(0,gO2) + vd*KroneckerDelta(1,gO2))*ZHR(gI1,0) + (
      1.4142135623730951*vd*KroneckerDelta(0,gO2)*Sqr(g2) + 1.4142135623730951*vu*
      KroneckerDelta(1,gO2)*(-2*AbsSqr(LamSU) + AbsSqr(LamTU) + Sqr(g2)) + 2*((-((
      2*MuU + 1.4142135623730951*LamSU*vS + LamTU*vT)*Conj(LamTU)) + g2*(g2*vT + 2
      *Conj(MDWBT)))*KroneckerDelta(2,gO2) - KroneckerDelta(3,gO2)*(-2*g2*MDWBT -
      vT*AbsSqr(LamTU) + 1.4142135623730951*LamTU*vS*Conj(LamSU) + 2*LamTU*Conj(
      MuU) + vT*Sqr(g2))))*ZHR(gI1,1));

   return result;
}

std::complex<double> CLASSNAME::CpconjUHpmRpmRh(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = -0.25*Conj(ZRP(gI1,1))*(2*((-((2*MuD + 1.4142135623730951*LamSD*vS
      + LamTD*vT)*Conj(LamTD)) + g2*(g2*vT + 2*Conj(MDWBT)))*KroneckerDelta(2,gO2)
      - KroneckerDelta(3,gO2)*(-2*g2*MDWBT - vT*AbsSqr(LamTD) +
      1.4142135623730951*LamTD*vS*Conj(LamSD) + 2*LamTD*Conj(MuD) + vT*Sqr(g2)))*
      ZHR(gI2,0) + 1.4142135623730951*KroneckerDelta(1,gO2)*(vu*Sqr(g2)*ZHR(gI2,0)
      + 2*LamTU*vd*Conj(LamTD)*ZHR(gI2,1)) + 1.4142135623730951*KroneckerDelta(0,
      gO2)*(vd*(-2*AbsSqr(LamSD) + AbsSqr(LamTD) + Sqr(g2))*ZHR(gI2,0) + vu*(2*
      LamSU*Conj(LamSD) + LamTU*Conj(LamTD))*ZHR(gI2,1)));

   return result;
}

std::complex<double> CLASSNAME::CpconjUHpmconjRhHpm(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = -(Conj(LamTU)*KroneckerDelta(2,gO2)*Mu*ZHR(gI1,1)*ZP(gI2,0)) + Conj
      (LamTD)*KroneckerDelta(1,gO2)*Mu*ZHR(gI1,0)*ZP(gI2,3);

   return result;
}

std::complex<double> CLASSNAME::CpconjUHpmRpmAh(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = std::complex<double>(0,0.5)*(Conj(Mu)*Conj(ZRP(gI1,0))*(
      1.4142135623730951*LamTU*KroneckerDelta(3,gO2)*ZA(gI2,0) + KroneckerDelta(0,
      gO2)*(1.4142135623730951*LamSU*ZA(gI2,2) + LamTU*ZA(gI2,3))) + Conj(ZRP(gI1,
      1))*Mu*(1.4142135623730951*Conj(LamSD)*KroneckerDelta(1,gO2)*ZA(gI2,2) +
      Conj(LamTD)*(1.4142135623730951*KroneckerDelta(2,gO2)*ZA(gI2,1) -
      KroneckerDelta(1,gO2)*ZA(gI2,3))));

   return result;
}

std::complex<double> CLASSNAME::CpconjUHpmRpmhh(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.5*(Conj(Mu)*Conj(ZRP(gI1,0))*(-1.4142135623730951*LamTU*
      KroneckerDelta(3,gO2)*ZH(gI2,0) + KroneckerDelta(0,gO2)*(1.4142135623730951*
      LamSU*ZH(gI2,2) + LamTU*ZH(gI2,3))) + Conj(ZRP(gI1,1))*Mu*(
      -1.4142135623730951*Conj(LamSD)*KroneckerDelta(1,gO2)*ZH(gI2,2) + Conj(LamTD
      )*(1.4142135623730951*KroneckerDelta(2,gO2)*ZH(gI2,1) + KroneckerDelta(1,gO2
      )*ZH(gI2,3))));

   return result;
}

std::complex<double> CLASSNAME::CpconjUHpmbarCha1ChiPR(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = -(Conj(LamSD)*KroneckerDelta(0,gO2)*UP1(gI1,1)*ZN2(gI2,0)) +
      1.4142135623730951*g2*KroneckerDelta(3,gO2)*UP1(gI1,0)*ZN2(gI2,1) +
      0.7071067811865475*Conj(LamTD)*KroneckerDelta(0,gO2)*UP1(gI1,1)*ZN2(gI2,1) -
      Conj(LamTD)*KroneckerDelta(2,gO2)*UP1(gI1,1)*ZN2(gI2,2) - g2*KroneckerDelta
      (1,gO2)*UP1(gI1,0)*ZN2(gI2,3);

   return result;
}

std::complex<double> CLASSNAME::CpconjUHpmbarCha1ChiPL(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = Conj(UM1(gI1,0))*(-(LamTU*Conj(ZN1(gI2,3))*KroneckerDelta(1,gO1)) +
      1.4142135623730951*g2*Conj(ZN1(gI2,1))*KroneckerDelta(2,gO1)) + Conj(UM1(
      gI1,1))*(0.5477225575051661*g1*Conj(ZN1(gI2,0))*KroneckerDelta(0,gO1) +
      0.7071067811865475*g2*Conj(ZN1(gI2,1))*KroneckerDelta(0,gO1) + LamTD*Conj(
      ZN1(gI2,2))*KroneckerDelta(3,gO1));

   return result;
}

std::complex<double> CLASSNAME::CpUHpmconjUHpmconjSvSv(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1371;
   tmp_1371 += std::complex<double>(0,-0.15)*KroneckerDelta(0,gO1)*
      KroneckerDelta(0,gO2)*KroneckerDelta(gI1,gI2)*Sqr(g1);
   tmp_1371 += std::complex<double>(0,0.25)*KroneckerDelta(0,gO1)*
      KroneckerDelta(0,gO2)*KroneckerDelta(gI1,gI2)*Sqr(g2);
   tmp_1371 += std::complex<double>(0,0.15)*KroneckerDelta(1,gO1)*
      KroneckerDelta(1,gO2)*KroneckerDelta(gI1,gI2)*Sqr(g1);
   tmp_1371 += std::complex<double>(0,-0.25)*KroneckerDelta(1,gO1)*
      KroneckerDelta(1,gO2)*KroneckerDelta(gI1,gI2)*Sqr(g2);
   tmp_1371 += std::complex<double>(0,0.5)*KroneckerDelta(2,gO1)*KroneckerDelta
      (2,gO2)*KroneckerDelta(gI1,gI2)*Sqr(g2);
   tmp_1371 += std::complex<double>(0,-0.5)*KroneckerDelta(3,gO1)*
      KroneckerDelta(3,gO2)*KroneckerDelta(gI1,gI2)*Sqr(g2);
   std::complex<double> tmp_1372;
   std::complex<double> tmp_1373;
   for (unsigned j3 = 0; j3 < 3; ++j3) {
      std::complex<double> tmp_1374;
      std::complex<double> tmp_1375;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         std::complex<double> tmp_1376;
         std::complex<double> tmp_1377;
         for (unsigned j1 = 0; j1 < 3; ++j1) {
            tmp_1377 += Conj(Ye(j1,j3))*Ye(j1,j2);
         }
         tmp_1376 += tmp_1377;
         tmp_1375 += (Conj(ZV(gI2,j2))) * tmp_1376;
      }
      tmp_1374 += tmp_1375;
      tmp_1373 += (ZV(gI1,j3)) * tmp_1374;
   }
   tmp_1372 += tmp_1373;
   tmp_1371 += (std::complex<double>(0,-1)*KroneckerDelta(0,gO1)*KroneckerDelta
      (0,gO2)) * tmp_1372;
   result += (std::complex<double>(0,-1)) * tmp_1371;

   return result;
}

std::complex<double> CLASSNAME::CpconjUHpmbarFuFdPR(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1378;
   std::complex<double> tmp_1379;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_1380;
      std::complex<double> tmp_1381;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1381 += Conj(Yd(j1,j2))*ZDR(gI2,j1);
      }
      tmp_1380 += tmp_1381;
      tmp_1379 += (ZUL(gI1,j2)) * tmp_1380;
   }
   tmp_1378 += tmp_1379;
   result += (KroneckerDelta(0,gO2)) * tmp_1378;

   return result;
}

std::complex<double> CLASSNAME::CpconjUHpmbarFuFdPL(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1382;
   std::complex<double> tmp_1383;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_1384;
      std::complex<double> tmp_1385;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1385 += Conj(ZUR(gI1,j1))*Yu(j1,j2);
      }
      tmp_1384 += tmp_1385;
      tmp_1383 += (Conj(ZDL(gI2,j2))) * tmp_1384;
   }
   tmp_1382 += tmp_1383;
   result += (KroneckerDelta(1,gO1)) * tmp_1382;

   return result;
}

std::complex<double> CLASSNAME::CpconjUHpmbarFvFePR(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1386;
   std::complex<double> tmp_1387;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1387 += Conj(Ye(j1,gI1))*ZER(gI2,j1);
   }
   tmp_1386 += tmp_1387;
   result += (KroneckerDelta(0,gO2)) * tmp_1386;

   return result;
}

double CLASSNAME::CpconjUHpmbarFvFePL(unsigned , unsigned , unsigned ) const
{
   double result = 0.0;

   result = 0;

   return result;
}

std::complex<double> CLASSNAME::CpconjUHpmconjSvSe(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1388;
   std::complex<double> tmp_1389;
   std::complex<double> tmp_1390;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1390 += Conj(ZE(gI2,j1))*ZV(gI1,j1);
   }
   tmp_1389 += tmp_1390;
   tmp_1388 += (std::complex<double>(0.,-0.35355339059327373)*vd*KroneckerDelta
      (0,gO2)*Sqr(g2)) * tmp_1389;
   std::complex<double> tmp_1391;
   std::complex<double> tmp_1392;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1392 += Conj(ZE(gI2,j1))*ZV(gI1,j1);
   }
   tmp_1391 += tmp_1392;
   tmp_1388 += (std::complex<double>(0.,-0.35355339059327373)*vu*KroneckerDelta
      (1,gO2)*Sqr(g2)) * tmp_1391;
   std::complex<double> tmp_1393;
   std::complex<double> tmp_1394;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1394 += Conj(ZE(gI2,j1))*ZV(gI1,j1);
   }
   tmp_1393 += tmp_1394;
   tmp_1388 += (std::complex<double>(0,-0.5)*vT*KroneckerDelta(2,gO2)*Sqr(g2))
      * tmp_1393;
   std::complex<double> tmp_1395;
   std::complex<double> tmp_1396;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1396 += Conj(ZE(gI2,j1))*ZV(gI1,j1);
   }
   tmp_1395 += tmp_1396;
   tmp_1388 += (std::complex<double>(0,-1)*g2*Conj(MDWBT)*KroneckerDelta(2,gO2)
      ) * tmp_1395;
   std::complex<double> tmp_1397;
   std::complex<double> tmp_1398;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1398 += Conj(ZE(gI2,j1))*ZV(gI1,j1);
   }
   tmp_1397 += tmp_1398;
   tmp_1388 += (std::complex<double>(0,-1)*g2*MDWBT*KroneckerDelta(3,gO2)) *
      tmp_1397;
   std::complex<double> tmp_1399;
   std::complex<double> tmp_1400;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1400 += Conj(ZE(gI2,j1))*ZV(gI1,j1);
   }
   tmp_1399 += tmp_1400;
   tmp_1388 += (std::complex<double>(0,0.5)*vT*KroneckerDelta(3,gO2)*Sqr(g2)) *
      tmp_1399;
   std::complex<double> tmp_1401;
   std::complex<double> tmp_1402;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_1403;
      std::complex<double> tmp_1404;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1404 += Conj(Ye(j1,j2))*Conj(ZE(gI2,3 + j1));
      }
      tmp_1403 += tmp_1404;
      tmp_1402 += (ZV(gI1,j2)) * tmp_1403;
   }
   tmp_1401 += tmp_1402;
   tmp_1388 += (std::complex<double>(0,1)*KroneckerDelta(1,gO2)*Mu) * tmp_1401;
   std::complex<double> tmp_1405;
   std::complex<double> tmp_1406;
   for (unsigned j3 = 0; j3 < 3; ++j3) {
      std::complex<double> tmp_1407;
      std::complex<double> tmp_1408;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         std::complex<double> tmp_1409;
         std::complex<double> tmp_1410;
         for (unsigned j1 = 0; j1 < 3; ++j1) {
            tmp_1410 += Conj(Ye(j1,j3))*Ye(j1,j2);
         }
         tmp_1409 += tmp_1410;
         tmp_1408 += (Conj(ZE(gI2,j2))) * tmp_1409;
      }
      tmp_1407 += tmp_1408;
      tmp_1406 += (ZV(gI1,j3)) * tmp_1407;
   }
   tmp_1405 += tmp_1406;
   tmp_1388 += (std::complex<double>(0.,0.7071067811865475)*vd*KroneckerDelta(0
      ,gO2)) * tmp_1405;
   result += (std::complex<double>(0,-1)) * tmp_1388;

   return result;
}

std::complex<double> CLASSNAME::CpUHpmconjUHpmAhAh(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.05*(5*(-(KroneckerDelta(3,gO1)*(1.4142135623730951*KroneckerDelta
      (0,gO2)*Sqr(g2)*ZA(gI1,3)*ZA(gI2,0) + 2*LamSU*Conj(LamTU)*KroneckerDelta(1,
      gO2)*ZA(gI1,2)*ZA(gI2,1) + 1.4142135623730951*AbsSqr(LamTU)*KroneckerDelta(1
      ,gO2)*ZA(gI1,3)*ZA(gI2,1) - 1.4142135623730951*KroneckerDelta(1,gO2)*Sqr(g2)
      *ZA(gI1,3)*ZA(gI2,1) + 2*LamSU*Conj(LamTU)*KroneckerDelta(1,gO2)*ZA(gI1,1)*
      ZA(gI2,2) + 1.4142135623730951*KroneckerDelta(0,gO2)*Sqr(g2)*ZA(gI1,0)*ZA(
      gI2,3) + 1.4142135623730951*AbsSqr(LamTU)*KroneckerDelta(1,gO2)*ZA(gI1,1)*ZA
      (gI2,3) - 1.4142135623730951*KroneckerDelta(1,gO2)*Sqr(g2)*ZA(gI1,1)*ZA(gI2,
      3) + 4*KroneckerDelta(2,gO2)*Sqr(g2)*ZA(gI1,3)*ZA(gI2,3) + 2*KroneckerDelta(
      3,gO2)*(Sqr(g2)*ZA(gI1,0)*ZA(gI2,0) - (-2*AbsSqr(LamTU) + Sqr(g2))*ZA(gI1,1)
      *ZA(gI2,1) + 2*Sqr(g2)*ZA(gI1,3)*ZA(gI2,3)) - Conj(LamTD)*KroneckerDelta(0,
      gO2)*(2*LamSD*ZA(gI1,2)*ZA(gI2,0) + 1.4142135623730951*LamTD*ZA(gI1,3)*ZA(
      gI2,0) + ZA(gI1,0)*(2*LamSD*ZA(gI2,2) + 1.4142135623730951*LamTD*ZA(gI2,3)))
      )) + KroneckerDelta(2,gO1)*(1.4142135623730951*AbsSqr(LamTD)*KroneckerDelta(
      0,gO2)*ZA(gI1,3)*ZA(gI2,0) - 1.4142135623730951*KroneckerDelta(0,gO2)*Sqr(g2
      )*ZA(gI1,3)*ZA(gI2,0) + 2*LamTU*Conj(LamSU)*KroneckerDelta(1,gO2)*ZA(gI1,2)*
      ZA(gI2,1) - 1.4142135623730951*AbsSqr(LamTU)*KroneckerDelta(1,gO2)*ZA(gI1,3)
      *ZA(gI2,1) + 1.4142135623730951*KroneckerDelta(1,gO2)*Sqr(g2)*ZA(gI1,3)*ZA(
      gI2,1) + 2*LamTU*Conj(LamSU)*KroneckerDelta(1,gO2)*ZA(gI1,1)*ZA(gI2,2) - 2*
      LamTD*Conj(LamSD)*KroneckerDelta(0,gO2)*(ZA(gI1,2)*ZA(gI2,0) + ZA(gI1,0)*ZA(
      gI2,2)) + 1.4142135623730951*AbsSqr(LamTD)*KroneckerDelta(0,gO2)*ZA(gI1,0)*
      ZA(gI2,3) - 1.4142135623730951*KroneckerDelta(0,gO2)*Sqr(g2)*ZA(gI1,0)*ZA(
      gI2,3) - 1.4142135623730951*AbsSqr(LamTU)*KroneckerDelta(1,gO2)*ZA(gI1,1)*ZA
      (gI2,3) + 1.4142135623730951*KroneckerDelta(1,gO2)*Sqr(g2)*ZA(gI1,1)*ZA(gI2,
      3) - 4*KroneckerDelta(3,gO2)*Sqr(g2)*ZA(gI1,3)*ZA(gI2,3) + 2*KroneckerDelta(
      2,gO2)*((-2*AbsSqr(LamTD) + Sqr(g2))*ZA(gI1,0)*ZA(gI2,0) - Sqr(g2)*(ZA(gI1,1
      )*ZA(gI2,1) + 2*ZA(gI1,3)*ZA(gI2,3))))) + KroneckerDelta(0,gO1)*(
      KroneckerDelta(0,gO2)*(-((3*Sqr(g1) + 5*Sqr(g2))*ZA(gI1,0)*ZA(gI2,0)) + (3*
      Sqr(g1) - 5*Sqr(g2))*ZA(gI1,1)*ZA(gI2,1) + 5*(Conj(LamTD)*(
      1.4142135623730951*LamSD*ZA(gI1,2)*ZA(gI2,3) + ZA(gI1,3)*(1.4142135623730951
      *LamSD*ZA(gI2,2) - 2*LamTD*ZA(gI2,3))) + Conj(LamSD)*(1.4142135623730951*
      LamTD*ZA(gI1,3)*ZA(gI2,2) + ZA(gI1,2)*(-4*LamSD*ZA(gI2,2) +
      1.4142135623730951*LamTD*ZA(gI2,3))))) + 5*(2*LamTD*Conj(LamSD)*
      KroneckerDelta(3,gO2)*ZA(gI1,2)*ZA(gI2,0) - 1.4142135623730951*
      KroneckerDelta(2,gO2)*Sqr(g2)*ZA(gI1,3)*ZA(gI2,0) - 1.4142135623730951*
      KroneckerDelta(3,gO2)*Sqr(g2)*ZA(gI1,3)*ZA(gI2,0) + KroneckerDelta(1,gO2)*
      Sqr(g2)*(ZA(gI1,1)*ZA(gI2,0) + ZA(gI1,0)*ZA(gI2,1)) + 2*LamTD*Conj(LamSD)*
      KroneckerDelta(3,gO2)*ZA(gI1,0)*ZA(gI2,2) - 1.4142135623730951*
      KroneckerDelta(2,gO2)*Sqr(g2)*ZA(gI1,0)*ZA(gI2,3) - 1.4142135623730951*
      KroneckerDelta(3,gO2)*Sqr(g2)*ZA(gI1,0)*ZA(gI2,3) + Conj(LamTD)*(
      1.4142135623730951*LamTD*KroneckerDelta(3,gO2)*(ZA(gI1,3)*ZA(gI2,0) + ZA(gI1
      ,0)*ZA(gI2,3)) + KroneckerDelta(2,gO2)*(-2*LamSD*ZA(gI1,2)*ZA(gI2,0) +
      1.4142135623730951*LamTD*ZA(gI1,3)*ZA(gI2,0) + ZA(gI1,0)*(-2*LamSD*ZA(gI2,2)
      + 1.4142135623730951*LamTD*ZA(gI2,3)))))) + KroneckerDelta(1,gO1)*(5*(-2*
      LamTU*Conj(LamSU)*KroneckerDelta(3,gO2)*ZA(gI1,2)*ZA(gI2,1) +
      1.4142135623730951*KroneckerDelta(2,gO2)*Sqr(g2)*ZA(gI1,3)*ZA(gI2,1) +
      1.4142135623730951*KroneckerDelta(3,gO2)*Sqr(g2)*ZA(gI1,3)*ZA(gI2,1) +
      KroneckerDelta(0,gO2)*Sqr(g2)*(ZA(gI1,1)*ZA(gI2,0) + ZA(gI1,0)*ZA(gI2,1)) -
      2*LamTU*Conj(LamSU)*KroneckerDelta(3,gO2)*ZA(gI1,1)*ZA(gI2,2) +
      1.4142135623730951*KroneckerDelta(2,gO2)*Sqr(g2)*ZA(gI1,1)*ZA(gI2,3) +
      1.4142135623730951*KroneckerDelta(3,gO2)*Sqr(g2)*ZA(gI1,1)*ZA(gI2,3) + Conj(
      LamTU)*(-1.4142135623730951*LamTU*KroneckerDelta(3,gO2)*(ZA(gI1,3)*ZA(gI2,1)
      + ZA(gI1,1)*ZA(gI2,3)) + KroneckerDelta(2,gO2)*(2*LamSU*ZA(gI1,2)*ZA(gI2,1)
      - 1.4142135623730951*LamTU*ZA(gI1,3)*ZA(gI2,1) + ZA(gI1,1)*(2*LamSU*ZA(gI2,
      2) - 1.4142135623730951*LamTU*ZA(gI2,3))))) + KroneckerDelta(1,gO2)*((3*Sqr(
      g1) - 5*Sqr(g2))*ZA(gI1,0)*ZA(gI2,0) - (3*Sqr(g1) + 5*Sqr(g2))*ZA(gI1,1)*ZA(
      gI2,1) - 5*(Conj(LamSU)*(1.4142135623730951*LamTU*ZA(gI1,3)*ZA(gI2,2) + ZA(
      gI1,2)*(4*LamSU*ZA(gI2,2) + 1.4142135623730951*LamTU*ZA(gI2,3))) + Conj(
      LamTU)*(1.4142135623730951*LamSU*ZA(gI1,2)*ZA(gI2,3) + ZA(gI1,3)*(
      1.4142135623730951*LamSU*ZA(gI2,2) + 2*LamTU*ZA(gI2,3)))))));

   return result;
}

std::complex<double> CLASSNAME::CpUHpmconjUHpmconjHpmHpm(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.05*(KroneckerDelta(1,gO1)*(ZP(gI1,1)*(KroneckerDelta(0,gO2)*(3*
      Sqr(g1) + 5*Sqr(g2))*ZP(gI2,0) + 10*(KroneckerDelta(2,gO2)*(-2*AbsSqr(LamTU)
      + Sqr(g2))*ZP(gI2,2) - KroneckerDelta(3,gO2)*Sqr(g2)*ZP(gI2,3))) +
      KroneckerDelta(1,gO2)*((3*Sqr(g1) + 5*Sqr(g2))*ZP(gI1,0)*ZP(gI2,0) - 2*((3*
      Sqr(g1) + 5*Sqr(g2))*ZP(gI1,1)*ZP(gI2,1) - 5*(-2*AbsSqr(LamTU) + Sqr(g2))*ZP
      (gI1,2)*ZP(gI2,2) + 5*Sqr(g2)*ZP(gI1,3)*ZP(gI2,3)))) + KroneckerDelta(0,gO1)
      *(ZP(gI1,0)*(KroneckerDelta(1,gO2)*(3*Sqr(g1) + 5*Sqr(g2))*ZP(gI2,1) - 10*(
      KroneckerDelta(2,gO2)*Sqr(g2)*ZP(gI2,2) - KroneckerDelta(3,gO2)*(-2*AbsSqr(
      LamTD) + Sqr(g2))*ZP(gI2,3))) + KroneckerDelta(0,gO2)*(-2*(3*Sqr(g1) + 5*Sqr
      (g2))*ZP(gI1,0)*ZP(gI2,0) + (3*Sqr(g1) + 5*Sqr(g2))*ZP(gI1,1)*ZP(gI2,1) - 10
      *(Sqr(g2)*ZP(gI1,2)*ZP(gI2,2) - (-2*AbsSqr(LamTD) + Sqr(g2))*ZP(gI1,3)*ZP(
      gI2,3)))) - 10*(KroneckerDelta(2,gO1)*(ZP(gI1,2)*(KroneckerDelta(0,gO2)*Sqr(
      g2)*ZP(gI2,0) - KroneckerDelta(1,gO2)*(-2*AbsSqr(LamTU) + Sqr(g2))*ZP(gI2,1)
      - 2*KroneckerDelta(3,gO2)*Sqr(g2)*ZP(gI2,3)) + KroneckerDelta(2,gO2)*(Sqr(
      g2)*ZP(gI1,0)*ZP(gI2,0) - (-2*AbsSqr(LamTU) + Sqr(g2))*ZP(gI1,1)*ZP(gI2,1) +
      2*Sqr(g2)*(2*ZP(gI1,2)*ZP(gI2,2) - ZP(gI1,3)*ZP(gI2,3)))) + KroneckerDelta(
      3,gO1)*(ZP(gI1,3)*(-(KroneckerDelta(0,gO2)*(-2*AbsSqr(LamTD) + Sqr(g2))*ZP(
      gI2,0)) + Sqr(g2)*(KroneckerDelta(1,gO2)*ZP(gI2,1) - 2*KroneckerDelta(2,gO2)
      *ZP(gI2,2))) + KroneckerDelta(3,gO2)*(-((-2*AbsSqr(LamTD) + Sqr(g2))*ZP(gI1,
      0)*ZP(gI2,0)) + Sqr(g2)*(ZP(gI1,1)*ZP(gI2,1) - 2*ZP(gI1,2)*ZP(gI2,2) + 4*ZP(
      gI1,3)*ZP(gI2,3))))));

   return result;
}

std::complex<double> CLASSNAME::CpUHpmconjUHpmhhhh(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.05*(5*(-(KroneckerDelta(3,gO1)*(-1.4142135623730951*
      KroneckerDelta(0,gO2)*Sqr(g2)*ZH(gI1,3)*ZH(gI2,0) + 2*LamSU*Conj(LamTU)*
      KroneckerDelta(1,gO2)*ZH(gI1,2)*ZH(gI2,1) + 1.4142135623730951*AbsSqr(LamTU)
      *KroneckerDelta(1,gO2)*ZH(gI1,3)*ZH(gI2,1) - 1.4142135623730951*
      KroneckerDelta(1,gO2)*Sqr(g2)*ZH(gI1,3)*ZH(gI2,1) + 2*LamSU*Conj(LamTU)*
      KroneckerDelta(1,gO2)*ZH(gI1,1)*ZH(gI2,2) - 1.4142135623730951*
      KroneckerDelta(0,gO2)*Sqr(g2)*ZH(gI1,0)*ZH(gI2,3) + 1.4142135623730951*
      AbsSqr(LamTU)*KroneckerDelta(1,gO2)*ZH(gI1,1)*ZH(gI2,3) - 1.4142135623730951
      *KroneckerDelta(1,gO2)*Sqr(g2)*ZH(gI1,1)*ZH(gI2,3) - 4*KroneckerDelta(2,gO2)
      *Sqr(g2)*ZH(gI1,3)*ZH(gI2,3) + 2*KroneckerDelta(3,gO2)*(Sqr(g2)*ZH(gI1,0)*ZH
      (gI2,0) - (-2*AbsSqr(LamTU) + Sqr(g2))*ZH(gI1,1)*ZH(gI2,1) + 2*Sqr(g2)*ZH(
      gI1,3)*ZH(gI2,3)) + Conj(LamTD)*KroneckerDelta(0,gO2)*(2*LamSD*ZH(gI1,2)*ZH(
      gI2,0) + 1.4142135623730951*LamTD*ZH(gI1,3)*ZH(gI2,0) + ZH(gI1,0)*(2*LamSD*
      ZH(gI2,2) + 1.4142135623730951*LamTD*ZH(gI2,3))))) + KroneckerDelta(2,gO1)*(
      1.4142135623730951*AbsSqr(LamTD)*KroneckerDelta(0,gO2)*ZH(gI1,3)*ZH(gI2,0) -
      1.4142135623730951*KroneckerDelta(0,gO2)*Sqr(g2)*ZH(gI1,3)*ZH(gI2,0) - 2*
      LamTU*Conj(LamSU)*KroneckerDelta(1,gO2)*ZH(gI1,2)*ZH(gI2,1) +
      1.4142135623730951*AbsSqr(LamTU)*KroneckerDelta(1,gO2)*ZH(gI1,3)*ZH(gI2,1) -
      1.4142135623730951*KroneckerDelta(1,gO2)*Sqr(g2)*ZH(gI1,3)*ZH(gI2,1) - 2*
      LamTU*Conj(LamSU)*KroneckerDelta(1,gO2)*ZH(gI1,1)*ZH(gI2,2) - 2*LamTD*Conj(
      LamSD)*KroneckerDelta(0,gO2)*(ZH(gI1,2)*ZH(gI2,0) + ZH(gI1,0)*ZH(gI2,2)) +
      1.4142135623730951*AbsSqr(LamTD)*KroneckerDelta(0,gO2)*ZH(gI1,0)*ZH(gI2,3) -
      1.4142135623730951*KroneckerDelta(0,gO2)*Sqr(g2)*ZH(gI1,0)*ZH(gI2,3) +
      1.4142135623730951*AbsSqr(LamTU)*KroneckerDelta(1,gO2)*ZH(gI1,1)*ZH(gI2,3) -
      1.4142135623730951*KroneckerDelta(1,gO2)*Sqr(g2)*ZH(gI1,1)*ZH(gI2,3) + 4*
      KroneckerDelta(3,gO2)*Sqr(g2)*ZH(gI1,3)*ZH(gI2,3) + 2*KroneckerDelta(2,gO2)*
      ((-2*AbsSqr(LamTD) + Sqr(g2))*ZH(gI1,0)*ZH(gI2,0) - Sqr(g2)*(ZH(gI1,1)*ZH(
      gI2,1) + 2*ZH(gI1,3)*ZH(gI2,3))))) - KroneckerDelta(0,gO1)*(5*(2*LamTD*Conj(
      LamSD)*KroneckerDelta(3,gO2)*ZH(gI1,2)*ZH(gI2,0) + 1.4142135623730951*
      KroneckerDelta(2,gO2)*Sqr(g2)*ZH(gI1,3)*ZH(gI2,0) - 1.4142135623730951*
      KroneckerDelta(3,gO2)*Sqr(g2)*ZH(gI1,3)*ZH(gI2,0) + KroneckerDelta(1,gO2)*
      Sqr(g2)*(ZH(gI1,1)*ZH(gI2,0) + ZH(gI1,0)*ZH(gI2,1)) + 2*LamTD*Conj(LamSD)*
      KroneckerDelta(3,gO2)*ZH(gI1,0)*ZH(gI2,2) + 1.4142135623730951*
      KroneckerDelta(2,gO2)*Sqr(g2)*ZH(gI1,0)*ZH(gI2,3) - 1.4142135623730951*
      KroneckerDelta(3,gO2)*Sqr(g2)*ZH(gI1,0)*ZH(gI2,3) + Conj(LamTD)*(
      1.4142135623730951*LamTD*KroneckerDelta(3,gO2)*(ZH(gI1,3)*ZH(gI2,0) + ZH(gI1
      ,0)*ZH(gI2,3)) + KroneckerDelta(2,gO2)*(2*LamSD*ZH(gI1,2)*ZH(gI2,0) -
      1.4142135623730951*LamTD*ZH(gI1,3)*ZH(gI2,0) + ZH(gI1,0)*(2*LamSD*ZH(gI2,2)
      - 1.4142135623730951*LamTD*ZH(gI2,3))))) + KroneckerDelta(0,gO2)*((3*Sqr(g1)
      + 5*Sqr(g2))*ZH(gI1,0)*ZH(gI2,0) + (-3*Sqr(g1) + 5*Sqr(g2))*ZH(gI1,1)*ZH(
      gI2,1) + 5*(-(Conj(LamTD)*(1.4142135623730951*LamSD*ZH(gI1,2)*ZH(gI2,3) + ZH
      (gI1,3)*(1.4142135623730951*LamSD*ZH(gI2,2) - 2*LamTD*ZH(gI2,3)))) - Conj(
      LamSD)*(1.4142135623730951*LamTD*ZH(gI1,3)*ZH(gI2,2) + ZH(gI1,2)*(-4*LamSD*
      ZH(gI2,2) + 1.4142135623730951*LamTD*ZH(gI2,3)))))) + KroneckerDelta(1,gO1)*
      (-5*(2*LamTU*Conj(LamSU)*KroneckerDelta(3,gO2)*ZH(gI1,2)*ZH(gI2,1) +
      1.4142135623730951*KroneckerDelta(2,gO2)*Sqr(g2)*ZH(gI1,3)*ZH(gI2,1) -
      1.4142135623730951*KroneckerDelta(3,gO2)*Sqr(g2)*ZH(gI1,3)*ZH(gI2,1) +
      KroneckerDelta(0,gO2)*Sqr(g2)*(ZH(gI1,1)*ZH(gI2,0) + ZH(gI1,0)*ZH(gI2,1)) +
      2*LamTU*Conj(LamSU)*KroneckerDelta(3,gO2)*ZH(gI1,1)*ZH(gI2,2) +
      1.4142135623730951*KroneckerDelta(2,gO2)*Sqr(g2)*ZH(gI1,1)*ZH(gI2,3) -
      1.4142135623730951*KroneckerDelta(3,gO2)*Sqr(g2)*ZH(gI1,1)*ZH(gI2,3) + Conj(
      LamTU)*(1.4142135623730951*LamTU*KroneckerDelta(3,gO2)*(ZH(gI1,3)*ZH(gI2,1)
      + ZH(gI1,1)*ZH(gI2,3)) + KroneckerDelta(2,gO2)*(2*LamSU*ZH(gI1,2)*ZH(gI2,1)
      - 1.4142135623730951*LamTU*ZH(gI1,3)*ZH(gI2,1) + ZH(gI1,1)*(2*LamSU*ZH(gI2,2
      ) - 1.4142135623730951*LamTU*ZH(gI2,3))))) + KroneckerDelta(1,gO2)*((3*Sqr(
      g1) - 5*Sqr(g2))*ZH(gI1,0)*ZH(gI2,0) - (3*Sqr(g1) + 5*Sqr(g2))*ZH(gI1,1)*ZH(
      gI2,1) - 5*(Conj(LamSU)*(1.4142135623730951*LamTU*ZH(gI1,3)*ZH(gI2,2) + ZH(
      gI1,2)*(4*LamSU*ZH(gI2,2) + 1.4142135623730951*LamTU*ZH(gI2,3))) + Conj(
      LamTU)*(1.4142135623730951*LamSU*ZH(gI1,2)*ZH(gI2,3) + ZH(gI1,3)*(
      1.4142135623730951*LamSU*ZH(gI2,2) + 2*LamTU*ZH(gI2,3)))))));

   return result;
}

std::complex<double> CLASSNAME::CpconjUHpmbarChiCha2PR(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = -1.4142135623730951*g2*KroneckerDelta(3,gO2)*UP2(gI2,0)*ZN1(gI1,1)
      - 0.1414213562373095*KroneckerDelta(1,gO2)*UP2(gI2,1)*(3.872983346207417*g1*
      ZN1(gI1,0) + 5*g2*ZN1(gI1,1)) + Conj(LamTD)*KroneckerDelta(0,gO2)*UP2(gI2,0)
      *ZN1(gI1,2) - Conj(LamTU)*KroneckerDelta(2,gO2)*UP2(gI2,1)*ZN1(gI1,3);

   return result;
}

std::complex<double> CLASSNAME::CpconjUHpmbarChiCha2PL(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = -(g2*Conj(UM2(gI2,0))*(Conj(ZN2(gI1,2))*KroneckerDelta(0,gO1) +
      1.4142135623730951*Conj(ZN2(gI1,1))*KroneckerDelta(2,gO1))) + 0.5*Conj(UM2(
      gI2,1))*(2*LamSU*Conj(ZN2(gI1,0))*KroneckerDelta(1,gO1) + 1.4142135623730951
      *LamTU*Conj(ZN2(gI1,1))*KroneckerDelta(1,gO1) + 2*LamTU*Conj(ZN2(gI1,3))*
      KroneckerDelta(3,gO1));

   return result;
}

std::complex<double> CLASSNAME::CpconjUHpmHpmAh(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = std::complex<double>(0,0.05)*(14.142135623730951*g2*MDWBT*
      KroneckerDelta(3,gO2)*ZA(gI2,0)*ZP(gI1,0) + 7.0710678118654755*vT*AbsSqr(
      LamTD)*KroneckerDelta(3,gO2)*ZA(gI2,0)*ZP(gI1,0) + 10*LamTD*vS*Conj(LamSD)*
      KroneckerDelta(3,gO2)*ZA(gI2,0)*ZP(gI1,0) + 14.142135623730951*LamTD*Conj(
      MuD)*KroneckerDelta(3,gO2)*ZA(gI2,0)*ZP(gI1,0) - 7.0710678118654755*vT*
      KroneckerDelta(3,gO2)*Sqr(g2)*ZA(gI2,0)*ZP(gI1,0) + 7.745966692414834*g1*
      MDBS*KroneckerDelta(0,gO2)*ZA(gI2,2)*ZP(gI1,0) + 14.142135623730951*MuD*Conj
      (LamSD)*KroneckerDelta(0,gO2)*ZA(gI2,2)*ZP(gI1,0) - 7.0710678118654755*LamTD
      *vT*Conj(LamSD)*KroneckerDelta(0,gO2)*ZA(gI2,2)*ZP(gI1,0) +
      7.0710678118654755*LamSD*vT*Conj(LamTD)*KroneckerDelta(0,gO2)*ZA(gI2,2)*ZP(
      gI1,0) - 7.745966692414834*g1*Conj(MDBS)*KroneckerDelta(0,gO2)*ZA(gI2,2)*ZP(
      gI1,0) - 14.142135623730951*LamSD*Conj(MuD)*KroneckerDelta(0,gO2)*ZA(gI2,2)*
      ZP(gI1,0) + 10*LamTD*vd*Conj(LamSD)*KroneckerDelta(3,gO2)*ZA(gI2,2)*ZP(gI1,0
      ) + 10*g2*MDWBT*KroneckerDelta(0,gO2)*ZA(gI2,3)*ZP(gI1,0) +
      7.0710678118654755*LamTD*vS*Conj(LamSD)*KroneckerDelta(0,gO2)*ZA(gI2,3)*ZP(
      gI1,0) - 10*MuD*Conj(LamTD)*KroneckerDelta(0,gO2)*ZA(gI2,3)*ZP(gI1,0) -
      7.0710678118654755*LamSD*vS*Conj(LamTD)*KroneckerDelta(0,gO2)*ZA(gI2,3)*ZP(
      gI1,0) - 10*g2*Conj(MDWBT)*KroneckerDelta(0,gO2)*ZA(gI2,3)*ZP(gI1,0) + 10*
      LamTD*Conj(MuD)*KroneckerDelta(0,gO2)*ZA(gI2,3)*ZP(gI1,0) +
      7.0710678118654755*vd*AbsSqr(LamTD)*KroneckerDelta(3,gO2)*ZA(gI2,3)*ZP(gI1,0
      ) - 7.0710678118654755*vd*KroneckerDelta(3,gO2)*Sqr(g2)*ZA(gI2,3)*ZP(gI1,0)
      - 5*vu*KroneckerDelta(0,gO2)*Sqr(g2)*ZA(gI2,0)*ZP(gI1,1) -
      14.142135623730951*g2*MDWBT*KroneckerDelta(3,gO2)*ZA(gI2,1)*ZP(gI1,1) -
      7.0710678118654755*vT*AbsSqr(LamTU)*KroneckerDelta(3,gO2)*ZA(gI2,1)*ZP(gI1,1
      ) - 10*LamTU*vS*Conj(LamSU)*KroneckerDelta(3,gO2)*ZA(gI2,1)*ZP(gI1,1) -
      14.142135623730951*LamTU*Conj(MuU)*KroneckerDelta(3,gO2)*ZA(gI2,1)*ZP(gI1,1)
      - 5*vd*KroneckerDelta(0,gO2)*Sqr(g2)*ZA(gI2,1)*ZP(gI1,1) +
      7.0710678118654755*vT*KroneckerDelta(3,gO2)*Sqr(g2)*ZA(gI2,1)*ZP(gI1,1) + 10
      *LamTU*vu*Conj(LamSU)*KroneckerDelta(3,gO2)*ZA(gI2,2)*ZP(gI1,1) +
      7.0710678118654755*vu*AbsSqr(LamTU)*KroneckerDelta(3,gO2)*ZA(gI2,3)*ZP(gI1,1
      ) - 7.0710678118654755*vu*KroneckerDelta(3,gO2)*Sqr(g2)*ZA(gI2,3)*ZP(gI1,1)
      - 14.142135623730951*g2*MDWBT*KroneckerDelta(0,gO2)*ZA(gI2,0)*ZP(gI1,2) +
      7.0710678118654755*vT*AbsSqr(LamTD)*KroneckerDelta(0,gO2)*ZA(gI2,0)*ZP(gI1,2
      ) - 10*LamTD*vS*Conj(LamSD)*KroneckerDelta(0,gO2)*ZA(gI2,0)*ZP(gI1,2) -
      14.142135623730951*LamTD*Conj(MuD)*KroneckerDelta(0,gO2)*ZA(gI2,0)*ZP(gI1,2)
      - 7.0710678118654755*vT*KroneckerDelta(0,gO2)*Sqr(g2)*ZA(gI2,0)*ZP(gI1,2) +
      10*LamTD*vd*Conj(LamSD)*KroneckerDelta(0,gO2)*ZA(gI2,2)*ZP(gI1,2) -
      7.0710678118654755*vd*AbsSqr(LamTD)*KroneckerDelta(0,gO2)*ZA(gI2,3)*ZP(gI1,2
      ) + 7.0710678118654755*vd*KroneckerDelta(0,gO2)*Sqr(g2)*ZA(gI2,3)*ZP(gI1,2)
      - 20*vT*KroneckerDelta(3,gO2)*Sqr(g2)*ZA(gI2,3)*ZP(gI1,2) -
      7.0710678118654755*vT*AbsSqr(LamTD)*KroneckerDelta(0,gO2)*ZA(gI2,0)*ZP(gI1,3
      ) - 14.142135623730951*MuD*Conj(LamTD)*KroneckerDelta(0,gO2)*ZA(gI2,0)*ZP(
      gI1,3) - 10*LamSD*vS*Conj(LamTD)*KroneckerDelta(0,gO2)*ZA(gI2,0)*ZP(gI1,3) -
      14.142135623730951*g2*Conj(MDWBT)*KroneckerDelta(0,gO2)*ZA(gI2,0)*ZP(gI1,3)
      + 7.0710678118654755*vT*KroneckerDelta(0,gO2)*Sqr(g2)*ZA(gI2,0)*ZP(gI1,3) -
      10*LamSD*vd*Conj(LamTD)*KroneckerDelta(0,gO2)*ZA(gI2,2)*ZP(gI1,3) -
      7.0710678118654755*vd*AbsSqr(LamTD)*KroneckerDelta(0,gO2)*ZA(gI2,3)*ZP(gI1,3
      ) + 7.0710678118654755*vd*KroneckerDelta(0,gO2)*Sqr(g2)*ZA(gI2,3)*ZP(gI1,3)
      + 5*KroneckerDelta(2,gO2)*(((2.8284271247461903*MuD + 2*LamSD*vS -
      1.4142135623730951*LamTD*vT)*Conj(LamTD) + 1.4142135623730951*g2*(g2*vT + 2*
      Conj(MDWBT)))*ZA(gI2,0)*ZP(gI1,0) - 1.4142135623730951*vd*Sqr(g2)*ZA(gI2,3)*
      ZP(gI1,0) + vd*Conj(LamTD)*(-2*LamSD*ZA(gI2,2) + 1.4142135623730951*LamTD*ZA
      (gI2,3))*ZP(gI1,0) + 1.4142135623730951*vT*AbsSqr(LamTU)*ZA(gI2,1)*ZP(gI1,1)
      - 2.8284271247461903*MuU*Conj(LamTU)*ZA(gI2,1)*ZP(gI1,1) - 2*LamSU*vS*Conj(
      LamTU)*ZA(gI2,1)*ZP(gI1,1) - 2.8284271247461903*g2*Conj(MDWBT)*ZA(gI2,1)*ZP(
      gI1,1) - 1.4142135623730951*vT*Sqr(g2)*ZA(gI2,1)*ZP(gI1,1) - 2*LamSU*vu*Conj
      (LamTU)*ZA(gI2,2)*ZP(gI1,1) + 1.4142135623730951*vu*AbsSqr(LamTU)*ZA(gI2,3)*
      ZP(gI1,1) - 1.4142135623730951*vu*Sqr(g2)*ZA(gI2,3)*ZP(gI1,1) + 4*vT*Sqr(g2)
      *ZA(gI2,3)*ZP(gI1,3)) + KroneckerDelta(1,gO2)*(5*vu*Sqr(g2)*ZA(gI2,0)*ZP(gI1
      ,0) - 7.745966692414834*g1*MDBS*ZA(gI2,2)*ZP(gI1,1) + 14.142135623730951*MuU
      *Conj(LamSU)*ZA(gI2,2)*ZP(gI1,1) + 7.0710678118654755*LamTU*vT*Conj(LamSU)*
      ZA(gI2,2)*ZP(gI1,1) - 7.0710678118654755*LamSU*vT*Conj(LamTU)*ZA(gI2,2)*ZP(
      gI1,1) + 7.745966692414834*g1*Conj(MDBS)*ZA(gI2,2)*ZP(gI1,1) -
      14.142135623730951*LamSU*Conj(MuU)*ZA(gI2,2)*ZP(gI1,1) - 10*g2*MDWBT*ZA(gI2,
      3)*ZP(gI1,1) - 7.0710678118654755*LamTU*vS*Conj(LamSU)*ZA(gI2,3)*ZP(gI1,1) +
      10*MuU*Conj(LamTU)*ZA(gI2,3)*ZP(gI1,1) + 7.0710678118654755*LamSU*vS*Conj(
      LamTU)*ZA(gI2,3)*ZP(gI1,1) + 10*g2*Conj(MDWBT)*ZA(gI2,3)*ZP(gI1,1) - 10*
      LamTU*Conj(MuU)*ZA(gI2,3)*ZP(gI1,1) + 10*LamTU*vu*Conj(LamSU)*ZA(gI2,2)*ZP(
      gI1,2) - 7.0710678118654755*vu*AbsSqr(LamTU)*ZA(gI2,3)*ZP(gI1,2) +
      7.0710678118654755*vu*Sqr(g2)*ZA(gI2,3)*ZP(gI1,2) - 10*LamSU*vu*Conj(LamTU)*
      ZA(gI2,2)*ZP(gI1,3) - 7.0710678118654755*vu*AbsSqr(LamTU)*ZA(gI2,3)*ZP(gI1,3
      ) + 7.0710678118654755*vu*Sqr(g2)*ZA(gI2,3)*ZP(gI1,3) + 5*ZA(gI2,1)*(vd*Sqr(
      g2)*ZP(gI1,0) + (2*LamTU*vS*Conj(LamSU) + 1.4142135623730951*(2*g2*MDWBT -
      vT*AbsSqr(LamTU) + 2*LamTU*Conj(MuU) + vT*Sqr(g2)))*ZP(gI1,2) + ((
      2.8284271247461903*MuU + 2*LamSU*vS + 1.4142135623730951*LamTU*vT)*Conj(
      LamTU) + 1.4142135623730951*g2*(-(g2*vT) + 2*Conj(MDWBT)))*ZP(gI1,3))));

   return result;
}

std::complex<double> CLASSNAME::CpconjUHpmHpmhh(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.05*(-(KroneckerDelta(0,gO2)*(-3*vu*Sqr(g1)*ZH(gI2,1)*ZP(gI1,0) +
      5*vu*Sqr(g2)*ZH(gI2,1)*ZP(gI1,0) - 7.745966692414834*g1*MDBS*ZH(gI2,2)*ZP(
      gI1,0) + 20*vS*AbsSqr(LamSD)*ZH(gI2,2)*ZP(gI1,0) + 14.142135623730951*MuD*
      Conj(LamSD)*ZH(gI2,2)*ZP(gI1,0) - 7.0710678118654755*LamTD*vT*Conj(LamSD)*ZH
      (gI2,2)*ZP(gI1,0) - 7.0710678118654755*LamSD*vT*Conj(LamTD)*ZH(gI2,2)*ZP(gI1
      ,0) - 7.745966692414834*g1*Conj(MDBS)*ZH(gI2,2)*ZP(gI1,0) +
      14.142135623730951*LamSD*Conj(MuD)*ZH(gI2,2)*ZP(gI1,0) - 10*g2*MDWBT*ZH(gI2,
      3)*ZP(gI1,0) + 10*vT*AbsSqr(LamTD)*ZH(gI2,3)*ZP(gI1,0) - 7.0710678118654755*
      LamTD*vS*Conj(LamSD)*ZH(gI2,3)*ZP(gI1,0) - 10*MuD*Conj(LamTD)*ZH(gI2,3)*ZP(
      gI1,0) - 7.0710678118654755*LamSD*vS*Conj(LamTD)*ZH(gI2,3)*ZP(gI1,0) - 10*g2
      *Conj(MDWBT)*ZH(gI2,3)*ZP(gI1,0) - 10*LamTD*Conj(MuD)*ZH(gI2,3)*ZP(gI1,0) +
      5*vd*Sqr(g2)*ZH(gI2,1)*ZP(gI1,1) + 10*LamTD*vd*Conj(LamSD)*ZH(gI2,2)*ZP(gI1,
      2) - 7.0710678118654755*vd*AbsSqr(LamTD)*ZH(gI2,3)*ZP(gI1,2) +
      7.0710678118654755*vd*Sqr(g2)*ZH(gI2,3)*ZP(gI1,2) + 10*LamSD*vd*Conj(LamTD)*
      ZH(gI2,2)*ZP(gI1,3) + 7.0710678118654755*vd*AbsSqr(LamTD)*ZH(gI2,3)*ZP(gI1,3
      ) - 7.0710678118654755*vd*Sqr(g2)*ZH(gI2,3)*ZP(gI1,3) + ZH(gI2,0)*(vd*(3*Sqr
      (g1) + 5*Sqr(g2))*ZP(gI1,0) + 5*(vu*Sqr(g2)*ZP(gI1,1) + (2*LamTD*vS*Conj(
      LamSD) + 1.4142135623730951*(2*g2*MDWBT - vT*AbsSqr(LamTD) + 2*LamTD*Conj(
      MuD) + vT*Sqr(g2)))*ZP(gI1,2) + ((2.8284271247461903*MuD + 2*LamSD*vS +
      1.4142135623730951*LamTD*vT)*Conj(LamTD) + 1.4142135623730951*g2*(-(g2*vT) +
      2*Conj(MDWBT)))*ZP(gI1,3))))) - KroneckerDelta(1,gO2)*(7.745966692414834*g1
      *MDBS*ZH(gI2,2)*ZP(gI1,1) + 20*vS*AbsSqr(LamSU)*ZH(gI2,2)*ZP(gI1,1) +
      14.142135623730951*MuU*Conj(LamSU)*ZH(gI2,2)*ZP(gI1,1) + 7.0710678118654755*
      LamTU*vT*Conj(LamSU)*ZH(gI2,2)*ZP(gI1,1) + 7.0710678118654755*LamSU*vT*Conj(
      LamTU)*ZH(gI2,2)*ZP(gI1,1) + 7.745966692414834*g1*Conj(MDBS)*ZH(gI2,2)*ZP(
      gI1,1) + 14.142135623730951*LamSU*Conj(MuU)*ZH(gI2,2)*ZP(gI1,1) + 10*g2*
      MDWBT*ZH(gI2,3)*ZP(gI1,1) + 10*vT*AbsSqr(LamTU)*ZH(gI2,3)*ZP(gI1,1) +
      7.0710678118654755*LamTU*vS*Conj(LamSU)*ZH(gI2,3)*ZP(gI1,1) + 10*MuU*Conj(
      LamTU)*ZH(gI2,3)*ZP(gI1,1) + 7.0710678118654755*LamSU*vS*Conj(LamTU)*ZH(gI2,
      3)*ZP(gI1,1) + 10*g2*Conj(MDWBT)*ZH(gI2,3)*ZP(gI1,1) + 10*LamTU*Conj(MuU)*ZH
      (gI2,3)*ZP(gI1,1) + ZH(gI2,0)*(5*vu*Sqr(g2)*ZP(gI1,0) + vd*(-3*Sqr(g1) + 5*
      Sqr(g2))*ZP(gI1,1)) + 10*LamTU*vu*Conj(LamSU)*ZH(gI2,2)*ZP(gI1,2) -
      7.0710678118654755*vu*AbsSqr(LamTU)*ZH(gI2,3)*ZP(gI1,2) + 7.0710678118654755
      *vu*Sqr(g2)*ZH(gI2,3)*ZP(gI1,2) + 10*LamSU*vu*Conj(LamTU)*ZH(gI2,2)*ZP(gI1,3
      ) + 7.0710678118654755*vu*AbsSqr(LamTU)*ZH(gI2,3)*ZP(gI1,3) -
      7.0710678118654755*vu*Sqr(g2)*ZH(gI2,3)*ZP(gI1,3) + ZH(gI2,1)*(5*vd*Sqr(g2)*
      ZP(gI1,0) + vu*(3*Sqr(g1) + 5*Sqr(g2))*ZP(gI1,1) + 5*((2*LamTU*vS*Conj(LamSU
      ) + 1.4142135623730951*(2*g2*MDWBT - vT*AbsSqr(LamTU) + 2*LamTU*Conj(MuU) +
      vT*Sqr(g2)))*ZP(gI1,2) + ((2.8284271247461903*MuU + 2*LamSU*vS +
      1.4142135623730951*LamTU*vT)*Conj(LamTU) + 1.4142135623730951*g2*(-(g2*vT) +
      2*Conj(MDWBT)))*ZP(gI1,3)))) - 5*(KroneckerDelta(2,gO2)*(1.4142135623730951
      *vd*Sqr(g2)*ZH(gI2,3)*ZP(gI1,0) + vd*Conj(LamTD)*(2*LamSD*ZH(gI2,2) -
      1.4142135623730951*LamTD*ZH(gI2,3))*ZP(gI1,0) - 1.4142135623730951*vT*AbsSqr
      (LamTU)*ZH(gI2,1)*ZP(gI1,1) + 2.8284271247461903*MuU*Conj(LamTU)*ZH(gI2,1)*
      ZP(gI1,1) + 2*LamSU*vS*Conj(LamTU)*ZH(gI2,1)*ZP(gI1,1) + 2.8284271247461903*
      g2*Conj(MDWBT)*ZH(gI2,1)*ZP(gI1,1) + 1.4142135623730951*vT*Sqr(g2)*ZH(gI2,1)
      *ZP(gI1,1) + 2*LamSU*vu*Conj(LamTU)*ZH(gI2,2)*ZP(gI1,1) - 1.4142135623730951
      *vu*AbsSqr(LamTU)*ZH(gI2,3)*ZP(gI1,1) + 1.4142135623730951*vu*Sqr(g2)*ZH(gI2
      ,3)*ZP(gI1,1) + 2*vu*Sqr(g2)*ZH(gI2,1)*ZP(gI1,2) + 4*vT*Sqr(g2)*ZH(gI2,3)*ZP
      (gI1,2) + ZH(gI2,0)*(((2.8284271247461903*MuD + 2*LamSD*vS -
      1.4142135623730951*LamTD*vT)*Conj(LamTD) + 1.4142135623730951*g2*(g2*vT + 2*
      Conj(MDWBT)))*ZP(gI1,0) - 2*vd*(-2*AbsSqr(LamTD) + Sqr(g2))*ZP(gI1,2)) - 4*
      vT*Sqr(g2)*ZH(gI2,3)*ZP(gI1,3)) + KroneckerDelta(3,gO2)*(2*LamTD*vd*Conj(
      LamSD)*ZH(gI2,2)*ZP(gI1,0) + 1.4142135623730951*vd*AbsSqr(LamTD)*ZH(gI2,3)*
      ZP(gI1,0) - 1.4142135623730951*vd*Sqr(g2)*ZH(gI2,3)*ZP(gI1,0) +
      2.8284271247461903*g2*MDWBT*ZH(gI2,1)*ZP(gI1,1) + 1.4142135623730951*vT*
      AbsSqr(LamTU)*ZH(gI2,1)*ZP(gI1,1) + 2*LamTU*vS*Conj(LamSU)*ZH(gI2,1)*ZP(gI1,
      1) + 2.8284271247461903*LamTU*Conj(MuU)*ZH(gI2,1)*ZP(gI1,1) -
      1.4142135623730951*vT*Sqr(g2)*ZH(gI2,1)*ZP(gI1,1) + 2*LamTU*vu*Conj(LamSU)*
      ZH(gI2,2)*ZP(gI1,1) + 1.4142135623730951*vu*AbsSqr(LamTU)*ZH(gI2,3)*ZP(gI1,1
      ) - 1.4142135623730951*vu*Sqr(g2)*ZH(gI2,3)*ZP(gI1,1) - 4*vT*Sqr(g2)*ZH(gI2,
      3)*ZP(gI1,2) + 4*vu*AbsSqr(LamTU)*ZH(gI2,1)*ZP(gI1,3) - 2*vu*Sqr(g2)*ZH(gI2,
      1)*ZP(gI1,3) + 4*vT*Sqr(g2)*ZH(gI2,3)*ZP(gI1,3) + ZH(gI2,0)*((2*LamTD*vS*
      Conj(LamSD) + 1.4142135623730951*(2*g2*MDWBT + vT*AbsSqr(LamTD) + 2*LamTD*
      Conj(MuD) - vT*Sqr(g2)))*ZP(gI1,0) + 2*vd*Sqr(g2)*ZP(gI1,3)))));

   return result;
}

std::complex<double> CLASSNAME::CpUHpmconjUHpmconjSdSd(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1411;
   std::complex<double> tmp_1412;
   std::complex<double> tmp_1413;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1413 += Conj(ZD(gI2,j1))*ZD(gI1,j1);
   }
   tmp_1412 += tmp_1413;
   tmp_1411 += (std::complex<double>(0,0.05)*KroneckerDelta(0,gO1)*
      KroneckerDelta(0,gO2)*Sqr(g1)) * tmp_1412;
   std::complex<double> tmp_1414;
   std::complex<double> tmp_1415;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1415 += Conj(ZD(gI2,j1))*ZD(gI1,j1);
   }
   tmp_1414 += tmp_1415;
   tmp_1411 += (std::complex<double>(0,-0.25)*KroneckerDelta(0,gO1)*
      KroneckerDelta(0,gO2)*Sqr(g2)) * tmp_1414;
   std::complex<double> tmp_1416;
   std::complex<double> tmp_1417;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1417 += Conj(ZD(gI2,j1))*ZD(gI1,j1);
   }
   tmp_1416 += tmp_1417;
   tmp_1411 += (std::complex<double>(0,-0.05)*KroneckerDelta(1,gO1)*
      KroneckerDelta(1,gO2)*Sqr(g1)) * tmp_1416;
   std::complex<double> tmp_1418;
   std::complex<double> tmp_1419;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1419 += Conj(ZD(gI2,j1))*ZD(gI1,j1);
   }
   tmp_1418 += tmp_1419;
   tmp_1411 += (std::complex<double>(0,0.25)*KroneckerDelta(1,gO1)*
      KroneckerDelta(1,gO2)*Sqr(g2)) * tmp_1418;
   std::complex<double> tmp_1420;
   std::complex<double> tmp_1421;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1421 += Conj(ZD(gI2,j1))*ZD(gI1,j1);
   }
   tmp_1420 += tmp_1421;
   tmp_1411 += (std::complex<double>(0,-0.5)*KroneckerDelta(2,gO1)*
      KroneckerDelta(2,gO2)*Sqr(g2)) * tmp_1420;
   std::complex<double> tmp_1422;
   std::complex<double> tmp_1423;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1423 += Conj(ZD(gI2,j1))*ZD(gI1,j1);
   }
   tmp_1422 += tmp_1423;
   tmp_1411 += (std::complex<double>(0,0.5)*KroneckerDelta(3,gO1)*
      KroneckerDelta(3,gO2)*Sqr(g2)) * tmp_1422;
   std::complex<double> tmp_1424;
   std::complex<double> tmp_1425;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1425 += Conj(ZD(gI2,3 + j1))*ZD(gI1,3 + j1);
   }
   tmp_1424 += tmp_1425;
   tmp_1411 += (std::complex<double>(0,0.1)*KroneckerDelta(0,gO1)*
      KroneckerDelta(0,gO2)*Sqr(g1)) * tmp_1424;
   std::complex<double> tmp_1426;
   std::complex<double> tmp_1427;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1427 += Conj(ZD(gI2,3 + j1))*ZD(gI1,3 + j1);
   }
   tmp_1426 += tmp_1427;
   tmp_1411 += (std::complex<double>(0,-0.1)*KroneckerDelta(1,gO1)*
      KroneckerDelta(1,gO2)*Sqr(g1)) * tmp_1426;
   std::complex<double> tmp_1428;
   std::complex<double> tmp_1429;
   for (unsigned j3 = 0; j3 < 3; ++j3) {
      std::complex<double> tmp_1430;
      std::complex<double> tmp_1431;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         std::complex<double> tmp_1432;
         std::complex<double> tmp_1433;
         for (unsigned j1 = 0; j1 < 3; ++j1) {
            tmp_1433 += Conj(Yd(j3,j1))*Yd(j2,j1);
         }
         tmp_1432 += tmp_1433;
         tmp_1431 += (ZD(gI1,3 + j2)) * tmp_1432;
      }
      tmp_1430 += tmp_1431;
      tmp_1429 += (Conj(ZD(gI2,3 + j3))) * tmp_1430;
   }
   tmp_1428 += tmp_1429;
   tmp_1411 += (std::complex<double>(0,-1)*KroneckerDelta(0,gO1)*KroneckerDelta
      (0,gO2)) * tmp_1428;
   std::complex<double> tmp_1434;
   std::complex<double> tmp_1435;
   for (unsigned j3 = 0; j3 < 3; ++j3) {
      std::complex<double> tmp_1436;
      std::complex<double> tmp_1437;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         std::complex<double> tmp_1438;
         std::complex<double> tmp_1439;
         for (unsigned j1 = 0; j1 < 3; ++j1) {
            tmp_1439 += Conj(Yu(j1,j3))*Yu(j1,j2);
         }
         tmp_1438 += tmp_1439;
         tmp_1437 += (Conj(ZD(gI2,j2))) * tmp_1438;
      }
      tmp_1436 += tmp_1437;
      tmp_1435 += (ZD(gI1,j3)) * tmp_1436;
   }
   tmp_1434 += tmp_1435;
   tmp_1411 += (std::complex<double>(0,-1)*KroneckerDelta(1,gO1)*KroneckerDelta
      (1,gO2)) * tmp_1434;
   result += (std::complex<double>(0,-1)) * tmp_1411;

   return result;
}

std::complex<double> CLASSNAME::CpUHpmconjUHpmconjSeSe(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1440;
   std::complex<double> tmp_1441;
   std::complex<double> tmp_1442;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1442 += Conj(ZE(gI2,j1))*ZE(gI1,j1);
   }
   tmp_1441 += tmp_1442;
   tmp_1440 += (std::complex<double>(0,-0.15)*KroneckerDelta(0,gO1)*
      KroneckerDelta(0,gO2)*Sqr(g1)) * tmp_1441;
   std::complex<double> tmp_1443;
   std::complex<double> tmp_1444;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1444 += Conj(ZE(gI2,j1))*ZE(gI1,j1);
   }
   tmp_1443 += tmp_1444;
   tmp_1440 += (std::complex<double>(0,-0.25)*KroneckerDelta(0,gO1)*
      KroneckerDelta(0,gO2)*Sqr(g2)) * tmp_1443;
   std::complex<double> tmp_1445;
   std::complex<double> tmp_1446;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1446 += Conj(ZE(gI2,j1))*ZE(gI1,j1);
   }
   tmp_1445 += tmp_1446;
   tmp_1440 += (std::complex<double>(0,0.15)*KroneckerDelta(1,gO1)*
      KroneckerDelta(1,gO2)*Sqr(g1)) * tmp_1445;
   std::complex<double> tmp_1447;
   std::complex<double> tmp_1448;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1448 += Conj(ZE(gI2,j1))*ZE(gI1,j1);
   }
   tmp_1447 += tmp_1448;
   tmp_1440 += (std::complex<double>(0,0.25)*KroneckerDelta(1,gO1)*
      KroneckerDelta(1,gO2)*Sqr(g2)) * tmp_1447;
   std::complex<double> tmp_1449;
   std::complex<double> tmp_1450;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1450 += Conj(ZE(gI2,j1))*ZE(gI1,j1);
   }
   tmp_1449 += tmp_1450;
   tmp_1440 += (std::complex<double>(0,-0.5)*KroneckerDelta(2,gO1)*
      KroneckerDelta(2,gO2)*Sqr(g2)) * tmp_1449;
   std::complex<double> tmp_1451;
   std::complex<double> tmp_1452;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1452 += Conj(ZE(gI2,j1))*ZE(gI1,j1);
   }
   tmp_1451 += tmp_1452;
   tmp_1440 += (std::complex<double>(0,0.5)*KroneckerDelta(3,gO1)*
      KroneckerDelta(3,gO2)*Sqr(g2)) * tmp_1451;
   std::complex<double> tmp_1453;
   std::complex<double> tmp_1454;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1454 += Conj(ZE(gI2,3 + j1))*ZE(gI1,3 + j1);
   }
   tmp_1453 += tmp_1454;
   tmp_1440 += (std::complex<double>(0,0.3)*KroneckerDelta(0,gO1)*
      KroneckerDelta(0,gO2)*Sqr(g1)) * tmp_1453;
   std::complex<double> tmp_1455;
   std::complex<double> tmp_1456;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1456 += Conj(ZE(gI2,3 + j1))*ZE(gI1,3 + j1);
   }
   tmp_1455 += tmp_1456;
   tmp_1440 += (std::complex<double>(0,-0.3)*KroneckerDelta(1,gO1)*
      KroneckerDelta(1,gO2)*Sqr(g1)) * tmp_1455;
   std::complex<double> tmp_1457;
   std::complex<double> tmp_1458;
   for (unsigned j3 = 0; j3 < 3; ++j3) {
      std::complex<double> tmp_1459;
      std::complex<double> tmp_1460;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         std::complex<double> tmp_1461;
         std::complex<double> tmp_1462;
         for (unsigned j1 = 0; j1 < 3; ++j1) {
            tmp_1462 += Conj(Ye(j3,j1))*Ye(j2,j1);
         }
         tmp_1461 += tmp_1462;
         tmp_1460 += (ZE(gI1,3 + j2)) * tmp_1461;
      }
      tmp_1459 += tmp_1460;
      tmp_1458 += (Conj(ZE(gI2,3 + j3))) * tmp_1459;
   }
   tmp_1457 += tmp_1458;
   tmp_1440 += (std::complex<double>(0,-1)*KroneckerDelta(0,gO1)*KroneckerDelta
      (0,gO2)) * tmp_1457;
   result += (std::complex<double>(0,-1)) * tmp_1440;

   return result;
}

std::complex<double> CLASSNAME::CpUHpmconjUHpmconjSuSu(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1463;
   std::complex<double> tmp_1464;
   std::complex<double> tmp_1465;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1465 += Conj(ZU(gI2,j1))*ZU(gI1,j1);
   }
   tmp_1464 += tmp_1465;
   tmp_1463 += (std::complex<double>(0,0.05)*KroneckerDelta(0,gO1)*
      KroneckerDelta(0,gO2)*Sqr(g1)) * tmp_1464;
   std::complex<double> tmp_1466;
   std::complex<double> tmp_1467;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1467 += Conj(ZU(gI2,j1))*ZU(gI1,j1);
   }
   tmp_1466 += tmp_1467;
   tmp_1463 += (std::complex<double>(0,0.25)*KroneckerDelta(0,gO1)*
      KroneckerDelta(0,gO2)*Sqr(g2)) * tmp_1466;
   std::complex<double> tmp_1468;
   std::complex<double> tmp_1469;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1469 += Conj(ZU(gI2,j1))*ZU(gI1,j1);
   }
   tmp_1468 += tmp_1469;
   tmp_1463 += (std::complex<double>(0,-0.05)*KroneckerDelta(1,gO1)*
      KroneckerDelta(1,gO2)*Sqr(g1)) * tmp_1468;
   std::complex<double> tmp_1470;
   std::complex<double> tmp_1471;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1471 += Conj(ZU(gI2,j1))*ZU(gI1,j1);
   }
   tmp_1470 += tmp_1471;
   tmp_1463 += (std::complex<double>(0,-0.25)*KroneckerDelta(1,gO1)*
      KroneckerDelta(1,gO2)*Sqr(g2)) * tmp_1470;
   std::complex<double> tmp_1472;
   std::complex<double> tmp_1473;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1473 += Conj(ZU(gI2,j1))*ZU(gI1,j1);
   }
   tmp_1472 += tmp_1473;
   tmp_1463 += (std::complex<double>(0,0.5)*KroneckerDelta(2,gO1)*
      KroneckerDelta(2,gO2)*Sqr(g2)) * tmp_1472;
   std::complex<double> tmp_1474;
   std::complex<double> tmp_1475;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1475 += Conj(ZU(gI2,j1))*ZU(gI1,j1);
   }
   tmp_1474 += tmp_1475;
   tmp_1463 += (std::complex<double>(0,-0.5)*KroneckerDelta(3,gO1)*
      KroneckerDelta(3,gO2)*Sqr(g2)) * tmp_1474;
   std::complex<double> tmp_1476;
   std::complex<double> tmp_1477;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1477 += Conj(ZU(gI2,3 + j1))*ZU(gI1,3 + j1);
   }
   tmp_1476 += tmp_1477;
   tmp_1463 += (std::complex<double>(0,-0.2)*KroneckerDelta(0,gO1)*
      KroneckerDelta(0,gO2)*Sqr(g1)) * tmp_1476;
   std::complex<double> tmp_1478;
   std::complex<double> tmp_1479;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1479 += Conj(ZU(gI2,3 + j1))*ZU(gI1,3 + j1);
   }
   tmp_1478 += tmp_1479;
   tmp_1463 += (std::complex<double>(0,0.2)*KroneckerDelta(1,gO1)*
      KroneckerDelta(1,gO2)*Sqr(g1)) * tmp_1478;
   std::complex<double> tmp_1480;
   std::complex<double> tmp_1481;
   for (unsigned j3 = 0; j3 < 3; ++j3) {
      std::complex<double> tmp_1482;
      std::complex<double> tmp_1483;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         std::complex<double> tmp_1484;
         std::complex<double> tmp_1485;
         for (unsigned j1 = 0; j1 < 3; ++j1) {
            tmp_1485 += Conj(Yu(j3,j1))*Yu(j2,j1);
         }
         tmp_1484 += tmp_1485;
         tmp_1483 += (ZU(gI1,3 + j2)) * tmp_1484;
      }
      tmp_1482 += tmp_1483;
      tmp_1481 += (Conj(ZU(gI2,3 + j3))) * tmp_1482;
   }
   tmp_1480 += tmp_1481;
   tmp_1463 += (std::complex<double>(0,-1)*KroneckerDelta(1,gO1)*KroneckerDelta
      (1,gO2)) * tmp_1480;
   std::complex<double> tmp_1486;
   std::complex<double> tmp_1487;
   for (unsigned j3 = 0; j3 < 3; ++j3) {
      std::complex<double> tmp_1488;
      std::complex<double> tmp_1489;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         std::complex<double> tmp_1490;
         std::complex<double> tmp_1491;
         for (unsigned j1 = 0; j1 < 3; ++j1) {
            tmp_1491 += Conj(Yd(j1,j3))*Yd(j1,j2);
         }
         tmp_1490 += tmp_1491;
         tmp_1489 += (Conj(ZU(gI2,j2))) * tmp_1490;
      }
      tmp_1488 += tmp_1489;
      tmp_1487 += (ZU(gI1,j3)) * tmp_1488;
   }
   tmp_1486 += tmp_1487;
   tmp_1463 += (std::complex<double>(0,-1)*KroneckerDelta(0,gO1)*KroneckerDelta
      (0,gO2)) * tmp_1486;
   result += (std::complex<double>(0,-1)) * tmp_1463;

   return result;
}

std::complex<double> CLASSNAME::CpconjUHpmconjSuSd(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1492;
   std::complex<double> tmp_1493;
   std::complex<double> tmp_1494;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1494 += Conj(ZD(gI2,j1))*ZU(gI1,j1);
   }
   tmp_1493 += tmp_1494;
   tmp_1492 += (std::complex<double>(0.,-0.35355339059327373)*vd*KroneckerDelta
      (0,gO2)*Sqr(g2)) * tmp_1493;
   std::complex<double> tmp_1495;
   std::complex<double> tmp_1496;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1496 += Conj(ZD(gI2,j1))*ZU(gI1,j1);
   }
   tmp_1495 += tmp_1496;
   tmp_1492 += (std::complex<double>(0.,-0.35355339059327373)*vu*KroneckerDelta
      (1,gO2)*Sqr(g2)) * tmp_1495;
   std::complex<double> tmp_1497;
   std::complex<double> tmp_1498;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1498 += Conj(ZD(gI2,j1))*ZU(gI1,j1);
   }
   tmp_1497 += tmp_1498;
   tmp_1492 += (std::complex<double>(0,-0.5)*vT*KroneckerDelta(2,gO2)*Sqr(g2))
      * tmp_1497;
   std::complex<double> tmp_1499;
   std::complex<double> tmp_1500;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1500 += Conj(ZD(gI2,j1))*ZU(gI1,j1);
   }
   tmp_1499 += tmp_1500;
   tmp_1492 += (std::complex<double>(0,-1)*g2*Conj(MDWBT)*KroneckerDelta(2,gO2)
      ) * tmp_1499;
   std::complex<double> tmp_1501;
   std::complex<double> tmp_1502;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1502 += Conj(ZD(gI2,j1))*ZU(gI1,j1);
   }
   tmp_1501 += tmp_1502;
   tmp_1492 += (std::complex<double>(0,-1)*g2*MDWBT*KroneckerDelta(3,gO2)) *
      tmp_1501;
   std::complex<double> tmp_1503;
   std::complex<double> tmp_1504;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1504 += Conj(ZD(gI2,j1))*ZU(gI1,j1);
   }
   tmp_1503 += tmp_1504;
   tmp_1492 += (std::complex<double>(0,0.5)*vT*KroneckerDelta(3,gO2)*Sqr(g2)) *
      tmp_1503;
   std::complex<double> tmp_1505;
   std::complex<double> tmp_1506;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_1507;
      std::complex<double> tmp_1508;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1508 += Yu(j1,j2)*ZU(gI1,3 + j1);
      }
      tmp_1507 += tmp_1508;
      tmp_1506 += (Conj(ZD(gI2,j2))) * tmp_1507;
   }
   tmp_1505 += tmp_1506;
   tmp_1492 += (std::complex<double>(0,1)*Conj(Mu)*KroneckerDelta(0,gO2)) *
      tmp_1505;
   std::complex<double> tmp_1509;
   std::complex<double> tmp_1510;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_1511;
      std::complex<double> tmp_1512;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1512 += Conj(Yd(j1,j2))*Conj(ZD(gI2,3 + j1));
      }
      tmp_1511 += tmp_1512;
      tmp_1510 += (ZU(gI1,j2)) * tmp_1511;
   }
   tmp_1509 += tmp_1510;
   tmp_1492 += (std::complex<double>(0,1)*KroneckerDelta(1,gO2)*Mu) * tmp_1509;
   std::complex<double> tmp_1513;
   std::complex<double> tmp_1514;
   for (unsigned j3 = 0; j3 < 3; ++j3) {
      std::complex<double> tmp_1515;
      std::complex<double> tmp_1516;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         std::complex<double> tmp_1517;
         std::complex<double> tmp_1518;
         for (unsigned j1 = 0; j1 < 3; ++j1) {
            tmp_1518 += Conj(Yd(j3,j1))*Yu(j2,j1);
         }
         tmp_1517 += tmp_1518;
         tmp_1516 += (ZU(gI1,3 + j2)) * tmp_1517;
      }
      tmp_1515 += tmp_1516;
      tmp_1514 += (Conj(ZD(gI2,3 + j3))) * tmp_1515;
   }
   tmp_1513 += tmp_1514;
   tmp_1492 += (std::complex<double>(0.,0.7071067811865475)*vu*KroneckerDelta(0
      ,gO2)) * tmp_1513;
   std::complex<double> tmp_1519;
   std::complex<double> tmp_1520;
   for (unsigned j3 = 0; j3 < 3; ++j3) {
      std::complex<double> tmp_1521;
      std::complex<double> tmp_1522;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         std::complex<double> tmp_1523;
         std::complex<double> tmp_1524;
         for (unsigned j1 = 0; j1 < 3; ++j1) {
            tmp_1524 += Conj(Yd(j3,j1))*Yu(j2,j1);
         }
         tmp_1523 += tmp_1524;
         tmp_1522 += (ZU(gI1,3 + j2)) * tmp_1523;
      }
      tmp_1521 += tmp_1522;
      tmp_1520 += (Conj(ZD(gI2,3 + j3))) * tmp_1521;
   }
   tmp_1519 += tmp_1520;
   tmp_1492 += (std::complex<double>(0.,0.7071067811865475)*vd*KroneckerDelta(1
      ,gO2)) * tmp_1519;
   std::complex<double> tmp_1525;
   std::complex<double> tmp_1526;
   for (unsigned j3 = 0; j3 < 3; ++j3) {
      std::complex<double> tmp_1527;
      std::complex<double> tmp_1528;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         std::complex<double> tmp_1529;
         std::complex<double> tmp_1530;
         for (unsigned j1 = 0; j1 < 3; ++j1) {
            tmp_1530 += Conj(Yd(j1,j3))*Yd(j1,j2);
         }
         tmp_1529 += tmp_1530;
         tmp_1528 += (Conj(ZD(gI2,j2))) * tmp_1529;
      }
      tmp_1527 += tmp_1528;
      tmp_1526 += (ZU(gI1,j3)) * tmp_1527;
   }
   tmp_1525 += tmp_1526;
   tmp_1492 += (std::complex<double>(0.,0.7071067811865475)*vd*KroneckerDelta(0
      ,gO2)) * tmp_1525;
   std::complex<double> tmp_1531;
   std::complex<double> tmp_1532;
   for (unsigned j3 = 0; j3 < 3; ++j3) {
      std::complex<double> tmp_1533;
      std::complex<double> tmp_1534;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         std::complex<double> tmp_1535;
         std::complex<double> tmp_1536;
         for (unsigned j1 = 0; j1 < 3; ++j1) {
            tmp_1536 += Conj(Yu(j1,j3))*Yu(j1,j2);
         }
         tmp_1535 += tmp_1536;
         tmp_1534 += (Conj(ZD(gI2,j2))) * tmp_1535;
      }
      tmp_1533 += tmp_1534;
      tmp_1532 += (ZU(gI1,j3)) * tmp_1533;
   }
   tmp_1531 += tmp_1532;
   tmp_1492 += (std::complex<double>(0.,0.7071067811865475)*vu*KroneckerDelta(1
      ,gO2)) * tmp_1531;
   result += (std::complex<double>(0,-1)) * tmp_1492;

   return result;
}

std::complex<double> CLASSNAME::CpconjUHpmVWmAh(unsigned gO2, unsigned gI2) const
{
   std::complex<double> result;

   result = std::complex<double>(0,-0.5)*g2*(KroneckerDelta(0,gO2)*ZA(gI2,0) +
      KroneckerDelta(1,gO2)*ZA(gI2,1) + 1.4142135623730951*(KroneckerDelta(2,gO2)
      - KroneckerDelta(3,gO2))*ZA(gI2,3));

   return result;
}

std::complex<double> CLASSNAME::CpconjUHpmVWmhh(unsigned gO2, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.5*g2*(KroneckerDelta(0,gO2)*ZH(gI2,0) - KroneckerDelta(1,gO2)*ZH(
      gI2,1) + 1.4142135623730951*(KroneckerDelta(2,gO2) + KroneckerDelta(3,gO2))*
      ZH(gI2,3));

   return result;
}

std::complex<double> CLASSNAME::CpconjUHpmVPHpm(unsigned gO2, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.1*(-(KroneckerDelta(0,gO2)*(3.872983346207417*g1*Cos(ThetaW()) +
      5*g2*Sin(ThetaW()))*ZP(gI2,0)) - KroneckerDelta(1,gO2)*(3.872983346207417*g1
      *Cos(ThetaW()) + 5*g2*Sin(ThetaW()))*ZP(gI2,1) - 10*g2*Sin(ThetaW())*(
      KroneckerDelta(2,gO2)*ZP(gI2,2) + KroneckerDelta(3,gO2)*ZP(gI2,3)));

   return result;
}

std::complex<double> CLASSNAME::CpconjUHpmVZHpm(unsigned gO2, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.1*(-(KroneckerDelta(0,gO2)*(5*g2*Cos(ThetaW()) -
      3.872983346207417*g1*Sin(ThetaW()))*ZP(gI2,0)) - KroneckerDelta(1,gO2)*(5*g2
      *Cos(ThetaW()) - 3.872983346207417*g1*Sin(ThetaW()))*ZP(gI2,1) - 10*g2*Cos(
      ThetaW())*(KroneckerDelta(2,gO2)*ZP(gI2,2) + KroneckerDelta(3,gO2)*ZP(gI2,3)
      ));

   return result;
}

std::complex<double> CLASSNAME::CpURpmconjURpmVZVZ(unsigned gO1, unsigned gO2) const
{
   std::complex<double> result;

   result = 0.05*(KroneckerDelta(0,gO1)*KroneckerDelta(0,gO2) + KroneckerDelta(
      1,gO1)*KroneckerDelta(1,gO2))*(-7.745966692414834*g1*g2*Sin(2*ThetaW()) + 3*
      Sqr(g1) + 5*Sqr(g2) + Cos(2*ThetaW())*(-3*Sqr(g1) + 5*Sqr(g2)));

   return result;
}

std::complex<double> CLASSNAME::CpURpmconjURpmconjVWmVWm(unsigned gO1, unsigned gO2) const
{
   std::complex<double> result;

   result = 0.5*(KroneckerDelta(0,gO1)*KroneckerDelta(0,gO2) + KroneckerDelta(1
      ,gO1)*KroneckerDelta(1,gO2))*Sqr(g2);

   return result;
}

std::complex<double> CLASSNAME::CpURpmconjURpmconjRhRh(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.05*(-(KroneckerDelta(1,gO1)*KroneckerDelta(1,gO2)*((3*Sqr(g1) + 5
      *Sqr(g2))*ZHR(gI1,0)*ZHR(gI2,0) + (-3*Sqr(g1) + 5*Sqr(g2))*ZHR(gI1,1)*ZHR(
      gI2,1))) + KroneckerDelta(0,gO1)*KroneckerDelta(0,gO2)*((3*Sqr(g1) - 5*Sqr(
      g2))*ZHR(gI1,0)*ZHR(gI2,0) - (3*Sqr(g1) + 5*Sqr(g2))*ZHR(gI1,1)*ZHR(gI2,1)))
      ;

   return result;
}

std::complex<double> CLASSNAME::CpURpmconjURpmconjRpmRpm(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = -0.05*(3*Sqr(g1) + 5*Sqr(g2))*(-(Conj(ZRP(gI2,1))*(-2*
      KroneckerDelta(1,gO1)*KroneckerDelta(1,gO2)*ZRP(gI1,1) + KroneckerDelta(0,
      gO1)*(KroneckerDelta(1,gO2)*ZRP(gI1,0) + KroneckerDelta(0,gO2)*ZRP(gI1,1))))
      + Conj(ZRP(gI2,0))*(2*KroneckerDelta(0,gO1)*KroneckerDelta(0,gO2)*ZRP(gI1,0
      ) - KroneckerDelta(1,gO1)*(KroneckerDelta(1,gO2)*ZRP(gI1,0) + KroneckerDelta
      (0,gO2)*ZRP(gI1,1))));

   return result;
}

std::complex<double> CLASSNAME::CpconjURpmconjRhVWm(unsigned gO2, unsigned gI1) const
{
   std::complex<double> result;

   result = 0.7071067811865475*g2*KroneckerDelta(1,gO2)*ZHR(gI1,0);

   return result;
}

std::complex<double> CLASSNAME::CpconjURpmconjRhHpm(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = -0.25*KroneckerDelta(1,gO2)*(1.4142135623730951*ZHR(gI1,1)*(2*LamSD
      *vu*Conj(LamSU)*ZP(gI2,0) + LamTD*Conj(LamTU)*(vu*ZP(gI2,0) + 2*vd*ZP(gI2,1)
      )) + ZHR(gI1,0)*(1.4142135623730951*vd*(-2*AbsSqr(LamSD) + AbsSqr(LamTD) +
      Sqr(g2))*ZP(gI2,0) + 1.4142135623730951*vu*Sqr(g2)*ZP(gI2,1) + 4*g2*MDWBT*ZP
      (gI2,2) - 2*vT*AbsSqr(LamTD)*ZP(gI2,2) - 2.8284271247461903*LamTD*vS*Conj(
      LamSD)*ZP(gI2,2) - 4*LamTD*Conj(MuD)*ZP(gI2,2) + 2*vT*Sqr(g2)*ZP(gI2,2) + 2*
      vT*AbsSqr(LamTD)*ZP(gI2,3) - 4*MuD*Conj(LamTD)*ZP(gI2,3) -
      2.8284271247461903*LamSD*vS*Conj(LamTD)*ZP(gI2,3) + 4*g2*Conj(MDWBT)*ZP(gI2,
      3) - 2*vT*Sqr(g2)*ZP(gI2,3)));

   return result;
}

std::complex<double> CLASSNAME::CpconjURpmRhHpm(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = -0.25*KroneckerDelta(0,gO2)*(2.8284271247461903*LamSD*vd*Conj(LamSU
      )*ZHR(gI1,0)*ZP(gI2,1) + ZHR(gI1,1)*(1.4142135623730951*vd*Sqr(g2)*ZP(gI2,0)
      + 1.4142135623730951*vu*(-2*AbsSqr(LamSU) + Sqr(g2))*ZP(gI2,1) + 4*g2*MDWBT
      *ZP(gI2,2) - 2.8284271247461903*LamTU*vS*Conj(LamSU)*ZP(gI2,2) - 4*LamTU*
      Conj(MuU)*ZP(gI2,2) + 2*vT*Sqr(g2)*ZP(gI2,2) + 4*g2*Conj(MDWBT)*ZP(gI2,3) -
      2*vT*Sqr(g2)*ZP(gI2,3)) + Conj(LamTU)*(1.4142135623730951*LamTD*ZHR(gI1,0)*(
      2*vu*ZP(gI2,0) + vd*ZP(gI2,1)) + ZHR(gI1,1)*(1.4142135623730951*LamTU*vu*ZP(
      gI2,1) - 2*(LamTU*vT*ZP(gI2,2) + (2*MuU + 1.4142135623730951*LamSU*vS -
      LamTU*vT)*ZP(gI2,3)))));

   return result;
}

std::complex<double> CLASSNAME::CpconjURpmRpmAh(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = std::complex<double>(0,0.05)*(Conj(ZRP(gI1,1))*KroneckerDelta(1,gO2
      )*((-7.745966692414834*g1*MDBS + 7.0710678118654755*(2*MuD - LamTD*vT)*Conj(
      LamSD) + 7.0710678118654755*LamSD*vT*Conj(LamTD) + 7.745966692414834*g1*Conj
      (MDBS) - 14.142135623730951*LamSD*Conj(MuD))*ZA(gI2,2) - 5*(2*g2*MDWBT -
      1.4142135623730951*LamTD*vS*Conj(LamSD) + 2*MuD*Conj(LamTD) +
      1.4142135623730951*LamSD*vS*Conj(LamTD) - 2*g2*Conj(MDWBT) - 2*LamTD*Conj(
      MuD))*ZA(gI2,3)) + Conj(ZRP(gI1,0))*KroneckerDelta(0,gO2)*((
      7.745966692414834*g1*MDBS + 7.0710678118654755*(2*MuU + LamTU*vT)*Conj(LamSU
      ) - 7.0710678118654755*LamSU*vT*Conj(LamTU) - 7.745966692414834*g1*Conj(MDBS
      ) - 14.142135623730951*LamSU*Conj(MuU))*ZA(gI2,2) + 5*(2*g2*MDWBT -
      1.4142135623730951*LamTU*vS*Conj(LamSU) + 2*MuU*Conj(LamTU) +
      1.4142135623730951*LamSU*vS*Conj(LamTU) - 2*g2*Conj(MDWBT) - 2*LamTU*Conj(
      MuU))*ZA(gI2,3)));

   return result;
}

std::complex<double> CLASSNAME::CpconjURpmRpmhh(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.05*(Conj(ZRP(gI1,1))*KroneckerDelta(1,gO2)*(vd*(-20*AbsSqr(LamTD)
      + 3*Sqr(g1) - 5*Sqr(g2))*ZH(gI2,0) + (-3*vu*Sqr(g1) + 5*vu*Sqr(g2))*ZH(gI2,
      1) - 7.745966692414834*g1*MDBS*ZH(gI2,2) - 20*vS*AbsSqr(LamSD)*ZH(gI2,2) -
      14.142135623730951*MuD*Conj(LamSD)*ZH(gI2,2) + 7.0710678118654755*LamTD*vT*
      Conj(LamSD)*ZH(gI2,2) + 7.0710678118654755*LamSD*vT*Conj(LamTD)*ZH(gI2,2) -
      7.745966692414834*g1*Conj(MDBS)*ZH(gI2,2) - 14.142135623730951*LamSD*Conj(
      MuD)*ZH(gI2,2) - 10*g2*MDWBT*ZH(gI2,3) - 10*vT*AbsSqr(LamTD)*ZH(gI2,3) +
      7.0710678118654755*LamTD*vS*Conj(LamSD)*ZH(gI2,3) + 10*MuD*Conj(LamTD)*ZH(
      gI2,3) + 7.0710678118654755*LamSD*vS*Conj(LamTD)*ZH(gI2,3) - 10*g2*Conj(
      MDWBT)*ZH(gI2,3) + 10*LamTD*Conj(MuD)*ZH(gI2,3)) - Conj(ZRP(gI1,0))*
      KroneckerDelta(0,gO2)*(vd*(3*Sqr(g1) - 5*Sqr(g2))*ZH(gI2,0) + vu*(20*AbsSqr(
      LamTU) - 3*Sqr(g1) + 5*Sqr(g2))*ZH(gI2,1) - 7.745966692414834*g1*MDBS*ZH(gI2
      ,2) + 20*vS*AbsSqr(LamSU)*ZH(gI2,2) + 14.142135623730951*MuU*Conj(LamSU)*ZH(
      gI2,2) + 7.0710678118654755*LamTU*vT*Conj(LamSU)*ZH(gI2,2) +
      7.0710678118654755*LamSU*vT*Conj(LamTU)*ZH(gI2,2) - 7.745966692414834*g1*
      Conj(MDBS)*ZH(gI2,2) + 14.142135623730951*LamSU*Conj(MuU)*ZH(gI2,2) - 10*g2*
      MDWBT*ZH(gI2,3) + 10*vT*AbsSqr(LamTU)*ZH(gI2,3) + 7.0710678118654755*LamTU*
      vS*Conj(LamSU)*ZH(gI2,3) + 10*MuU*Conj(LamTU)*ZH(gI2,3) + 7.0710678118654755
      *LamSU*vS*Conj(LamTU)*ZH(gI2,3) - 10*g2*Conj(MDWBT)*ZH(gI2,3) + 10*LamTU*
      Conj(MuU)*ZH(gI2,3)));

   return result;
}

std::complex<double> CLASSNAME::CpURpmconjURpmconjSvSv(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = -0.05*(KroneckerDelta(0,gO1)*KroneckerDelta(0,gO2) - KroneckerDelta
      (1,gO1)*KroneckerDelta(1,gO2))*KroneckerDelta(gI1,gI2)*(3*Sqr(g1) - 5*Sqr(g2
      ));

   return result;
}

std::complex<double> CLASSNAME::CpconjURpmconjSvSe(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1537;
   std::complex<double> tmp_1538;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_1539;
      std::complex<double> tmp_1540;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1540 += Conj(Ye(j1,j2))*Conj(ZE(gI2,3 + j1));
      }
      tmp_1539 += tmp_1540;
      tmp_1538 += (ZV(gI1,j2)) * tmp_1539;
   }
   tmp_1537 += tmp_1538;
   result += (0.5*(2*MuD + 1.4142135623730951*LamSD*vS - LamTD*vT)*
      KroneckerDelta(1,gO2)) * tmp_1537;

   return result;
}

std::complex<double> CLASSNAME::CpURpmconjURpmAhAh(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.05*(KroneckerDelta(1,gO1)*KroneckerDelta(1,gO2)*((-20*AbsSqr(
      LamTD) + 3*Sqr(g1) - 5*Sqr(g2))*ZA(gI1,0)*ZA(gI2,0) + (-3*Sqr(g1) + 5*Sqr(g2
      ))*ZA(gI1,1)*ZA(gI2,1) + 5*(Conj(LamTD)*(1.4142135623730951*LamSD*ZA(gI1,2)*
      ZA(gI2,3) + ZA(gI1,3)*(1.4142135623730951*LamSD*ZA(gI2,2) - 2*LamTD*ZA(gI2,3
      ))) + Conj(LamSD)*(1.4142135623730951*LamTD*ZA(gI1,3)*ZA(gI2,2) + ZA(gI1,2)*
      (-4*LamSD*ZA(gI2,2) + 1.4142135623730951*LamTD*ZA(gI2,3))))) -
      KroneckerDelta(0,gO1)*KroneckerDelta(0,gO2)*((3*Sqr(g1) - 5*Sqr(g2))*ZA(gI1,
      0)*ZA(gI2,0) + (20*AbsSqr(LamTU) - 3*Sqr(g1) + 5*Sqr(g2))*ZA(gI1,1)*ZA(gI2,1
      ) + 5*(Conj(LamSU)*(1.4142135623730951*LamTU*ZA(gI1,3)*ZA(gI2,2) + ZA(gI1,2)
      *(4*LamSU*ZA(gI2,2) + 1.4142135623730951*LamTU*ZA(gI2,3))) + Conj(LamTU)*(
      1.4142135623730951*LamSU*ZA(gI1,2)*ZA(gI2,3) + ZA(gI1,3)*(1.4142135623730951
      *LamSU*ZA(gI2,2) + 2*LamTU*ZA(gI2,3))))));

   return result;
}

std::complex<double> CLASSNAME::CpURpmconjURpmconjHpmHpm(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.05*(KroneckerDelta(1,gO1)*KroneckerDelta(1,gO2)*((-20*AbsSqr(
      LamSD) - 10*AbsSqr(LamTD) + 3*Sqr(g1) + 5*Sqr(g2))*ZP(gI1,0)*ZP(gI2,0) - (3*
      Sqr(g1) + 5*Sqr(g2))*ZP(gI1,1)*ZP(gI2,1) + 10*((-2*AbsSqr(LamTD) + Sqr(g2))*
      ZP(gI1,2)*ZP(gI2,2) - Sqr(g2)*ZP(gI1,3)*ZP(gI2,3))) - KroneckerDelta(0,gO1)*
      KroneckerDelta(0,gO2)*((3*Sqr(g1) + 5*Sqr(g2))*ZP(gI1,0)*ZP(gI2,0) + (20*
      AbsSqr(LamSU) + 10*AbsSqr(LamTU) - 3*Sqr(g1) - 5*Sqr(g2))*ZP(gI1,1)*ZP(gI2,1
      ) + 10*(Sqr(g2)*ZP(gI1,2)*ZP(gI2,2) - (-2*AbsSqr(LamTU) + Sqr(g2))*ZP(gI1,3)
      *ZP(gI2,3))));

   return result;
}

std::complex<double> CLASSNAME::CpURpmconjURpmhhhh(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.05*(KroneckerDelta(1,gO1)*KroneckerDelta(1,gO2)*((-20*AbsSqr(
      LamTD) + 3*Sqr(g1) - 5*Sqr(g2))*ZH(gI1,0)*ZH(gI2,0) + (-3*Sqr(g1) + 5*Sqr(g2
      ))*ZH(gI1,1)*ZH(gI2,1) + 5*(Conj(LamTD)*(1.4142135623730951*LamSD*ZH(gI1,2)*
      ZH(gI2,3) + ZH(gI1,3)*(1.4142135623730951*LamSD*ZH(gI2,2) - 2*LamTD*ZH(gI2,3
      ))) + Conj(LamSD)*(1.4142135623730951*LamTD*ZH(gI1,3)*ZH(gI2,2) + ZH(gI1,2)*
      (-4*LamSD*ZH(gI2,2) + 1.4142135623730951*LamTD*ZH(gI2,3))))) -
      KroneckerDelta(0,gO1)*KroneckerDelta(0,gO2)*((3*Sqr(g1) - 5*Sqr(g2))*ZH(gI1,
      0)*ZH(gI2,0) + (20*AbsSqr(LamTU) - 3*Sqr(g1) + 5*Sqr(g2))*ZH(gI1,1)*ZH(gI2,1
      ) + 5*(Conj(LamSU)*(1.4142135623730951*LamTU*ZH(gI1,3)*ZH(gI2,2) + ZH(gI1,2)
      *(4*LamSU*ZH(gI2,2) + 1.4142135623730951*LamTU*ZH(gI2,3))) + Conj(LamTU)*(
      1.4142135623730951*LamSU*ZH(gI1,2)*ZH(gI2,3) + ZH(gI1,3)*(1.4142135623730951
      *LamSU*ZH(gI2,2) + 2*LamTU*ZH(gI2,3))))));

   return result;
}

std::complex<double> CLASSNAME::CpconjURpmbarChibarCha1PR(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = -0.5*KroneckerDelta(1,gO2)*(UP1(gI2,1)*(1.0954451150103321*g1*ZN1(
      gI1,0) + 1.4142135623730951*g2*ZN1(gI1,1)) + 2*g2*UP1(gI2,0)*ZN1(gI1,2));

   return result;
}

std::complex<double> CLASSNAME::CpconjURpmbarChibarCha1PL(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = -0.5*(Conj(UM1(gI2,1))*(2*LamSD*Conj(ZN2(gI1,0)) -
      1.4142135623730951*LamTD*Conj(ZN2(gI1,1))) + 2*LamTD*Conj(UM1(gI2,0))*Conj(
      ZN2(gI1,2)))*KroneckerDelta(1,gO1);

   return result;
}

std::complex<double> CLASSNAME::CpconjURpmChiCha2PR(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.5*KroneckerDelta(0,gO2)*(2*Conj(LamSU)*UP2(gI2,1)*ZN2(gI1,0) +
      Conj(LamTU)*(1.4142135623730951*UP2(gI2,1)*ZN2(gI1,1) + 2*UP2(gI2,0)*ZN2(gI1
      ,3)));

   return result;
}

std::complex<double> CLASSNAME::CpconjURpmChiCha2PL(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.5*(Conj(UM2(gI2,1))*(1.0954451150103321*g1*Conj(ZN1(gI1,0)) +
      1.4142135623730951*g2*Conj(ZN1(gI1,1))) - 2*g2*Conj(UM2(gI2,0))*Conj(ZN1(gI1
      ,3)))*KroneckerDelta(0,gO1);

   return result;
}

std::complex<double> CLASSNAME::CpconjURpmHpmAh(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = std::complex<double>(0,-0.5)*(1.4142135623730951*Conj(LamSU)*
      KroneckerDelta(0,gO2)*Mu*ZA(gI2,2)*ZP(gI1,0) + Conj(Mu)*KroneckerDelta(1,gO2
      )*(1.4142135623730951*LamSD*ZA(gI2,2)*ZP(gI1,1) - LamTD*ZA(gI2,3)*ZP(gI1,1)
      + 1.4142135623730951*LamTD*ZA(gI2,1)*ZP(gI1,2)) + Conj(LamTU)*KroneckerDelta
      (0,gO2)*Mu*(ZA(gI2,3)*ZP(gI1,0) + 1.4142135623730951*ZA(gI2,0)*ZP(gI1,3)));

   return result;
}

std::complex<double> CLASSNAME::CpconjURpmHpmhh(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.5*(1.4142135623730951*Conj(LamSU)*KroneckerDelta(0,gO2)*Mu*ZH(gI2
      ,2)*ZP(gI1,0) + Conj(Mu)*KroneckerDelta(1,gO2)*(-1.4142135623730951*LamSD*ZH
      (gI2,2)*ZP(gI1,1) + LamTD*ZH(gI2,3)*ZP(gI1,1) + 1.4142135623730951*LamTD*ZH(
      gI2,1)*ZP(gI1,2)) + Conj(LamTU)*KroneckerDelta(0,gO2)*Mu*(ZH(gI2,3)*ZP(gI1,0
      ) - 1.4142135623730951*ZH(gI2,0)*ZP(gI1,3)));

   return result;
}

std::complex<double> CLASSNAME::CpURpmconjURpmconjSdSd(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1541;
   std::complex<double> tmp_1542;
   std::complex<double> tmp_1543;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1543 += Conj(ZD(gI2,j1))*ZD(gI1,j1);
   }
   tmp_1542 += tmp_1543;
   tmp_1541 += (std::complex<double>(0,0.05)*KroneckerDelta(0,gO1)*
      KroneckerDelta(0,gO2)*Sqr(g1)) * tmp_1542;
   std::complex<double> tmp_1544;
   std::complex<double> tmp_1545;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1545 += Conj(ZD(gI2,j1))*ZD(gI1,j1);
   }
   tmp_1544 += tmp_1545;
   tmp_1541 += (std::complex<double>(0,-0.25)*KroneckerDelta(0,gO1)*
      KroneckerDelta(0,gO2)*Sqr(g2)) * tmp_1544;
   std::complex<double> tmp_1546;
   std::complex<double> tmp_1547;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1547 += Conj(ZD(gI2,j1))*ZD(gI1,j1);
   }
   tmp_1546 += tmp_1547;
   tmp_1541 += (std::complex<double>(0,-0.05)*KroneckerDelta(1,gO1)*
      KroneckerDelta(1,gO2)*Sqr(g1)) * tmp_1546;
   std::complex<double> tmp_1548;
   std::complex<double> tmp_1549;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1549 += Conj(ZD(gI2,j1))*ZD(gI1,j1);
   }
   tmp_1548 += tmp_1549;
   tmp_1541 += (std::complex<double>(0,0.25)*KroneckerDelta(1,gO1)*
      KroneckerDelta(1,gO2)*Sqr(g2)) * tmp_1548;
   std::complex<double> tmp_1550;
   std::complex<double> tmp_1551;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1551 += Conj(ZD(gI2,3 + j1))*ZD(gI1,3 + j1);
   }
   tmp_1550 += tmp_1551;
   tmp_1541 += (std::complex<double>(0,0.1)*KroneckerDelta(0,gO1)*
      KroneckerDelta(0,gO2)*Sqr(g1)) * tmp_1550;
   std::complex<double> tmp_1552;
   std::complex<double> tmp_1553;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1553 += Conj(ZD(gI2,3 + j1))*ZD(gI1,3 + j1);
   }
   tmp_1552 += tmp_1553;
   tmp_1541 += (std::complex<double>(0,-0.1)*KroneckerDelta(1,gO1)*
      KroneckerDelta(1,gO2)*Sqr(g1)) * tmp_1552;
   result += (std::complex<double>(0,-1)) * tmp_1541;

   return result;
}

std::complex<double> CLASSNAME::CpURpmconjURpmconjSeSe(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1554;
   std::complex<double> tmp_1555;
   std::complex<double> tmp_1556;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1556 += Conj(ZE(gI2,j1))*ZE(gI1,j1);
   }
   tmp_1555 += tmp_1556;
   tmp_1554 += (std::complex<double>(0,-0.15)*KroneckerDelta(0,gO1)*
      KroneckerDelta(0,gO2)*Sqr(g1)) * tmp_1555;
   std::complex<double> tmp_1557;
   std::complex<double> tmp_1558;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1558 += Conj(ZE(gI2,j1))*ZE(gI1,j1);
   }
   tmp_1557 += tmp_1558;
   tmp_1554 += (std::complex<double>(0,-0.25)*KroneckerDelta(0,gO1)*
      KroneckerDelta(0,gO2)*Sqr(g2)) * tmp_1557;
   std::complex<double> tmp_1559;
   std::complex<double> tmp_1560;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1560 += Conj(ZE(gI2,j1))*ZE(gI1,j1);
   }
   tmp_1559 += tmp_1560;
   tmp_1554 += (std::complex<double>(0,0.15)*KroneckerDelta(1,gO1)*
      KroneckerDelta(1,gO2)*Sqr(g1)) * tmp_1559;
   std::complex<double> tmp_1561;
   std::complex<double> tmp_1562;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1562 += Conj(ZE(gI2,j1))*ZE(gI1,j1);
   }
   tmp_1561 += tmp_1562;
   tmp_1554 += (std::complex<double>(0,0.25)*KroneckerDelta(1,gO1)*
      KroneckerDelta(1,gO2)*Sqr(g2)) * tmp_1561;
   std::complex<double> tmp_1563;
   std::complex<double> tmp_1564;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1564 += Conj(ZE(gI2,3 + j1))*ZE(gI1,3 + j1);
   }
   tmp_1563 += tmp_1564;
   tmp_1554 += (std::complex<double>(0,0.3)*KroneckerDelta(0,gO1)*
      KroneckerDelta(0,gO2)*Sqr(g1)) * tmp_1563;
   std::complex<double> tmp_1565;
   std::complex<double> tmp_1566;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1566 += Conj(ZE(gI2,3 + j1))*ZE(gI1,3 + j1);
   }
   tmp_1565 += tmp_1566;
   tmp_1554 += (std::complex<double>(0,-0.3)*KroneckerDelta(1,gO1)*
      KroneckerDelta(1,gO2)*Sqr(g1)) * tmp_1565;
   result += (std::complex<double>(0,-1)) * tmp_1554;

   return result;
}

std::complex<double> CLASSNAME::CpURpmconjURpmconjSuSu(unsigned gO1, unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1567;
   std::complex<double> tmp_1568;
   std::complex<double> tmp_1569;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1569 += Conj(ZU(gI2,j1))*ZU(gI1,j1);
   }
   tmp_1568 += tmp_1569;
   tmp_1567 += (std::complex<double>(0,0.05)*KroneckerDelta(0,gO1)*
      KroneckerDelta(0,gO2)*Sqr(g1)) * tmp_1568;
   std::complex<double> tmp_1570;
   std::complex<double> tmp_1571;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1571 += Conj(ZU(gI2,j1))*ZU(gI1,j1);
   }
   tmp_1570 += tmp_1571;
   tmp_1567 += (std::complex<double>(0,0.25)*KroneckerDelta(0,gO1)*
      KroneckerDelta(0,gO2)*Sqr(g2)) * tmp_1570;
   std::complex<double> tmp_1572;
   std::complex<double> tmp_1573;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1573 += Conj(ZU(gI2,j1))*ZU(gI1,j1);
   }
   tmp_1572 += tmp_1573;
   tmp_1567 += (std::complex<double>(0,-0.05)*KroneckerDelta(1,gO1)*
      KroneckerDelta(1,gO2)*Sqr(g1)) * tmp_1572;
   std::complex<double> tmp_1574;
   std::complex<double> tmp_1575;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1575 += Conj(ZU(gI2,j1))*ZU(gI1,j1);
   }
   tmp_1574 += tmp_1575;
   tmp_1567 += (std::complex<double>(0,-0.25)*KroneckerDelta(1,gO1)*
      KroneckerDelta(1,gO2)*Sqr(g2)) * tmp_1574;
   std::complex<double> tmp_1576;
   std::complex<double> tmp_1577;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1577 += Conj(ZU(gI2,3 + j1))*ZU(gI1,3 + j1);
   }
   tmp_1576 += tmp_1577;
   tmp_1567 += (std::complex<double>(0,-0.2)*KroneckerDelta(0,gO1)*
      KroneckerDelta(0,gO2)*Sqr(g1)) * tmp_1576;
   std::complex<double> tmp_1578;
   std::complex<double> tmp_1579;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1579 += Conj(ZU(gI2,3 + j1))*ZU(gI1,3 + j1);
   }
   tmp_1578 += tmp_1579;
   tmp_1567 += (std::complex<double>(0,0.2)*KroneckerDelta(1,gO1)*
      KroneckerDelta(1,gO2)*Sqr(g1)) * tmp_1578;
   result += (std::complex<double>(0,-1)) * tmp_1567;

   return result;
}

std::complex<double> CLASSNAME::CpconjURpmconjSuSd(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1580;
   std::complex<double> tmp_1581;
   std::complex<double> tmp_1582;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_1583;
      std::complex<double> tmp_1584;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1584 += Yu(j1,j2)*ZU(gI1,3 + j1);
      }
      tmp_1583 += tmp_1584;
      tmp_1582 += (Conj(ZD(gI2,j2))) * tmp_1583;
   }
   tmp_1581 += tmp_1582;
   tmp_1580 += (std::complex<double>(0.,-0.7071067811865475)*vS*Conj(LamSU)*
      KroneckerDelta(0,gO2)) * tmp_1581;
   std::complex<double> tmp_1585;
   std::complex<double> tmp_1586;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_1587;
      std::complex<double> tmp_1588;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1588 += Yu(j1,j2)*ZU(gI1,3 + j1);
      }
      tmp_1587 += tmp_1588;
      tmp_1586 += (Conj(ZD(gI2,j2))) * tmp_1587;
   }
   tmp_1585 += tmp_1586;
   tmp_1580 += (std::complex<double>(0,-0.5)*vT*Conj(LamTU)*KroneckerDelta(0,
      gO2)) * tmp_1585;
   std::complex<double> tmp_1589;
   std::complex<double> tmp_1590;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_1591;
      std::complex<double> tmp_1592;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1592 += Yu(j1,j2)*ZU(gI1,3 + j1);
      }
      tmp_1591 += tmp_1592;
      tmp_1590 += (Conj(ZD(gI2,j2))) * tmp_1591;
   }
   tmp_1589 += tmp_1590;
   tmp_1580 += (std::complex<double>(0,-1)*Conj(MuU)*KroneckerDelta(0,gO2)) *
      tmp_1589;
   std::complex<double> tmp_1593;
   std::complex<double> tmp_1594;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_1595;
      std::complex<double> tmp_1596;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1596 += Conj(Yd(j1,j2))*Conj(ZD(gI2,3 + j1));
      }
      tmp_1595 += tmp_1596;
      tmp_1594 += (ZU(gI1,j2)) * tmp_1595;
   }
   tmp_1593 += tmp_1594;
   tmp_1580 += (std::complex<double>(0,1)*MuD*KroneckerDelta(1,gO2)) * tmp_1593
      ;
   std::complex<double> tmp_1597;
   std::complex<double> tmp_1598;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_1599;
      std::complex<double> tmp_1600;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1600 += Conj(Yd(j1,j2))*Conj(ZD(gI2,3 + j1));
      }
      tmp_1599 += tmp_1600;
      tmp_1598 += (ZU(gI1,j2)) * tmp_1599;
   }
   tmp_1597 += tmp_1598;
   tmp_1580 += (std::complex<double>(0.,0.7071067811865475)*LamSD*vS*
      KroneckerDelta(1,gO2)) * tmp_1597;
   std::complex<double> tmp_1601;
   std::complex<double> tmp_1602;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_1603;
      std::complex<double> tmp_1604;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1604 += Conj(Yd(j1,j2))*Conj(ZD(gI2,3 + j1));
      }
      tmp_1603 += tmp_1604;
      tmp_1602 += (ZU(gI1,j2)) * tmp_1603;
   }
   tmp_1601 += tmp_1602;
   tmp_1580 += (std::complex<double>(0,-0.5)*LamTD*vT*KroneckerDelta(1,gO2)) *
      tmp_1601;
   result += (std::complex<double>(0,-1)) * tmp_1580;

   return result;
}

std::complex<double> CLASSNAME::CpconjURpmVWmRh(unsigned gO2, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.7071067811865475*g2*KroneckerDelta(0,gO2)*ZHR(gI2,1);

   return result;
}

std::complex<double> CLASSNAME::CpconjURpmVPRpm(unsigned gO2, unsigned gI2) const
{
   std::complex<double> result;

   if (gI2 < 2) {
      result += -0.3872983346207417*g1*Conj(ZRP(gI2,gO2))*Cos(ThetaW());
   }
   if (gI2 < 2) {
      result += -0.5*g2*Conj(ZRP(gI2,gO2))*Sin(ThetaW());
   }

   return result;
}

std::complex<double> CLASSNAME::CpconjURpmVZRpm(unsigned gO2, unsigned gI2) const
{
   std::complex<double> result;

   if (gI2 < 2) {
      result += -0.5*g2*Conj(ZRP(gI2,gO2))*Cos(ThetaW());
   }
   if (gI2 < 2) {
      result += 0.3872983346207417*g1*Conj(ZRP(gI2,gO2))*Sin(ThetaW());
   }

   return result;
}

double CLASSNAME::CpSOcconjSOcconjSOcSOc() const
{
   double result = 0.0;

   result = -128*Sqr(g3);

   return result;
}

std::complex<double> CLASSNAME::CpconjSOcVGSOc() const
{
   std::complex<double> result;

   result = std::complex<double>(0,-1)*g3;

   return result;
}

std::complex<double> CLASSNAME::CpSOcconjSOcconjSdSd(unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1605;
   std::complex<double> tmp_1606;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1606 += Conj(ZD(gI2,j1))*ZD(gI1,j1);
   }
   tmp_1605 += tmp_1606;
   std::complex<double> tmp_1607;
   std::complex<double> tmp_1608;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1608 += Conj(ZD(gI2,3 + j1))*ZD(gI1,3 + j1);
   }
   tmp_1607 += tmp_1608;
   tmp_1605 += (-1) * tmp_1607;
   result += (std::complex<double>(0,-24)*Sqr(g3)) * tmp_1605;

   return result;
}

std::complex<double> CLASSNAME::CpSOcconjSOcconjSuSu(unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1609;
   std::complex<double> tmp_1610;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1610 += Conj(ZU(gI2,j1))*ZU(gI1,j1);
   }
   tmp_1609 += tmp_1610;
   std::complex<double> tmp_1611;
   std::complex<double> tmp_1612;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1612 += Conj(ZU(gI2,3 + j1))*ZU(gI1,3 + j1);
   }
   tmp_1611 += tmp_1612;
   tmp_1609 += (-1) * tmp_1611;
   result += (std::complex<double>(0,-24)*Sqr(g3)) * tmp_1609;

   return result;
}

std::complex<double> CLASSNAME::CpconjSOcconjSdSd(unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1613;
   std::complex<double> tmp_1614;
   std::complex<double> tmp_1615;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1615 += Conj(ZD(gI2,j1))*ZD(gI1,j1);
   }
   tmp_1614 += tmp_1615;
   tmp_1613 += (-1) * tmp_1614;
   std::complex<double> tmp_1616;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1616 += Conj(ZD(gI2,3 + j1))*ZD(gI1,3 + j1);
   }
   tmp_1613 += tmp_1616;
   result += (1.4142135623730951*g3*Conj(MDGoc)) * tmp_1613;

   return result;
}

std::complex<double> CLASSNAME::CpconjSOcconjSuSu(unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1617;
   std::complex<double> tmp_1618;
   std::complex<double> tmp_1619;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1619 += Conj(ZU(gI2,j1))*ZU(gI1,j1);
   }
   tmp_1618 += tmp_1619;
   tmp_1617 += (-1) * tmp_1618;
   std::complex<double> tmp_1620;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1620 += Conj(ZU(gI2,3 + j1))*ZU(gI1,3 + j1);
   }
   tmp_1617 += tmp_1620;
   result += (1.4142135623730951*g3*Conj(MDGoc)) * tmp_1617;

   return result;
}

double CLASSNAME::CpconjSOcbarGluGluPR(unsigned , unsigned ) const
{
   double result = 0.0;

   result = 0;

   return result;
}

std::complex<double> CLASSNAME::CpconjSOcbarGluGluPL(unsigned , unsigned ) const
{
   std::complex<double> result;

   result = std::complex<double>(0.,1.4142135623730951)*g3;

   return result;
}

double CLASSNAME::CpVZbargWmgWm() const
{
   double result = 0.0;

   result = -(g2*Cos(ThetaW()));

   return result;
}

double CLASSNAME::CpVZbargWmCgWmC() const
{
   double result = 0.0;

   result = g2*Cos(ThetaW());

   return result;
}

double CLASSNAME::CpVZconjVWmVWm() const
{
   double result = 0.0;

   result = -(g2*Cos(ThetaW()));

   return result;
}

std::complex<double> CLASSNAME::CpVZVZconjRhRh(unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.05*(7.745966692414834*g1*g2*Sin(2*ThetaW()) + 3*Sqr(g1) + 5*Sqr(
      g2) + Cos(2*ThetaW())*(-3*Sqr(g1) + 5*Sqr(g2)))*(ZHR(gI1,0)*ZHR(gI2,0) + ZHR
      (gI1,1)*ZHR(gI2,1));

   return result;
}

std::complex<double> CLASSNAME::CpVZVZconjRpmRpm(unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.05*(-7.745966692414834*g1*g2*Sin(2*ThetaW()) + 3*Sqr(g1) + 5*Sqr(
      g2) + Cos(2*ThetaW())*(-3*Sqr(g1) + 5*Sqr(g2)))*(Conj(ZRP(gI2,0))*ZRP(gI1,0)
      + Conj(ZRP(gI2,1))*ZRP(gI1,1));

   return result;
}

std::complex<double> CLASSNAME::CpVZconjRhRh(unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = -0.5*(g2*Cos(ThetaW()) + 0.7745966692414834*g1*Sin(ThetaW()))*(ZHR(
      gI1,0)*ZHR(gI2,0) - ZHR(gI1,1)*ZHR(gI2,1));

   return result;
}

double CLASSNAME::CpVZconjRpmRpm(unsigned gI1, unsigned gI2) const
{
   double result = 0.0;

   result = 0.1*KroneckerDelta(gI1,gI2)*(-5*g2*Cos(ThetaW()) +
      3.872983346207417*g1*Sin(ThetaW()));

   return result;
}

std::complex<double> CLASSNAME::CpVZbarCha1Cha1PL(unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.1*(-10*g2*Conj(UP1(gI2,0))*Cos(ThetaW())*UP1(gI1,0) + Conj(UP1(
      gI2,1))*(-5*g2*Cos(ThetaW()) + 3.872983346207417*g1*Sin(ThetaW()))*UP1(gI1,1
      ));

   return result;
}

std::complex<double> CLASSNAME::CpVZbarCha1Cha1PR(unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.1*(-10*g2*Conj(UM1(gI1,0))*Cos(ThetaW())*UM1(gI2,0) + Conj(UM1(
      gI1,1))*(-5*g2*Cos(ThetaW()) + 3.872983346207417*g1*Sin(ThetaW()))*UM1(gI2,1
      ));

   return result;
}

std::complex<double> CLASSNAME::CpVZbarCha2Cha2PL(unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.5*(2*g2*Conj(UM2(gI2,0))*Cos(ThetaW())*UM2(gI1,0) + Conj(UM2(gI2,
      1))*(g2*Cos(ThetaW()) - 0.7745966692414834*g1*Sin(ThetaW()))*UM2(gI1,1));

   return result;
}

std::complex<double> CLASSNAME::CpVZbarCha2Cha2PR(unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.5*(2*g2*Conj(UP2(gI1,0))*Cos(ThetaW())*UP2(gI2,0) + Conj(UP2(gI1,
      1))*(g2*Cos(ThetaW()) - 0.7745966692414834*g1*Sin(ThetaW()))*UP2(gI2,1));

   return result;
}

std::complex<double> CLASSNAME::CpVZVZconjSvSv(unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.1*KroneckerDelta(gI1,gI2)*(g1*Sin(ThetaW())*(7.745966692414834*g2
      *Cos(ThetaW()) + 3*g1*Sin(ThetaW())) + 5*Sqr(g2)*Sqr(Cos(ThetaW())));

   return result;
}

double CLASSNAME::CpVZconjSvSv(unsigned gI1, unsigned gI2) const
{
   double result = 0.0;

   result = 0.5*KroneckerDelta(gI1,gI2)*(g2*Cos(ThetaW()) + 0.7745966692414834*
      g1*Sin(ThetaW()));

   return result;
}

double CLASSNAME::CpVZbarFdFdPL(unsigned gI1, unsigned gI2) const
{
   double result = 0.0;

   result = 0.16666666666666666*KroneckerDelta(gI1,gI2)*(3*g2*Cos(ThetaW()) +
      0.7745966692414834*g1*Sin(ThetaW()));

   return result;
}

double CLASSNAME::CpVZbarFdFdPR(unsigned gI1, unsigned gI2) const
{
   double result = 0.0;

   result = -0.2581988897471611*g1*KroneckerDelta(gI1,gI2)*Sin(ThetaW());

   return result;
}

double CLASSNAME::CpVZbarFeFePL(unsigned gI1, unsigned gI2) const
{
   double result = 0.0;

   result = 0.5*KroneckerDelta(gI1,gI2)*(g2*Cos(ThetaW()) - 0.7745966692414834*
      g1*Sin(ThetaW()));

   return result;
}

double CLASSNAME::CpVZbarFeFePR(unsigned gI1, unsigned gI2) const
{
   double result = 0.0;

   result = -0.7745966692414834*g1*KroneckerDelta(gI1,gI2)*Sin(ThetaW());

   return result;
}

double CLASSNAME::CpVZbarFuFuPL(unsigned gI1, unsigned gI2) const
{
   double result = 0.0;

   result = 0.03333333333333333*KroneckerDelta(gI1,gI2)*(-15*g2*Cos(ThetaW()) +
      3.872983346207417*g1*Sin(ThetaW()));

   return result;
}

double CLASSNAME::CpVZbarFuFuPR(unsigned gI1, unsigned gI2) const
{
   double result = 0.0;

   result = 0.5163977794943222*g1*KroneckerDelta(gI1,gI2)*Sin(ThetaW());

   return result;
}

double CLASSNAME::CpVZbarFvFvPL(unsigned gI1, unsigned gI2) const
{
   double result = 0.0;

   result = -0.5*KroneckerDelta(gI1,gI2)*(g2*Cos(ThetaW()) + 0.7745966692414834
      *g1*Sin(ThetaW()));

   return result;
}

double CLASSNAME::CpVZbarFvFvPR(unsigned , unsigned ) const
{
   double result = 0.0;

   result = 0;

   return result;
}

std::complex<double> CLASSNAME::CpVZVZAhAh(unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.05*(7.745966692414834*g1*g2*Sin(2*ThetaW()) + 3*Sqr(g1) + 5*Sqr(
      g2) + Cos(2*ThetaW())*(-3*Sqr(g1) + 5*Sqr(g2)))*(ZA(gI1,0)*ZA(gI2,0) + ZA(
      gI1,1)*ZA(gI2,1));

   return result;
}

std::complex<double> CLASSNAME::CpVZVZconjHpmHpm(unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.1*((-7.745966692414834*g1*g2*Cos(ThetaW())*Sin(ThetaW()) + 5*Sqr(
      g2)*Sqr(Cos(ThetaW())) + 3*Sqr(g1)*Sqr(Sin(ThetaW())))*ZP(gI1,0)*ZP(gI2,0) +
      (-7.745966692414834*g1*g2*Cos(ThetaW())*Sin(ThetaW()) + 5*Sqr(g2)*Sqr(Cos(
      ThetaW())) + 3*Sqr(g1)*Sqr(Sin(ThetaW())))*ZP(gI1,1)*ZP(gI2,1) + 20*Sqr(g2)*
      Sqr(Cos(ThetaW()))*(ZP(gI1,2)*ZP(gI2,2) + ZP(gI1,3)*ZP(gI2,3)));

   return result;
}

std::complex<double> CLASSNAME::CpVZVZhhhh(unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.05*(7.745966692414834*g1*g2*Sin(2*ThetaW()) + 3*Sqr(g1) + 5*Sqr(
      g2) + Cos(2*ThetaW())*(-3*Sqr(g1) + 5*Sqr(g2)))*(ZH(gI1,0)*ZH(gI2,0) + ZH(
      gI1,1)*ZH(gI2,1));

   return result;
}

std::complex<double> CLASSNAME::CpVZconjHpmHpm(unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.1*((-5*g2*Cos(ThetaW()) + 3.872983346207417*g1*Sin(ThetaW()))*ZP(
      gI1,0)*ZP(gI2,0) + (-5*g2*Cos(ThetaW()) + 3.872983346207417*g1*Sin(ThetaW())
      )*ZP(gI1,1)*ZP(gI2,1) - 10*g2*Cos(ThetaW())*(ZP(gI1,2)*ZP(gI2,2) + ZP(gI1,3)
      *ZP(gI2,3)));

   return result;
}

std::complex<double> CLASSNAME::CpVZhhAh(unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = std::complex<double>(0,-0.5)*(g2*Cos(ThetaW()) + 0.7745966692414834
      *g1*Sin(ThetaW()))*(ZA(gI2,0)*ZH(gI1,0) - ZA(gI2,1)*ZH(gI1,1));

   return result;
}

std::complex<double> CLASSNAME::CpVZbarChiChiPL(unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.5*(g2*Cos(ThetaW()) + 0.7745966692414834*g1*Sin(ThetaW()))*(Conj(
      ZN1(gI2,2))*ZN1(gI1,2) - Conj(ZN1(gI2,3))*ZN1(gI1,3));

   return result;
}

std::complex<double> CLASSNAME::CpVZbarChiChiPR(unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.5*(g2*Cos(ThetaW()) + 0.7745966692414834*g1*Sin(ThetaW()))*(Conj(
      ZN2(gI1,2))*ZN2(gI2,2) - Conj(ZN2(gI1,3))*ZN2(gI2,3));

   return result;
}

std::complex<double> CLASSNAME::CpVZVZconjSdSd(unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1621;
   std::complex<double> tmp_1622;
   std::complex<double> tmp_1623;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1623 += Conj(ZD(gI2,j1))*ZD(gI1,j1);
   }
   tmp_1622 += tmp_1623;
   tmp_1621 += (std::complex<double>(0,0.5)*Sqr(g2)*Sqr(Cos(ThetaW()))) *
      tmp_1622;
   std::complex<double> tmp_1624;
   std::complex<double> tmp_1625;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1625 += Conj(ZD(gI2,j1))*ZD(gI1,j1);
   }
   tmp_1624 += tmp_1625;
   tmp_1621 += (std::complex<double>(0.,0.2581988897471611)*g1*g2*Cos(ThetaW())
      *Sin(ThetaW())) * tmp_1624;
   std::complex<double> tmp_1626;
   std::complex<double> tmp_1627;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1627 += Conj(ZD(gI2,j1))*ZD(gI1,j1);
   }
   tmp_1626 += tmp_1627;
   tmp_1621 += (std::complex<double>(0,0.03333333333333333)*Sqr(g1)*Sqr(Sin(
      ThetaW()))) * tmp_1626;
   std::complex<double> tmp_1628;
   std::complex<double> tmp_1629;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1629 += Conj(ZD(gI2,3 + j1))*ZD(gI1,3 + j1);
   }
   tmp_1628 += tmp_1629;
   tmp_1621 += (std::complex<double>(0,0.13333333333333333)*Sqr(g1)*Sqr(Sin(
      ThetaW()))) * tmp_1628;
   result += (std::complex<double>(0,-1)) * tmp_1621;

   return result;
}

std::complex<double> CLASSNAME::CpVZVZconjSeSe(unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1630;
   std::complex<double> tmp_1631;
   std::complex<double> tmp_1632;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1632 += Conj(ZE(gI2,j1))*ZE(gI1,j1);
   }
   tmp_1631 += tmp_1632;
   tmp_1630 += (std::complex<double>(0,0.5)*Sqr(g2)*Sqr(Cos(ThetaW()))) *
      tmp_1631;
   std::complex<double> tmp_1633;
   std::complex<double> tmp_1634;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1634 += Conj(ZE(gI2,j1))*ZE(gI1,j1);
   }
   tmp_1633 += tmp_1634;
   tmp_1630 += (std::complex<double>(0.,-0.7745966692414834)*g1*g2*Cos(ThetaW()
      )*Sin(ThetaW())) * tmp_1633;
   std::complex<double> tmp_1635;
   std::complex<double> tmp_1636;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1636 += Conj(ZE(gI2,j1))*ZE(gI1,j1);
   }
   tmp_1635 += tmp_1636;
   tmp_1630 += (std::complex<double>(0,0.3)*Sqr(g1)*Sqr(Sin(ThetaW()))) *
      tmp_1635;
   std::complex<double> tmp_1637;
   std::complex<double> tmp_1638;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1638 += Conj(ZE(gI2,3 + j1))*ZE(gI1,3 + j1);
   }
   tmp_1637 += tmp_1638;
   tmp_1630 += (std::complex<double>(0,1.2)*Sqr(g1)*Sqr(Sin(ThetaW()))) *
      tmp_1637;
   result += (std::complex<double>(0,-1)) * tmp_1630;

   return result;
}

std::complex<double> CLASSNAME::CpVZVZconjSuSu(unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1639;
   std::complex<double> tmp_1640;
   std::complex<double> tmp_1641;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1641 += Conj(ZU(gI2,j1))*ZU(gI1,j1);
   }
   tmp_1640 += tmp_1641;
   tmp_1639 += (std::complex<double>(0,0.5)*Sqr(g2)*Sqr(Cos(ThetaW()))) *
      tmp_1640;
   std::complex<double> tmp_1642;
   std::complex<double> tmp_1643;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1643 += Conj(ZU(gI2,j1))*ZU(gI1,j1);
   }
   tmp_1642 += tmp_1643;
   tmp_1639 += (std::complex<double>(0.,-0.2581988897471611)*g1*g2*Cos(ThetaW()
      )*Sin(ThetaW())) * tmp_1642;
   std::complex<double> tmp_1644;
   std::complex<double> tmp_1645;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1645 += Conj(ZU(gI2,j1))*ZU(gI1,j1);
   }
   tmp_1644 += tmp_1645;
   tmp_1639 += (std::complex<double>(0,0.03333333333333333)*Sqr(g1)*Sqr(Sin(
      ThetaW()))) * tmp_1644;
   std::complex<double> tmp_1646;
   std::complex<double> tmp_1647;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1647 += Conj(ZU(gI2,3 + j1))*ZU(gI1,3 + j1);
   }
   tmp_1646 += tmp_1647;
   tmp_1639 += (std::complex<double>(0,0.5333333333333333)*Sqr(g1)*Sqr(Sin(
      ThetaW()))) * tmp_1646;
   result += (std::complex<double>(0,-1)) * tmp_1639;

   return result;
}

std::complex<double> CLASSNAME::CpVZconjSdSd(unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1648;
   std::complex<double> tmp_1649;
   std::complex<double> tmp_1650;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1650 += Conj(ZD(gI2,3 + j1))*ZD(gI1,3 + j1);
   }
   tmp_1649 += tmp_1650;
   tmp_1648 += (1.5491933384829668*g1*Sin(ThetaW())) * tmp_1649;
   std::complex<double> tmp_1651;
   std::complex<double> tmp_1652;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1652 += Conj(ZD(gI2,j1))*ZD(gI1,j1);
   }
   tmp_1651 += tmp_1652;
   tmp_1648 += (-3*g2*Cos(ThetaW()) - 0.7745966692414834*g1*Sin(ThetaW())) *
      tmp_1651;
   result += (0.16666666666666666) * tmp_1648;

   return result;
}

std::complex<double> CLASSNAME::CpVZconjSeSe(unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1653;
   std::complex<double> tmp_1654;
   std::complex<double> tmp_1655;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1655 += Conj(ZE(gI2,3 + j1))*ZE(gI1,3 + j1);
   }
   tmp_1654 += tmp_1655;
   tmp_1653 += (1.5491933384829668*g1*Sin(ThetaW())) * tmp_1654;
   std::complex<double> tmp_1656;
   std::complex<double> tmp_1657;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1657 += Conj(ZE(gI2,j1))*ZE(gI1,j1);
   }
   tmp_1656 += tmp_1657;
   tmp_1653 += (-(g2*Cos(ThetaW())) + 0.7745966692414834*g1*Sin(ThetaW())) *
      tmp_1656;
   result += (0.5) * tmp_1653;

   return result;
}

std::complex<double> CLASSNAME::CpVZconjSuSu(unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1658;
   std::complex<double> tmp_1659;
   std::complex<double> tmp_1660;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1660 += Conj(ZU(gI2,3 + j1))*ZU(gI1,3 + j1);
   }
   tmp_1659 += tmp_1660;
   tmp_1658 += (-3.0983866769659336*g1*Sin(ThetaW())) * tmp_1659;
   std::complex<double> tmp_1661;
   std::complex<double> tmp_1662;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1662 += Conj(ZU(gI2,j1))*ZU(gI1,j1);
   }
   tmp_1661 += tmp_1662;
   tmp_1658 += (3*g2*Cos(ThetaW()) - 0.7745966692414834*g1*Sin(ThetaW())) *
      tmp_1661;
   result += (0.16666666666666666) * tmp_1658;

   return result;
}

std::complex<double> CLASSNAME::CpVZVZhh(unsigned gI2) const
{
   std::complex<double> result;

   result = 0.5*Sqr(g2*Cos(ThetaW()) + 0.7745966692414834*g1*Sin(ThetaW()))*(vd
      *ZH(gI2,0) + vu*ZH(gI2,1));

   return result;
}

std::complex<double> CLASSNAME::CpVZconjVWmHpm(unsigned gI2) const
{
   std::complex<double> result;

   result = -0.5*g2*(-0.7745966692414834*g1*vd*Sin(ThetaW())*ZP(gI2,0) +
      0.7745966692414834*g1*vu*Sin(ThetaW())*ZP(gI2,1) + 1.4142135623730951*g2*vT*
      Cos(ThetaW())*(ZP(gI2,2) + ZP(gI2,3)));

   return result;
}

double CLASSNAME::CpVZVZconjVWmVWm1() const
{
   double result = 0.0;

   result = -2*Sqr(g2)*Sqr(Cos(ThetaW()));

   return result;
}

double CLASSNAME::CpVZVZconjVWmVWm2() const
{
   double result = 0.0;

   result = Sqr(g2)*Sqr(Cos(ThetaW()));

   return result;
}

double CLASSNAME::CpVZVZconjVWmVWm3() const
{
   double result = 0.0;

   result = Sqr(g2)*Sqr(Cos(ThetaW()));

   return result;
}

double CLASSNAME::CpconjVWmbargPgWm() const
{
   double result = 0.0;

   result = g2*Sin(ThetaW());

   return result;
}

double CLASSNAME::CpconjVWmbargWmCgP() const
{
   double result = 0.0;

   result = -(g2*Sin(ThetaW()));

   return result;
}

double CLASSNAME::CpconjVWmbargWmCgZ() const
{
   double result = 0.0;

   result = -(g2*Cos(ThetaW()));

   return result;
}

double CLASSNAME::CpconjVWmbargZgWm() const
{
   double result = 0.0;

   result = g2*Cos(ThetaW());

   return result;
}

double CLASSNAME::CpconjVWmVWmVP() const
{
   double result = 0.0;

   result = -(g2*Sin(ThetaW()));

   return result;
}

double CLASSNAME::CpconjVWmVZVWm() const
{
   double result = 0.0;

   result = g2*Cos(ThetaW());

   return result;
}

std::complex<double> CLASSNAME::CpVWmconjVWmconjRhRh(unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.5*Sqr(g2)*(ZHR(gI1,0)*ZHR(gI2,0) + ZHR(gI1,1)*ZHR(gI2,1));

   return result;
}

std::complex<double> CLASSNAME::CpVWmconjVWmconjRpmRpm(unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.5*Sqr(g2)*(Conj(ZRP(gI2,0))*ZRP(gI1,0) + Conj(ZRP(gI2,1))*ZRP(gI1
      ,1));

   return result;
}

std::complex<double> CLASSNAME::CpconjVWmconjRhRpm(unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.7071067811865475*g2*Conj(ZRP(gI2,0))*ZHR(gI1,1);

   return result;
}

std::complex<double> CLASSNAME::CpconjVWmRpmRh(unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = -0.7071067811865475*g2*Conj(ZRP(gI1,1))*ZHR(gI2,0);

   return result;
}

std::complex<double> CLASSNAME::CpconjVWmbarCha1ChiPL(unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = g2*Conj(ZN1(gI2,1))*UP1(gI1,0) - 0.7071067811865475*g2*Conj(ZN1(gI2
      ,2))*UP1(gI1,1);

   return result;
}

std::complex<double> CLASSNAME::CpconjVWmbarCha1ChiPR(unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = g2*Conj(UM1(gI1,0))*ZN2(gI2,1) + 0.7071067811865475*g2*Conj(UM1(gI1
      ,1))*ZN2(gI2,2);

   return result;
}

double CLASSNAME::CpVWmconjVWmconjSvSv(unsigned gI1, unsigned gI2) const
{
   double result = 0.0;

   result = 0.5*KroneckerDelta(gI1,gI2)*Sqr(g2);

   return result;
}

std::complex<double> CLASSNAME::CpconjVWmbarFuFdPL(unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1663;
   std::complex<double> tmp_1664;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1664 += Conj(ZDL(gI2,j1))*ZUL(gI1,j1);
   }
   tmp_1663 += tmp_1664;
   result += (-0.7071067811865475*g2) * tmp_1663;

   return result;
}

double CLASSNAME::CpconjVWmbarFuFdPR(unsigned , unsigned ) const
{
   double result = 0.0;

   result = 0;

   return result;
}

std::complex<double> CLASSNAME::CpconjVWmbarFvFePL(unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gI1 < 3) {
      result += -0.7071067811865475*g2*Conj(ZEL(gI2,gI1));
   }

   return result;
}

double CLASSNAME::CpconjVWmbarFvFePR(unsigned , unsigned ) const
{
   double result = 0.0;

   result = 0;

   return result;
}

std::complex<double> CLASSNAME::CpconjVWmconjSvSe(unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1665;
   std::complex<double> tmp_1666;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1666 += Conj(ZE(gI2,j1))*ZV(gI1,j1);
   }
   tmp_1665 += tmp_1666;
   result += (0.7071067811865475*g2) * tmp_1665;

   return result;
}

std::complex<double> CLASSNAME::CpVWmconjVWmAhAh(unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.5*Sqr(g2)*(ZA(gI1,0)*ZA(gI2,0) + ZA(gI1,1)*ZA(gI2,1) + 4*ZA(gI1,3
      )*ZA(gI2,3));

   return result;
}

std::complex<double> CLASSNAME::CpVWmconjVWmconjHpmHpm(unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.5*Sqr(g2)*(ZP(gI1,0)*ZP(gI2,0) + ZP(gI1,1)*ZP(gI2,1) + 2*ZP(gI1,2
      )*ZP(gI2,2) + 2*ZP(gI1,3)*ZP(gI2,3));

   return result;
}

std::complex<double> CLASSNAME::CpVWmconjVWmhhhh(unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.5*Sqr(g2)*(ZH(gI1,0)*ZH(gI2,0) + ZH(gI1,1)*ZH(gI2,1) + 4*ZH(gI1,3
      )*ZH(gI2,3));

   return result;
}

std::complex<double> CLASSNAME::CpconjVWmbarChiCha2PL(unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = -0.5*g2*(2*Conj(UM2(gI2,0))*ZN1(gI1,1) + 1.4142135623730951*Conj(
      UM2(gI2,1))*ZN1(gI1,3));

   return result;
}

std::complex<double> CLASSNAME::CpconjVWmbarChiCha2PR(unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = -(g2*Conj(ZN2(gI1,1))*UP2(gI2,0)) + 0.7071067811865475*g2*Conj(ZN2(
      gI1,3))*UP2(gI2,1);

   return result;
}

std::complex<double> CLASSNAME::CpconjVWmHpmAh(unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = std::complex<double>(0,-0.5)*g2*(ZA(gI2,0)*ZP(gI1,0) + ZA(gI2,1)*ZP
      (gI1,1) + 1.4142135623730951*ZA(gI2,3)*(ZP(gI1,2) - ZP(gI1,3)));

   return result;
}

std::complex<double> CLASSNAME::CpconjVWmHpmhh(unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.5*g2*(ZH(gI2,0)*ZP(gI1,0) - ZH(gI2,1)*ZP(gI1,1) +
      1.4142135623730951*ZH(gI2,3)*(ZP(gI1,2) + ZP(gI1,3)));

   return result;
}

std::complex<double> CLASSNAME::CpVWmconjVWmconjSdSd(unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1667;
   std::complex<double> tmp_1668;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1668 += Conj(ZD(gI2,j1))*ZD(gI1,j1);
   }
   tmp_1667 += tmp_1668;
   result += (0.5*Sqr(g2)) * tmp_1667;

   return result;
}

std::complex<double> CLASSNAME::CpVWmconjVWmconjSeSe(unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1669;
   std::complex<double> tmp_1670;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1670 += Conj(ZE(gI2,j1))*ZE(gI1,j1);
   }
   tmp_1669 += tmp_1670;
   result += (0.5*Sqr(g2)) * tmp_1669;

   return result;
}

std::complex<double> CLASSNAME::CpVWmconjVWmconjSuSu(unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1671;
   std::complex<double> tmp_1672;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1672 += Conj(ZU(gI2,j1))*ZU(gI1,j1);
   }
   tmp_1671 += tmp_1672;
   result += (0.5*Sqr(g2)) * tmp_1671;

   return result;
}

std::complex<double> CLASSNAME::CpconjVWmconjSuSd(unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1673;
   std::complex<double> tmp_1674;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1674 += Conj(ZD(gI2,j1))*ZU(gI1,j1);
   }
   tmp_1673 += tmp_1674;
   result += (0.7071067811865475*g2) * tmp_1673;

   return result;
}

std::complex<double> CLASSNAME::CpconjVWmVPHpm(unsigned gI2) const
{
   std::complex<double> result;

   result = -0.5*g2*(0.7745966692414834*g1*vd*Cos(ThetaW())*ZP(gI2,0) -
      0.7745966692414834*g1*vu*Cos(ThetaW())*ZP(gI2,1) + 1.4142135623730951*g2*vT*
      Sin(ThetaW())*(ZP(gI2,2) + ZP(gI2,3)));

   return result;
}

std::complex<double> CLASSNAME::CpconjVWmVWmhh(unsigned gI2) const
{
   std::complex<double> result;

   result = 0.5*Sqr(g2)*(vd*ZH(gI2,0) + vu*ZH(gI2,1) + 4*vT*ZH(gI2,3));

   return result;
}

std::complex<double> CLASSNAME::CpconjVWmVZHpm(unsigned gI2) const
{
   std::complex<double> result;

   result = -0.5*g2*(-0.7745966692414834*g1*vd*Sin(ThetaW())*ZP(gI2,0) +
      0.7745966692414834*g1*vu*Sin(ThetaW())*ZP(gI2,1) + 1.4142135623730951*g2*vT*
      Cos(ThetaW())*(ZP(gI2,2) + ZP(gI2,3)));

   return result;
}

double CLASSNAME::CpVWmconjVWmVPVP1() const
{
   double result = 0.0;

   result = -2*Sqr(g2)*Sqr(Sin(ThetaW()));

   return result;
}

double CLASSNAME::CpVWmconjVWmVPVP2() const
{
   double result = 0.0;

   result = Sqr(g2)*Sqr(Sin(ThetaW()));

   return result;
}

double CLASSNAME::CpVWmconjVWmVPVP3() const
{
   double result = 0.0;

   result = Sqr(g2)*Sqr(Sin(ThetaW()));

   return result;
}

double CLASSNAME::CpVWmconjVWmVZVZ1() const
{
   double result = 0.0;

   result = -2*Sqr(g2)*Sqr(Cos(ThetaW()));

   return result;
}

double CLASSNAME::CpVWmconjVWmVZVZ2() const
{
   double result = 0.0;

   result = Sqr(g2)*Sqr(Cos(ThetaW()));

   return result;
}

double CLASSNAME::CpVWmconjVWmVZVZ3() const
{
   double result = 0.0;

   result = Sqr(g2)*Sqr(Cos(ThetaW()));

   return result;
}

double CLASSNAME::CpVWmconjVWmconjVWmVWm1() const
{
   double result = 0.0;

   result = -Sqr(g2);

   return result;
}

double CLASSNAME::CpVWmconjVWmconjVWmVWm2() const
{
   double result = 0.0;

   result = -Sqr(g2);

   return result;
}

double CLASSNAME::CpVWmconjVWmconjVWmVWm3() const
{
   double result = 0.0;

   result = 2*Sqr(g2);

   return result;
}

std::complex<double> CLASSNAME::CpbarUChibarCha2RpmPL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.5*Conj(ZRP(gI2,0))*(Conj(UP2(gI1,1))*(2*LamSU*KroneckerDelta(0,
      gO2) + 1.4142135623730951*LamTU*KroneckerDelta(1,gO2)) + 2*LamTU*Conj(UP2(
      gI1,0))*KroneckerDelta(3,gO2));

   return result;
}

std::complex<double> CLASSNAME::CpbarUChibarCha2RpmPR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.1*Conj(ZRP(gI2,0))*(-10*g2*KroneckerDelta(3,gO1)*UM2(gI1,0) +
      1.4142135623730951*(3.872983346207417*g1*KroneckerDelta(0,gO1) + 5*g2*
      KroneckerDelta(1,gO1))*UM2(gI1,1));

   return result;
}

std::complex<double> CLASSNAME::CpbarUChiconjRpmbarCha1PL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = -0.5*(Conj(UM1(gI2,1))*(2*LamSD*KroneckerDelta(0,gO2) -
      1.4142135623730951*LamTD*KroneckerDelta(1,gO2)) + 2*LamTD*Conj(UM1(gI2,0))*
      KroneckerDelta(2,gO2))*ZRP(gI1,1);

   return result;
}

std::complex<double> CLASSNAME::CpbarUChiconjRpmbarCha1PR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = -0.1*(10*g2*KroneckerDelta(2,gO1)*UP1(gI2,0) + 1.4142135623730951*(
      3.872983346207417*g1*KroneckerDelta(0,gO1) + 5*g2*KroneckerDelta(1,gO1))*UP1
      (gI2,1))*ZRP(gI1,1);

   return result;
}

double CLASSNAME::CpbarUChibarFvSvPL(unsigned , unsigned , unsigned ) const
{
   double result = 0.0;

   result = 0;

   return result;
}

std::complex<double> CLASSNAME::CpbarUChibarFvSvPR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gI1 < 3) {
      result += 0.5477225575051661*g1*Conj(ZV(gI2,gI1))*KroneckerDelta(0,gO1
         );
   }
   if (gI1 < 3) {
      result += -0.7071067811865475*g2*Conj(ZV(gI2,gI1))*KroneckerDelta(1,
         gO1);
   }

   return result;
}

std::complex<double> CLASSNAME::CpbarUChibarFdSdPL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1675;
   std::complex<double> tmp_1676;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_1677;
      std::complex<double> tmp_1678;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1678 += Conj(ZDR(gI1,j1))*Yd(j1,j2);
      }
      tmp_1677 += tmp_1678;
      tmp_1676 += (Conj(ZD(gI2,j2))) * tmp_1677;
   }
   tmp_1675 += tmp_1676;
   result += (-KroneckerDelta(2,gO2)) * tmp_1675;

   return result;
}

std::complex<double> CLASSNAME::CpbarUChibarFdSdPR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1679;
   std::complex<double> tmp_1680;
   std::complex<double> tmp_1681;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1681 += Conj(ZD(gI2,j1))*ZDL(gI1,j1);
   }
   tmp_1680 += tmp_1681;
   tmp_1679 += (std::complex<double>(0.,-0.18257418583505536)*g1*KroneckerDelta
      (0,gO1)) * tmp_1680;
   std::complex<double> tmp_1682;
   std::complex<double> tmp_1683;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1683 += Conj(ZD(gI2,j1))*ZDL(gI1,j1);
   }
   tmp_1682 += tmp_1683;
   tmp_1679 += (std::complex<double>(0.,0.7071067811865475)*g2*KroneckerDelta(1
      ,gO1)) * tmp_1682;
   result += (std::complex<double>(0,-1)) * tmp_1679;

   return result;
}

std::complex<double> CLASSNAME::CpbarUChibarFeSePL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1684;
   std::complex<double> tmp_1685;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_1686;
      std::complex<double> tmp_1687;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1687 += Conj(ZER(gI1,j1))*Ye(j1,j2);
      }
      tmp_1686 += tmp_1687;
      tmp_1685 += (Conj(ZE(gI2,j2))) * tmp_1686;
   }
   tmp_1684 += tmp_1685;
   result += (-KroneckerDelta(2,gO2)) * tmp_1684;

   return result;
}

std::complex<double> CLASSNAME::CpbarUChibarFeSePR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1688;
   std::complex<double> tmp_1689;
   std::complex<double> tmp_1690;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1690 += Conj(ZE(gI2,j1))*ZEL(gI1,j1);
   }
   tmp_1689 += tmp_1690;
   tmp_1688 += (std::complex<double>(0.,0.5477225575051661)*g1*KroneckerDelta(0
      ,gO1)) * tmp_1689;
   std::complex<double> tmp_1691;
   std::complex<double> tmp_1692;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1692 += Conj(ZE(gI2,j1))*ZEL(gI1,j1);
   }
   tmp_1691 += tmp_1692;
   tmp_1688 += (std::complex<double>(0.,0.7071067811865475)*g2*KroneckerDelta(1
      ,gO1)) * tmp_1691;
   result += (std::complex<double>(0,-1)) * tmp_1688;

   return result;
}

std::complex<double> CLASSNAME::CpbarUChibarFuSuPL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1693;
   std::complex<double> tmp_1694;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_1695;
      std::complex<double> tmp_1696;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1696 += Conj(ZUR(gI1,j1))*Yu(j1,j2);
      }
      tmp_1695 += tmp_1696;
      tmp_1694 += (Conj(ZU(gI2,j2))) * tmp_1695;
   }
   tmp_1693 += tmp_1694;
   result += (-KroneckerDelta(3,gO2)) * tmp_1693;

   return result;
}

std::complex<double> CLASSNAME::CpbarUChibarFuSuPR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1697;
   std::complex<double> tmp_1698;
   std::complex<double> tmp_1699;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1699 += Conj(ZU(gI2,j1))*ZUL(gI1,j1);
   }
   tmp_1698 += tmp_1699;
   tmp_1697 += (std::complex<double>(0.,-0.18257418583505536)*g1*KroneckerDelta
      (0,gO1)) * tmp_1698;
   std::complex<double> tmp_1700;
   std::complex<double> tmp_1701;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1701 += Conj(ZU(gI2,j1))*ZUL(gI1,j1);
   }
   tmp_1700 += tmp_1701;
   tmp_1697 += (std::complex<double>(0.,-0.7071067811865475)*g2*KroneckerDelta(
      1,gO1)) * tmp_1700;
   result += (std::complex<double>(0,-1)) * tmp_1697;

   return result;
}

std::complex<double> CLASSNAME::CpbarUChibarChiRhPL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.7071067811865475*LamTD*Conj(ZN2(gI1,1))*KroneckerDelta(2,gO2)*ZHR
      (gI2,0) + Conj(ZN2(gI1,2))*(LamSD*KroneckerDelta(0,gO2)*ZHR(gI2,0) +
      0.7071067811865475*LamTD*KroneckerDelta(1,gO2)*ZHR(gI2,0)) - LamSU*Conj(ZN2(
      gI1,3))*KroneckerDelta(0,gO2)*ZHR(gI2,1) + 0.7071067811865475*LamTU*Conj(ZN2
      (gI1,3))*KroneckerDelta(1,gO2)*ZHR(gI2,1) + 0.7071067811865475*LamTU*Conj(
      ZN2(gI1,1))*KroneckerDelta(3,gO2)*ZHR(gI2,1) + Conj(ZN2(gI1,0))*(LamSD*
      KroneckerDelta(2,gO2)*ZHR(gI2,0) - LamSU*KroneckerDelta(3,gO2)*ZHR(gI2,1));

   return result;
}

std::complex<double> CLASSNAME::CpbarUChibarChiRhPR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.1414213562373095*(KroneckerDelta(3,gO1)*ZHR(gI2,1)*(
      3.872983346207417*g1*ZN1(gI1,0) - 5*g2*ZN1(gI1,1)) + KroneckerDelta(2,gO1)*
      ZHR(gI2,0)*(-3.872983346207417*g1*ZN1(gI1,0) + 5*g2*ZN1(gI1,1)) - (
      3.872983346207417*g1*KroneckerDelta(0,gO1) - 5*g2*KroneckerDelta(1,gO1))*(
      ZHR(gI2,0)*ZN1(gI1,2) - ZHR(gI2,1)*ZN1(gI1,3)));

   return result;
}

std::complex<double> CLASSNAME::CpbarUChiconjHpmCha2PL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = -(g2*Conj(UM2(gI2,0))*(KroneckerDelta(2,gO2)*ZP(gI1,0) +
      1.4142135623730951*KroneckerDelta(1,gO2)*ZP(gI1,2))) + 0.5*Conj(UM2(gI2,1))*
      (2*LamSU*KroneckerDelta(0,gO2)*ZP(gI1,1) + 1.4142135623730951*LamTU*
      KroneckerDelta(1,gO2)*ZP(gI1,1) + 2*LamTU*KroneckerDelta(3,gO2)*ZP(gI1,3));

   return result;
}

std::complex<double> CLASSNAME::CpbarUChiconjHpmCha2PR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = Conj(LamTD)*KroneckerDelta(2,gO1)*UP2(gI2,0)*ZP(gI1,0) -
      0.5477225575051661*g1*KroneckerDelta(0,gO1)*UP2(gI2,1)*ZP(gI1,1) -
      0.7071067811865475*g2*KroneckerDelta(1,gO1)*UP2(gI2,1)*ZP(gI1,1) - Conj(
      LamTU)*KroneckerDelta(3,gO1)*UP2(gI2,1)*ZP(gI1,2) - 1.4142135623730951*g2*
      KroneckerDelta(1,gO1)*UP2(gI2,0)*ZP(gI1,3);

   return result;
}

std::complex<double> CLASSNAME::CpbarUChiHpmCha1PL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = Conj(UP1(gI2,1))*(-(LamSD*KroneckerDelta(0,gO2)*ZP(gI1,0)) +
      0.7071067811865475*LamTD*KroneckerDelta(1,gO2)*ZP(gI1,0) - LamTD*
      KroneckerDelta(2,gO2)*ZP(gI1,2)) + g2*Conj(UP1(gI2,0))*(-(KroneckerDelta(3,
      gO2)*ZP(gI1,1)) + 1.4142135623730951*KroneckerDelta(1,gO2)*ZP(gI1,3));

   return result;
}

std::complex<double> CLASSNAME::CpbarUChiHpmCha1PR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.5477225575051661*g1*KroneckerDelta(0,gO1)*UM1(gI2,1)*ZP(gI1,0) -
      Conj(LamTU)*KroneckerDelta(3,gO1)*UM1(gI2,0)*ZP(gI1,1) + 0.7071067811865475*
      g2*KroneckerDelta(1,gO1)*(UM1(gI2,1)*ZP(gI1,0) + 2*UM1(gI2,0)*ZP(gI1,2)) +
      Conj(LamTD)*KroneckerDelta(2,gO1)*UM1(gI2,1)*ZP(gI1,3);

   return result;
}

std::complex<double> CLASSNAME::CpbarUChiChiAhPL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = std::complex<double>(0,0.1)*(3.872983346207417*g1*Conj(ZN1(gI1,0))*
      (-(KroneckerDelta(2,gO2)*ZA(gI2,0)) + KroneckerDelta(3,gO2)*ZA(gI2,1)) + 5*
      Conj(ZN1(gI1,2))*(1.4142135623730951*LamSD*KroneckerDelta(0,gO2)*ZA(gI2,0) +
      LamTD*KroneckerDelta(1,gO2)*ZA(gI2,0) + KroneckerDelta(2,gO2)*(
      1.4142135623730951*LamSD*ZA(gI2,2) + LamTD*ZA(gI2,3))) + 5*(g2*Conj(ZN1(gI1,
      1))*(KroneckerDelta(2,gO2)*ZA(gI2,0) - KroneckerDelta(3,gO2)*ZA(gI2,1)) +
      Conj(ZN1(gI1,3))*(-1.4142135623730951*LamSU*KroneckerDelta(0,gO2)*ZA(gI2,1)
      + LamTU*KroneckerDelta(1,gO2)*ZA(gI2,1) + KroneckerDelta(3,gO2)*(
      -1.4142135623730951*LamSU*ZA(gI2,2) + LamTU*ZA(gI2,3)))));

   return result;
}

std::complex<double> CLASSNAME::CpbarUChiChiAhPR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = std::complex<double>(0,-0.1)*(5*Conj(LamTD)*KroneckerDelta(2,gO1)*
      ZA(gI2,0)*ZN2(gI1,1) + 5*Conj(LamTU)*KroneckerDelta(3,gO1)*ZA(gI2,1)*ZN2(gI1
      ,1) - 3.872983346207417*g1*KroneckerDelta(0,gO1)*ZA(gI2,0)*ZN2(gI1,2) + 5*g2
      *KroneckerDelta(1,gO1)*ZA(gI2,0)*ZN2(gI1,2) + 5*Conj(LamTD)*KroneckerDelta(2
      ,gO1)*ZA(gI2,3)*ZN2(gI1,2) + 7.0710678118654755*Conj(LamSD)*KroneckerDelta(2
      ,gO1)*(ZA(gI2,0)*ZN2(gI1,0) + ZA(gI2,2)*ZN2(gI1,2)) + 3.872983346207417*g1*
      KroneckerDelta(0,gO1)*ZA(gI2,1)*ZN2(gI1,3) - 5*g2*KroneckerDelta(1,gO1)*ZA(
      gI2,1)*ZN2(gI1,3) + 5*Conj(LamTU)*KroneckerDelta(3,gO1)*ZA(gI2,3)*ZN2(gI1,3)
      - 7.0710678118654755*Conj(LamSU)*KroneckerDelta(3,gO1)*(ZA(gI2,1)*ZN2(gI1,0
      ) + ZA(gI2,2)*ZN2(gI1,3)));

   return result;
}

std::complex<double> CLASSNAME::CpbarUChihhChiPL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.1*(3.872983346207417*g1*Conj(ZN1(gI2,0))*(KroneckerDelta(2,gO2)*
      ZH(gI1,0) - KroneckerDelta(3,gO2)*ZH(gI1,1)) + 5*Conj(ZN1(gI2,2))*(
      1.4142135623730951*LamSD*KroneckerDelta(0,gO2)*ZH(gI1,0) + LamTD*
      KroneckerDelta(1,gO2)*ZH(gI1,0) + KroneckerDelta(2,gO2)*(1.4142135623730951*
      LamSD*ZH(gI1,2) + LamTD*ZH(gI1,3))) + 5*(Conj(ZN1(gI2,1))*(-(g2*
      KroneckerDelta(2,gO2)*ZH(gI1,0)) + g2*KroneckerDelta(3,gO2)*ZH(gI1,1)) +
      Conj(ZN1(gI2,3))*(-1.4142135623730951*LamSU*KroneckerDelta(0,gO2)*ZH(gI1,1)
      + LamTU*KroneckerDelta(1,gO2)*ZH(gI1,1) + KroneckerDelta(3,gO2)*(
      -1.4142135623730951*LamSU*ZH(gI1,2) + LamTU*ZH(gI1,3)))));

   return result;
}

std::complex<double> CLASSNAME::CpbarUChihhChiPR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.1*(5*Conj(LamTD)*KroneckerDelta(2,gO1)*ZH(gI1,0)*ZN2(gI2,1) + 5*
      Conj(LamTU)*KroneckerDelta(3,gO1)*ZH(gI1,1)*ZN2(gI2,1) + 3.872983346207417*
      g1*KroneckerDelta(0,gO1)*ZH(gI1,0)*ZN2(gI2,2) - 5*g2*KroneckerDelta(1,gO1)*
      ZH(gI1,0)*ZN2(gI2,2) + 5*Conj(LamTD)*KroneckerDelta(2,gO1)*ZH(gI1,3)*ZN2(gI2
      ,2) + 7.0710678118654755*Conj(LamSD)*KroneckerDelta(2,gO1)*(ZH(gI1,0)*ZN2(
      gI2,0) + ZH(gI1,2)*ZN2(gI2,2)) - 3.872983346207417*g1*KroneckerDelta(0,gO1)*
      ZH(gI1,1)*ZN2(gI2,3) + 5*g2*KroneckerDelta(1,gO1)*ZH(gI1,1)*ZN2(gI2,3) + 5*
      Conj(LamTU)*KroneckerDelta(3,gO1)*ZH(gI1,3)*ZN2(gI2,3) - 7.0710678118654755*
      Conj(LamSU)*KroneckerDelta(3,gO1)*(ZH(gI1,1)*ZN2(gI2,0) + ZH(gI1,2)*ZN2(gI2,
      3)));

   return result;
}

std::complex<double> CLASSNAME::CpbarUChiconjSdFdPL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1702;
   std::complex<double> tmp_1703;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_1704;
      std::complex<double> tmp_1705;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1705 += Yd(j1,j2)*ZD(gI1,3 + j1);
      }
      tmp_1704 += tmp_1705;
      tmp_1703 += (Conj(ZDL(gI2,j2))) * tmp_1704;
   }
   tmp_1702 += tmp_1703;
   result += (-KroneckerDelta(2,gO2)) * tmp_1702;

   return result;
}

std::complex<double> CLASSNAME::CpbarUChiconjSdFdPR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1706;
   std::complex<double> tmp_1707;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1707 += ZD(gI1,3 + j1)*ZDR(gI2,j1);
   }
   tmp_1706 += tmp_1707;
   result += (-0.3651483716701107*g1*KroneckerDelta(0,gO1)) * tmp_1706;

   return result;
}

std::complex<double> CLASSNAME::CpbarUChiconjSeFePL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1708;
   std::complex<double> tmp_1709;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_1710;
      std::complex<double> tmp_1711;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1711 += Ye(j1,j2)*ZE(gI1,3 + j1);
      }
      tmp_1710 += tmp_1711;
      tmp_1709 += (Conj(ZEL(gI2,j2))) * tmp_1710;
   }
   tmp_1708 += tmp_1709;
   result += (-KroneckerDelta(2,gO2)) * tmp_1708;

   return result;
}

std::complex<double> CLASSNAME::CpbarUChiconjSeFePR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1712;
   std::complex<double> tmp_1713;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1713 += ZE(gI1,3 + j1)*ZER(gI2,j1);
   }
   tmp_1712 += tmp_1713;
   result += (-1.0954451150103321*g1*KroneckerDelta(0,gO1)) * tmp_1712;

   return result;
}

std::complex<double> CLASSNAME::CpbarUChiconjSuFuPL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1714;
   std::complex<double> tmp_1715;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_1716;
      std::complex<double> tmp_1717;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1717 += Yu(j1,j2)*ZU(gI1,3 + j1);
      }
      tmp_1716 += tmp_1717;
      tmp_1715 += (Conj(ZUL(gI2,j2))) * tmp_1716;
   }
   tmp_1714 += tmp_1715;
   result += (-KroneckerDelta(3,gO2)) * tmp_1714;

   return result;
}

std::complex<double> CLASSNAME::CpbarUChiconjSuFuPR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1718;
   std::complex<double> tmp_1719;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1719 += ZU(gI1,3 + j1)*ZUR(gI2,j1);
   }
   tmp_1718 += tmp_1719;
   result += (0.7302967433402214*g1*KroneckerDelta(0,gO1)) * tmp_1718;

   return result;
}

std::complex<double> CLASSNAME::CpbarUChiVWmCha1PR(unsigned gO2, unsigned gI2) const
{
   std::complex<double> result;

   result = g2*KroneckerDelta(1,gO2)*UM1(gI2,0) + 0.7071067811865475*g2*
      KroneckerDelta(2,gO2)*UM1(gI2,1);

   return result;
}

std::complex<double> CLASSNAME::CpbarUChiVWmCha1PL(unsigned gO1, unsigned gI2) const
{
   std::complex<double> result;

   result = g2*Conj(UP1(gI2,0))*KroneckerDelta(1,gO1) - 0.7071067811865475*g2*
      Conj(UP1(gI2,1))*KroneckerDelta(2,gO1);

   return result;
}

std::complex<double> CLASSNAME::CpbarUChiconjVWmCha2PR(unsigned gO2, unsigned gI2) const
{
   std::complex<double> result;

   result = -(g2*KroneckerDelta(1,gO2)*UP2(gI2,0)) + 0.7071067811865475*g2*
      KroneckerDelta(3,gO2)*UP2(gI2,1);

   return result;
}

std::complex<double> CLASSNAME::CpbarUChiconjVWmCha2PL(unsigned gO1, unsigned gI2) const
{
   std::complex<double> result;

   result = -0.5*g2*(2*Conj(UM2(gI2,0))*KroneckerDelta(1,gO1) +
      1.4142135623730951*Conj(UM2(gI2,1))*KroneckerDelta(3,gO1));

   return result;
}

std::complex<double> CLASSNAME::CpbarUChiVZChiPR(unsigned gO2, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.1*(5*g2*Cos(ThetaW()) + 3.872983346207417*g1*Sin(ThetaW()))*(
      KroneckerDelta(2,gO2)*ZN2(gI2,2) - KroneckerDelta(3,gO2)*ZN2(gI2,3));

   return result;
}

std::complex<double> CLASSNAME::CpbarUChiVZChiPL(unsigned gO1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.1*(Conj(ZN1(gI2,2))*KroneckerDelta(2,gO1) - Conj(ZN1(gI2,3))*
      KroneckerDelta(3,gO1))*(5*g2*Cos(ThetaW()) + 3.872983346207417*g1*Sin(ThetaW
      ()));

   return result;
}

std::complex<double> CLASSNAME::CpbarUCha1barCha2RhPL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1720;
   std::complex<double> tmp_1721;
   std::complex<double> tmp_1722;
   for (unsigned gl1263 = 0; gl1263 < 2; ++gl1263) {
      tmp_1722 += Conj(UM1(gl1263,1))*UP1(gl1263,gO2);
   }
   tmp_1721 += tmp_1722;
   tmp_1720 += (std::complex<double>(0,1)*LamTD*Conj(UP2(gI1,0))*ZHR(gI2,0)) *
      tmp_1721;
   std::complex<double> tmp_1723;
   std::complex<double> tmp_1724;
   for (unsigned gl1263 = 0; gl1263 < 2; ++gl1263) {
      tmp_1724 += Conj(UM1(gl1263,0))*UP1(gl1263,gO2);
   }
   tmp_1723 += tmp_1724;
   tmp_1720 += (std::complex<double>(0,-1)*LamTU*Conj(UP2(gI1,1))*ZHR(gI2,1)) *
      tmp_1723;
   result += (std::complex<double>(0,-1)) * tmp_1720;

   return result;
}

std::complex<double> CLASSNAME::CpbarUCha1barCha2RhPR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1725;
   std::complex<double> tmp_1726;
   std::complex<double> tmp_1727;
   for (unsigned gl1266 = 0; gl1266 < 2; ++gl1266) {
      tmp_1727 += Conj(UM1(gl1266,gO1))*UP1(gl1266,1);
   }
   tmp_1726 += tmp_1727;
   tmp_1725 += (std::complex<double>(0,-1)*g2*UM2(gI1,0)*ZHR(gI2,0)) * tmp_1726
      ;
   std::complex<double> tmp_1728;
   std::complex<double> tmp_1729;
   for (unsigned gl1266 = 0; gl1266 < 2; ++gl1266) {
      tmp_1729 += Conj(UM1(gl1266,gO1))*UP1(gl1266,0);
   }
   tmp_1728 += tmp_1729;
   tmp_1725 += (std::complex<double>(0,-1)*g2*UM2(gI1,1)*ZHR(gI2,1)) * tmp_1728
      ;
   result += (std::complex<double>(0,-1)) * tmp_1725;

   return result;
}

std::complex<double> CLASSNAME::CpbarUCha1Cha1AhPL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1730;
   std::complex<double> tmp_1731;
   std::complex<double> tmp_1732;
   for (unsigned gl1269 = 0; gl1269 < 2; ++gl1269) {
      tmp_1732 += Conj(UM1(gl1269,0))*UP1(gl1269,gO2);
   }
   tmp_1731 += tmp_1732;
   tmp_1730 += (0.7071067811865475*LamTD*Conj(UP1(gI1,1))*ZA(gI2,0)) * tmp_1731
      ;
   std::complex<double> tmp_1733;
   std::complex<double> tmp_1734;
   for (unsigned gl1269 = 0; gl1269 < 2; ++gl1269) {
      tmp_1734 += Conj(UM1(gl1269,1))*UP1(gl1269,gO2);
   }
   tmp_1733 += tmp_1734;
   tmp_1730 += (-0.7071067811865475*g2*Conj(UP1(gI1,0))*ZA(gI2,0)) * tmp_1733;
   std::complex<double> tmp_1735;
   std::complex<double> tmp_1736;
   for (unsigned gl1269 = 0; gl1269 < 2; ++gl1269) {
      tmp_1736 += Conj(UM1(gl1269,1))*UP1(gl1269,gO2);
   }
   tmp_1735 += tmp_1736;
   tmp_1730 += (0.7071067811865475*LamSD*Conj(UP1(gI1,1))*ZA(gI2,2)) * tmp_1735
      ;
   std::complex<double> tmp_1737;
   std::complex<double> tmp_1738;
   for (unsigned gl1269 = 0; gl1269 < 2; ++gl1269) {
      tmp_1738 += Conj(UM1(gl1269,0))*UP1(gl1269,gO2);
   }
   tmp_1737 += tmp_1738;
   tmp_1730 += (-(g2*Conj(UP1(gI1,0))*ZA(gI2,3))) * tmp_1737;
   std::complex<double> tmp_1739;
   std::complex<double> tmp_1740;
   for (unsigned gl1269 = 0; gl1269 < 2; ++gl1269) {
      tmp_1740 += Conj(UM1(gl1269,1))*UP1(gl1269,gO2);
   }
   tmp_1739 += tmp_1740;
   tmp_1730 += (-0.5*LamTD*Conj(UP1(gI1,1))*ZA(gI2,3)) * tmp_1739;
   result += (std::complex<double>(0,-1)) * tmp_1730;

   return result;
}

std::complex<double> CLASSNAME::CpbarUCha1Cha1AhPR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1741;
   std::complex<double> tmp_1742;
   std::complex<double> tmp_1743;
   for (unsigned gl1272 = 0; gl1272 < 2; ++gl1272) {
      tmp_1743 += Conj(UM1(gl1272,gO1))*UP1(gl1272,1);
   }
   tmp_1742 += tmp_1743;
   tmp_1741 += (-0.7071067811865475*Conj(LamTD)*UM1(gI1,0)*ZA(gI2,0)) *
      tmp_1742;
   std::complex<double> tmp_1744;
   std::complex<double> tmp_1745;
   for (unsigned gl1272 = 0; gl1272 < 2; ++gl1272) {
      tmp_1745 += Conj(UM1(gl1272,gO1))*UP1(gl1272,0);
   }
   tmp_1744 += tmp_1745;
   tmp_1741 += (0.7071067811865475*g2*UM1(gI1,1)*ZA(gI2,0)) * tmp_1744;
   std::complex<double> tmp_1746;
   std::complex<double> tmp_1747;
   for (unsigned gl1272 = 0; gl1272 < 2; ++gl1272) {
      tmp_1747 += Conj(UM1(gl1272,gO1))*UP1(gl1272,1);
   }
   tmp_1746 += tmp_1747;
   tmp_1741 += (-0.7071067811865475*Conj(LamSD)*UM1(gI1,1)*ZA(gI2,2)) *
      tmp_1746;
   std::complex<double> tmp_1748;
   std::complex<double> tmp_1749;
   for (unsigned gl1272 = 0; gl1272 < 2; ++gl1272) {
      tmp_1749 += Conj(UM1(gl1272,gO1))*UP1(gl1272,0);
   }
   tmp_1748 += tmp_1749;
   tmp_1741 += (g2*UM1(gI1,0)*ZA(gI2,3)) * tmp_1748;
   std::complex<double> tmp_1750;
   std::complex<double> tmp_1751;
   for (unsigned gl1272 = 0; gl1272 < 2; ++gl1272) {
      tmp_1751 += Conj(UM1(gl1272,gO1))*UP1(gl1272,1);
   }
   tmp_1750 += tmp_1751;
   tmp_1741 += (0.5*Conj(LamTD)*UM1(gI1,1)*ZA(gI2,3)) * tmp_1750;
   result += (std::complex<double>(0,-1)) * tmp_1741;

   return result;
}

std::complex<double> CLASSNAME::CpbarUCha1conjRpmbarChiPL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1752;
   std::complex<double> tmp_1753;
   std::complex<double> tmp_1754;
   for (unsigned gl1275 = 0; gl1275 < 2; ++gl1275) {
      tmp_1754 += Conj(UM1(gl1275,0))*UP1(gl1275,gO2);
   }
   tmp_1753 += tmp_1754;
   tmp_1752 += (std::complex<double>(0,-1)*LamTD*Conj(ZN2(gI2,2))*ZRP(gI1,1)) *
      tmp_1753;
   std::complex<double> tmp_1755;
   std::complex<double> tmp_1756;
   for (unsigned gl1275 = 0; gl1275 < 2; ++gl1275) {
      tmp_1756 += Conj(UM1(gl1275,1))*UP1(gl1275,gO2);
   }
   tmp_1755 += tmp_1756;
   tmp_1752 += (std::complex<double>(0,-1)*LamSD*Conj(ZN2(gI2,0))*ZRP(gI1,1)) *
      tmp_1755;
   std::complex<double> tmp_1757;
   std::complex<double> tmp_1758;
   for (unsigned gl1275 = 0; gl1275 < 2; ++gl1275) {
      tmp_1758 += Conj(UM1(gl1275,1))*UP1(gl1275,gO2);
   }
   tmp_1757 += tmp_1758;
   tmp_1752 += (std::complex<double>(0.,0.7071067811865475)*LamTD*Conj(ZN2(gI2,
      1))*ZRP(gI1,1)) * tmp_1757;
   result += (std::complex<double>(0,-1)) * tmp_1752;

   return result;
}

std::complex<double> CLASSNAME::CpbarUCha1conjRpmbarChiPR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1759;
   std::complex<double> tmp_1760;
   std::complex<double> tmp_1761;
   for (unsigned gl1278 = 0; gl1278 < 2; ++gl1278) {
      tmp_1761 += Conj(UM1(gl1278,gO1))*UP1(gl1278,1);
   }
   tmp_1760 += tmp_1761;
   tmp_1759 += (std::complex<double>(0.,-0.5477225575051661)*g1*ZN1(gI2,0)*ZRP(
      gI1,1)) * tmp_1760;
   std::complex<double> tmp_1762;
   std::complex<double> tmp_1763;
   for (unsigned gl1278 = 0; gl1278 < 2; ++gl1278) {
      tmp_1763 += Conj(UM1(gl1278,gO1))*UP1(gl1278,1);
   }
   tmp_1762 += tmp_1763;
   tmp_1759 += (std::complex<double>(0.,-0.7071067811865475)*g2*ZN1(gI2,1)*ZRP(
      gI1,1)) * tmp_1762;
   std::complex<double> tmp_1764;
   std::complex<double> tmp_1765;
   for (unsigned gl1278 = 0; gl1278 < 2; ++gl1278) {
      tmp_1765 += Conj(UM1(gl1278,gO1))*UP1(gl1278,0);
   }
   tmp_1764 += tmp_1765;
   tmp_1759 += (std::complex<double>(0,-1)*g2*ZN1(gI2,2)*ZRP(gI1,1)) * tmp_1764
      ;
   result += (std::complex<double>(0,-1)) * tmp_1759;

   return result;
}

std::complex<double> CLASSNAME::CpbarUCha1barFeSvPL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1766;
   std::complex<double> tmp_1768;
   for (unsigned gl1281 = 0; gl1281 < 2; ++gl1281) {
      tmp_1768 += Conj(UM1(gl1281,1))*UP1(gl1281,gO2);
   }
   tmp_1766 += tmp_1768;
   std::complex<double> tmp_1767;
   std::complex<double> tmp_1769;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_1770;
      std::complex<double> tmp_1771;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1771 += Conj(ZER(gI1,j1))*Ye(j1,j2);
      }
      tmp_1770 += tmp_1771;
      tmp_1769 += (Conj(ZV(gI2,j2))) * tmp_1770;
   }
   tmp_1767 += tmp_1769;
   result += (1) * tmp_1766 * tmp_1767;

   return result;
}

std::complex<double> CLASSNAME::CpbarUCha1barFeSvPR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1772;
   std::complex<double> tmp_1774;
   for (unsigned gl1284 = 0; gl1284 < 2; ++gl1284) {
      tmp_1774 += Conj(UM1(gl1284,gO1))*UP1(gl1284,0);
   }
   tmp_1772 += tmp_1774;
   std::complex<double> tmp_1773;
   std::complex<double> tmp_1775;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1775 += Conj(ZV(gI2,j1))*ZEL(gI1,j1);
   }
   tmp_1773 += tmp_1775;
   result += (-g2) * tmp_1772 * tmp_1773;

   return result;
}

std::complex<double> CLASSNAME::CpbarUCha1barFdSuPL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1776;
   std::complex<double> tmp_1778;
   for (unsigned gl1287 = 0; gl1287 < 2; ++gl1287) {
      tmp_1778 += Conj(UM1(gl1287,1))*UP1(gl1287,gO2);
   }
   tmp_1776 += tmp_1778;
   std::complex<double> tmp_1777;
   std::complex<double> tmp_1779;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_1780;
      std::complex<double> tmp_1781;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1781 += Conj(ZDR(gI1,j1))*Yd(j1,j2);
      }
      tmp_1780 += tmp_1781;
      tmp_1779 += (Conj(ZU(gI2,j2))) * tmp_1780;
   }
   tmp_1777 += tmp_1779;
   result += (1) * tmp_1776 * tmp_1777;

   return result;
}

std::complex<double> CLASSNAME::CpbarUCha1barFdSuPR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1782;
   std::complex<double> tmp_1784;
   for (unsigned gl1290 = 0; gl1290 < 2; ++gl1290) {
      tmp_1784 += Conj(UM1(gl1290,gO1))*UP1(gl1290,0);
   }
   tmp_1782 += tmp_1784;
   std::complex<double> tmp_1783;
   std::complex<double> tmp_1785;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1785 += Conj(ZU(gI2,j1))*ZDL(gI1,j1);
   }
   tmp_1783 += tmp_1785;
   result += (-g2) * tmp_1782 * tmp_1783;

   return result;
}

std::complex<double> CLASSNAME::CpbarUCha1hhCha1PL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1786;
   std::complex<double> tmp_1787;
   std::complex<double> tmp_1788;
   for (unsigned gl1293 = 0; gl1293 < 2; ++gl1293) {
      tmp_1788 += Conj(UM1(gl1293,0))*UP1(gl1293,gO2);
   }
   tmp_1787 += tmp_1788;
   tmp_1786 += (std::complex<double>(0.,-0.7071067811865475)*LamTD*Conj(UP1(gI2
      ,1))*ZH(gI1,0)) * tmp_1787;
   std::complex<double> tmp_1789;
   std::complex<double> tmp_1790;
   for (unsigned gl1293 = 0; gl1293 < 2; ++gl1293) {
      tmp_1790 += Conj(UM1(gl1293,1))*UP1(gl1293,gO2);
   }
   tmp_1789 += tmp_1790;
   tmp_1786 += (std::complex<double>(0.,-0.7071067811865475)*g2*Conj(UP1(gI2,0)
      )*ZH(gI1,0)) * tmp_1789;
   std::complex<double> tmp_1791;
   std::complex<double> tmp_1792;
   for (unsigned gl1293 = 0; gl1293 < 2; ++gl1293) {
      tmp_1792 += Conj(UM1(gl1293,1))*UP1(gl1293,gO2);
   }
   tmp_1791 += tmp_1792;
   tmp_1786 += (std::complex<double>(0.,-0.7071067811865475)*LamSD*Conj(UP1(gI2
      ,1))*ZH(gI1,2)) * tmp_1791;
   std::complex<double> tmp_1793;
   std::complex<double> tmp_1794;
   for (unsigned gl1293 = 0; gl1293 < 2; ++gl1293) {
      tmp_1794 += Conj(UM1(gl1293,0))*UP1(gl1293,gO2);
   }
   tmp_1793 += tmp_1794;
   tmp_1786 += (std::complex<double>(0,-1)*g2*Conj(UP1(gI2,0))*ZH(gI1,3)) *
      tmp_1793;
   std::complex<double> tmp_1795;
   std::complex<double> tmp_1796;
   for (unsigned gl1293 = 0; gl1293 < 2; ++gl1293) {
      tmp_1796 += Conj(UM1(gl1293,1))*UP1(gl1293,gO2);
   }
   tmp_1795 += tmp_1796;
   tmp_1786 += (std::complex<double>(0,0.5)*LamTD*Conj(UP1(gI2,1))*ZH(gI1,3)) *
      tmp_1795;
   result += (std::complex<double>(0,-1)) * tmp_1786;

   return result;
}

std::complex<double> CLASSNAME::CpbarUCha1hhCha1PR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1797;
   std::complex<double> tmp_1798;
   std::complex<double> tmp_1799;
   for (unsigned gl1296 = 0; gl1296 < 2; ++gl1296) {
      tmp_1799 += Conj(UM1(gl1296,gO1))*UP1(gl1296,1);
   }
   tmp_1798 += tmp_1799;
   tmp_1797 += (std::complex<double>(0.,-0.7071067811865475)*Conj(LamTD)*UM1(
      gI2,0)*ZH(gI1,0)) * tmp_1798;
   std::complex<double> tmp_1800;
   std::complex<double> tmp_1801;
   for (unsigned gl1296 = 0; gl1296 < 2; ++gl1296) {
      tmp_1801 += Conj(UM1(gl1296,gO1))*UP1(gl1296,0);
   }
   tmp_1800 += tmp_1801;
   tmp_1797 += (std::complex<double>(0.,-0.7071067811865475)*g2*UM1(gI2,1)*ZH(
      gI1,0)) * tmp_1800;
   std::complex<double> tmp_1802;
   std::complex<double> tmp_1803;
   for (unsigned gl1296 = 0; gl1296 < 2; ++gl1296) {
      tmp_1803 += Conj(UM1(gl1296,gO1))*UP1(gl1296,1);
   }
   tmp_1802 += tmp_1803;
   tmp_1797 += (std::complex<double>(0.,-0.7071067811865475)*Conj(LamSD)*UM1(
      gI2,1)*ZH(gI1,2)) * tmp_1802;
   std::complex<double> tmp_1804;
   std::complex<double> tmp_1805;
   for (unsigned gl1296 = 0; gl1296 < 2; ++gl1296) {
      tmp_1805 += Conj(UM1(gl1296,gO1))*UP1(gl1296,0);
   }
   tmp_1804 += tmp_1805;
   tmp_1797 += (std::complex<double>(0,-1)*g2*UM1(gI2,0)*ZH(gI1,3)) * tmp_1804;
   std::complex<double> tmp_1806;
   std::complex<double> tmp_1807;
   for (unsigned gl1296 = 0; gl1296 < 2; ++gl1296) {
      tmp_1807 += Conj(UM1(gl1296,gO1))*UP1(gl1296,1);
   }
   tmp_1806 += tmp_1807;
   tmp_1797 += (std::complex<double>(0,0.5)*Conj(LamTD)*UM1(gI2,1)*ZH(gI1,3)) *
      tmp_1806;
   result += (std::complex<double>(0,-1)) * tmp_1797;

   return result;
}

std::complex<double> CLASSNAME::CpbarUCha1conjHpmChiPL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1808;
   std::complex<double> tmp_1809;
   std::complex<double> tmp_1810;
   for (unsigned gl1299 = 0; gl1299 < 2; ++gl1299) {
      tmp_1810 += Conj(UM1(gl1299,1))*UP1(gl1299,gO2);
   }
   tmp_1809 += tmp_1810;
   tmp_1808 += (std::complex<double>(0.,0.5477225575051661)*g1*Conj(ZN1(gI2,0))
      *ZP(gI1,0)) * tmp_1809;
   std::complex<double> tmp_1811;
   std::complex<double> tmp_1812;
   for (unsigned gl1299 = 0; gl1299 < 2; ++gl1299) {
      tmp_1812 += Conj(UM1(gl1299,1))*UP1(gl1299,gO2);
   }
   tmp_1811 += tmp_1812;
   tmp_1808 += (std::complex<double>(0.,0.7071067811865475)*g2*Conj(ZN1(gI2,1))
      *ZP(gI1,0)) * tmp_1811;
   std::complex<double> tmp_1813;
   std::complex<double> tmp_1814;
   for (unsigned gl1299 = 0; gl1299 < 2; ++gl1299) {
      tmp_1814 += Conj(UM1(gl1299,0))*UP1(gl1299,gO2);
   }
   tmp_1813 += tmp_1814;
   tmp_1808 += (std::complex<double>(0,-1)*LamTU*Conj(ZN1(gI2,3))*ZP(gI1,1)) *
      tmp_1813;
   std::complex<double> tmp_1815;
   std::complex<double> tmp_1816;
   for (unsigned gl1299 = 0; gl1299 < 2; ++gl1299) {
      tmp_1816 += Conj(UM1(gl1299,0))*UP1(gl1299,gO2);
   }
   tmp_1815 += tmp_1816;
   tmp_1808 += (std::complex<double>(0.,1.4142135623730951)*g2*Conj(ZN1(gI2,1))
      *ZP(gI1,2)) * tmp_1815;
   std::complex<double> tmp_1817;
   std::complex<double> tmp_1818;
   for (unsigned gl1299 = 0; gl1299 < 2; ++gl1299) {
      tmp_1818 += Conj(UM1(gl1299,1))*UP1(gl1299,gO2);
   }
   tmp_1817 += tmp_1818;
   tmp_1808 += (std::complex<double>(0,1)*LamTD*Conj(ZN1(gI2,2))*ZP(gI1,3)) *
      tmp_1817;
   result += (std::complex<double>(0,-1)) * tmp_1808;

   return result;
}

std::complex<double> CLASSNAME::CpbarUCha1conjHpmChiPR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1819;
   std::complex<double> tmp_1820;
   std::complex<double> tmp_1821;
   for (unsigned gl1302 = 0; gl1302 < 2; ++gl1302) {
      tmp_1821 += Conj(UM1(gl1302,gO1))*UP1(gl1302,1);
   }
   tmp_1820 += tmp_1821;
   tmp_1819 += (std::complex<double>(0,-1)*Conj(LamSD)*ZN2(gI2,0)*ZP(gI1,0)) *
      tmp_1820;
   std::complex<double> tmp_1822;
   std::complex<double> tmp_1823;
   for (unsigned gl1302 = 0; gl1302 < 2; ++gl1302) {
      tmp_1823 += Conj(UM1(gl1302,gO1))*UP1(gl1302,1);
   }
   tmp_1822 += tmp_1823;
   tmp_1819 += (std::complex<double>(0.,0.7071067811865475)*Conj(LamTD)*ZN2(gI2
      ,1)*ZP(gI1,0)) * tmp_1822;
   std::complex<double> tmp_1824;
   std::complex<double> tmp_1825;
   for (unsigned gl1302 = 0; gl1302 < 2; ++gl1302) {
      tmp_1825 += Conj(UM1(gl1302,gO1))*UP1(gl1302,0);
   }
   tmp_1824 += tmp_1825;
   tmp_1819 += (std::complex<double>(0,-1)*g2*ZN2(gI2,3)*ZP(gI1,1)) * tmp_1824;
   std::complex<double> tmp_1826;
   std::complex<double> tmp_1827;
   for (unsigned gl1302 = 0; gl1302 < 2; ++gl1302) {
      tmp_1827 += Conj(UM1(gl1302,gO1))*UP1(gl1302,1);
   }
   tmp_1826 += tmp_1827;
   tmp_1819 += (std::complex<double>(0,-1)*Conj(LamTD)*ZN2(gI2,2)*ZP(gI1,2)) *
      tmp_1826;
   std::complex<double> tmp_1828;
   std::complex<double> tmp_1829;
   for (unsigned gl1302 = 0; gl1302 < 2; ++gl1302) {
      tmp_1829 += Conj(UM1(gl1302,gO1))*UP1(gl1302,0);
   }
   tmp_1828 += tmp_1829;
   tmp_1819 += (std::complex<double>(0.,1.4142135623730951)*g2*ZN2(gI2,1)*ZP(
      gI1,3)) * tmp_1828;
   result += (std::complex<double>(0,-1)) * tmp_1819;

   return result;
}

std::complex<double> CLASSNAME::CpbarUCha1conjSdFuPL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1830;
   std::complex<double> tmp_1832;
   for (unsigned gl1305 = 0; gl1305 < 2; ++gl1305) {
      tmp_1832 += Conj(UM1(gl1305,1))*UP1(gl1305,gO2);
   }
   tmp_1830 += tmp_1832;
   std::complex<double> tmp_1831;
   std::complex<double> tmp_1833;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_1834;
      std::complex<double> tmp_1835;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1835 += Yd(j1,j2)*ZD(gI1,3 + j1);
      }
      tmp_1834 += tmp_1835;
      tmp_1833 += (Conj(ZUL(gI2,j2))) * tmp_1834;
   }
   tmp_1831 += tmp_1833;
   result += (1) * tmp_1830 * tmp_1831;

   return result;
}

double CLASSNAME::CpbarUCha1conjSdFuPR(unsigned , unsigned , unsigned ) const
{
   double result = 0.0;

   result = 0;

   return result;
}

std::complex<double> CLASSNAME::CpbarUCha1conjSeFvPL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1836;
   std::complex<double> tmp_1838;
   for (unsigned gl1311 = 0; gl1311 < 2; ++gl1311) {
      tmp_1838 += Conj(UM1(gl1311,1))*UP1(gl1311,gO2);
   }
   tmp_1836 += tmp_1838;
   std::complex<double> tmp_1837;
   std::complex<double> tmp_1839;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1839 += Ye(j1,gI2)*ZE(gI1,3 + j1);
   }
   tmp_1837 += tmp_1839;
   result += (1) * tmp_1836 * tmp_1837;

   return result;
}

double CLASSNAME::CpbarUCha1conjSeFvPR(unsigned , unsigned , unsigned ) const
{
   double result = 0.0;

   result = 0;

   return result;
}

std::complex<double> CLASSNAME::CpbarUCha1VPCha1PR(unsigned gO2, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1840;
   std::complex<double> tmp_1841;
   std::complex<double> tmp_1842;
   for (unsigned gl1317 = 0; gl1317 < 2; ++gl1317) {
      tmp_1842 += Conj(UM1(gl1317,0))*UP1(gl1317,gO2);
   }
   tmp_1841 += tmp_1842;
   tmp_1840 += (std::complex<double>(0,-1)*g2*Sin(ThetaW())*UM1(gI2,0)) *
      tmp_1841;
   std::complex<double> tmp_1843;
   std::complex<double> tmp_1844;
   for (unsigned gl1317 = 0; gl1317 < 2; ++gl1317) {
      tmp_1844 += Conj(UM1(gl1317,1))*UP1(gl1317,gO2);
   }
   tmp_1843 += tmp_1844;
   tmp_1840 += (std::complex<double>(0.,-0.3872983346207417)*g1*Cos(ThetaW())*
      UM1(gI2,1)) * tmp_1843;
   std::complex<double> tmp_1845;
   std::complex<double> tmp_1846;
   for (unsigned gl1317 = 0; gl1317 < 2; ++gl1317) {
      tmp_1846 += Conj(UM1(gl1317,1))*UP1(gl1317,gO2);
   }
   tmp_1845 += tmp_1846;
   tmp_1840 += (std::complex<double>(0,-0.5)*g2*Sin(ThetaW())*UM1(gI2,1)) *
      tmp_1845;
   result += (std::complex<double>(0,-1)) * tmp_1840;

   return result;
}

std::complex<double> CLASSNAME::CpbarUCha1VPCha1PL(unsigned gO1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1847;
   std::complex<double> tmp_1848;
   std::complex<double> tmp_1849;
   for (unsigned gl1320 = 0; gl1320 < 2; ++gl1320) {
      tmp_1849 += Conj(UM1(gl1320,gO1))*UP1(gl1320,1);
   }
   tmp_1848 += tmp_1849;
   tmp_1847 += (std::complex<double>(0.,-0.3872983346207417)*g1*Conj(UP1(gI2,1)
      )*Cos(ThetaW())) * tmp_1848;
   std::complex<double> tmp_1850;
   std::complex<double> tmp_1851;
   for (unsigned gl1320 = 0; gl1320 < 2; ++gl1320) {
      tmp_1851 += Conj(UM1(gl1320,gO1))*UP1(gl1320,0);
   }
   tmp_1850 += tmp_1851;
   tmp_1847 += (std::complex<double>(0,-1)*g2*Conj(UP1(gI2,0))*Sin(ThetaW())) *
      tmp_1850;
   std::complex<double> tmp_1852;
   std::complex<double> tmp_1853;
   for (unsigned gl1320 = 0; gl1320 < 2; ++gl1320) {
      tmp_1853 += Conj(UM1(gl1320,gO1))*UP1(gl1320,1);
   }
   tmp_1852 += tmp_1853;
   tmp_1847 += (std::complex<double>(0,-0.5)*g2*Conj(UP1(gI2,1))*Sin(ThetaW()))
      * tmp_1852;
   result += (std::complex<double>(0,-1)) * tmp_1847;

   return result;
}

std::complex<double> CLASSNAME::CpbarUCha1VZCha1PR(unsigned gO2, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1854;
   std::complex<double> tmp_1855;
   std::complex<double> tmp_1856;
   for (unsigned gl1323 = 0; gl1323 < 2; ++gl1323) {
      tmp_1856 += Conj(UM1(gl1323,0))*UP1(gl1323,gO2);
   }
   tmp_1855 += tmp_1856;
   tmp_1854 += (std::complex<double>(0,-1)*g2*Cos(ThetaW())*UM1(gI2,0)) *
      tmp_1855;
   std::complex<double> tmp_1857;
   std::complex<double> tmp_1858;
   for (unsigned gl1323 = 0; gl1323 < 2; ++gl1323) {
      tmp_1858 += Conj(UM1(gl1323,1))*UP1(gl1323,gO2);
   }
   tmp_1857 += tmp_1858;
   tmp_1854 += (std::complex<double>(0,-0.5)*g2*Cos(ThetaW())*UM1(gI2,1)) *
      tmp_1857;
   std::complex<double> tmp_1859;
   std::complex<double> tmp_1860;
   for (unsigned gl1323 = 0; gl1323 < 2; ++gl1323) {
      tmp_1860 += Conj(UM1(gl1323,1))*UP1(gl1323,gO2);
   }
   tmp_1859 += tmp_1860;
   tmp_1854 += (std::complex<double>(0.,0.3872983346207417)*g1*Sin(ThetaW())*
      UM1(gI2,1)) * tmp_1859;
   result += (std::complex<double>(0,-1)) * tmp_1854;

   return result;
}

std::complex<double> CLASSNAME::CpbarUCha1VZCha1PL(unsigned gO1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1861;
   std::complex<double> tmp_1862;
   std::complex<double> tmp_1863;
   for (unsigned gl1326 = 0; gl1326 < 2; ++gl1326) {
      tmp_1863 += Conj(UM1(gl1326,gO1))*UP1(gl1326,0);
   }
   tmp_1862 += tmp_1863;
   tmp_1861 += (std::complex<double>(0,-1)*g2*Conj(UP1(gI2,0))*Cos(ThetaW())) *
      tmp_1862;
   std::complex<double> tmp_1864;
   std::complex<double> tmp_1865;
   for (unsigned gl1326 = 0; gl1326 < 2; ++gl1326) {
      tmp_1865 += Conj(UM1(gl1326,gO1))*UP1(gl1326,1);
   }
   tmp_1864 += tmp_1865;
   tmp_1861 += (std::complex<double>(0,-0.5)*g2*Conj(UP1(gI2,1))*Cos(ThetaW()))
      * tmp_1864;
   std::complex<double> tmp_1866;
   std::complex<double> tmp_1867;
   for (unsigned gl1326 = 0; gl1326 < 2; ++gl1326) {
      tmp_1867 += Conj(UM1(gl1326,gO1))*UP1(gl1326,1);
   }
   tmp_1866 += tmp_1867;
   tmp_1861 += (std::complex<double>(0.,0.3872983346207417)*g1*Conj(UP1(gI2,1))
      *Sin(ThetaW())) * tmp_1866;
   result += (std::complex<double>(0,-1)) * tmp_1861;

   return result;
}

std::complex<double> CLASSNAME::CpbarUCha1conjVWmChiPR(unsigned gO2, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1868;
   std::complex<double> tmp_1869;
   std::complex<double> tmp_1870;
   for (unsigned gl1329 = 0; gl1329 < 2; ++gl1329) {
      tmp_1870 += Conj(UM1(gl1329,0))*UP1(gl1329,gO2);
   }
   tmp_1869 += tmp_1870;
   tmp_1868 += (std::complex<double>(0,1)*g2*ZN2(gI2,1)) * tmp_1869;
   std::complex<double> tmp_1871;
   std::complex<double> tmp_1872;
   for (unsigned gl1329 = 0; gl1329 < 2; ++gl1329) {
      tmp_1872 += Conj(UM1(gl1329,1))*UP1(gl1329,gO2);
   }
   tmp_1871 += tmp_1872;
   tmp_1868 += (std::complex<double>(0.,0.7071067811865475)*g2*ZN2(gI2,2)) *
      tmp_1871;
   result += (std::complex<double>(0,-1)) * tmp_1868;

   return result;
}

std::complex<double> CLASSNAME::CpbarUCha1conjVWmChiPL(unsigned gO1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1873;
   std::complex<double> tmp_1874;
   std::complex<double> tmp_1875;
   for (unsigned gl1332 = 0; gl1332 < 2; ++gl1332) {
      tmp_1875 += Conj(UM1(gl1332,gO1))*UP1(gl1332,0);
   }
   tmp_1874 += tmp_1875;
   tmp_1873 += (std::complex<double>(0,1)*g2*Conj(ZN1(gI2,1))) * tmp_1874;
   std::complex<double> tmp_1876;
   std::complex<double> tmp_1877;
   for (unsigned gl1332 = 0; gl1332 < 2; ++gl1332) {
      tmp_1877 += Conj(UM1(gl1332,gO1))*UP1(gl1332,1);
   }
   tmp_1876 += tmp_1877;
   tmp_1873 += (std::complex<double>(0.,-0.7071067811865475)*g2*Conj(ZN1(gI2,2)
      )) * tmp_1876;
   result += (std::complex<double>(0,-1)) * tmp_1873;

   return result;
}

std::complex<double> CLASSNAME::CpbarUCha2barCha1RhPL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = LamTD*Conj(UM1(gI1,1))*KroneckerDelta(0,gO2)*ZHR(gI2,0) - LamTU*
      Conj(UM1(gI1,0))*KroneckerDelta(1,gO2)*ZHR(gI2,1);

   return result;
}

std::complex<double> CLASSNAME::CpbarUCha2barCha1RhPR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = -(g2*(KroneckerDelta(0,gO1)*UP1(gI1,1)*ZHR(gI2,0) + KroneckerDelta(
      1,gO1)*UP1(gI1,0)*ZHR(gI2,1)));

   return result;
}

std::complex<double> CLASSNAME::CpbarUCha2Cha2AhPL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = std::complex<double>(0,0.5)*(g2*Conj(UM2(gI1,0))*(
      1.4142135623730951*KroneckerDelta(1,gO2)*ZA(gI2,1) - 2*KroneckerDelta(0,gO2)
      *ZA(gI2,3)) + Conj(UM2(gI1,1))*(1.4142135623730951*LamTU*KroneckerDelta(0,
      gO2)*ZA(gI2,1) + KroneckerDelta(1,gO2)*(1.4142135623730951*LamSU*ZA(gI2,2) +
      LamTU*ZA(gI2,3))));

   return result;
}

std::complex<double> CLASSNAME::CpbarUCha2Cha2AhPR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = std::complex<double>(0,-0.5)*(1.4142135623730951*Conj(LamSU)*
      KroneckerDelta(1,gO1)*UP2(gI1,1)*ZA(gI2,2) + g2*KroneckerDelta(0,gO1)*(
      1.4142135623730951*UP2(gI1,1)*ZA(gI2,1) - 2*UP2(gI1,0)*ZA(gI2,3)) + Conj(
      LamTU)*KroneckerDelta(1,gO1)*(1.4142135623730951*UP2(gI1,0)*ZA(gI2,1) + UP2(
      gI1,1)*ZA(gI2,3)));

   return result;
}

std::complex<double> CLASSNAME::CpbarUCha2barFuSdPL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1878;
   std::complex<double> tmp_1879;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_1880;
      std::complex<double> tmp_1881;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1881 += Conj(ZUR(gI1,j1))*Yu(j1,j2);
      }
      tmp_1880 += tmp_1881;
      tmp_1879 += (Conj(ZD(gI2,j2))) * tmp_1880;
   }
   tmp_1878 += tmp_1879;
   result += (KroneckerDelta(1,gO2)) * tmp_1878;

   return result;
}

std::complex<double> CLASSNAME::CpbarUCha2barFuSdPR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1882;
   std::complex<double> tmp_1883;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1883 += Conj(ZD(gI2,j1))*ZUL(gI1,j1);
   }
   tmp_1882 += tmp_1883;
   result += (-(g2*KroneckerDelta(0,gO1))) * tmp_1882;

   return result;
}

double CLASSNAME::CpbarUCha2barFvSePL(unsigned , unsigned , unsigned ) const
{
   double result = 0.0;

   result = 0;

   return result;
}

std::complex<double> CLASSNAME::CpbarUCha2barFvSePR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gI1 < 3) {
      result += -(g2*Conj(ZE(gI2,gI1))*KroneckerDelta(0,gO1));
   }

   return result;
}

std::complex<double> CLASSNAME::CpbarUCha2barChiRpmPL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.5*Conj(ZRP(gI2,0))*(2*LamTU*Conj(ZN2(gI1,3))*KroneckerDelta(0,gO2
      ) + (2*LamSU*Conj(ZN2(gI1,0)) + 1.4142135623730951*LamTU*Conj(ZN2(gI1,1)))*
      KroneckerDelta(1,gO2));

   return result;
}

std::complex<double> CLASSNAME::CpbarUCha2barChiRpmPR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.1*Conj(ZRP(gI2,0))*(KroneckerDelta(1,gO1)*(5.477225575051661*g1*
      ZN1(gI1,0) + 7.0710678118654755*g2*ZN1(gI1,1)) - 10*g2*KroneckerDelta(0,gO1)
      *ZN1(gI1,3));

   return result;
}

std::complex<double> CLASSNAME::CpbarUCha2hhCha2PL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.5*(g2*Conj(UM2(gI2,0))*(-1.4142135623730951*KroneckerDelta(1,gO2)
      *ZH(gI1,1) + 2*KroneckerDelta(0,gO2)*ZH(gI1,3)) + Conj(UM2(gI2,1))*(
      1.4142135623730951*LamTU*KroneckerDelta(0,gO2)*ZH(gI1,1) + KroneckerDelta(1,
      gO2)*(1.4142135623730951*LamSU*ZH(gI1,2) + LamTU*ZH(gI1,3))));

   return result;
}

std::complex<double> CLASSNAME::CpbarUCha2hhCha2PR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = 0.5*(1.4142135623730951*Conj(LamSU)*KroneckerDelta(1,gO1)*UP2(gI2,1
      )*ZH(gI1,2) + KroneckerDelta(0,gO1)*(-1.4142135623730951*g2*UP2(gI2,1)*ZH(
      gI1,1) + 2*g2*UP2(gI2,0)*ZH(gI1,3)) + Conj(LamTU)*KroneckerDelta(1,gO1)*(
      1.4142135623730951*UP2(gI2,0)*ZH(gI1,1) + UP2(gI2,1)*ZH(gI1,3)));

   return result;
}

std::complex<double> CLASSNAME::CpbarUCha2HpmChiPL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = LamTD*Conj(ZN1(gI2,2))*KroneckerDelta(0,gO2)*ZP(gI1,0) -
      0.5477225575051661*g1*Conj(ZN1(gI2,0))*KroneckerDelta(1,gO2)*ZP(gI1,1) -
      0.7071067811865475*g2*Conj(ZN1(gI2,1))*KroneckerDelta(1,gO2)*ZP(gI1,1) -
      LamTU*Conj(ZN1(gI2,3))*KroneckerDelta(1,gO2)*ZP(gI1,2) - 1.4142135623730951*
      g2*Conj(ZN1(gI2,1))*KroneckerDelta(0,gO2)*ZP(gI1,3);

   return result;
}

std::complex<double> CLASSNAME::CpbarUCha2HpmChiPR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   result = -(g2*KroneckerDelta(0,gO1)*(ZN2(gI2,2)*ZP(gI1,0) +
      1.4142135623730951*ZN2(gI2,1)*ZP(gI1,2))) + 0.5*KroneckerDelta(1,gO1)*(2*
      Conj(LamSU)*ZN2(gI2,0)*ZP(gI1,1) + Conj(LamTU)*(1.4142135623730951*ZN2(gI2,1
      )*ZP(gI1,1) + 2*ZN2(gI2,3)*ZP(gI1,3)));

   return result;
}

std::complex<double> CLASSNAME::CpbarUCha2conjSuFdPL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1884;
   std::complex<double> tmp_1885;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_1886;
      std::complex<double> tmp_1887;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1887 += Yu(j1,j2)*ZU(gI1,3 + j1);
      }
      tmp_1886 += tmp_1887;
      tmp_1885 += (Conj(ZDL(gI2,j2))) * tmp_1886;
   }
   tmp_1884 += tmp_1885;
   result += (KroneckerDelta(1,gO2)) * tmp_1884;

   return result;
}

double CLASSNAME::CpbarUCha2conjSuFdPR(unsigned , unsigned , unsigned ) const
{
   double result = 0.0;

   result = 0;

   return result;
}

std::complex<double> CLASSNAME::CpbarUCha2VPCha2PR(unsigned gO2, unsigned gI2) const
{
   std::complex<double> result;

   result = g2*KroneckerDelta(0,gO2)*Sin(ThetaW())*UP2(gI2,0) + 0.1*
      KroneckerDelta(1,gO2)*(3.872983346207417*g1*Cos(ThetaW()) + 5*g2*Sin(ThetaW(
      )))*UP2(gI2,1);

   return result;
}

std::complex<double> CLASSNAME::CpbarUCha2VPCha2PL(unsigned gO1, unsigned gI2) const
{
   std::complex<double> result;

   result = g2*Conj(UM2(gI2,0))*KroneckerDelta(0,gO1)*Sin(ThetaW()) + 0.1*Conj(
      UM2(gI2,1))*KroneckerDelta(1,gO1)*(3.872983346207417*g1*Cos(ThetaW()) + 5*g2
      *Sin(ThetaW()));

   return result;
}

std::complex<double> CLASSNAME::CpbarUCha2VZCha2PR(unsigned gO2, unsigned gI2) const
{
   std::complex<double> result;

   result = g2*Cos(ThetaW())*KroneckerDelta(0,gO2)*UP2(gI2,0) + 0.1*
      KroneckerDelta(1,gO2)*(5*g2*Cos(ThetaW()) - 3.872983346207417*g1*Sin(ThetaW(
      )))*UP2(gI2,1);

   return result;
}

std::complex<double> CLASSNAME::CpbarUCha2VZCha2PL(unsigned gO1, unsigned gI2) const
{
   std::complex<double> result;

   result = g2*Conj(UM2(gI2,0))*Cos(ThetaW())*KroneckerDelta(0,gO1) + 0.1*Conj(
      UM2(gI2,1))*KroneckerDelta(1,gO1)*(5*g2*Cos(ThetaW()) - 3.872983346207417*g1
      *Sin(ThetaW()));

   return result;
}

std::complex<double> CLASSNAME::CpbarUCha2VWmChiPR(unsigned gO2, unsigned gI2) const
{
   std::complex<double> result;

   result = -(g2*KroneckerDelta(0,gO2)*ZN2(gI2,1)) + 0.7071067811865475*g2*
      KroneckerDelta(1,gO2)*ZN2(gI2,3);

   return result;
}

std::complex<double> CLASSNAME::CpbarUCha2VWmChiPL(unsigned gO1, unsigned gI2) const
{
   std::complex<double> result;

   result = -0.5*g2*(2*Conj(ZN1(gI2,1))*KroneckerDelta(0,gO1) +
      1.4142135623730951*Conj(ZN1(gI2,3))*KroneckerDelta(1,gO1));

   return result;
}

std::complex<double> CLASSNAME::CpbarUFebarCha1SvPL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gO2 < 3) {
      std::complex<double> tmp_1888;
      std::complex<double> tmp_1889;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         tmp_1889 += Conj(ZV(gI2,j2))*Ye(gO2,j2);
      }
      tmp_1888 += tmp_1889;
      result += (Conj(UM1(gI1,1))) * tmp_1888;
   }

   return result;
}

std::complex<double> CLASSNAME::CpbarUFebarCha1SvPR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gO1 < 3) {
      result += -(g2*Conj(ZV(gI2,gO1))*UP1(gI1,0));
   }

   return result;
}

std::complex<double> CLASSNAME::CpbarUFeFeAhPL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gO2 < 3) {
      std::complex<double> tmp_1890;
      std::complex<double> tmp_1891;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         tmp_1891 += Conj(ZEL(gI1,j2))*Ye(gO2,j2);
      }
      tmp_1890 += tmp_1891;
      result += (std::complex<double>(0.,-0.7071067811865475)*ZA(gI2,0)) *
         tmp_1890;
   }

   return result;
}

std::complex<double> CLASSNAME::CpbarUFeFeAhPR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gO1 < 3) {
      std::complex<double> tmp_1892;
      std::complex<double> tmp_1893;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1893 += Conj(Ye(j1,gO1))*ZER(gI1,j1);
      }
      tmp_1892 += tmp_1893;
      result += (std::complex<double>(0.,0.7071067811865475)*ZA(gI2,0)) *
         tmp_1892;
   }

   return result;
}

std::complex<double> CLASSNAME::CpbarUFehhFePL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gO2 < 3) {
      std::complex<double> tmp_1894;
      std::complex<double> tmp_1895;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         tmp_1895 += Conj(ZEL(gI2,j2))*Ye(gO2,j2);
      }
      tmp_1894 += tmp_1895;
      result += (-0.7071067811865475*ZH(gI1,0)) * tmp_1894;
   }

   return result;
}

std::complex<double> CLASSNAME::CpbarUFehhFePR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gO1 < 3) {
      std::complex<double> tmp_1896;
      std::complex<double> tmp_1897;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1897 += Conj(Ye(j1,gO1))*ZER(gI2,j1);
      }
      tmp_1896 += tmp_1897;
      result += (-0.7071067811865475*ZH(gI1,0)) * tmp_1896;
   }

   return result;
}

std::complex<double> CLASSNAME::CpbarUFeHpmFvPL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gO2 < 3) {
      result += Ye(gO2,gI2)*ZP(gI1,0);
   }

   return result;
}

double CLASSNAME::CpbarUFeHpmFvPR(unsigned , unsigned , unsigned ) const
{
   double result = 0.0;

   result = 0;

   return result;
}

std::complex<double> CLASSNAME::CpbarUFebarChiSePL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gO2 < 3) {
      std::complex<double> tmp_1898;
      std::complex<double> tmp_1899;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         tmp_1899 += Conj(ZE(gI2,j2))*Ye(gO2,j2);
      }
      tmp_1898 += tmp_1899;
      result += (-Conj(ZN2(gI1,2))) * tmp_1898;
   }

   return result;
}

std::complex<double> CLASSNAME::CpbarUFebarChiSePR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gO1 < 3) {
      result += 0.5477225575051661*g1*Conj(ZE(gI2,gO1))*ZN1(gI1,0);
   }
   if (gO1 < 3) {
      result += 0.7071067811865475*g2*Conj(ZE(gI2,gO1))*ZN1(gI1,1);
   }

   return result;
}

std::complex<double> CLASSNAME::CpbarUFeSeChiPL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gO2 < 3) {
      result += -1.0954451150103321*g1*Conj(ZE(gI1,3 + gO2))*Conj(ZN1(gI2,0)
         );
   }

   return result;
}

std::complex<double> CLASSNAME::CpbarUFeSeChiPR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gO1 < 3) {
      std::complex<double> tmp_1900;
      std::complex<double> tmp_1901;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1901 += Conj(Ye(j1,gO1))*Conj(ZE(gI1,3 + j1));
      }
      tmp_1900 += tmp_1901;
      result += (-ZN2(gI2,2)) * tmp_1900;
   }

   return result;
}

std::complex<double> CLASSNAME::CpbarUFeVPFePR(unsigned gO2, unsigned gI2) const
{
   std::complex<double> result;

   if (gI2 < 3) {
      result += 0.7745966692414834*g1*Cos(ThetaW())*ZER(gI2,gO2);
   }

   return result;
}

std::complex<double> CLASSNAME::CpbarUFeVPFePL(unsigned gO1, unsigned gI2) const
{
   std::complex<double> result;

   if (gI2 < 3) {
      result += 0.3872983346207417*g1*Conj(ZEL(gI2,gO1))*Cos(ThetaW());
   }
   if (gI2 < 3) {
      result += 0.5*g2*Conj(ZEL(gI2,gO1))*Sin(ThetaW());
   }

   return result;
}

double CLASSNAME::CpbarUFeVWmFvPR(unsigned , unsigned ) const
{
   double result = 0.0;

   result = 0;

   return result;
}

double CLASSNAME::CpbarUFeVWmFvPL(unsigned gO1, unsigned gI2) const
{
   double result = 0.0;

   if (gI2 < 3) {
      result += -0.7071067811865475*g2*KroneckerDelta(gI2,gO1);
   }

   return result;
}

std::complex<double> CLASSNAME::CpbarUFeVZFePR(unsigned gO2, unsigned gI2) const
{
   std::complex<double> result;

   if (gI2 < 3) {
      result += -0.7745966692414834*g1*Sin(ThetaW())*ZER(gI2,gO2);
   }

   return result;
}

std::complex<double> CLASSNAME::CpbarUFeVZFePL(unsigned gO1, unsigned gI2) const
{
   std::complex<double> result;

   if (gI2 < 3) {
      result += 0.5*g2*Conj(ZEL(gI2,gO1))*Cos(ThetaW());
   }
   if (gI2 < 3) {
      result += -0.3872983346207417*g1*Conj(ZEL(gI2,gO1))*Sin(ThetaW());
   }

   return result;
}

std::complex<double> CLASSNAME::CpbarUFdbarCha1SuPL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gO2 < 3) {
      std::complex<double> tmp_1902;
      std::complex<double> tmp_1903;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         tmp_1903 += Conj(ZU(gI2,j2))*Yd(gO2,j2);
      }
      tmp_1902 += tmp_1903;
      result += (Conj(UM1(gI1,1))) * tmp_1902;
   }

   return result;
}

std::complex<double> CLASSNAME::CpbarUFdbarCha1SuPR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gO1 < 3) {
      result += -(g2*Conj(ZU(gI2,gO1))*UP1(gI1,0));
   }

   return result;
}

std::complex<double> CLASSNAME::CpbarUFdFdAhPL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gO2 < 3) {
      std::complex<double> tmp_1904;
      std::complex<double> tmp_1905;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         tmp_1905 += Conj(ZDL(gI1,j2))*Yd(gO2,j2);
      }
      tmp_1904 += tmp_1905;
      result += (std::complex<double>(0.,-0.7071067811865475)*ZA(gI2,0)) *
         tmp_1904;
   }

   return result;
}

std::complex<double> CLASSNAME::CpbarUFdFdAhPR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gO1 < 3) {
      std::complex<double> tmp_1906;
      std::complex<double> tmp_1907;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1907 += Conj(Yd(j1,gO1))*ZDR(gI1,j1);
      }
      tmp_1906 += tmp_1907;
      result += (std::complex<double>(0.,0.7071067811865475)*ZA(gI2,0)) *
         tmp_1906;
   }

   return result;
}

std::complex<double> CLASSNAME::CpbarUFdhhFdPL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gO2 < 3) {
      std::complex<double> tmp_1908;
      std::complex<double> tmp_1909;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         tmp_1909 += Conj(ZDL(gI2,j2))*Yd(gO2,j2);
      }
      tmp_1908 += tmp_1909;
      result += (-0.7071067811865475*ZH(gI1,0)) * tmp_1908;
   }

   return result;
}

std::complex<double> CLASSNAME::CpbarUFdhhFdPR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gO1 < 3) {
      std::complex<double> tmp_1910;
      std::complex<double> tmp_1911;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1911 += Conj(Yd(j1,gO1))*ZDR(gI2,j1);
      }
      tmp_1910 += tmp_1911;
      result += (-0.7071067811865475*ZH(gI1,0)) * tmp_1910;
   }

   return result;
}

std::complex<double> CLASSNAME::CpbarUFdHpmFuPL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gO2 < 3) {
      std::complex<double> tmp_1912;
      std::complex<double> tmp_1913;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         tmp_1913 += Conj(ZUL(gI2,j2))*Yd(gO2,j2);
      }
      tmp_1912 += tmp_1913;
      result += (ZP(gI1,0)) * tmp_1912;
   }

   return result;
}

std::complex<double> CLASSNAME::CpbarUFdHpmFuPR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gO1 < 3) {
      std::complex<double> tmp_1914;
      std::complex<double> tmp_1915;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1915 += Conj(Yu(j1,gO1))*ZUR(gI2,j1);
      }
      tmp_1914 += tmp_1915;
      result += (ZP(gI1,1)) * tmp_1914;
   }

   return result;
}

std::complex<double> CLASSNAME::CpbarUFdbarChiSdPL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gO2 < 3) {
      std::complex<double> tmp_1916;
      std::complex<double> tmp_1917;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         tmp_1917 += Conj(ZD(gI2,j2))*Yd(gO2,j2);
      }
      tmp_1916 += tmp_1917;
      result += (-Conj(ZN2(gI1,2))) * tmp_1916;
   }

   return result;
}

std::complex<double> CLASSNAME::CpbarUFdbarChiSdPR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gO1 < 3) {
      result += -0.18257418583505536*g1*Conj(ZD(gI2,gO1))*ZN1(gI1,0);
   }
   if (gO1 < 3) {
      result += 0.7071067811865475*g2*Conj(ZD(gI2,gO1))*ZN1(gI1,1);
   }

   return result;
}

double CLASSNAME::CpbarUFdSuCha2PL(unsigned , unsigned , unsigned ) const
{
   double result = 0.0;

   result = 0;

   return result;
}

std::complex<double> CLASSNAME::CpbarUFdSuCha2PR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gO1 < 3) {
      std::complex<double> tmp_1918;
      std::complex<double> tmp_1919;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1919 += Conj(Yu(j1,gO1))*Conj(ZU(gI1,3 + j1));
      }
      tmp_1918 += tmp_1919;
      result += (UP2(gI2,1)) * tmp_1918;
   }

   return result;
}

std::complex<double> CLASSNAME::CpbarUFdSdChiPL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gO2 < 3) {
      result += -0.3651483716701107*g1*Conj(ZD(gI1,3 + gO2))*Conj(ZN1(gI2,0)
         );
   }

   return result;
}

std::complex<double> CLASSNAME::CpbarUFdSdChiPR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gO1 < 3) {
      std::complex<double> tmp_1920;
      std::complex<double> tmp_1921;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1921 += Conj(Yd(j1,gO1))*Conj(ZD(gI1,3 + j1));
      }
      tmp_1920 += tmp_1921;
      result += (-ZN2(gI2,2)) * tmp_1920;
   }

   return result;
}

std::complex<double> CLASSNAME::CpbarUFdSdGluPL(unsigned gO2, unsigned gI1, unsigned ) const
{
   std::complex<double> result;

   if (gO2 < 3) {
      result += 1.4142135623730951*g3*Conj(ZD(gI1,3 + gO2));
   }

   return result;
}

double CLASSNAME::CpbarUFdSdGluPR(unsigned , unsigned , unsigned ) const
{
   double result = 0.0;

   result = 0;

   return result;
}

std::complex<double> CLASSNAME::CpbarUFdVGFdPR(unsigned gO2, unsigned gI2) const
{
   std::complex<double> result;

   if (gI2 < 3) {
      result += -(g3*ZDR(gI2,gO2));
   }

   return result;
}

std::complex<double> CLASSNAME::CpbarUFdVGFdPL(unsigned gO1, unsigned gI2) const
{
   std::complex<double> result;

   if (gI2 < 3) {
      result += -(g3*Conj(ZDL(gI2,gO1)));
   }

   return result;
}

std::complex<double> CLASSNAME::CpbarUFdVPFdPR(unsigned gO2, unsigned gI2) const
{
   std::complex<double> result;

   if (gI2 < 3) {
      result += 0.2581988897471611*g1*Cos(ThetaW())*ZDR(gI2,gO2);
   }

   return result;
}

std::complex<double> CLASSNAME::CpbarUFdVPFdPL(unsigned gO1, unsigned gI2) const
{
   std::complex<double> result;

   if (gI2 < 3) {
      result += -0.12909944487358055*g1*Conj(ZDL(gI2,gO1))*Cos(ThetaW());
   }
   if (gI2 < 3) {
      result += 0.5*g2*Conj(ZDL(gI2,gO1))*Sin(ThetaW());
   }

   return result;
}

double CLASSNAME::CpbarUFdVWmFuPR(unsigned , unsigned ) const
{
   double result = 0.0;

   result = 0;

   return result;
}

std::complex<double> CLASSNAME::CpbarUFdVWmFuPL(unsigned gO1, unsigned gI2) const
{
   std::complex<double> result;

   if (gO1 < 3) {
      result += -0.7071067811865475*g2*Conj(ZUL(gI2,gO1));
   }

   return result;
}

std::complex<double> CLASSNAME::CpbarUFdVZFdPR(unsigned gO2, unsigned gI2) const
{
   std::complex<double> result;

   if (gI2 < 3) {
      result += -0.2581988897471611*g1*Sin(ThetaW())*ZDR(gI2,gO2);
   }

   return result;
}

std::complex<double> CLASSNAME::CpbarUFdVZFdPL(unsigned gO1, unsigned gI2) const
{
   std::complex<double> result;

   if (gI2 < 3) {
      result += 0.5*g2*Conj(ZDL(gI2,gO1))*Cos(ThetaW());
   }
   if (gI2 < 3) {
      result += 0.12909944487358055*g1*Conj(ZDL(gI2,gO1))*Sin(ThetaW());
   }

   return result;
}

double CLASSNAME::CpbarUFdbarGluSdPL(unsigned , unsigned , unsigned ) const
{
   double result = 0.0;

   result = 0;

   return result;
}

std::complex<double> CLASSNAME::CpbarUFdbarGluSdPR(unsigned gO1, unsigned , unsigned gI2) const
{
   std::complex<double> result;

   if (gO1 < 3) {
      result += -1.4142135623730951*g3*Conj(ZD(gI2,gO1));
   }

   return result;
}

std::complex<double> CLASSNAME::CpbarUFubarCha2SdPL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gO2 < 3) {
      std::complex<double> tmp_1922;
      std::complex<double> tmp_1923;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         tmp_1923 += Conj(ZD(gI2,j2))*Yu(gO2,j2);
      }
      tmp_1922 += tmp_1923;
      result += (Conj(UP2(gI1,1))) * tmp_1922;
   }

   return result;
}

std::complex<double> CLASSNAME::CpbarUFubarCha2SdPR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gO1 < 3) {
      result += -(g2*Conj(ZD(gI2,gO1))*UM2(gI1,0));
   }

   return result;
}

std::complex<double> CLASSNAME::CpbarUFuFuAhPL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gO2 < 3) {
      std::complex<double> tmp_1924;
      std::complex<double> tmp_1925;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         tmp_1925 += Conj(ZUL(gI1,j2))*Yu(gO2,j2);
      }
      tmp_1924 += tmp_1925;
      result += (std::complex<double>(0.,-0.7071067811865475)*ZA(gI2,1)) *
         tmp_1924;
   }

   return result;
}

std::complex<double> CLASSNAME::CpbarUFuFuAhPR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gO1 < 3) {
      std::complex<double> tmp_1926;
      std::complex<double> tmp_1927;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1927 += Conj(Yu(j1,gO1))*ZUR(gI1,j1);
      }
      tmp_1926 += tmp_1927;
      result += (std::complex<double>(0.,0.7071067811865475)*ZA(gI2,1)) *
         tmp_1926;
   }

   return result;
}

std::complex<double> CLASSNAME::CpbarUFuconjHpmFdPL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gO2 < 3) {
      std::complex<double> tmp_1928;
      std::complex<double> tmp_1929;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         tmp_1929 += Conj(ZDL(gI2,j2))*Yu(gO2,j2);
      }
      tmp_1928 += tmp_1929;
      result += (ZP(gI1,1)) * tmp_1928;
   }

   return result;
}

std::complex<double> CLASSNAME::CpbarUFuconjHpmFdPR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gO1 < 3) {
      std::complex<double> tmp_1930;
      std::complex<double> tmp_1931;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1931 += Conj(Yd(j1,gO1))*ZDR(gI2,j1);
      }
      tmp_1930 += tmp_1931;
      result += (ZP(gI1,0)) * tmp_1930;
   }

   return result;
}

std::complex<double> CLASSNAME::CpbarUFuhhFuPL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gO2 < 3) {
      std::complex<double> tmp_1932;
      std::complex<double> tmp_1933;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         tmp_1933 += Conj(ZUL(gI2,j2))*Yu(gO2,j2);
      }
      tmp_1932 += tmp_1933;
      result += (-0.7071067811865475*ZH(gI1,1)) * tmp_1932;
   }

   return result;
}

std::complex<double> CLASSNAME::CpbarUFuhhFuPR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gO1 < 3) {
      std::complex<double> tmp_1934;
      std::complex<double> tmp_1935;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1935 += Conj(Yu(j1,gO1))*ZUR(gI2,j1);
      }
      tmp_1934 += tmp_1935;
      result += (-0.7071067811865475*ZH(gI1,1)) * tmp_1934;
   }

   return result;
}

std::complex<double> CLASSNAME::CpbarUFubarChiSuPL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gO2 < 3) {
      std::complex<double> tmp_1936;
      std::complex<double> tmp_1937;
      for (unsigned j2 = 0; j2 < 3; ++j2) {
         tmp_1937 += Conj(ZU(gI2,j2))*Yu(gO2,j2);
      }
      tmp_1936 += tmp_1937;
      result += (-Conj(ZN2(gI1,3))) * tmp_1936;
   }

   return result;
}

std::complex<double> CLASSNAME::CpbarUFubarChiSuPR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gO1 < 3) {
      result += -0.18257418583505536*g1*Conj(ZU(gI2,gO1))*ZN1(gI1,0);
   }
   if (gO1 < 3) {
      result += -0.7071067811865475*g2*Conj(ZU(gI2,gO1))*ZN1(gI1,1);
   }

   return result;
}

double CLASSNAME::CpbarUFuSdCha1PL(unsigned , unsigned , unsigned ) const
{
   double result = 0.0;

   result = 0;

   return result;
}

std::complex<double> CLASSNAME::CpbarUFuSdCha1PR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gO1 < 3) {
      std::complex<double> tmp_1938;
      std::complex<double> tmp_1939;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1939 += Conj(Yd(j1,gO1))*Conj(ZD(gI1,3 + j1));
      }
      tmp_1938 += tmp_1939;
      result += (UM1(gI2,1)) * tmp_1938;
   }

   return result;
}

std::complex<double> CLASSNAME::CpbarUFuSuChiPL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gO2 < 3) {
      result += 0.7302967433402214*g1*Conj(ZN1(gI2,0))*Conj(ZU(gI1,3 + gO2))
         ;
   }

   return result;
}

std::complex<double> CLASSNAME::CpbarUFuSuChiPR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   if (gO1 < 3) {
      std::complex<double> tmp_1940;
      std::complex<double> tmp_1941;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1941 += Conj(Yu(j1,gO1))*Conj(ZU(gI1,3 + j1));
      }
      tmp_1940 += tmp_1941;
      result += (-ZN2(gI2,3)) * tmp_1940;
   }

   return result;
}

std::complex<double> CLASSNAME::CpbarUFuSuGluPL(unsigned gO2, unsigned gI1, unsigned ) const
{
   std::complex<double> result;

   if (gO2 < 3) {
      result += 1.4142135623730951*g3*Conj(ZU(gI1,3 + gO2));
   }

   return result;
}

double CLASSNAME::CpbarUFuSuGluPR(unsigned , unsigned , unsigned ) const
{
   double result = 0.0;

   result = 0;

   return result;
}

std::complex<double> CLASSNAME::CpbarUFuVGFuPR(unsigned gO2, unsigned gI2) const
{
   std::complex<double> result;

   if (gI2 < 3) {
      result += -(g3*ZUR(gI2,gO2));
   }

   return result;
}

std::complex<double> CLASSNAME::CpbarUFuVGFuPL(unsigned gO1, unsigned gI2) const
{
   std::complex<double> result;

   if (gI2 < 3) {
      result += -(g3*Conj(ZUL(gI2,gO1)));
   }

   return result;
}

std::complex<double> CLASSNAME::CpbarUFuVPFuPR(unsigned gO2, unsigned gI2) const
{
   std::complex<double> result;

   if (gI2 < 3) {
      result += -0.5163977794943222*g1*Cos(ThetaW())*ZUR(gI2,gO2);
   }

   return result;
}

std::complex<double> CLASSNAME::CpbarUFuVPFuPL(unsigned gO1, unsigned gI2) const
{
   std::complex<double> result;

   if (gI2 < 3) {
      result += -0.12909944487358055*g1*Conj(ZUL(gI2,gO1))*Cos(ThetaW());
   }
   if (gI2 < 3) {
      result += -0.5*g2*Conj(ZUL(gI2,gO1))*Sin(ThetaW());
   }

   return result;
}

std::complex<double> CLASSNAME::CpbarUFuVZFuPR(unsigned gO2, unsigned gI2) const
{
   std::complex<double> result;

   if (gI2 < 3) {
      result += 0.5163977794943222*g1*Sin(ThetaW())*ZUR(gI2,gO2);
   }

   return result;
}

std::complex<double> CLASSNAME::CpbarUFuVZFuPL(unsigned gO1, unsigned gI2) const
{
   std::complex<double> result;

   if (gI2 < 3) {
      result += -0.5*g2*Conj(ZUL(gI2,gO1))*Cos(ThetaW());
   }
   if (gI2 < 3) {
      result += 0.12909944487358055*g1*Conj(ZUL(gI2,gO1))*Sin(ThetaW());
   }

   return result;
}

double CLASSNAME::CpbarUFuconjVWmFdPR(unsigned , unsigned ) const
{
   double result = 0.0;

   result = 0;

   return result;
}

std::complex<double> CLASSNAME::CpbarUFuconjVWmFdPL(unsigned gO1, unsigned gI2) const
{
   std::complex<double> result;

   if (gO1 < 3) {
      result += -0.7071067811865475*g2*Conj(ZDL(gI2,gO1));
   }

   return result;
}

double CLASSNAME::CpbarUFubarGluSuPL(unsigned , unsigned , unsigned ) const
{
   double result = 0.0;

   result = 0;

   return result;
}

std::complex<double> CLASSNAME::CpbarUFubarGluSuPR(unsigned gO1, unsigned , unsigned gI2) const
{
   std::complex<double> result;

   if (gO1 < 3) {
      result += -1.4142135623730951*g3*Conj(ZU(gI2,gO1));
   }

   return result;
}

double CLASSNAME::CpbarGlubarFdSdPL(unsigned , unsigned ) const
{
   double result = 0.0;

   result = 0;

   return result;
}

std::complex<double> CLASSNAME::CpbarGlubarFdSdPR(unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1942;
   std::complex<double> tmp_1943;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1943 += Conj(ZD(gI2,j1))*ZDL(gI1,j1);
   }
   tmp_1942 += tmp_1943;
   result += (-1.4142135623730951*g3) * tmp_1942;

   return result;
}

double CLASSNAME::CpbarGlubarFuSuPL(unsigned , unsigned ) const
{
   double result = 0.0;

   result = 0;

   return result;
}

std::complex<double> CLASSNAME::CpbarGlubarFuSuPR(unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1944;
   std::complex<double> tmp_1945;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1945 += Conj(ZU(gI2,j1))*ZUL(gI1,j1);
   }
   tmp_1944 += tmp_1945;
   result += (-1.4142135623730951*g3) * tmp_1944;

   return result;
}

double CLASSNAME::CpbarGluconjSdFdPL(unsigned , unsigned ) const
{
   double result = 0.0;

   result = 0;

   return result;
}

std::complex<double> CLASSNAME::CpbarGluconjSdFdPR(unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1946;
   std::complex<double> tmp_1947;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1947 += ZD(gI1,3 + j1)*ZDR(gI2,j1);
   }
   tmp_1946 += tmp_1947;
   result += (1.4142135623730951*g3) * tmp_1946;

   return result;
}

double CLASSNAME::CpbarGluconjSuFuPL(unsigned , unsigned ) const
{
   double result = 0.0;

   result = 0;

   return result;
}

std::complex<double> CLASSNAME::CpbarGluconjSuFuPR(unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1948;
   std::complex<double> tmp_1949;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1949 += ZU(gI1,3 + j1)*ZUR(gI2,j1);
   }
   tmp_1948 += tmp_1949;
   result += (1.4142135623730951*g3) * tmp_1948;

   return result;
}

std::complex<double> CLASSNAME::CpbarGluVGGluPR() const
{
   std::complex<double> result;

   result = std::complex<double>(0,-1)*g3;

   return result;
}

std::complex<double> CLASSNAME::CpbarGluVGGluPL() const
{
   std::complex<double> result;

   result = std::complex<double>(0,-1)*g3;

   return result;
}

std::complex<double> CLASSNAME::CpbarGluconjSOcGluPL() const
{
   std::complex<double> result;

   result = std::complex<double>(0.,-1.4142135623730951)*g3;

   return result;
}

double CLASSNAME::CpbarGluconjSOcGluPR() const
{
   double result = 0.0;

   result = 0;

   return result;
}

std::complex<double> CLASSNAME::CpbarFebarCha1SvPL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1950;
   std::complex<double> tmp_1951;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_1952;
      std::complex<double> tmp_1953;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1953 += Conj(ZER(gO2,j1))*Ye(j1,j2);
      }
      tmp_1952 += tmp_1953;
      tmp_1951 += (Conj(ZV(gI2,j2))) * tmp_1952;
   }
   tmp_1950 += tmp_1951;
   result += (Conj(UM1(gI1,1))) * tmp_1950;

   return result;
}

std::complex<double> CLASSNAME::CpbarFebarCha1SvPR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1954;
   std::complex<double> tmp_1955;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1955 += Conj(ZV(gI2,j1))*ZEL(gO1,j1);
   }
   tmp_1954 += tmp_1955;
   result += (-(g2*UP1(gI1,0))) * tmp_1954;

   return result;
}

std::complex<double> CLASSNAME::CpbarFeFeAhPL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1956;
   std::complex<double> tmp_1957;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_1958;
      std::complex<double> tmp_1959;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1959 += Conj(ZER(gO2,j1))*Ye(j1,j2);
      }
      tmp_1958 += tmp_1959;
      tmp_1957 += (Conj(ZEL(gI1,j2))) * tmp_1958;
   }
   tmp_1956 += tmp_1957;
   result += (std::complex<double>(0.,-0.7071067811865475)*ZA(gI2,0)) *
      tmp_1956;

   return result;
}

std::complex<double> CLASSNAME::CpbarFeFeAhPR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1960;
   std::complex<double> tmp_1961;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_1962;
      std::complex<double> tmp_1963;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1963 += Conj(Ye(j1,j2))*ZER(gI1,j1);
      }
      tmp_1962 += tmp_1963;
      tmp_1961 += (ZEL(gO1,j2)) * tmp_1962;
   }
   tmp_1960 += tmp_1961;
   result += (std::complex<double>(0.,0.7071067811865475)*ZA(gI2,0)) * tmp_1960
      ;

   return result;
}

std::complex<double> CLASSNAME::CpbarFehhFePL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1964;
   std::complex<double> tmp_1965;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_1966;
      std::complex<double> tmp_1967;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1967 += Conj(ZER(gO2,j1))*Ye(j1,j2);
      }
      tmp_1966 += tmp_1967;
      tmp_1965 += (Conj(ZEL(gI2,j2))) * tmp_1966;
   }
   tmp_1964 += tmp_1965;
   result += (-0.7071067811865475*ZH(gI1,0)) * tmp_1964;

   return result;
}

std::complex<double> CLASSNAME::CpbarFehhFePR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1968;
   std::complex<double> tmp_1969;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_1970;
      std::complex<double> tmp_1971;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1971 += Conj(Ye(j1,j2))*ZER(gI2,j1);
      }
      tmp_1970 += tmp_1971;
      tmp_1969 += (ZEL(gO1,j2)) * tmp_1970;
   }
   tmp_1968 += tmp_1969;
   result += (-0.7071067811865475*ZH(gI1,0)) * tmp_1968;

   return result;
}

std::complex<double> CLASSNAME::CpbarFeHpmFvPL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1972;
   std::complex<double> tmp_1973;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1973 += Conj(ZER(gO2,j1))*Ye(j1,gI2);
   }
   tmp_1972 += tmp_1973;
   result += (ZP(gI1,0)) * tmp_1972;

   return result;
}

double CLASSNAME::CpbarFeHpmFvPR(unsigned , unsigned , unsigned ) const
{
   double result = 0.0;

   result = 0;

   return result;
}

std::complex<double> CLASSNAME::CpbarFebarChiSePL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1974;
   std::complex<double> tmp_1975;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_1976;
      std::complex<double> tmp_1977;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1977 += Conj(ZER(gO2,j1))*Ye(j1,j2);
      }
      tmp_1976 += tmp_1977;
      tmp_1975 += (Conj(ZE(gI2,j2))) * tmp_1976;
   }
   tmp_1974 += tmp_1975;
   result += (-Conj(ZN2(gI1,2))) * tmp_1974;

   return result;
}

std::complex<double> CLASSNAME::CpbarFebarChiSePR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1978;
   std::complex<double> tmp_1979;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1979 += Conj(ZE(gI2,j1))*ZEL(gO1,j1);
   }
   tmp_1978 += tmp_1979;
   result += (0.7071067811865475*(0.7745966692414834*g1*ZN1(gI1,0) + g2*ZN1(gI1
      ,1))) * tmp_1978;

   return result;
}

std::complex<double> CLASSNAME::CpbarFeSeChiPL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1980;
   std::complex<double> tmp_1981;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1981 += Conj(ZE(gI1,3 + j1))*Conj(ZER(gO2,j1));
   }
   tmp_1980 += tmp_1981;
   result += (-1.0954451150103321*g1*Conj(ZN1(gI2,0))) * tmp_1980;

   return result;
}

std::complex<double> CLASSNAME::CpbarFeSeChiPR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1982;
   std::complex<double> tmp_1983;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_1984;
      std::complex<double> tmp_1985;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1985 += Conj(Ye(j1,j2))*Conj(ZE(gI1,3 + j1));
      }
      tmp_1984 += tmp_1985;
      tmp_1983 += (ZEL(gO1,j2)) * tmp_1984;
   }
   tmp_1982 += tmp_1983;
   result += (-ZN2(gI2,2)) * tmp_1982;

   return result;
}

double CLASSNAME::CpbarFeVWmFvPR(unsigned , unsigned ) const
{
   double result = 0.0;

   result = 0;

   return result;
}

std::complex<double> CLASSNAME::CpbarFeVWmFvPL(unsigned gO1, unsigned gI2) const
{
   std::complex<double> result;

   if (gI2 < 3) {
      result += -0.7071067811865475*g2*ZEL(gO1,gI2);
   }

   return result;
}

double CLASSNAME::CpbarFeVZFePR(unsigned gO2, unsigned gI2) const
{
   double result = 0.0;

   result = -0.7745966692414834*g1*KroneckerDelta(gI2,gO2)*Sin(ThetaW());

   return result;
}

double CLASSNAME::CpbarFeVZFePL(unsigned gO1, unsigned gI2) const
{
   double result = 0.0;

   result = 0.5*KroneckerDelta(gI2,gO1)*(g2*Cos(ThetaW()) - 0.7745966692414834*
      g1*Sin(ThetaW()));

   return result;
}

std::complex<double> CLASSNAME::CpbarFdbarCha1SuPL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1986;
   std::complex<double> tmp_1987;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_1988;
      std::complex<double> tmp_1989;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1989 += Conj(ZDR(gO2,j1))*Yd(j1,j2);
      }
      tmp_1988 += tmp_1989;
      tmp_1987 += (Conj(ZU(gI2,j2))) * tmp_1988;
   }
   tmp_1986 += tmp_1987;
   result += (Conj(UM1(gI1,1))) * tmp_1986;

   return result;
}

std::complex<double> CLASSNAME::CpbarFdbarCha1SuPR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1990;
   std::complex<double> tmp_1991;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_1991 += Conj(ZU(gI2,j1))*ZDL(gO1,j1);
   }
   tmp_1990 += tmp_1991;
   result += (-(g2*UP1(gI1,0))) * tmp_1990;

   return result;
}

std::complex<double> CLASSNAME::CpbarFdFdAhPL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1992;
   std::complex<double> tmp_1993;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_1994;
      std::complex<double> tmp_1995;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1995 += Conj(ZDR(gO2,j1))*Yd(j1,j2);
      }
      tmp_1994 += tmp_1995;
      tmp_1993 += (Conj(ZDL(gI1,j2))) * tmp_1994;
   }
   tmp_1992 += tmp_1993;
   result += (std::complex<double>(0.,-0.7071067811865475)*ZA(gI2,0)) *
      tmp_1992;

   return result;
}

std::complex<double> CLASSNAME::CpbarFdFdAhPR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_1996;
   std::complex<double> tmp_1997;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_1998;
      std::complex<double> tmp_1999;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_1999 += Conj(Yd(j1,j2))*ZDR(gI1,j1);
      }
      tmp_1998 += tmp_1999;
      tmp_1997 += (ZDL(gO1,j2)) * tmp_1998;
   }
   tmp_1996 += tmp_1997;
   result += (std::complex<double>(0.,0.7071067811865475)*ZA(gI2,0)) * tmp_1996
      ;

   return result;
}

std::complex<double> CLASSNAME::CpbarFdhhFdPL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_2000;
   std::complex<double> tmp_2001;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_2002;
      std::complex<double> tmp_2003;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_2003 += Conj(ZDR(gO2,j1))*Yd(j1,j2);
      }
      tmp_2002 += tmp_2003;
      tmp_2001 += (Conj(ZDL(gI2,j2))) * tmp_2002;
   }
   tmp_2000 += tmp_2001;
   result += (-0.7071067811865475*ZH(gI1,0)) * tmp_2000;

   return result;
}

std::complex<double> CLASSNAME::CpbarFdhhFdPR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_2004;
   std::complex<double> tmp_2005;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_2006;
      std::complex<double> tmp_2007;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_2007 += Conj(Yd(j1,j2))*ZDR(gI2,j1);
      }
      tmp_2006 += tmp_2007;
      tmp_2005 += (ZDL(gO1,j2)) * tmp_2006;
   }
   tmp_2004 += tmp_2005;
   result += (-0.7071067811865475*ZH(gI1,0)) * tmp_2004;

   return result;
}

std::complex<double> CLASSNAME::CpbarFdHpmFuPL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_2008;
   std::complex<double> tmp_2009;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_2010;
      std::complex<double> tmp_2011;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_2011 += Conj(ZDR(gO2,j1))*Yd(j1,j2);
      }
      tmp_2010 += tmp_2011;
      tmp_2009 += (Conj(ZUL(gI2,j2))) * tmp_2010;
   }
   tmp_2008 += tmp_2009;
   result += (ZP(gI1,0)) * tmp_2008;

   return result;
}

std::complex<double> CLASSNAME::CpbarFdHpmFuPR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_2012;
   std::complex<double> tmp_2013;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_2014;
      std::complex<double> tmp_2015;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_2015 += Conj(Yu(j1,j2))*ZUR(gI2,j1);
      }
      tmp_2014 += tmp_2015;
      tmp_2013 += (ZDL(gO1,j2)) * tmp_2014;
   }
   tmp_2012 += tmp_2013;
   result += (ZP(gI1,1)) * tmp_2012;

   return result;
}

std::complex<double> CLASSNAME::CpbarFdbarChiSdPL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_2016;
   std::complex<double> tmp_2017;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_2018;
      std::complex<double> tmp_2019;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_2019 += Conj(ZDR(gO2,j1))*Yd(j1,j2);
      }
      tmp_2018 += tmp_2019;
      tmp_2017 += (Conj(ZD(gI2,j2))) * tmp_2018;
   }
   tmp_2016 += tmp_2017;
   result += (-Conj(ZN2(gI1,2))) * tmp_2016;

   return result;
}

std::complex<double> CLASSNAME::CpbarFdbarChiSdPR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_2020;
   std::complex<double> tmp_2021;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_2021 += Conj(ZD(gI2,j1))*ZDL(gO1,j1);
   }
   tmp_2020 += tmp_2021;
   result += (-0.2357022603955158*(0.7745966692414834*g1*ZN1(gI1,0) - 3*g2*ZN1(
      gI1,1))) * tmp_2020;

   return result;
}

double CLASSNAME::CpbarFdSuCha2PL(unsigned , unsigned , unsigned ) const
{
   double result = 0.0;

   result = 0;

   return result;
}

std::complex<double> CLASSNAME::CpbarFdSuCha2PR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_2022;
   std::complex<double> tmp_2023;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_2024;
      std::complex<double> tmp_2025;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_2025 += Conj(Yu(j1,j2))*Conj(ZU(gI1,3 + j1));
      }
      tmp_2024 += tmp_2025;
      tmp_2023 += (ZDL(gO1,j2)) * tmp_2024;
   }
   tmp_2022 += tmp_2023;
   result += (UP2(gI2,1)) * tmp_2022;

   return result;
}

std::complex<double> CLASSNAME::CpbarFdSdChiPL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_2026;
   std::complex<double> tmp_2027;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_2027 += Conj(ZD(gI1,3 + j1))*Conj(ZDR(gO2,j1));
   }
   tmp_2026 += tmp_2027;
   result += (-0.3651483716701107*g1*Conj(ZN1(gI2,0))) * tmp_2026;

   return result;
}

std::complex<double> CLASSNAME::CpbarFdSdChiPR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_2028;
   std::complex<double> tmp_2029;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_2030;
      std::complex<double> tmp_2031;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_2031 += Conj(Yd(j1,j2))*Conj(ZD(gI1,3 + j1));
      }
      tmp_2030 += tmp_2031;
      tmp_2029 += (ZDL(gO1,j2)) * tmp_2030;
   }
   tmp_2028 += tmp_2029;
   result += (-ZN2(gI2,2)) * tmp_2028;

   return result;
}

std::complex<double> CLASSNAME::CpbarFdSdGluPL(unsigned gO2, unsigned gI1, unsigned ) const
{
   std::complex<double> result;

   std::complex<double> tmp_2032;
   std::complex<double> tmp_2033;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_2033 += Conj(ZD(gI1,3 + j1))*Conj(ZDR(gO2,j1));
   }
   tmp_2032 += tmp_2033;
   result += (1.4142135623730951*g3) * tmp_2032;

   return result;
}

double CLASSNAME::CpbarFdSdGluPR(unsigned , unsigned , unsigned ) const
{
   double result = 0.0;

   result = 0;

   return result;
}

double CLASSNAME::CpbarFdVWmFuPR(unsigned , unsigned ) const
{
   double result = 0.0;

   result = 0;

   return result;
}

std::complex<double> CLASSNAME::CpbarFdVWmFuPL(unsigned gO1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_2034;
   std::complex<double> tmp_2035;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_2035 += Conj(ZUL(gI2,j1))*ZDL(gO1,j1);
   }
   tmp_2034 += tmp_2035;
   result += (-0.7071067811865475*g2) * tmp_2034;

   return result;
}

double CLASSNAME::CpbarFdVZFdPR(unsigned gO2, unsigned gI2) const
{
   double result = 0.0;

   result = -0.2581988897471611*g1*KroneckerDelta(gI2,gO2)*Sin(ThetaW());

   return result;
}

double CLASSNAME::CpbarFdVZFdPL(unsigned gO1, unsigned gI2) const
{
   double result = 0.0;

   result = 0.16666666666666666*KroneckerDelta(gI2,gO1)*(3*g2*Cos(ThetaW()) +
      0.7745966692414834*g1*Sin(ThetaW()));

   return result;
}

double CLASSNAME::CpbarFdbarGluSdPL(unsigned , unsigned , unsigned ) const
{
   double result = 0.0;

   result = 0;

   return result;
}

std::complex<double> CLASSNAME::CpbarFdbarGluSdPR(unsigned gO1, unsigned , unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_2036;
   std::complex<double> tmp_2037;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_2037 += Conj(ZD(gI2,j1))*ZDL(gO1,j1);
   }
   tmp_2036 += tmp_2037;
   result += (-1.4142135623730951*g3) * tmp_2036;

   return result;
}

std::complex<double> CLASSNAME::CpbarFubarCha2SdPL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_2038;
   std::complex<double> tmp_2039;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_2040;
      std::complex<double> tmp_2041;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_2041 += Conj(ZUR(gO2,j1))*Yu(j1,j2);
      }
      tmp_2040 += tmp_2041;
      tmp_2039 += (Conj(ZD(gI2,j2))) * tmp_2040;
   }
   tmp_2038 += tmp_2039;
   result += (Conj(UP2(gI1,1))) * tmp_2038;

   return result;
}

std::complex<double> CLASSNAME::CpbarFubarCha2SdPR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_2042;
   std::complex<double> tmp_2043;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_2043 += Conj(ZD(gI2,j1))*ZUL(gO1,j1);
   }
   tmp_2042 += tmp_2043;
   result += (-(g2*UM2(gI1,0))) * tmp_2042;

   return result;
}

std::complex<double> CLASSNAME::CpbarFuFuAhPL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_2044;
   std::complex<double> tmp_2045;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_2046;
      std::complex<double> tmp_2047;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_2047 += Conj(ZUR(gO2,j1))*Yu(j1,j2);
      }
      tmp_2046 += tmp_2047;
      tmp_2045 += (Conj(ZUL(gI1,j2))) * tmp_2046;
   }
   tmp_2044 += tmp_2045;
   result += (std::complex<double>(0.,-0.7071067811865475)*ZA(gI2,1)) *
      tmp_2044;

   return result;
}

std::complex<double> CLASSNAME::CpbarFuFuAhPR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_2048;
   std::complex<double> tmp_2049;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_2050;
      std::complex<double> tmp_2051;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_2051 += Conj(Yu(j1,j2))*ZUR(gI1,j1);
      }
      tmp_2050 += tmp_2051;
      tmp_2049 += (ZUL(gO1,j2)) * tmp_2050;
   }
   tmp_2048 += tmp_2049;
   result += (std::complex<double>(0.,0.7071067811865475)*ZA(gI2,1)) * tmp_2048
      ;

   return result;
}

std::complex<double> CLASSNAME::CpbarFuconjHpmFdPL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_2052;
   std::complex<double> tmp_2053;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_2054;
      std::complex<double> tmp_2055;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_2055 += Conj(ZUR(gO2,j1))*Yu(j1,j2);
      }
      tmp_2054 += tmp_2055;
      tmp_2053 += (Conj(ZDL(gI2,j2))) * tmp_2054;
   }
   tmp_2052 += tmp_2053;
   result += (ZP(gI1,1)) * tmp_2052;

   return result;
}

std::complex<double> CLASSNAME::CpbarFuconjHpmFdPR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_2056;
   std::complex<double> tmp_2057;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_2058;
      std::complex<double> tmp_2059;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_2059 += Conj(Yd(j1,j2))*ZDR(gI2,j1);
      }
      tmp_2058 += tmp_2059;
      tmp_2057 += (ZUL(gO1,j2)) * tmp_2058;
   }
   tmp_2056 += tmp_2057;
   result += (ZP(gI1,0)) * tmp_2056;

   return result;
}

std::complex<double> CLASSNAME::CpbarFuhhFuPL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_2060;
   std::complex<double> tmp_2061;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_2062;
      std::complex<double> tmp_2063;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_2063 += Conj(ZUR(gO2,j1))*Yu(j1,j2);
      }
      tmp_2062 += tmp_2063;
      tmp_2061 += (Conj(ZUL(gI2,j2))) * tmp_2062;
   }
   tmp_2060 += tmp_2061;
   result += (-0.7071067811865475*ZH(gI1,1)) * tmp_2060;

   return result;
}

std::complex<double> CLASSNAME::CpbarFuhhFuPR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_2064;
   std::complex<double> tmp_2065;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_2066;
      std::complex<double> tmp_2067;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_2067 += Conj(Yu(j1,j2))*ZUR(gI2,j1);
      }
      tmp_2066 += tmp_2067;
      tmp_2065 += (ZUL(gO1,j2)) * tmp_2066;
   }
   tmp_2064 += tmp_2065;
   result += (-0.7071067811865475*ZH(gI1,1)) * tmp_2064;

   return result;
}

std::complex<double> CLASSNAME::CpbarFubarChiSuPL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_2068;
   std::complex<double> tmp_2069;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_2070;
      std::complex<double> tmp_2071;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_2071 += Conj(ZUR(gO2,j1))*Yu(j1,j2);
      }
      tmp_2070 += tmp_2071;
      tmp_2069 += (Conj(ZU(gI2,j2))) * tmp_2070;
   }
   tmp_2068 += tmp_2069;
   result += (-Conj(ZN2(gI1,3))) * tmp_2068;

   return result;
}

std::complex<double> CLASSNAME::CpbarFubarChiSuPR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_2072;
   std::complex<double> tmp_2073;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_2073 += Conj(ZU(gI2,j1))*ZUL(gO1,j1);
   }
   tmp_2072 += tmp_2073;
   result += (-0.2357022603955158*(0.7745966692414834*g1*ZN1(gI1,0) + 3*g2*ZN1(
      gI1,1))) * tmp_2072;

   return result;
}

double CLASSNAME::CpbarFuSdCha1PL(unsigned , unsigned , unsigned ) const
{
   double result = 0.0;

   result = 0;

   return result;
}

std::complex<double> CLASSNAME::CpbarFuSdCha1PR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_2074;
   std::complex<double> tmp_2075;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_2076;
      std::complex<double> tmp_2077;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_2077 += Conj(Yd(j1,j2))*Conj(ZD(gI1,3 + j1));
      }
      tmp_2076 += tmp_2077;
      tmp_2075 += (ZUL(gO1,j2)) * tmp_2076;
   }
   tmp_2074 += tmp_2075;
   result += (UM1(gI2,1)) * tmp_2074;

   return result;
}

std::complex<double> CLASSNAME::CpbarFuSuChiPL(unsigned gO2, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_2078;
   std::complex<double> tmp_2079;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_2079 += Conj(ZU(gI1,3 + j1))*Conj(ZUR(gO2,j1));
   }
   tmp_2078 += tmp_2079;
   result += (0.7302967433402214*g1*Conj(ZN1(gI2,0))) * tmp_2078;

   return result;
}

std::complex<double> CLASSNAME::CpbarFuSuChiPR(unsigned gO1, unsigned gI1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_2080;
   std::complex<double> tmp_2081;
   for (unsigned j2 = 0; j2 < 3; ++j2) {
      std::complex<double> tmp_2082;
      std::complex<double> tmp_2083;
      for (unsigned j1 = 0; j1 < 3; ++j1) {
         tmp_2083 += Conj(Yu(j1,j2))*Conj(ZU(gI1,3 + j1));
      }
      tmp_2082 += tmp_2083;
      tmp_2081 += (ZUL(gO1,j2)) * tmp_2082;
   }
   tmp_2080 += tmp_2081;
   result += (-ZN2(gI2,3)) * tmp_2080;

   return result;
}

std::complex<double> CLASSNAME::CpbarFuSuGluPL(unsigned gO2, unsigned gI1, unsigned ) const
{
   std::complex<double> result;

   std::complex<double> tmp_2084;
   std::complex<double> tmp_2085;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_2085 += Conj(ZU(gI1,3 + j1))*Conj(ZUR(gO2,j1));
   }
   tmp_2084 += tmp_2085;
   result += (1.4142135623730951*g3) * tmp_2084;

   return result;
}

double CLASSNAME::CpbarFuSuGluPR(unsigned , unsigned , unsigned ) const
{
   double result = 0.0;

   result = 0;

   return result;
}

double CLASSNAME::CpbarFuVPFuPR(unsigned gO2, unsigned gI2) const
{
   double result = 0.0;

   result = -0.5163977794943222*g1*Cos(ThetaW())*KroneckerDelta(gI2,gO2);

   return result;
}

double CLASSNAME::CpbarFuVPFuPL(unsigned gO1, unsigned gI2) const
{
   double result = 0.0;

   result = -0.16666666666666666*KroneckerDelta(gI2,gO1)*(0.7745966692414834*g1
      *Cos(ThetaW()) + 3*g2*Sin(ThetaW()));

   return result;
}

double CLASSNAME::CpbarFuVZFuPR(unsigned gO2, unsigned gI2) const
{
   double result = 0.0;

   result = 0.5163977794943222*g1*KroneckerDelta(gI2,gO2)*Sin(ThetaW());

   return result;
}

double CLASSNAME::CpbarFuVZFuPL(unsigned gO1, unsigned gI2) const
{
   double result = 0.0;

   result = 0.03333333333333333*KroneckerDelta(gI2,gO1)*(-15*g2*Cos(ThetaW()) +
      3.872983346207417*g1*Sin(ThetaW()));

   return result;
}

double CLASSNAME::CpbarFuconjVWmFdPR(unsigned , unsigned ) const
{
   double result = 0.0;

   result = 0;

   return result;
}

std::complex<double> CLASSNAME::CpbarFuconjVWmFdPL(unsigned gO1, unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_2086;
   std::complex<double> tmp_2087;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_2087 += Conj(ZDL(gI2,j1))*ZUL(gO1,j1);
   }
   tmp_2086 += tmp_2087;
   result += (-0.7071067811865475*g2) * tmp_2086;

   return result;
}

double CLASSNAME::CpbarFubarGluSuPL(unsigned , unsigned , unsigned ) const
{
   double result = 0.0;

   result = 0;

   return result;
}

std::complex<double> CLASSNAME::CpbarFubarGluSuPR(unsigned gO1, unsigned , unsigned gI2) const
{
   std::complex<double> result;

   std::complex<double> tmp_2088;
   std::complex<double> tmp_2089;
   for (unsigned j1 = 0; j1 < 3; ++j1) {
      tmp_2089 += Conj(ZU(gI2,j1))*ZUL(gO1,j1);
   }
   tmp_2088 += tmp_2089;
   result += (-1.4142135623730951*g3) * tmp_2088;

   return result;
}


std::complex<double> CLASSNAME::self_energy_Sd(double p , unsigned gO1, unsigned gO2) const
{
   std::complex<double> result;

   result += -(A0(MSOc)*CpUSdconjUSdconjSOcSOc(gO1,gO2));
   result += 4*A0(MVWm)*CpUSdconjUSdconjVWmVWm(gO1,gO2);
   result += 2*A0(MVZ)*CpUSdconjUSdVZVZ(gO1,gO2);
   std::complex<double> tmp_2090;
   std::complex<double> tmp_2091;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      tmp_2091 += A0(MRh(gI1))*CpUSdconjUSdconjRhRh(gO1,gO2,gI1,gI1);
   }
   tmp_2090 += tmp_2091;
   result += (-1) * tmp_2090;
   std::complex<double> tmp_2092;
   std::complex<double> tmp_2093;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      tmp_2093 += A0(MRpm(gI1))*CpUSdconjUSdconjRpmRpm(gO1,gO2,gI1,gI1);
   }
   tmp_2092 += tmp_2093;
   result += (-1) * tmp_2092;
   std::complex<double> tmp_2094;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2095;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_2095 += (Conj(CpconjUSdbarCha1FuPL(gO2,gI1,gI2))*
            CpconjUSdbarCha1FuPL(gO1,gI1,gI2) + Conj(CpconjUSdbarCha1FuPR(gO2,gI1,
            gI2))*CpconjUSdbarCha1FuPR(gO1,gI1,gI2))*G0(p,MCha1(gI1),MFu(gI2));
      }
      tmp_2094 += tmp_2095;
   }
   result += tmp_2094;
   std::complex<double> tmp_2096;
   std::complex<double> tmp_2097;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2098;
      std::complex<double> tmp_2099;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_2099 += B0(p,MCha1(gI1),MFu(gI2))*(Conj(CpconjUSdbarCha1FuPR
            (gO2,gI1,gI2))*CpconjUSdbarCha1FuPL(gO1,gI1,gI2) + Conj(
            CpconjUSdbarCha1FuPL(gO2,gI1,gI2))*CpconjUSdbarCha1FuPR(gO1,gI1,gI2))*
            MFu(gI2);
      }
      tmp_2098 += tmp_2099;
      tmp_2097 += (MCha1(gI1)) * tmp_2098;
   }
   tmp_2096 += tmp_2097;
   result += (-2) * tmp_2096;
   std::complex<double> tmp_2100;
   std::complex<double> tmp_2101;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      tmp_2101 += A0(MSv(gI1))*CpUSdconjUSdconjSvSv(gO1,gO2,gI1,gI1);
   }
   tmp_2100 += tmp_2101;
   result += (-1) * tmp_2100;
   std::complex<double> tmp_2102;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2103;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2103 += (Conj(CpconjUSdFuCha2PL(gO2,gI1,gI2))*
            CpconjUSdFuCha2PL(gO1,gI1,gI2) + Conj(CpconjUSdFuCha2PR(gO2,gI1,gI2))*
            CpconjUSdFuCha2PR(gO1,gI1,gI2))*G0(p,MFu(gI1),MCha2(gI2));
      }
      tmp_2102 += tmp_2103;
   }
   result += tmp_2102;
   std::complex<double> tmp_2104;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2105;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2105 += (Conj(CpconjUSdFdChiPL(gO2,gI1,gI2))*
            CpconjUSdFdChiPL(gO1,gI1,gI2) + Conj(CpconjUSdFdChiPR(gO2,gI1,gI2))*
            CpconjUSdFdChiPR(gO1,gI1,gI2))*G0(p,MFd(gI1),MChi(gI2));
      }
      tmp_2104 += tmp_2105;
   }
   result += tmp_2104;
   std::complex<double> tmp_2106;
   std::complex<double> tmp_2107;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2108;
      std::complex<double> tmp_2109;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2109 += B0(p,MFd(gI1),MChi(gI2))*(Conj(CpconjUSdFdChiPR(gO2,
            gI1,gI2))*CpconjUSdFdChiPL(gO1,gI1,gI2) + Conj(CpconjUSdFdChiPL(gO2,
            gI1,gI2))*CpconjUSdFdChiPR(gO1,gI1,gI2))*MChi(gI2);
      }
      tmp_2108 += tmp_2109;
      tmp_2107 += (MFd(gI1)) * tmp_2108;
   }
   tmp_2106 += tmp_2107;
   result += (-2) * tmp_2106;
   std::complex<double> tmp_2110;
   std::complex<double> tmp_2111;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2112;
      std::complex<double> tmp_2113;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2113 += B0(p,MFu(gI1),MCha2(gI2))*(Conj(CpconjUSdFuCha2PR(
            gO2,gI1,gI2))*CpconjUSdFuCha2PL(gO1,gI1,gI2) + Conj(CpconjUSdFuCha2PL(
            gO2,gI1,gI2))*CpconjUSdFuCha2PR(gO1,gI1,gI2))*MCha2(gI2);
      }
      tmp_2112 += tmp_2113;
      tmp_2111 += (MFu(gI1)) * tmp_2112;
   }
   tmp_2110 += tmp_2111;
   result += (-2) * tmp_2110;
   std::complex<double> tmp_2114;
   std::complex<double> tmp_2115;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      tmp_2115 += A0(MAh(gI1))*CpUSdconjUSdAhAh(gO1,gO2,gI1,gI1);
   }
   tmp_2114 += tmp_2115;
   result += (-0.5) * tmp_2114;
   std::complex<double> tmp_2116;
   std::complex<double> tmp_2117;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      tmp_2117 += A0(MHpm(gI1))*CpUSdconjUSdconjHpmHpm(gO1,gO2,gI1,gI1);
   }
   tmp_2116 += tmp_2117;
   result += (-1) * tmp_2116;
   std::complex<double> tmp_2118;
   std::complex<double> tmp_2119;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      tmp_2119 += A0(Mhh(gI1))*CpUSdconjUSdhhhh(gO1,gO2,gI1,gI1);
   }
   tmp_2118 += tmp_2119;
   result += (-0.5) * tmp_2118;
   std::complex<double> tmp_2120;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2121;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_2121 += (Conj(CpconjUSdbarChiFdPL(gO2,gI1,gI2))*
            CpconjUSdbarChiFdPL(gO1,gI1,gI2) + Conj(CpconjUSdbarChiFdPR(gO2,gI1,
            gI2))*CpconjUSdbarChiFdPR(gO1,gI1,gI2))*G0(p,MChi(gI1),MFd(gI2));
      }
      tmp_2120 += tmp_2121;
   }
   result += tmp_2120;
   std::complex<double> tmp_2122;
   std::complex<double> tmp_2123;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2124;
      std::complex<double> tmp_2125;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_2125 += B0(p,MChi(gI1),MFd(gI2))*(Conj(CpconjUSdbarChiFdPR(
            gO2,gI1,gI2))*CpconjUSdbarChiFdPL(gO1,gI1,gI2) + Conj(
            CpconjUSdbarChiFdPL(gO2,gI1,gI2))*CpconjUSdbarChiFdPR(gO1,gI1,gI2))*
            MFd(gI2);
      }
      tmp_2124 += tmp_2125;
      tmp_2123 += (MChi(gI1)) * tmp_2124;
   }
   tmp_2122 += tmp_2123;
   result += (-2) * tmp_2122;
   std::complex<double> tmp_2126;
   std::complex<double> tmp_2127;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      tmp_2127 += A0(MSd(gI1))*CpUSdconjUSdconjSdSd(gO1,gO2,gI1,gI1);
   }
   tmp_2126 += tmp_2127;
   result += (-1) * tmp_2126;
   std::complex<double> tmp_2128;
   std::complex<double> tmp_2129;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      tmp_2129 += A0(MSe(gI1))*CpUSdconjUSdconjSeSe(gO1,gO2,gI1,gI1);
   }
   tmp_2128 += tmp_2129;
   result += (-1) * tmp_2128;
   std::complex<double> tmp_2130;
   std::complex<double> tmp_2131;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      tmp_2131 += A0(MSu(gI1))*CpUSdconjUSdconjSuSu(gO1,gO2,gI1,gI1);
   }
   tmp_2130 += tmp_2131;
   result += (-1) * tmp_2130;
   std::complex<double> tmp_2132;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_2133;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2133 += B0(p,MSd(gI1),MRh(gI2))*Conj(CpconjUSdSdRh(gO2,gI1,
            gI2))*CpconjUSdSdRh(gO1,gI1,gI2);
      }
      tmp_2132 += tmp_2133;
   }
   result += tmp_2132;
   std::complex<double> tmp_2134;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_2135;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2135 += B0(p,MSu(gI1),MRpm(gI2))*Conj(CpconjUSdSuRpm(gO2,gI1
            ,gI2))*CpconjUSdSuRpm(gO1,gI1,gI2);
      }
      tmp_2134 += tmp_2135;
   }
   result += tmp_2134;
   std::complex<double> tmp_2136;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_2137;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2137 += B0(p,MSd(gI1),MAh(gI2))*Conj(CpconjUSdSdAh(gO2,gI1,
            gI2))*CpconjUSdSdAh(gO1,gI1,gI2);
      }
      tmp_2136 += tmp_2137;
   }
   result += tmp_2136;
   std::complex<double> tmp_2138;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_2139;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2139 += B0(p,MSd(gI1),Mhh(gI2))*Conj(CpconjUSdSdhh(gO2,gI1,
            gI2))*CpconjUSdSdhh(gO1,gI1,gI2);
      }
      tmp_2138 += tmp_2139;
   }
   result += tmp_2138;
   std::complex<double> tmp_2140;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_2141;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2141 += B0(p,MSu(gI1),MHpm(gI2))*Conj(CpconjUSdSuHpm(gO2,gI1
            ,gI2))*CpconjUSdSuHpm(gO1,gI1,gI2);
      }
      tmp_2140 += tmp_2141;
   }
   result += tmp_2140;
   std::complex<double> tmp_2142;
   std::complex<double> tmp_2143;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_2143 += (Conj(CpconjUSdbarGluFdPL(gO2,1,gI2))*CpconjUSdbarGluFdPL(
         gO1,1,gI2) + Conj(CpconjUSdbarGluFdPR(gO2,1,gI2))*CpconjUSdbarGluFdPR(gO1
         ,1,gI2))*G0(p,MGlu,MFd(gI2));
   }
   tmp_2142 += tmp_2143;
   result += (1.3333333333333333) * tmp_2142;
   std::complex<double> tmp_2144;
   std::complex<double> tmp_2145;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_2145 += (Conj(CpconjUSdGluFdPL(gO2,1,gI2))*CpconjUSdGluFdPL(gO1,1,
         gI2) + Conj(CpconjUSdGluFdPR(gO2,1,gI2))*CpconjUSdGluFdPR(gO1,1,gI2))*G0(
         p,MGlu,MFd(gI2));
   }
   tmp_2144 += tmp_2145;
   result += (1.3333333333333333) * tmp_2144;
   std::complex<double> tmp_2146;
   std::complex<double> tmp_2147;
   for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
      tmp_2147 += B0(p,MSOc,MSd(gI2))*Conj(CpconjUSdconjSOcSd(gO2,gI2))*
         CpconjUSdconjSOcSd(gO1,gI2);
   }
   tmp_2146 += tmp_2147;
   result += (1.3333333333333333) * tmp_2146;
   std::complex<double> tmp_2148;
   std::complex<double> tmp_2149;
   for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
      tmp_2149 += Conj(CpconjUSdVGSd(gO2,gI2))*CpconjUSdVGSd(gO1,gI2)*F0(p,
         MSd(gI2),0);
   }
   tmp_2148 += tmp_2149;
   result += (1.3333333333333333) * tmp_2148;
   std::complex<double> tmp_2150;
   for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
      tmp_2150 += Conj(CpconjUSdVPSd(gO2,gI2))*CpconjUSdVPSd(gO1,gI2)*F0(p,
         MSd(gI2),0);
   }
   result += tmp_2150;
   std::complex<double> tmp_2151;
   for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
      tmp_2151 += Conj(CpconjUSdVZSd(gO2,gI2))*CpconjUSdVZSd(gO1,gI2)*F0(p,
         MSd(gI2),MVZ);
   }
   result += tmp_2151;
   std::complex<double> tmp_2152;
   for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
      tmp_2152 += Conj(CpconjUSdVWmSu(gO2,gI2))*CpconjUSdVWmSu(gO1,gI2)*F0(p
         ,MSu(gI2),MVWm);
   }
   result += tmp_2152;
   std::complex<double> tmp_2153;
   std::complex<double> tmp_2154;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_2154 += B0(p,MGlu,MFd(gI2))*(Conj(CpconjUSdbarGluFdPR(gO2,1,gI2))*
         CpconjUSdbarGluFdPL(gO1,1,gI2) + Conj(CpconjUSdbarGluFdPL(gO2,1,gI2))*
         CpconjUSdbarGluFdPR(gO1,1,gI2))*MFd(gI2);
   }
   tmp_2153 += tmp_2154;
   result += (-2.6666666666666665*MGlu) * tmp_2153;
   std::complex<double> tmp_2155;
   std::complex<double> tmp_2156;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_2156 += B0(p,MGlu,MFd(gI2))*(Conj(CpconjUSdGluFdPR(gO2,1,gI2))*
         CpconjUSdGluFdPL(gO1,1,gI2) + Conj(CpconjUSdGluFdPL(gO2,1,gI2))*
         CpconjUSdGluFdPR(gO1,1,gI2))*MFd(gI2);
   }
   tmp_2155 += tmp_2156;
   result += (-2.6666666666666665*MGlu) * tmp_2155;

   return result * oneOver16PiSqr;

}

std::complex<double> CLASSNAME::self_energy_Sv(double p , unsigned gO1, unsigned gO2) const
{
   std::complex<double> result;

   result += 4*A0(MVWm)*CpUSvconjUSvconjVWmVWm(gO1,gO2);
   result += 2*A0(MVZ)*CpUSvconjUSvVZVZ(gO1,gO2);
   std::complex<double> tmp_2157;
   std::complex<double> tmp_2158;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      tmp_2158 += A0(MRh(gI1))*CpUSvconjUSvconjRhRh(gO1,gO2,gI1,gI1);
   }
   tmp_2157 += tmp_2158;
   result += (-1) * tmp_2157;
   std::complex<double> tmp_2159;
   std::complex<double> tmp_2160;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      tmp_2160 += A0(MRpm(gI1))*CpUSvconjUSvconjRpmRpm(gO1,gO2,gI1,gI1);
   }
   tmp_2159 += tmp_2160;
   result += (-1) * tmp_2159;
   std::complex<double> tmp_2161;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2162;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_2162 += B0(p,MRpm(gI1),MSe(gI2))*Conj(CpconjUSvconjRpmSe(gO2
            ,gI1,gI2))*CpconjUSvconjRpmSe(gO1,gI1,gI2);
      }
      tmp_2161 += tmp_2162;
   }
   result += tmp_2161;
   std::complex<double> tmp_2163;
   std::complex<double> tmp_2164;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      tmp_2164 += A0(MSv(gI1))*CpUSvconjUSvconjSvSv(gO1,gO2,gI1,gI1);
   }
   tmp_2163 += tmp_2164;
   result += (-1) * tmp_2163;
   std::complex<double> tmp_2165;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2166;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2166 += (Conj(CpconjUSvFeCha1PL(gO2,gI1,gI2))*
            CpconjUSvFeCha1PL(gO1,gI1,gI2) + Conj(CpconjUSvFeCha1PR(gO2,gI1,gI2))*
            CpconjUSvFeCha1PR(gO1,gI1,gI2))*G0(p,MFe(gI1),MCha1(gI2));
      }
      tmp_2165 += tmp_2166;
   }
   result += tmp_2165;
   std::complex<double> tmp_2167;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2168;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2168 += B0(p,MSv(gI1),MAh(gI2))*Conj(CpconjUSvSvAh(gO2,gI1,
            gI2))*CpconjUSvSvAh(gO1,gI1,gI2);
      }
      tmp_2167 += tmp_2168;
   }
   result += tmp_2167;
   std::complex<double> tmp_2169;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2170;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2170 += B0(p,MSv(gI1),Mhh(gI2))*Conj(CpconjUSvSvhh(gO2,gI1,
            gI2))*CpconjUSvSvhh(gO1,gI1,gI2);
      }
      tmp_2169 += tmp_2170;
   }
   result += tmp_2169;
   std::complex<double> tmp_2171;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2172;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2172 += (Conj(CpconjUSvFvChiPL(gO2,gI1,gI2))*
            CpconjUSvFvChiPL(gO1,gI1,gI2) + Conj(CpconjUSvFvChiPR(gO2,gI1,gI2))*
            CpconjUSvFvChiPR(gO1,gI1,gI2))*G0(p,MFv(gI1),MChi(gI2));
      }
      tmp_2171 += tmp_2172;
   }
   result += tmp_2171;
   std::complex<double> tmp_2173;
   std::complex<double> tmp_2174;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2175;
      std::complex<double> tmp_2176;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2176 += B0(p,MFe(gI1),MCha1(gI2))*(Conj(CpconjUSvFeCha1PR(
            gO2,gI1,gI2))*CpconjUSvFeCha1PL(gO1,gI1,gI2) + Conj(CpconjUSvFeCha1PL(
            gO2,gI1,gI2))*CpconjUSvFeCha1PR(gO1,gI1,gI2))*MCha1(gI2);
      }
      tmp_2175 += tmp_2176;
      tmp_2174 += (MFe(gI1)) * tmp_2175;
   }
   tmp_2173 += tmp_2174;
   result += (-2) * tmp_2173;
   std::complex<double> tmp_2177;
   std::complex<double> tmp_2178;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2179;
      std::complex<double> tmp_2180;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2180 += B0(p,MFv(gI1),MChi(gI2))*(Conj(CpconjUSvFvChiPR(gO2,
            gI1,gI2))*CpconjUSvFvChiPL(gO1,gI1,gI2) + Conj(CpconjUSvFvChiPL(gO2,
            gI1,gI2))*CpconjUSvFvChiPR(gO1,gI1,gI2))*MChi(gI2);
      }
      tmp_2179 += tmp_2180;
      tmp_2178 += (MFv(gI1)) * tmp_2179;
   }
   tmp_2177 += tmp_2178;
   result += (-2) * tmp_2177;
   std::complex<double> tmp_2181;
   std::complex<double> tmp_2182;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      tmp_2182 += A0(MAh(gI1))*CpUSvconjUSvAhAh(gO1,gO2,gI1,gI1);
   }
   tmp_2181 += tmp_2182;
   result += (-0.5) * tmp_2181;
   std::complex<double> tmp_2183;
   std::complex<double> tmp_2184;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      tmp_2184 += A0(MHpm(gI1))*CpUSvconjUSvconjHpmHpm(gO1,gO2,gI1,gI1);
   }
   tmp_2183 += tmp_2184;
   result += (-1) * tmp_2183;
   std::complex<double> tmp_2185;
   std::complex<double> tmp_2186;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      tmp_2186 += A0(Mhh(gI1))*CpUSvconjUSvhhhh(gO1,gO2,gI1,gI1);
   }
   tmp_2185 += tmp_2186;
   result += (-0.5) * tmp_2185;
   std::complex<double> tmp_2187;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2188;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_2188 += B0(p,MHpm(gI1),MSe(gI2))*Conj(CpconjUSvconjHpmSe(gO2
            ,gI1,gI2))*CpconjUSvconjHpmSe(gO1,gI1,gI2);
      }
      tmp_2187 += tmp_2188;
   }
   result += tmp_2187;
   std::complex<double> tmp_2189;
   std::complex<double> tmp_2190;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      tmp_2190 += A0(MSd(gI1))*CpUSvconjUSvconjSdSd(gO1,gO2,gI1,gI1);
   }
   tmp_2189 += tmp_2190;
   result += (-3) * tmp_2189;
   std::complex<double> tmp_2191;
   std::complex<double> tmp_2192;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      tmp_2192 += A0(MSe(gI1))*CpUSvconjUSvconjSeSe(gO1,gO2,gI1,gI1);
   }
   tmp_2191 += tmp_2192;
   result += (-1) * tmp_2191;
   std::complex<double> tmp_2193;
   std::complex<double> tmp_2194;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      tmp_2194 += A0(MSu(gI1))*CpUSvconjUSvconjSuSu(gO1,gO2,gI1,gI1);
   }
   tmp_2193 += tmp_2194;
   result += (-3) * tmp_2193;
   std::complex<double> tmp_2195;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_2195 += Conj(CpconjUSvVZSv(gO2,gI2))*CpconjUSvVZSv(gO1,gI2)*F0(p,
         MSv(gI2),MVZ);
   }
   result += tmp_2195;
   std::complex<double> tmp_2196;
   for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
      tmp_2196 += Conj(CpconjUSvconjVWmSe(gO2,gI2))*CpconjUSvconjVWmSe(gO1,
         gI2)*F0(p,MSe(gI2),MVWm);
   }
   result += tmp_2196;

   return result * oneOver16PiSqr;

}

std::complex<double> CLASSNAME::self_energy_Su(double p , unsigned gO1, unsigned gO2) const
{
   std::complex<double> result;

   result += -(A0(MSOc)*CpUSuconjUSuconjSOcSOc(gO1,gO2));
   result += 4*A0(MVWm)*CpUSuconjUSuconjVWmVWm(gO1,gO2);
   result += 2*A0(MVZ)*CpUSuconjUSuVZVZ(gO1,gO2);
   std::complex<double> tmp_2197;
   std::complex<double> tmp_2198;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      tmp_2198 += A0(MRh(gI1))*CpUSuconjUSuconjRhRh(gO1,gO2,gI1,gI1);
   }
   tmp_2197 += tmp_2198;
   result += (-1) * tmp_2197;
   std::complex<double> tmp_2199;
   std::complex<double> tmp_2200;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      tmp_2200 += A0(MRpm(gI1))*CpUSuconjUSuconjRpmRpm(gO1,gO2,gI1,gI1);
   }
   tmp_2199 += tmp_2200;
   result += (-1) * tmp_2199;
   std::complex<double> tmp_2201;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2202;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_2202 += (Conj(CpconjUSubarCha2FdPL(gO2,gI1,gI2))*
            CpconjUSubarCha2FdPL(gO1,gI1,gI2) + Conj(CpconjUSubarCha2FdPR(gO2,gI1,
            gI2))*CpconjUSubarCha2FdPR(gO1,gI1,gI2))*G0(p,MCha2(gI1),MFd(gI2));
      }
      tmp_2201 += tmp_2202;
   }
   result += tmp_2201;
   std::complex<double> tmp_2203;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2204;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_2204 += B0(p,MRpm(gI1),MSd(gI2))*Conj(CpconjUSuconjRpmSd(gO2
            ,gI1,gI2))*CpconjUSuconjRpmSd(gO1,gI1,gI2);
      }
      tmp_2203 += tmp_2204;
   }
   result += tmp_2203;
   std::complex<double> tmp_2205;
   std::complex<double> tmp_2206;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2207;
      std::complex<double> tmp_2208;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_2208 += B0(p,MCha2(gI1),MFd(gI2))*(Conj(CpconjUSubarCha2FdPR
            (gO2,gI1,gI2))*CpconjUSubarCha2FdPL(gO1,gI1,gI2) + Conj(
            CpconjUSubarCha2FdPL(gO2,gI1,gI2))*CpconjUSubarCha2FdPR(gO1,gI1,gI2))*
            MFd(gI2);
      }
      tmp_2207 += tmp_2208;
      tmp_2206 += (MCha2(gI1)) * tmp_2207;
   }
   tmp_2205 += tmp_2206;
   result += (-2) * tmp_2205;
   std::complex<double> tmp_2209;
   std::complex<double> tmp_2210;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      tmp_2210 += A0(MSv(gI1))*CpUSuconjUSuconjSvSv(gO1,gO2,gI1,gI1);
   }
   tmp_2209 += tmp_2210;
   result += (-1) * tmp_2209;
   std::complex<double> tmp_2211;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2212;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2212 += (Conj(CpconjUSuFdCha1PL(gO2,gI1,gI2))*
            CpconjUSuFdCha1PL(gO1,gI1,gI2) + Conj(CpconjUSuFdCha1PR(gO2,gI1,gI2))*
            CpconjUSuFdCha1PR(gO1,gI1,gI2))*G0(p,MFd(gI1),MCha1(gI2));
      }
      tmp_2211 += tmp_2212;
   }
   result += tmp_2211;
   std::complex<double> tmp_2213;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2214;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2214 += (Conj(CpconjUSuFuChiPL(gO2,gI1,gI2))*
            CpconjUSuFuChiPL(gO1,gI1,gI2) + Conj(CpconjUSuFuChiPR(gO2,gI1,gI2))*
            CpconjUSuFuChiPR(gO1,gI1,gI2))*G0(p,MFu(gI1),MChi(gI2));
      }
      tmp_2213 += tmp_2214;
   }
   result += tmp_2213;
   std::complex<double> tmp_2215;
   std::complex<double> tmp_2216;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2217;
      std::complex<double> tmp_2218;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2218 += B0(p,MFd(gI1),MCha1(gI2))*(Conj(CpconjUSuFdCha1PR(
            gO2,gI1,gI2))*CpconjUSuFdCha1PL(gO1,gI1,gI2) + Conj(CpconjUSuFdCha1PL(
            gO2,gI1,gI2))*CpconjUSuFdCha1PR(gO1,gI1,gI2))*MCha1(gI2);
      }
      tmp_2217 += tmp_2218;
      tmp_2216 += (MFd(gI1)) * tmp_2217;
   }
   tmp_2215 += tmp_2216;
   result += (-2) * tmp_2215;
   std::complex<double> tmp_2219;
   std::complex<double> tmp_2220;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2221;
      std::complex<double> tmp_2222;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2222 += B0(p,MFu(gI1),MChi(gI2))*(Conj(CpconjUSuFuChiPR(gO2,
            gI1,gI2))*CpconjUSuFuChiPL(gO1,gI1,gI2) + Conj(CpconjUSuFuChiPL(gO2,
            gI1,gI2))*CpconjUSuFuChiPR(gO1,gI1,gI2))*MChi(gI2);
      }
      tmp_2221 += tmp_2222;
      tmp_2220 += (MFu(gI1)) * tmp_2221;
   }
   tmp_2219 += tmp_2220;
   result += (-2) * tmp_2219;
   std::complex<double> tmp_2223;
   std::complex<double> tmp_2224;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      tmp_2224 += A0(MAh(gI1))*CpUSuconjUSuAhAh(gO1,gO2,gI1,gI1);
   }
   tmp_2223 += tmp_2224;
   result += (-0.5) * tmp_2223;
   std::complex<double> tmp_2225;
   std::complex<double> tmp_2226;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      tmp_2226 += A0(MHpm(gI1))*CpUSuconjUSuconjHpmHpm(gO1,gO2,gI1,gI1);
   }
   tmp_2225 += tmp_2226;
   result += (-1) * tmp_2225;
   std::complex<double> tmp_2227;
   std::complex<double> tmp_2228;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      tmp_2228 += A0(Mhh(gI1))*CpUSuconjUSuhhhh(gO1,gO2,gI1,gI1);
   }
   tmp_2227 += tmp_2228;
   result += (-0.5) * tmp_2227;
   std::complex<double> tmp_2229;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2230;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_2230 += (Conj(CpconjUSubarChiFuPL(gO2,gI1,gI2))*
            CpconjUSubarChiFuPL(gO1,gI1,gI2) + Conj(CpconjUSubarChiFuPR(gO2,gI1,
            gI2))*CpconjUSubarChiFuPR(gO1,gI1,gI2))*G0(p,MChi(gI1),MFu(gI2));
      }
      tmp_2229 += tmp_2230;
   }
   result += tmp_2229;
   std::complex<double> tmp_2231;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2232;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_2232 += B0(p,MHpm(gI1),MSd(gI2))*Conj(CpconjUSuconjHpmSd(gO2
            ,gI1,gI2))*CpconjUSuconjHpmSd(gO1,gI1,gI2);
      }
      tmp_2231 += tmp_2232;
   }
   result += tmp_2231;
   std::complex<double> tmp_2233;
   std::complex<double> tmp_2234;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2235;
      std::complex<double> tmp_2236;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_2236 += B0(p,MChi(gI1),MFu(gI2))*(Conj(CpconjUSubarChiFuPR(
            gO2,gI1,gI2))*CpconjUSubarChiFuPL(gO1,gI1,gI2) + Conj(
            CpconjUSubarChiFuPL(gO2,gI1,gI2))*CpconjUSubarChiFuPR(gO1,gI1,gI2))*
            MFu(gI2);
      }
      tmp_2235 += tmp_2236;
      tmp_2234 += (MChi(gI1)) * tmp_2235;
   }
   tmp_2233 += tmp_2234;
   result += (-2) * tmp_2233;
   std::complex<double> tmp_2237;
   std::complex<double> tmp_2238;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      tmp_2238 += B0(p,MSu(gI1),MSOc)*Conj(CpconjUSuSuSOc(gO2,gI1))*
         CpconjUSuSuSOc(gO1,gI1);
   }
   tmp_2237 += tmp_2238;
   result += (1.3333333333333333) * tmp_2237;
   std::complex<double> tmp_2239;
   std::complex<double> tmp_2240;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      tmp_2240 += A0(MSd(gI1))*CpUSuconjUSuconjSdSd(gO1,gO2,gI1,gI1);
   }
   tmp_2239 += tmp_2240;
   result += (-1) * tmp_2239;
   std::complex<double> tmp_2241;
   std::complex<double> tmp_2242;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      tmp_2242 += A0(MSe(gI1))*CpUSuconjUSuconjSeSe(gO1,gO2,gI1,gI1);
   }
   tmp_2241 += tmp_2242;
   result += (-1) * tmp_2241;
   std::complex<double> tmp_2243;
   std::complex<double> tmp_2244;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      tmp_2244 += A0(MSu(gI1))*CpUSuconjUSuconjSuSu(gO1,gO2,gI1,gI1);
   }
   tmp_2243 += tmp_2244;
   result += (-1) * tmp_2243;
   std::complex<double> tmp_2245;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_2246;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2246 += B0(p,MSu(gI1),MRh(gI2))*Conj(CpconjUSuSuRh(gO2,gI1,
            gI2))*CpconjUSuSuRh(gO1,gI1,gI2);
      }
      tmp_2245 += tmp_2246;
   }
   result += tmp_2245;
   std::complex<double> tmp_2247;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_2248;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2248 += B0(p,MSu(gI1),MAh(gI2))*Conj(CpconjUSuSuAh(gO2,gI1,
            gI2))*CpconjUSuSuAh(gO1,gI1,gI2);
      }
      tmp_2247 += tmp_2248;
   }
   result += tmp_2247;
   std::complex<double> tmp_2249;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_2250;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2250 += B0(p,MSu(gI1),Mhh(gI2))*Conj(CpconjUSuSuhh(gO2,gI1,
            gI2))*CpconjUSuSuhh(gO1,gI1,gI2);
      }
      tmp_2249 += tmp_2250;
   }
   result += tmp_2249;
   std::complex<double> tmp_2251;
   std::complex<double> tmp_2252;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_2252 += (Conj(CpconjUSubarGluFuPL(gO2,1,gI2))*CpconjUSubarGluFuPL(
         gO1,1,gI2) + Conj(CpconjUSubarGluFuPR(gO2,1,gI2))*CpconjUSubarGluFuPR(gO1
         ,1,gI2))*G0(p,MGlu,MFu(gI2));
   }
   tmp_2251 += tmp_2252;
   result += (1.3333333333333333) * tmp_2251;
   std::complex<double> tmp_2253;
   std::complex<double> tmp_2254;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_2254 += (Conj(CpconjUSuGluFuPL(gO2,1,gI2))*CpconjUSuGluFuPL(gO1,1,
         gI2) + Conj(CpconjUSuGluFuPR(gO2,1,gI2))*CpconjUSuGluFuPR(gO1,1,gI2))*G0(
         p,MGlu,MFu(gI2));
   }
   tmp_2253 += tmp_2254;
   result += (1.3333333333333333) * tmp_2253;
   std::complex<double> tmp_2255;
   for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
      tmp_2255 += Conj(CpconjUSuconjVWmSd(gO2,gI2))*CpconjUSuconjVWmSd(gO1,
         gI2)*F0(p,MSd(gI2),MVWm);
   }
   result += tmp_2255;
   std::complex<double> tmp_2256;
   std::complex<double> tmp_2257;
   for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
      tmp_2257 += Conj(CpconjUSuVGSu(gO2,gI2))*CpconjUSuVGSu(gO1,gI2)*F0(p,
         MSu(gI2),0);
   }
   tmp_2256 += tmp_2257;
   result += (1.3333333333333333) * tmp_2256;
   std::complex<double> tmp_2258;
   for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
      tmp_2258 += Conj(CpconjUSuVPSu(gO2,gI2))*CpconjUSuVPSu(gO1,gI2)*F0(p,
         MSu(gI2),0);
   }
   result += tmp_2258;
   std::complex<double> tmp_2259;
   for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
      tmp_2259 += Conj(CpconjUSuVZSu(gO2,gI2))*CpconjUSuVZSu(gO1,gI2)*F0(p,
         MSu(gI2),MVZ);
   }
   result += tmp_2259;
   std::complex<double> tmp_2260;
   std::complex<double> tmp_2261;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_2261 += B0(p,MGlu,MFu(gI2))*(Conj(CpconjUSubarGluFuPR(gO2,1,gI2))*
         CpconjUSubarGluFuPL(gO1,1,gI2) + Conj(CpconjUSubarGluFuPL(gO2,1,gI2))*
         CpconjUSubarGluFuPR(gO1,1,gI2))*MFu(gI2);
   }
   tmp_2260 += tmp_2261;
   result += (-2.6666666666666665*MGlu) * tmp_2260;
   std::complex<double> tmp_2262;
   std::complex<double> tmp_2263;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_2263 += B0(p,MGlu,MFu(gI2))*(Conj(CpconjUSuGluFuPR(gO2,1,gI2))*
         CpconjUSuGluFuPL(gO1,1,gI2) + Conj(CpconjUSuGluFuPL(gO2,1,gI2))*
         CpconjUSuGluFuPR(gO1,1,gI2))*MFu(gI2);
   }
   tmp_2262 += tmp_2263;
   result += (-2.6666666666666665*MGlu) * tmp_2262;

   return result * oneOver16PiSqr;

}

std::complex<double> CLASSNAME::self_energy_Se(double p , unsigned gO1, unsigned gO2) const
{
   std::complex<double> result;

   result += 4*A0(MVWm)*CpUSeconjUSeconjVWmVWm(gO1,gO2);
   result += 2*A0(MVZ)*CpUSeconjUSeVZVZ(gO1,gO2);
   std::complex<double> tmp_2264;
   std::complex<double> tmp_2265;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      tmp_2265 += A0(MRh(gI1))*CpUSeconjUSeconjRhRh(gO1,gO2,gI1,gI1);
   }
   tmp_2264 += tmp_2265;
   result += (-1) * tmp_2264;
   std::complex<double> tmp_2266;
   std::complex<double> tmp_2267;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      tmp_2267 += A0(MRpm(gI1))*CpUSeconjUSeconjRpmRpm(gO1,gO2,gI1,gI1);
   }
   tmp_2266 += tmp_2267;
   result += (-1) * tmp_2266;
   std::complex<double> tmp_2268;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2269;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_2269 += (Conj(CpconjUSebarCha1FvPL(gO2,gI1,gI2))*
            CpconjUSebarCha1FvPL(gO1,gI1,gI2) + Conj(CpconjUSebarCha1FvPR(gO2,gI1,
            gI2))*CpconjUSebarCha1FvPR(gO1,gI1,gI2))*G0(p,MCha1(gI1),MFv(gI2));
      }
      tmp_2268 += tmp_2269;
   }
   result += tmp_2268;
   std::complex<double> tmp_2270;
   std::complex<double> tmp_2271;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2272;
      std::complex<double> tmp_2273;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_2273 += B0(p,MCha1(gI1),MFv(gI2))*(Conj(CpconjUSebarCha1FvPR
            (gO2,gI1,gI2))*CpconjUSebarCha1FvPL(gO1,gI1,gI2) + Conj(
            CpconjUSebarCha1FvPL(gO2,gI1,gI2))*CpconjUSebarCha1FvPR(gO1,gI1,gI2))*
            MFv(gI2);
      }
      tmp_2272 += tmp_2273;
      tmp_2271 += (MCha1(gI1)) * tmp_2272;
   }
   tmp_2270 += tmp_2271;
   result += (-2) * tmp_2270;
   std::complex<double> tmp_2274;
   std::complex<double> tmp_2275;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      tmp_2275 += A0(MSv(gI1))*CpUSeconjUSeconjSvSv(gO1,gO2,gI1,gI1);
   }
   tmp_2274 += tmp_2275;
   result += (-1) * tmp_2274;
   std::complex<double> tmp_2276;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2277;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2277 += B0(p,MSv(gI1),MRpm(gI2))*Conj(CpconjUSeSvRpm(gO2,gI1
            ,gI2))*CpconjUSeSvRpm(gO1,gI1,gI2);
      }
      tmp_2276 += tmp_2277;
   }
   result += tmp_2276;
   std::complex<double> tmp_2278;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2279;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2279 += (Conj(CpconjUSeFvCha2PL(gO2,gI1,gI2))*
            CpconjUSeFvCha2PL(gO1,gI1,gI2) + Conj(CpconjUSeFvCha2PR(gO2,gI1,gI2))*
            CpconjUSeFvCha2PR(gO1,gI1,gI2))*G0(p,MFv(gI1),MCha2(gI2));
      }
      tmp_2278 += tmp_2279;
   }
   result += tmp_2278;
   std::complex<double> tmp_2280;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2281;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2281 += B0(p,MSv(gI1),MHpm(gI2))*Conj(CpconjUSeSvHpm(gO2,gI1
            ,gI2))*CpconjUSeSvHpm(gO1,gI1,gI2);
      }
      tmp_2280 += tmp_2281;
   }
   result += tmp_2280;
   std::complex<double> tmp_2282;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2283;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2283 += (Conj(CpconjUSeFeChiPL(gO2,gI1,gI2))*
            CpconjUSeFeChiPL(gO1,gI1,gI2) + Conj(CpconjUSeFeChiPR(gO2,gI1,gI2))*
            CpconjUSeFeChiPR(gO1,gI1,gI2))*G0(p,MFe(gI1),MChi(gI2));
      }
      tmp_2282 += tmp_2283;
   }
   result += tmp_2282;
   std::complex<double> tmp_2284;
   std::complex<double> tmp_2285;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2286;
      std::complex<double> tmp_2287;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2287 += B0(p,MFe(gI1),MChi(gI2))*(Conj(CpconjUSeFeChiPR(gO2,
            gI1,gI2))*CpconjUSeFeChiPL(gO1,gI1,gI2) + Conj(CpconjUSeFeChiPL(gO2,
            gI1,gI2))*CpconjUSeFeChiPR(gO1,gI1,gI2))*MChi(gI2);
      }
      tmp_2286 += tmp_2287;
      tmp_2285 += (MFe(gI1)) * tmp_2286;
   }
   tmp_2284 += tmp_2285;
   result += (-2) * tmp_2284;
   std::complex<double> tmp_2288;
   std::complex<double> tmp_2289;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2290;
      std::complex<double> tmp_2291;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2291 += B0(p,MFv(gI1),MCha2(gI2))*(Conj(CpconjUSeFvCha2PR(
            gO2,gI1,gI2))*CpconjUSeFvCha2PL(gO1,gI1,gI2) + Conj(CpconjUSeFvCha2PL(
            gO2,gI1,gI2))*CpconjUSeFvCha2PR(gO1,gI1,gI2))*MCha2(gI2);
      }
      tmp_2290 += tmp_2291;
      tmp_2289 += (MFv(gI1)) * tmp_2290;
   }
   tmp_2288 += tmp_2289;
   result += (-2) * tmp_2288;
   std::complex<double> tmp_2292;
   std::complex<double> tmp_2293;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      tmp_2293 += A0(MAh(gI1))*CpUSeconjUSeAhAh(gO1,gO2,gI1,gI1);
   }
   tmp_2292 += tmp_2293;
   result += (-0.5) * tmp_2292;
   std::complex<double> tmp_2294;
   std::complex<double> tmp_2295;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      tmp_2295 += A0(MHpm(gI1))*CpUSeconjUSeconjHpmHpm(gO1,gO2,gI1,gI1);
   }
   tmp_2294 += tmp_2295;
   result += (-1) * tmp_2294;
   std::complex<double> tmp_2296;
   std::complex<double> tmp_2297;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      tmp_2297 += A0(Mhh(gI1))*CpUSeconjUSehhhh(gO1,gO2,gI1,gI1);
   }
   tmp_2296 += tmp_2297;
   result += (-0.5) * tmp_2296;
   std::complex<double> tmp_2298;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2299;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_2299 += (Conj(CpconjUSebarChiFePL(gO2,gI1,gI2))*
            CpconjUSebarChiFePL(gO1,gI1,gI2) + Conj(CpconjUSebarChiFePR(gO2,gI1,
            gI2))*CpconjUSebarChiFePR(gO1,gI1,gI2))*G0(p,MChi(gI1),MFe(gI2));
      }
      tmp_2298 += tmp_2299;
   }
   result += tmp_2298;
   std::complex<double> tmp_2300;
   std::complex<double> tmp_2301;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2302;
      std::complex<double> tmp_2303;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_2303 += B0(p,MChi(gI1),MFe(gI2))*(Conj(CpconjUSebarChiFePR(
            gO2,gI1,gI2))*CpconjUSebarChiFePL(gO1,gI1,gI2) + Conj(
            CpconjUSebarChiFePL(gO2,gI1,gI2))*CpconjUSebarChiFePR(gO1,gI1,gI2))*
            MFe(gI2);
      }
      tmp_2302 += tmp_2303;
      tmp_2301 += (MChi(gI1)) * tmp_2302;
   }
   tmp_2300 += tmp_2301;
   result += (-2) * tmp_2300;
   std::complex<double> tmp_2304;
   std::complex<double> tmp_2305;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      tmp_2305 += A0(MSd(gI1))*CpUSeconjUSeconjSdSd(gO1,gO2,gI1,gI1);
   }
   tmp_2304 += tmp_2305;
   result += (-3) * tmp_2304;
   std::complex<double> tmp_2306;
   std::complex<double> tmp_2307;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      tmp_2307 += A0(MSe(gI1))*CpUSeconjUSeconjSeSe(gO1,gO2,gI1,gI1);
   }
   tmp_2306 += tmp_2307;
   result += (-1) * tmp_2306;
   std::complex<double> tmp_2308;
   std::complex<double> tmp_2309;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      tmp_2309 += A0(MSu(gI1))*CpUSeconjUSeconjSuSu(gO1,gO2,gI1,gI1);
   }
   tmp_2308 += tmp_2309;
   result += (-3) * tmp_2308;
   std::complex<double> tmp_2310;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_2311;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2311 += B0(p,MSe(gI1),MRh(gI2))*Conj(CpconjUSeSeRh(gO2,gI1,
            gI2))*CpconjUSeSeRh(gO1,gI1,gI2);
      }
      tmp_2310 += tmp_2311;
   }
   result += tmp_2310;
   std::complex<double> tmp_2312;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_2313;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2313 += B0(p,MSe(gI1),MAh(gI2))*Conj(CpconjUSeSeAh(gO2,gI1,
            gI2))*CpconjUSeSeAh(gO1,gI1,gI2);
      }
      tmp_2312 += tmp_2313;
   }
   result += tmp_2312;
   std::complex<double> tmp_2314;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_2315;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2315 += B0(p,MSe(gI1),Mhh(gI2))*Conj(CpconjUSeSehh(gO2,gI1,
            gI2))*CpconjUSeSehh(gO1,gI1,gI2);
      }
      tmp_2314 += tmp_2315;
   }
   result += tmp_2314;
   std::complex<double> tmp_2316;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_2316 += Conj(CpconjUSeVWmSv(gO2,gI2))*CpconjUSeVWmSv(gO1,gI2)*F0(p
         ,MSv(gI2),MVWm);
   }
   result += tmp_2316;
   std::complex<double> tmp_2317;
   for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
      tmp_2317 += Conj(CpconjUSeVPSe(gO2,gI2))*CpconjUSeVPSe(gO1,gI2)*F0(p,
         MSe(gI2),0);
   }
   result += tmp_2317;
   std::complex<double> tmp_2318;
   for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
      tmp_2318 += Conj(CpconjUSeVZSe(gO2,gI2))*CpconjUSeVZSe(gO1,gI2)*F0(p,
         MSe(gI2),MVZ);
   }
   result += tmp_2318;

   return result * oneOver16PiSqr;

}

std::complex<double> CLASSNAME::self_energy_hh(double p , unsigned gO1, unsigned gO2) const
{
   std::complex<double> result;

   result += -(B0(p,MVWm,MVWm)*CpUhhbargWmCgWmC(gO1)*CpUhhbargWmCgWmC(gO2));
   result += -(B0(p,MVWm,MVWm)*CpUhhbargWmgWm(gO1)*CpUhhbargWmgWm(gO2));
   result += -(B0(p,MVZ,MVZ)*CpUhhbargZgZ(gO1)*CpUhhbargZgZ(gO2));
   result += 4*B0(p,MVWm,MVWm)*Conj(CpUhhconjVWmVWm(gO2))*CpUhhconjVWmVWm(gO1);
   result += 4*A0(MVWm)*CpUhhUhhconjVWmVWm(gO1,gO2);
   result += 2*A0(MVZ)*CpUhhUhhVZVZ(gO1,gO2);
   result += 2*B0(p,MVZ,MVZ)*Conj(CpUhhVZVZ(gO2))*CpUhhVZVZ(gO1);
   std::complex<double> tmp_2319;
   std::complex<double> tmp_2320;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      tmp_2320 += A0(MRh(gI1))*CpUhhUhhconjRhRh(gO1,gO2,gI1,gI1);
   }
   tmp_2319 += tmp_2320;
   result += (-1) * tmp_2319;
   std::complex<double> tmp_2321;
   std::complex<double> tmp_2322;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      tmp_2322 += A0(MRpm(gI1))*CpUhhUhhconjRpmRpm(gO1,gO2,gI1,gI1);
   }
   tmp_2321 += tmp_2322;
   result += (-1) * tmp_2321;
   std::complex<double> tmp_2323;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2324;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2324 += B0(p,MRh(gI1),MRh(gI2))*Conj(CpUhhconjRhRh(gO2,gI1,
            gI2))*CpUhhconjRhRh(gO1,gI1,gI2);
      }
      tmp_2323 += tmp_2324;
   }
   result += tmp_2323;
   std::complex<double> tmp_2325;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2326;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2326 += B0(p,MRpm(gI1),MRpm(gI2))*Conj(CpUhhconjRpmRpm(gO2,
            gI1,gI2))*CpUhhconjRpmRpm(gO1,gI1,gI2);
      }
      tmp_2325 += tmp_2326;
   }
   result += tmp_2325;
   std::complex<double> tmp_2327;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2328;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2328 += (Conj(CpUhhbarCha1Cha1PL(gO2,gI1,gI2))*
            CpUhhbarCha1Cha1PL(gO1,gI1,gI2) + Conj(CpUhhbarCha1Cha1PR(gO2,gI1,gI2)
            )*CpUhhbarCha1Cha1PR(gO1,gI1,gI2))*G0(p,MCha1(gI1),MCha1(gI2));
      }
      tmp_2327 += tmp_2328;
   }
   result += tmp_2327;
   std::complex<double> tmp_2329;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2330;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2330 += (Conj(CpUhhbarCha2Cha2PL(gO2,gI1,gI2))*
            CpUhhbarCha2Cha2PL(gO1,gI1,gI2) + Conj(CpUhhbarCha2Cha2PR(gO2,gI1,gI2)
            )*CpUhhbarCha2Cha2PR(gO1,gI1,gI2))*G0(p,MCha2(gI1),MCha2(gI2));
      }
      tmp_2329 += tmp_2330;
   }
   result += tmp_2329;
   std::complex<double> tmp_2331;
   std::complex<double> tmp_2332;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2333;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2333 += B0(p,MRh(gI1),MAh(gI2))*Conj(CpUhhconjRhAh(gO2,gI1,
            gI2))*CpUhhconjRhAh(gO1,gI1,gI2);
      }
      tmp_2332 += tmp_2333;
   }
   tmp_2331 += tmp_2332;
   result += (2) * tmp_2331;
   std::complex<double> tmp_2334;
   std::complex<double> tmp_2335;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2336;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2336 += B0(p,MRh(gI1),Mhh(gI2))*Conj(CpUhhconjRhhh(gO2,gI1,
            gI2))*CpUhhconjRhhh(gO1,gI1,gI2);
      }
      tmp_2335 += tmp_2336;
   }
   tmp_2334 += tmp_2335;
   result += (2) * tmp_2334;
   std::complex<double> tmp_2337;
   std::complex<double> tmp_2338;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2339;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2339 += B0(p,MRpm(gI1),MHpm(gI2))*Conj(CpUhhconjRpmHpm(gO2,
            gI1,gI2))*CpUhhconjRpmHpm(gO1,gI1,gI2);
      }
      tmp_2338 += tmp_2339;
   }
   tmp_2337 += tmp_2338;
   result += (2) * tmp_2337;
   std::complex<double> tmp_2340;
   std::complex<double> tmp_2341;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2342;
      std::complex<double> tmp_2343;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2343 += B0(p,MCha1(gI1),MCha1(gI2))*(Conj(CpUhhbarCha1Cha1PR
            (gO2,gI1,gI2))*CpUhhbarCha1Cha1PL(gO1,gI1,gI2) + Conj(
            CpUhhbarCha1Cha1PL(gO2,gI1,gI2))*CpUhhbarCha1Cha1PR(gO1,gI1,gI2))*
            MCha1(gI2);
      }
      tmp_2342 += tmp_2343;
      tmp_2341 += (MCha1(gI1)) * tmp_2342;
   }
   tmp_2340 += tmp_2341;
   result += (-2) * tmp_2340;
   std::complex<double> tmp_2344;
   std::complex<double> tmp_2345;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2346;
      std::complex<double> tmp_2347;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2347 += B0(p,MCha2(gI1),MCha2(gI2))*(Conj(CpUhhbarCha2Cha2PR
            (gO2,gI1,gI2))*CpUhhbarCha2Cha2PL(gO1,gI1,gI2) + Conj(
            CpUhhbarCha2Cha2PL(gO2,gI1,gI2))*CpUhhbarCha2Cha2PR(gO1,gI1,gI2))*
            MCha2(gI2);
      }
      tmp_2346 += tmp_2347;
      tmp_2345 += (MCha2(gI1)) * tmp_2346;
   }
   tmp_2344 += tmp_2345;
   result += (-2) * tmp_2344;
   std::complex<double> tmp_2348;
   std::complex<double> tmp_2349;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      tmp_2349 += A0(MSv(gI1))*CpUhhUhhconjSvSv(gO1,gO2,gI1,gI1);
   }
   tmp_2348 += tmp_2349;
   result += (-1) * tmp_2348;
   std::complex<double> tmp_2350;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2351;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_2351 += B0(p,MSv(gI1),MSv(gI2))*Conj(CpUhhconjSvSv(gO2,gI1,
            gI2))*CpUhhconjSvSv(gO1,gI1,gI2);
      }
      tmp_2350 += tmp_2351;
   }
   result += tmp_2350;
   std::complex<double> tmp_2352;
   std::complex<double> tmp_2353;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2354;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_2354 += (Conj(CpUhhbarFdFdPL(gO2,gI1,gI2))*CpUhhbarFdFdPL(
            gO1,gI1,gI2) + Conj(CpUhhbarFdFdPR(gO2,gI1,gI2))*CpUhhbarFdFdPR(gO1,
            gI1,gI2))*G0(p,MFd(gI1),MFd(gI2));
      }
      tmp_2353 += tmp_2354;
   }
   tmp_2352 += tmp_2353;
   result += (3) * tmp_2352;
   std::complex<double> tmp_2355;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2356;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_2356 += (Conj(CpUhhbarFeFePL(gO2,gI1,gI2))*CpUhhbarFeFePL(
            gO1,gI1,gI2) + Conj(CpUhhbarFeFePR(gO2,gI1,gI2))*CpUhhbarFeFePR(gO1,
            gI1,gI2))*G0(p,MFe(gI1),MFe(gI2));
      }
      tmp_2355 += tmp_2356;
   }
   result += tmp_2355;
   std::complex<double> tmp_2357;
   std::complex<double> tmp_2358;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2359;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_2359 += (Conj(CpUhhbarFuFuPL(gO2,gI1,gI2))*CpUhhbarFuFuPL(
            gO1,gI1,gI2) + Conj(CpUhhbarFuFuPR(gO2,gI1,gI2))*CpUhhbarFuFuPR(gO1,
            gI1,gI2))*G0(p,MFu(gI1),MFu(gI2));
      }
      tmp_2358 += tmp_2359;
   }
   tmp_2357 += tmp_2358;
   result += (3) * tmp_2357;
   std::complex<double> tmp_2360;
   std::complex<double> tmp_2361;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2362;
      std::complex<double> tmp_2363;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_2363 += B0(p,MFd(gI1),MFd(gI2))*(Conj(CpUhhbarFdFdPR(gO2,gI1
            ,gI2))*CpUhhbarFdFdPL(gO1,gI1,gI2) + Conj(CpUhhbarFdFdPL(gO2,gI1,gI2))
            *CpUhhbarFdFdPR(gO1,gI1,gI2))*MFd(gI2);
      }
      tmp_2362 += tmp_2363;
      tmp_2361 += (MFd(gI1)) * tmp_2362;
   }
   tmp_2360 += tmp_2361;
   result += (-6) * tmp_2360;
   std::complex<double> tmp_2364;
   std::complex<double> tmp_2365;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2366;
      std::complex<double> tmp_2367;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_2367 += B0(p,MFe(gI1),MFe(gI2))*(Conj(CpUhhbarFeFePR(gO2,gI1
            ,gI2))*CpUhhbarFeFePL(gO1,gI1,gI2) + Conj(CpUhhbarFeFePL(gO2,gI1,gI2))
            *CpUhhbarFeFePR(gO1,gI1,gI2))*MFe(gI2);
      }
      tmp_2366 += tmp_2367;
      tmp_2365 += (MFe(gI1)) * tmp_2366;
   }
   tmp_2364 += tmp_2365;
   result += (-2) * tmp_2364;
   std::complex<double> tmp_2368;
   std::complex<double> tmp_2369;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2370;
      std::complex<double> tmp_2371;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_2371 += B0(p,MFu(gI1),MFu(gI2))*(Conj(CpUhhbarFuFuPR(gO2,gI1
            ,gI2))*CpUhhbarFuFuPL(gO1,gI1,gI2) + Conj(CpUhhbarFuFuPL(gO2,gI1,gI2))
            *CpUhhbarFuFuPR(gO1,gI1,gI2))*MFu(gI2);
      }
      tmp_2370 += tmp_2371;
      tmp_2369 += (MFu(gI1)) * tmp_2370;
   }
   tmp_2368 += tmp_2369;
   result += (-6) * tmp_2368;
   std::complex<double> tmp_2372;
   std::complex<double> tmp_2373;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      tmp_2373 += A0(MAh(gI1))*CpUhhUhhAhAh(gO1,gO2,gI1,gI1);
   }
   tmp_2372 += tmp_2373;
   result += (-0.5) * tmp_2372;
   std::complex<double> tmp_2374;
   std::complex<double> tmp_2375;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      tmp_2375 += A0(MHpm(gI1))*CpUhhUhhconjHpmHpm(gO1,gO2,gI1,gI1);
   }
   tmp_2374 += tmp_2375;
   result += (-1) * tmp_2374;
   std::complex<double> tmp_2376;
   std::complex<double> tmp_2377;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      tmp_2377 += A0(Mhh(gI1))*CpUhhUhhhhhh(gO1,gO2,gI1,gI1);
   }
   tmp_2376 += tmp_2377;
   result += (-0.5) * tmp_2376;
   std::complex<double> tmp_2378;
   std::complex<double> tmp_2379;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2380;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2380 += B0(p,MAh(gI1),MAh(gI2))*Conj(CpUhhAhAh(gO2,gI1,gI2))
            *CpUhhAhAh(gO1,gI1,gI2);
      }
      tmp_2379 += tmp_2380;
   }
   tmp_2378 += tmp_2379;
   result += (0.5) * tmp_2378;
   std::complex<double> tmp_2381;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2382;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2382 += B0(p,MHpm(gI1),MHpm(gI2))*Conj(CpUhhconjHpmHpm(gO2,
            gI1,gI2))*CpUhhconjHpmHpm(gO1,gI1,gI2);
      }
      tmp_2381 += tmp_2382;
   }
   result += tmp_2381;
   std::complex<double> tmp_2383;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2384;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2384 += B0(p,Mhh(gI1),MAh(gI2))*Conj(CpUhhhhAh(gO2,gI1,gI2))
            *CpUhhhhAh(gO1,gI1,gI2);
      }
      tmp_2383 += tmp_2384;
   }
   result += tmp_2383;
   std::complex<double> tmp_2385;
   std::complex<double> tmp_2386;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2387;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2387 += B0(p,Mhh(gI1),Mhh(gI2))*Conj(CpUhhhhhh(gO2,gI1,gI2))
            *CpUhhhhhh(gO1,gI1,gI2);
      }
      tmp_2386 += tmp_2387;
   }
   tmp_2385 += tmp_2386;
   result += (0.5) * tmp_2385;
   std::complex<double> tmp_2388;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2389;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2389 += (Conj(CpUhhbarChiChiPL(gO2,gI1,gI2))*
            CpUhhbarChiChiPL(gO1,gI1,gI2) + Conj(CpUhhbarChiChiPR(gO2,gI1,gI2))*
            CpUhhbarChiChiPR(gO1,gI1,gI2))*G0(p,MChi(gI1),MChi(gI2));
      }
      tmp_2388 += tmp_2389;
   }
   result += tmp_2388;
   std::complex<double> tmp_2390;
   std::complex<double> tmp_2391;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2392;
      std::complex<double> tmp_2393;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2393 += B0(p,MChi(gI1),MChi(gI2))*(Conj(CpUhhbarChiChiPR(gO2
            ,gI1,gI2))*CpUhhbarChiChiPL(gO1,gI1,gI2) + Conj(CpUhhbarChiChiPL(gO2,
            gI1,gI2))*CpUhhbarChiChiPR(gO1,gI1,gI2))*MChi(gI2);
      }
      tmp_2392 += tmp_2393;
      tmp_2391 += (MChi(gI1)) * tmp_2392;
   }
   tmp_2390 += tmp_2391;
   result += (-2) * tmp_2390;
   std::complex<double> tmp_2394;
   std::complex<double> tmp_2395;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      tmp_2395 += A0(MSd(gI1))*CpUhhUhhconjSdSd(gO1,gO2,gI1,gI1);
   }
   tmp_2394 += tmp_2395;
   result += (-3) * tmp_2394;
   std::complex<double> tmp_2396;
   std::complex<double> tmp_2397;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      tmp_2397 += A0(MSe(gI1))*CpUhhUhhconjSeSe(gO1,gO2,gI1,gI1);
   }
   tmp_2396 += tmp_2397;
   result += (-1) * tmp_2396;
   std::complex<double> tmp_2398;
   std::complex<double> tmp_2399;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      tmp_2399 += A0(MSu(gI1))*CpUhhUhhconjSuSu(gO1,gO2,gI1,gI1);
   }
   tmp_2398 += tmp_2399;
   result += (-3) * tmp_2398;
   std::complex<double> tmp_2400;
   std::complex<double> tmp_2401;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_2402;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_2402 += B0(p,MSd(gI1),MSd(gI2))*Conj(CpUhhconjSdSd(gO2,gI1,
            gI2))*CpUhhconjSdSd(gO1,gI1,gI2);
      }
      tmp_2401 += tmp_2402;
   }
   tmp_2400 += tmp_2401;
   result += (3) * tmp_2400;
   std::complex<double> tmp_2403;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_2404;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_2404 += B0(p,MSe(gI1),MSe(gI2))*Conj(CpUhhconjSeSe(gO2,gI1,
            gI2))*CpUhhconjSeSe(gO1,gI1,gI2);
      }
      tmp_2403 += tmp_2404;
   }
   result += tmp_2403;
   std::complex<double> tmp_2405;
   std::complex<double> tmp_2406;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_2407;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_2407 += B0(p,MSu(gI1),MSu(gI2))*Conj(CpUhhconjSuSu(gO2,gI1,
            gI2))*CpUhhconjSuSu(gO1,gI1,gI2);
      }
      tmp_2406 += tmp_2407;
   }
   tmp_2405 += tmp_2406;
   result += (3) * tmp_2405;
   std::complex<double> tmp_2408;
   for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
      tmp_2408 += Conj(CpUhhVZAh(gO2,gI2))*CpUhhVZAh(gO1,gI2)*F0(p,MAh(gI2),
         MVZ);
   }
   result += tmp_2408;
   std::complex<double> tmp_2409;
   std::complex<double> tmp_2410;
   for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
      tmp_2410 += Conj(CpUhhconjVWmHpm(gO2,gI2))*CpUhhconjVWmHpm(gO1,gI2)*F0
         (p,MHpm(gI2),MVWm);
   }
   tmp_2409 += tmp_2410;
   result += (2) * tmp_2409;

   return result * oneOver16PiSqr;

}

std::complex<double> CLASSNAME::self_energy_Ah(double p , unsigned gO1, unsigned gO2) const
{
   std::complex<double> result;

   result += -(B0(p,MVWm,MVWm)*CpUAhbargWmCgWmC(gO1)*CpUAhbargWmCgWmC(gO2));
   result += -(B0(p,MVWm,MVWm)*CpUAhbargWmgWm(gO1)*CpUAhbargWmgWm(gO2));
   result += 4*A0(MVWm)*CpUAhUAhconjVWmVWm(gO1,gO2);
   result += 2*A0(MVZ)*CpUAhUAhVZVZ(gO1,gO2);
   std::complex<double> tmp_2411;
   std::complex<double> tmp_2412;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      tmp_2412 += A0(MRh(gI1))*CpUAhUAhconjRhRh(gO1,gO2,gI1,gI1);
   }
   tmp_2411 += tmp_2412;
   result += (-1) * tmp_2411;
   std::complex<double> tmp_2413;
   std::complex<double> tmp_2414;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      tmp_2414 += A0(MRpm(gI1))*CpUAhUAhconjRpmRpm(gO1,gO2,gI1,gI1);
   }
   tmp_2413 += tmp_2414;
   result += (-1) * tmp_2413;
   std::complex<double> tmp_2415;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2416;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2416 += B0(p,MRh(gI1),MRh(gI2))*Conj(CpUAhconjRhRh(gO2,gI1,
            gI2))*CpUAhconjRhRh(gO1,gI1,gI2);
      }
      tmp_2415 += tmp_2416;
   }
   result += tmp_2415;
   std::complex<double> tmp_2417;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2418;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2418 += B0(p,MRpm(gI1),MRpm(gI2))*Conj(CpUAhconjRpmRpm(gO2,
            gI1,gI2))*CpUAhconjRpmRpm(gO1,gI1,gI2);
      }
      tmp_2417 += tmp_2418;
   }
   result += tmp_2417;
   std::complex<double> tmp_2419;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2420;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2420 += (Conj(CpUAhbarCha1Cha1PL(gO2,gI1,gI2))*
            CpUAhbarCha1Cha1PL(gO1,gI1,gI2) + Conj(CpUAhbarCha1Cha1PR(gO2,gI1,gI2)
            )*CpUAhbarCha1Cha1PR(gO1,gI1,gI2))*G0(p,MCha1(gI1),MCha1(gI2));
      }
      tmp_2419 += tmp_2420;
   }
   result += tmp_2419;
   std::complex<double> tmp_2421;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2422;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2422 += (Conj(CpUAhbarCha2Cha2PL(gO2,gI1,gI2))*
            CpUAhbarCha2Cha2PL(gO1,gI1,gI2) + Conj(CpUAhbarCha2Cha2PR(gO2,gI1,gI2)
            )*CpUAhbarCha2Cha2PR(gO1,gI1,gI2))*G0(p,MCha2(gI1),MCha2(gI2));
      }
      tmp_2421 += tmp_2422;
   }
   result += tmp_2421;
   std::complex<double> tmp_2423;
   std::complex<double> tmp_2424;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2425;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2425 += B0(p,MRh(gI1),MAh(gI2))*Conj(CpUAhconjRhAh(gO2,gI1,
            gI2))*CpUAhconjRhAh(gO1,gI1,gI2);
      }
      tmp_2424 += tmp_2425;
   }
   tmp_2423 += tmp_2424;
   result += (2) * tmp_2423;
   std::complex<double> tmp_2426;
   std::complex<double> tmp_2427;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2428;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2428 += B0(p,MRh(gI1),Mhh(gI2))*Conj(CpUAhconjRhhh(gO2,gI1,
            gI2))*CpUAhconjRhhh(gO1,gI1,gI2);
      }
      tmp_2427 += tmp_2428;
   }
   tmp_2426 += tmp_2427;
   result += (2) * tmp_2426;
   std::complex<double> tmp_2429;
   std::complex<double> tmp_2430;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2431;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2431 += B0(p,MRpm(gI1),MHpm(gI2))*Conj(CpUAhconjRpmHpm(gO2,
            gI1,gI2))*CpUAhconjRpmHpm(gO1,gI1,gI2);
      }
      tmp_2430 += tmp_2431;
   }
   tmp_2429 += tmp_2430;
   result += (2) * tmp_2429;
   std::complex<double> tmp_2432;
   std::complex<double> tmp_2433;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2434;
      std::complex<double> tmp_2435;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2435 += B0(p,MCha1(gI1),MCha1(gI2))*(Conj(CpUAhbarCha1Cha1PR
            (gO2,gI1,gI2))*CpUAhbarCha1Cha1PL(gO1,gI1,gI2) + Conj(
            CpUAhbarCha1Cha1PL(gO2,gI1,gI2))*CpUAhbarCha1Cha1PR(gO1,gI1,gI2))*
            MCha1(gI2);
      }
      tmp_2434 += tmp_2435;
      tmp_2433 += (MCha1(gI1)) * tmp_2434;
   }
   tmp_2432 += tmp_2433;
   result += (-2) * tmp_2432;
   std::complex<double> tmp_2436;
   std::complex<double> tmp_2437;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2438;
      std::complex<double> tmp_2439;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2439 += B0(p,MCha2(gI1),MCha2(gI2))*(Conj(CpUAhbarCha2Cha2PR
            (gO2,gI1,gI2))*CpUAhbarCha2Cha2PL(gO1,gI1,gI2) + Conj(
            CpUAhbarCha2Cha2PL(gO2,gI1,gI2))*CpUAhbarCha2Cha2PR(gO1,gI1,gI2))*
            MCha2(gI2);
      }
      tmp_2438 += tmp_2439;
      tmp_2437 += (MCha2(gI1)) * tmp_2438;
   }
   tmp_2436 += tmp_2437;
   result += (-2) * tmp_2436;
   std::complex<double> tmp_2440;
   std::complex<double> tmp_2441;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      tmp_2441 += A0(MSv(gI1))*CpUAhUAhconjSvSv(gO1,gO2,gI1,gI1);
   }
   tmp_2440 += tmp_2441;
   result += (-1) * tmp_2440;
   std::complex<double> tmp_2442;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2443;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_2443 += B0(p,MSv(gI1),MSv(gI2))*Conj(CpUAhconjSvSv(gO2,gI1,
            gI2))*CpUAhconjSvSv(gO1,gI1,gI2);
      }
      tmp_2442 += tmp_2443;
   }
   result += tmp_2442;
   std::complex<double> tmp_2444;
   std::complex<double> tmp_2445;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2446;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_2446 += (Conj(CpUAhbarFdFdPL(gO2,gI1,gI2))*CpUAhbarFdFdPL(
            gO1,gI1,gI2) + Conj(CpUAhbarFdFdPR(gO2,gI1,gI2))*CpUAhbarFdFdPR(gO1,
            gI1,gI2))*G0(p,MFd(gI1),MFd(gI2));
      }
      tmp_2445 += tmp_2446;
   }
   tmp_2444 += tmp_2445;
   result += (3) * tmp_2444;
   std::complex<double> tmp_2447;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2448;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_2448 += (Conj(CpUAhbarFeFePL(gO2,gI1,gI2))*CpUAhbarFeFePL(
            gO1,gI1,gI2) + Conj(CpUAhbarFeFePR(gO2,gI1,gI2))*CpUAhbarFeFePR(gO1,
            gI1,gI2))*G0(p,MFe(gI1),MFe(gI2));
      }
      tmp_2447 += tmp_2448;
   }
   result += tmp_2447;
   std::complex<double> tmp_2449;
   std::complex<double> tmp_2450;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2451;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_2451 += (Conj(CpUAhbarFuFuPL(gO2,gI1,gI2))*CpUAhbarFuFuPL(
            gO1,gI1,gI2) + Conj(CpUAhbarFuFuPR(gO2,gI1,gI2))*CpUAhbarFuFuPR(gO1,
            gI1,gI2))*G0(p,MFu(gI1),MFu(gI2));
      }
      tmp_2450 += tmp_2451;
   }
   tmp_2449 += tmp_2450;
   result += (3) * tmp_2449;
   std::complex<double> tmp_2452;
   std::complex<double> tmp_2453;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2454;
      std::complex<double> tmp_2455;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_2455 += B0(p,MFd(gI1),MFd(gI2))*(Conj(CpUAhbarFdFdPR(gO2,gI1
            ,gI2))*CpUAhbarFdFdPL(gO1,gI1,gI2) + Conj(CpUAhbarFdFdPL(gO2,gI1,gI2))
            *CpUAhbarFdFdPR(gO1,gI1,gI2))*MFd(gI2);
      }
      tmp_2454 += tmp_2455;
      tmp_2453 += (MFd(gI1)) * tmp_2454;
   }
   tmp_2452 += tmp_2453;
   result += (-6) * tmp_2452;
   std::complex<double> tmp_2456;
   std::complex<double> tmp_2457;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2458;
      std::complex<double> tmp_2459;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_2459 += B0(p,MFe(gI1),MFe(gI2))*(Conj(CpUAhbarFeFePR(gO2,gI1
            ,gI2))*CpUAhbarFeFePL(gO1,gI1,gI2) + Conj(CpUAhbarFeFePL(gO2,gI1,gI2))
            *CpUAhbarFeFePR(gO1,gI1,gI2))*MFe(gI2);
      }
      tmp_2458 += tmp_2459;
      tmp_2457 += (MFe(gI1)) * tmp_2458;
   }
   tmp_2456 += tmp_2457;
   result += (-2) * tmp_2456;
   std::complex<double> tmp_2460;
   std::complex<double> tmp_2461;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2462;
      std::complex<double> tmp_2463;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_2463 += B0(p,MFu(gI1),MFu(gI2))*(Conj(CpUAhbarFuFuPR(gO2,gI1
            ,gI2))*CpUAhbarFuFuPL(gO1,gI1,gI2) + Conj(CpUAhbarFuFuPL(gO2,gI1,gI2))
            *CpUAhbarFuFuPR(gO1,gI1,gI2))*MFu(gI2);
      }
      tmp_2462 += tmp_2463;
      tmp_2461 += (MFu(gI1)) * tmp_2462;
   }
   tmp_2460 += tmp_2461;
   result += (-6) * tmp_2460;
   std::complex<double> tmp_2464;
   std::complex<double> tmp_2465;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      tmp_2465 += A0(MAh(gI1))*CpUAhUAhAhAh(gO1,gO2,gI1,gI1);
   }
   tmp_2464 += tmp_2465;
   result += (-0.5) * tmp_2464;
   std::complex<double> tmp_2466;
   std::complex<double> tmp_2467;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      tmp_2467 += A0(MHpm(gI1))*CpUAhUAhconjHpmHpm(gO1,gO2,gI1,gI1);
   }
   tmp_2466 += tmp_2467;
   result += (-1) * tmp_2466;
   std::complex<double> tmp_2468;
   std::complex<double> tmp_2469;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      tmp_2469 += A0(Mhh(gI1))*CpUAhUAhhhhh(gO1,gO2,gI1,gI1);
   }
   tmp_2468 += tmp_2469;
   result += (-0.5) * tmp_2468;
   std::complex<double> tmp_2470;
   std::complex<double> tmp_2471;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2472;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2472 += B0(p,MAh(gI1),MAh(gI2))*Conj(CpUAhAhAh(gO2,gI1,gI2))
            *CpUAhAhAh(gO1,gI1,gI2);
      }
      tmp_2471 += tmp_2472;
   }
   tmp_2470 += tmp_2471;
   result += (0.5) * tmp_2470;
   std::complex<double> tmp_2473;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2474;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2474 += B0(p,MHpm(gI1),MHpm(gI2))*Conj(CpUAhconjHpmHpm(gO2,
            gI1,gI2))*CpUAhconjHpmHpm(gO1,gI1,gI2);
      }
      tmp_2473 += tmp_2474;
   }
   result += tmp_2473;
   std::complex<double> tmp_2475;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2476;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2476 += B0(p,Mhh(gI1),MAh(gI2))*Conj(CpUAhhhAh(gO2,gI1,gI2))
            *CpUAhhhAh(gO1,gI1,gI2);
      }
      tmp_2475 += tmp_2476;
   }
   result += tmp_2475;
   std::complex<double> tmp_2477;
   std::complex<double> tmp_2478;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2479;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2479 += B0(p,Mhh(gI1),Mhh(gI2))*Conj(CpUAhhhhh(gO2,gI1,gI2))
            *CpUAhhhhh(gO1,gI1,gI2);
      }
      tmp_2478 += tmp_2479;
   }
   tmp_2477 += tmp_2478;
   result += (0.5) * tmp_2477;
   std::complex<double> tmp_2480;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2481;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2481 += (Conj(CpUAhbarChiChiPL(gO2,gI1,gI2))*
            CpUAhbarChiChiPL(gO1,gI1,gI2) + Conj(CpUAhbarChiChiPR(gO2,gI1,gI2))*
            CpUAhbarChiChiPR(gO1,gI1,gI2))*G0(p,MChi(gI1),MChi(gI2));
      }
      tmp_2480 += tmp_2481;
   }
   result += tmp_2480;
   std::complex<double> tmp_2482;
   std::complex<double> tmp_2483;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2484;
      std::complex<double> tmp_2485;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2485 += B0(p,MChi(gI1),MChi(gI2))*(Conj(CpUAhbarChiChiPR(gO2
            ,gI1,gI2))*CpUAhbarChiChiPL(gO1,gI1,gI2) + Conj(CpUAhbarChiChiPL(gO2,
            gI1,gI2))*CpUAhbarChiChiPR(gO1,gI1,gI2))*MChi(gI2);
      }
      tmp_2484 += tmp_2485;
      tmp_2483 += (MChi(gI1)) * tmp_2484;
   }
   tmp_2482 += tmp_2483;
   result += (-2) * tmp_2482;
   std::complex<double> tmp_2486;
   std::complex<double> tmp_2487;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      tmp_2487 += A0(MSd(gI1))*CpUAhUAhconjSdSd(gO1,gO2,gI1,gI1);
   }
   tmp_2486 += tmp_2487;
   result += (-3) * tmp_2486;
   std::complex<double> tmp_2488;
   std::complex<double> tmp_2489;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      tmp_2489 += A0(MSe(gI1))*CpUAhUAhconjSeSe(gO1,gO2,gI1,gI1);
   }
   tmp_2488 += tmp_2489;
   result += (-1) * tmp_2488;
   std::complex<double> tmp_2490;
   std::complex<double> tmp_2491;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      tmp_2491 += A0(MSu(gI1))*CpUAhUAhconjSuSu(gO1,gO2,gI1,gI1);
   }
   tmp_2490 += tmp_2491;
   result += (-3) * tmp_2490;
   std::complex<double> tmp_2492;
   std::complex<double> tmp_2493;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_2494;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_2494 += B0(p,MSd(gI1),MSd(gI2))*Conj(CpUAhconjSdSd(gO2,gI1,
            gI2))*CpUAhconjSdSd(gO1,gI1,gI2);
      }
      tmp_2493 += tmp_2494;
   }
   tmp_2492 += tmp_2493;
   result += (3) * tmp_2492;
   std::complex<double> tmp_2495;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_2496;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_2496 += B0(p,MSe(gI1),MSe(gI2))*Conj(CpUAhconjSeSe(gO2,gI1,
            gI2))*CpUAhconjSeSe(gO1,gI1,gI2);
      }
      tmp_2495 += tmp_2496;
   }
   result += tmp_2495;
   std::complex<double> tmp_2497;
   std::complex<double> tmp_2498;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_2499;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_2499 += B0(p,MSu(gI1),MSu(gI2))*Conj(CpUAhconjSuSu(gO2,gI1,
            gI2))*CpUAhconjSuSu(gO1,gI1,gI2);
      }
      tmp_2498 += tmp_2499;
   }
   tmp_2497 += tmp_2498;
   result += (3) * tmp_2497;
   std::complex<double> tmp_2500;
   for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
      tmp_2500 += Conj(CpUAhVZhh(gO2,gI2))*CpUAhVZhh(gO1,gI2)*F0(p,Mhh(gI2),
         MVZ);
   }
   result += tmp_2500;
   std::complex<double> tmp_2501;
   std::complex<double> tmp_2502;
   for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
      tmp_2502 += Conj(CpUAhconjVWmHpm(gO2,gI2))*CpUAhconjVWmHpm(gO1,gI2)*F0
         (p,MHpm(gI2),MVWm);
   }
   tmp_2501 += tmp_2502;
   result += (2) * tmp_2501;

   return result * oneOver16PiSqr;

}

std::complex<double> CLASSNAME::self_energy_Rh(double p , unsigned gO1, unsigned gO2) const
{
   std::complex<double> result;

   result += 4*A0(MVWm)*CpURhconjURhconjVWmVWm(gO1,gO2);
   result += 2*A0(MVZ)*CpURhconjURhVZVZ(gO1,gO2);
   std::complex<double> tmp_2503;
   std::complex<double> tmp_2504;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      tmp_2504 += A0(MRh(gI1))*CpURhconjURhconjRhRh(gO1,gO2,gI1,gI1);
   }
   tmp_2503 += tmp_2504;
   result += (-1) * tmp_2503;
   std::complex<double> tmp_2505;
   std::complex<double> tmp_2506;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      tmp_2506 += A0(MRpm(gI1))*CpURhconjURhconjRpmRpm(gO1,gO2,gI1,gI1);
   }
   tmp_2505 += tmp_2506;
   result += (-1) * tmp_2505;
   std::complex<double> tmp_2507;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      tmp_2507 += Conj(CpconjURhconjRpmVWm(gO2,gI1))*CpconjURhconjRpmVWm(gO1
         ,gI1)*F0(p,MRpm(gI1),MVWm);
   }
   result += tmp_2507;
   std::complex<double> tmp_2508;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2509;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2509 += (Conj(CpconjURhCha2Cha1PL(gO2,gI1,gI2))*
            CpconjURhCha2Cha1PL(gO1,gI1,gI2) + Conj(CpconjURhCha2Cha1PR(gO2,gI1,
            gI2))*CpconjURhCha2Cha1PR(gO1,gI1,gI2))*G0(p,MCha2(gI1),MCha1(gI2));
      }
      tmp_2508 += tmp_2509;
   }
   result += tmp_2508;
   std::complex<double> tmp_2510;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2511;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2511 += B0(p,MRpm(gI1),MHpm(gI2))*Conj(CpconjURhconjRpmHpm(
            gO2,gI1,gI2))*CpconjURhconjRpmHpm(gO1,gI1,gI2);
      }
      tmp_2510 += tmp_2511;
   }
   result += tmp_2510;
   std::complex<double> tmp_2512;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2513;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2513 += B0(p,MRh(gI1),MAh(gI2))*Conj(CpconjURhRhAh(gO2,gI1,
            gI2))*CpconjURhRhAh(gO1,gI1,gI2);
      }
      tmp_2512 += tmp_2513;
   }
   result += tmp_2512;
   std::complex<double> tmp_2514;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2515;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2515 += B0(p,MRh(gI1),Mhh(gI2))*Conj(CpconjURhRhhh(gO2,gI1,
            gI2))*CpconjURhRhhh(gO1,gI1,gI2);
      }
      tmp_2514 += tmp_2515;
   }
   result += tmp_2514;
   std::complex<double> tmp_2516;
   std::complex<double> tmp_2517;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2518;
      std::complex<double> tmp_2519;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2519 += B0(p,MCha2(gI1),MCha1(gI2))*(Conj(
            CpconjURhCha2Cha1PR(gO2,gI1,gI2))*CpconjURhCha2Cha1PL(gO1,gI1,gI2) +
            Conj(CpconjURhCha2Cha1PL(gO2,gI1,gI2))*CpconjURhCha2Cha1PR(gO1,gI1,gI2
            ))*MCha1(gI2);
      }
      tmp_2518 += tmp_2519;
      tmp_2517 += (MCha2(gI1)) * tmp_2518;
   }
   tmp_2516 += tmp_2517;
   result += (-2) * tmp_2516;
   std::complex<double> tmp_2520;
   std::complex<double> tmp_2521;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      tmp_2521 += A0(MSv(gI1))*CpURhconjURhconjSvSv(gO1,gO2,gI1,gI1);
   }
   tmp_2520 += tmp_2521;
   result += (-1) * tmp_2520;
   std::complex<double> tmp_2522;
   std::complex<double> tmp_2523;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      tmp_2523 += A0(MAh(gI1))*CpURhconjURhAhAh(gO1,gO2,gI1,gI1);
   }
   tmp_2522 += tmp_2523;
   result += (-0.5) * tmp_2522;
   std::complex<double> tmp_2524;
   std::complex<double> tmp_2525;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      tmp_2525 += A0(MHpm(gI1))*CpURhconjURhconjHpmHpm(gO1,gO2,gI1,gI1);
   }
   tmp_2524 += tmp_2525;
   result += (-1) * tmp_2524;
   std::complex<double> tmp_2526;
   std::complex<double> tmp_2527;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      tmp_2527 += A0(Mhh(gI1))*CpURhconjURhhhhh(gO1,gO2,gI1,gI1);
   }
   tmp_2526 += tmp_2527;
   result += (-0.5) * tmp_2526;
   std::complex<double> tmp_2528;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2529;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2529 += B0(p,MHpm(gI1),MRpm(gI2))*Conj(CpconjURhconjHpmRpm(
            gO2,gI1,gI2))*CpconjURhconjHpmRpm(gO1,gI1,gI2);
      }
      tmp_2528 += tmp_2529;
   }
   result += tmp_2528;
   std::complex<double> tmp_2530;
   std::complex<double> tmp_2531;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2532;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2532 += B0(p,MAh(gI1),MAh(gI2))*Conj(CpconjURhAhAh(gO2,gI1,
            gI2))*CpconjURhAhAh(gO1,gI1,gI2);
      }
      tmp_2531 += tmp_2532;
   }
   tmp_2530 += tmp_2531;
   result += (0.25) * tmp_2530;
   std::complex<double> tmp_2533;
   std::complex<double> tmp_2534;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2535;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2535 += B0(p,MHpm(gI1),MHpm(gI2))*Conj(CpconjURhconjHpmHpm(
            gO2,gI1,gI2))*CpconjURhconjHpmHpm(gO1,gI1,gI2);
      }
      tmp_2534 += tmp_2535;
   }
   tmp_2533 += tmp_2534;
   result += (0.5) * tmp_2533;
   std::complex<double> tmp_2536;
   std::complex<double> tmp_2537;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2538;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2538 += B0(p,Mhh(gI1),MAh(gI2))*Conj(CpconjURhhhAh(gO2,gI1,
            gI2))*CpconjURhhhAh(gO1,gI1,gI2);
      }
      tmp_2537 += tmp_2538;
   }
   tmp_2536 += tmp_2537;
   result += (0.5) * tmp_2536;
   std::complex<double> tmp_2539;
   std::complex<double> tmp_2540;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2541;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2541 += B0(p,Mhh(gI1),Mhh(gI2))*Conj(CpconjURhhhhh(gO2,gI1,
            gI2))*CpconjURhhhhh(gO1,gI1,gI2);
      }
      tmp_2540 += tmp_2541;
   }
   tmp_2539 += tmp_2540;
   result += (0.25) * tmp_2539;
   std::complex<double> tmp_2542;
   std::complex<double> tmp_2543;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2544;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2544 += (Conj(CpconjURhChiChiPL(gO2,gI1,gI2))*
            CpconjURhChiChiPL(gO1,gI1,gI2) + Conj(CpconjURhChiChiPR(gO2,gI1,gI2))*
            CpconjURhChiChiPR(gO1,gI1,gI2))*G0(p,MChi(gI1),MChi(gI2));
      }
      tmp_2543 += tmp_2544;
   }
   tmp_2542 += tmp_2543;
   result += (0.5) * tmp_2542;
   std::complex<double> tmp_2545;
   std::complex<double> tmp_2546;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2547;
      std::complex<double> tmp_2548;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2548 += B0(p,MChi(gI1),MChi(gI2))*(Conj(CpconjURhChiChiPR(
            gO2,gI1,gI2))*CpconjURhChiChiPL(gO1,gI1,gI2) + Conj(CpconjURhChiChiPL(
            gO2,gI1,gI2))*CpconjURhChiChiPR(gO1,gI1,gI2))*MChi(gI2);
      }
      tmp_2547 += tmp_2548;
      tmp_2546 += (MChi(gI1)) * tmp_2547;
   }
   tmp_2545 += tmp_2546;
   result += (-1) * tmp_2545;
   std::complex<double> tmp_2549;
   std::complex<double> tmp_2550;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      tmp_2550 += A0(MSd(gI1))*CpURhconjURhconjSdSd(gO1,gO2,gI1,gI1);
   }
   tmp_2549 += tmp_2550;
   result += (-3) * tmp_2549;
   std::complex<double> tmp_2551;
   std::complex<double> tmp_2552;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      tmp_2552 += A0(MSe(gI1))*CpURhconjURhconjSeSe(gO1,gO2,gI1,gI1);
   }
   tmp_2551 += tmp_2552;
   result += (-1) * tmp_2551;
   std::complex<double> tmp_2553;
   std::complex<double> tmp_2554;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      tmp_2554 += A0(MSu(gI1))*CpURhconjURhconjSuSu(gO1,gO2,gI1,gI1);
   }
   tmp_2553 += tmp_2554;
   result += (-3) * tmp_2553;
   std::complex<double> tmp_2555;
   std::complex<double> tmp_2556;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_2557;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_2557 += B0(p,MSd(gI1),MSd(gI2))*Conj(CpconjURhconjSdSd(gO2,
            gI1,gI2))*CpconjURhconjSdSd(gO1,gI1,gI2);
      }
      tmp_2556 += tmp_2557;
   }
   tmp_2555 += tmp_2556;
   result += (1.5) * tmp_2555;
   std::complex<double> tmp_2558;
   std::complex<double> tmp_2559;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_2560;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_2560 += B0(p,MSe(gI1),MSe(gI2))*Conj(CpconjURhconjSeSe(gO2,
            gI1,gI2))*CpconjURhconjSeSe(gO1,gI1,gI2);
      }
      tmp_2559 += tmp_2560;
   }
   tmp_2558 += tmp_2559;
   result += (0.5) * tmp_2558;
   std::complex<double> tmp_2561;
   std::complex<double> tmp_2562;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_2563;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_2563 += B0(p,MSu(gI1),MSu(gI2))*Conj(CpconjURhconjSuSu(gO2,
            gI1,gI2))*CpconjURhconjSuSu(gO1,gI1,gI2);
      }
      tmp_2562 += tmp_2563;
   }
   tmp_2561 += tmp_2562;
   result += (1.5) * tmp_2561;
   std::complex<double> tmp_2564;
   for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
      tmp_2564 += Conj(CpconjURhVZRh(gO2,gI2))*CpconjURhVZRh(gO1,gI2)*F0(p,
         MRh(gI2),MVZ);
   }
   result += tmp_2564;
   std::complex<double> tmp_2565;
   for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
      tmp_2565 += Conj(CpconjURhconjVWmRpm(gO2,gI2))*CpconjURhconjVWmRpm(gO1
         ,gI2)*F0(p,MRpm(gI2),MVWm);
   }
   result += tmp_2565;

   return result * oneOver16PiSqr;

}

std::complex<double> CLASSNAME::self_energy_Hpm(double p , unsigned gO1, unsigned gO2) const
{
   std::complex<double> result;

   result += 4*B0(p,0,MVWm)*Conj(CpconjUHpmVWmVP(gO2))*CpconjUHpmVWmVP(gO1);
   result += 4*B0(p,MVWm,MVZ)*Conj(CpconjUHpmVZVWm(gO2))*CpconjUHpmVZVWm(gO1);
   result += 4*A0(MVWm)*CpUHpmconjUHpmconjVWmVWm(gO1,gO2);
   result += 2*A0(MVZ)*CpUHpmconjUHpmVZVZ(gO1,gO2);
   result += -(B0(p,MVZ,MVWm)*CpconjUHpmbargWmCgZ(gO1)*CpUHpmgWmCbargZ(gO2));
   result += -(B0(p,MVWm,MVZ)*CpconjUHpmbargZgWm(gO1)*CpUHpmgZbargWm(gO2));
   std::complex<double> tmp_2566;
   std::complex<double> tmp_2567;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      tmp_2567 += A0(MRh(gI1))*CpUHpmconjUHpmconjRhRh(gO1,gO2,gI1,gI1);
   }
   tmp_2566 += tmp_2567;
   result += (-1) * tmp_2566;
   std::complex<double> tmp_2568;
   std::complex<double> tmp_2569;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      tmp_2569 += A0(MRpm(gI1))*CpUHpmconjUHpmconjRpmRpm(gO1,gO2,gI1,gI1);
   }
   tmp_2568 += tmp_2569;
   result += (-1) * tmp_2568;
   std::complex<double> tmp_2570;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2571;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2571 += B0(p,MRh(gI1),MRpm(gI2))*Conj(CpconjUHpmconjRhRpm(
            gO2,gI1,gI2))*CpconjUHpmconjRhRpm(gO1,gI1,gI2);
      }
      tmp_2570 += tmp_2571;
   }
   result += tmp_2570;
   std::complex<double> tmp_2572;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2573;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2573 += B0(p,MRpm(gI1),MRh(gI2))*Conj(CpconjUHpmRpmRh(gO2,
            gI1,gI2))*CpconjUHpmRpmRh(gO1,gI1,gI2);
      }
      tmp_2572 += tmp_2573;
   }
   result += tmp_2572;
   std::complex<double> tmp_2574;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2575;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2575 += B0(p,MRh(gI1),MHpm(gI2))*Conj(CpconjUHpmconjRhHpm(
            gO2,gI1,gI2))*CpconjUHpmconjRhHpm(gO1,gI1,gI2);
      }
      tmp_2574 += tmp_2575;
   }
   result += tmp_2574;
   std::complex<double> tmp_2576;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2577;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2577 += B0(p,MRpm(gI1),MAh(gI2))*Conj(CpconjUHpmRpmAh(gO2,
            gI1,gI2))*CpconjUHpmRpmAh(gO1,gI1,gI2);
      }
      tmp_2576 += tmp_2577;
   }
   result += tmp_2576;
   std::complex<double> tmp_2578;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2579;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2579 += B0(p,MRpm(gI1),Mhh(gI2))*Conj(CpconjUHpmRpmhh(gO2,
            gI1,gI2))*CpconjUHpmRpmhh(gO1,gI1,gI2);
      }
      tmp_2578 += tmp_2579;
   }
   result += tmp_2578;
   std::complex<double> tmp_2580;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2581;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2581 += (Conj(CpconjUHpmbarCha1ChiPL(gO2,gI1,gI2))*
            CpconjUHpmbarCha1ChiPL(gO1,gI1,gI2) + Conj(CpconjUHpmbarCha1ChiPR(gO2,
            gI1,gI2))*CpconjUHpmbarCha1ChiPR(gO1,gI1,gI2))*G0(p,MCha1(gI1),MChi(
            gI2));
      }
      tmp_2580 += tmp_2581;
   }
   result += tmp_2580;
   std::complex<double> tmp_2582;
   std::complex<double> tmp_2583;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2584;
      std::complex<double> tmp_2585;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2585 += B0(p,MCha1(gI1),MChi(gI2))*(Conj(
            CpconjUHpmbarCha1ChiPR(gO2,gI1,gI2))*CpconjUHpmbarCha1ChiPL(gO1,gI1,
            gI2) + Conj(CpconjUHpmbarCha1ChiPL(gO2,gI1,gI2))*
            CpconjUHpmbarCha1ChiPR(gO1,gI1,gI2))*MChi(gI2);
      }
      tmp_2584 += tmp_2585;
      tmp_2583 += (MCha1(gI1)) * tmp_2584;
   }
   tmp_2582 += tmp_2583;
   result += (-2) * tmp_2582;
   std::complex<double> tmp_2586;
   std::complex<double> tmp_2587;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      tmp_2587 += A0(MSv(gI1))*CpUHpmconjUHpmconjSvSv(gO1,gO2,gI1,gI1);
   }
   tmp_2586 += tmp_2587;
   result += (-1) * tmp_2586;
   std::complex<double> tmp_2588;
   std::complex<double> tmp_2589;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2590;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_2590 += (Conj(CpconjUHpmbarFuFdPL(gO2,gI1,gI2))*
            CpconjUHpmbarFuFdPL(gO1,gI1,gI2) + Conj(CpconjUHpmbarFuFdPR(gO2,gI1,
            gI2))*CpconjUHpmbarFuFdPR(gO1,gI1,gI2))*G0(p,MFu(gI1),MFd(gI2));
      }
      tmp_2589 += tmp_2590;
   }
   tmp_2588 += tmp_2589;
   result += (3) * tmp_2588;
   std::complex<double> tmp_2591;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2592;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_2592 += (Conj(CpconjUHpmbarFvFePL(gO2,gI1,gI2))*
            CpconjUHpmbarFvFePL(gO1,gI1,gI2) + Conj(CpconjUHpmbarFvFePR(gO2,gI1,
            gI2))*CpconjUHpmbarFvFePR(gO1,gI1,gI2))*G0(p,MFv(gI1),MFe(gI2));
      }
      tmp_2591 += tmp_2592;
   }
   result += tmp_2591;
   std::complex<double> tmp_2593;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2594;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_2594 += B0(p,MSv(gI1),MSe(gI2))*Conj(CpconjUHpmconjSvSe(gO2,
            gI1,gI2))*CpconjUHpmconjSvSe(gO1,gI1,gI2);
      }
      tmp_2593 += tmp_2594;
   }
   result += tmp_2593;
   std::complex<double> tmp_2595;
   std::complex<double> tmp_2596;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2597;
      std::complex<double> tmp_2598;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_2598 += B0(p,MFu(gI1),MFd(gI2))*(Conj(CpconjUHpmbarFuFdPR(
            gO2,gI1,gI2))*CpconjUHpmbarFuFdPL(gO1,gI1,gI2) + Conj(
            CpconjUHpmbarFuFdPL(gO2,gI1,gI2))*CpconjUHpmbarFuFdPR(gO1,gI1,gI2))*
            MFd(gI2);
      }
      tmp_2597 += tmp_2598;
      tmp_2596 += (MFu(gI1)) * tmp_2597;
   }
   tmp_2595 += tmp_2596;
   result += (-6) * tmp_2595;
   std::complex<double> tmp_2599;
   std::complex<double> tmp_2600;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2601;
      std::complex<double> tmp_2602;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_2602 += B0(p,MFv(gI1),MFe(gI2))*(Conj(CpconjUHpmbarFvFePR(
            gO2,gI1,gI2))*CpconjUHpmbarFvFePL(gO1,gI1,gI2) + Conj(
            CpconjUHpmbarFvFePL(gO2,gI1,gI2))*CpconjUHpmbarFvFePR(gO1,gI1,gI2))*
            MFe(gI2);
      }
      tmp_2601 += tmp_2602;
      tmp_2600 += (MFv(gI1)) * tmp_2601;
   }
   tmp_2599 += tmp_2600;
   result += (-2) * tmp_2599;
   std::complex<double> tmp_2603;
   std::complex<double> tmp_2604;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      tmp_2604 += A0(MAh(gI1))*CpUHpmconjUHpmAhAh(gO1,gO2,gI1,gI1);
   }
   tmp_2603 += tmp_2604;
   result += (-0.5) * tmp_2603;
   std::complex<double> tmp_2605;
   std::complex<double> tmp_2606;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      tmp_2606 += A0(MHpm(gI1))*CpUHpmconjUHpmconjHpmHpm(gO1,gO2,gI1,gI1);
   }
   tmp_2605 += tmp_2606;
   result += (-1) * tmp_2605;
   std::complex<double> tmp_2607;
   std::complex<double> tmp_2608;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      tmp_2608 += A0(Mhh(gI1))*CpUHpmconjUHpmhhhh(gO1,gO2,gI1,gI1);
   }
   tmp_2607 += tmp_2608;
   result += (-0.5) * tmp_2607;
   std::complex<double> tmp_2609;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2610;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2610 += (Conj(CpconjUHpmbarChiCha2PL(gO2,gI1,gI2))*
            CpconjUHpmbarChiCha2PL(gO1,gI1,gI2) + Conj(CpconjUHpmbarChiCha2PR(gO2,
            gI1,gI2))*CpconjUHpmbarChiCha2PR(gO1,gI1,gI2))*G0(p,MChi(gI1),MCha2(
            gI2));
      }
      tmp_2609 += tmp_2610;
   }
   result += tmp_2609;
   std::complex<double> tmp_2611;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2612;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2612 += B0(p,MHpm(gI1),MAh(gI2))*Conj(CpconjUHpmHpmAh(gO2,
            gI1,gI2))*CpconjUHpmHpmAh(gO1,gI1,gI2);
      }
      tmp_2611 += tmp_2612;
   }
   result += tmp_2611;
   std::complex<double> tmp_2613;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2614;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2614 += B0(p,MHpm(gI1),Mhh(gI2))*Conj(CpconjUHpmHpmhh(gO2,
            gI1,gI2))*CpconjUHpmHpmhh(gO1,gI1,gI2);
      }
      tmp_2613 += tmp_2614;
   }
   result += tmp_2613;
   std::complex<double> tmp_2615;
   std::complex<double> tmp_2616;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2617;
      std::complex<double> tmp_2618;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2618 += B0(p,MChi(gI1),MCha2(gI2))*(Conj(
            CpconjUHpmbarChiCha2PR(gO2,gI1,gI2))*CpconjUHpmbarChiCha2PL(gO1,gI1,
            gI2) + Conj(CpconjUHpmbarChiCha2PL(gO2,gI1,gI2))*
            CpconjUHpmbarChiCha2PR(gO1,gI1,gI2))*MCha2(gI2);
      }
      tmp_2617 += tmp_2618;
      tmp_2616 += (MChi(gI1)) * tmp_2617;
   }
   tmp_2615 += tmp_2616;
   result += (-2) * tmp_2615;
   std::complex<double> tmp_2619;
   std::complex<double> tmp_2620;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      tmp_2620 += A0(MSd(gI1))*CpUHpmconjUHpmconjSdSd(gO1,gO2,gI1,gI1);
   }
   tmp_2619 += tmp_2620;
   result += (-3) * tmp_2619;
   std::complex<double> tmp_2621;
   std::complex<double> tmp_2622;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      tmp_2622 += A0(MSe(gI1))*CpUHpmconjUHpmconjSeSe(gO1,gO2,gI1,gI1);
   }
   tmp_2621 += tmp_2622;
   result += (-1) * tmp_2621;
   std::complex<double> tmp_2623;
   std::complex<double> tmp_2624;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      tmp_2624 += A0(MSu(gI1))*CpUHpmconjUHpmconjSuSu(gO1,gO2,gI1,gI1);
   }
   tmp_2623 += tmp_2624;
   result += (-3) * tmp_2623;
   std::complex<double> tmp_2625;
   std::complex<double> tmp_2626;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_2627;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_2627 += B0(p,MSu(gI1),MSd(gI2))*Conj(CpconjUHpmconjSuSd(gO2,
            gI1,gI2))*CpconjUHpmconjSuSd(gO1,gI1,gI2);
      }
      tmp_2626 += tmp_2627;
   }
   tmp_2625 += tmp_2626;
   result += (3) * tmp_2625;
   std::complex<double> tmp_2628;
   for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
      tmp_2628 += Conj(CpconjUHpmVWmAh(gO2,gI2))*CpconjUHpmVWmAh(gO1,gI2)*F0
         (p,MAh(gI2),MVWm);
   }
   result += tmp_2628;
   std::complex<double> tmp_2629;
   for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
      tmp_2629 += Conj(CpconjUHpmVWmhh(gO2,gI2))*CpconjUHpmVWmhh(gO1,gI2)*F0
         (p,Mhh(gI2),MVWm);
   }
   result += tmp_2629;
   std::complex<double> tmp_2630;
   for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
      tmp_2630 += Conj(CpconjUHpmVPHpm(gO2,gI2))*CpconjUHpmVPHpm(gO1,gI2)*F0
         (p,MHpm(gI2),0);
   }
   result += tmp_2630;
   std::complex<double> tmp_2631;
   for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
      tmp_2631 += Conj(CpconjUHpmVZHpm(gO2,gI2))*CpconjUHpmVZHpm(gO1,gI2)*F0
         (p,MHpm(gI2),MVZ);
   }
   result += tmp_2631;

   return result * oneOver16PiSqr;

}

std::complex<double> CLASSNAME::self_energy_Rpm(double p , unsigned gO1, unsigned gO2) const
{
   std::complex<double> result;

   result += 4*A0(MVWm)*CpURpmconjURpmconjVWmVWm(gO1,gO2);
   result += 2*A0(MVZ)*CpURpmconjURpmVZVZ(gO1,gO2);
   std::complex<double> tmp_2632;
   std::complex<double> tmp_2633;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      tmp_2633 += A0(MRh(gI1))*CpURpmconjURpmconjRhRh(gO1,gO2,gI1,gI1);
   }
   tmp_2632 += tmp_2633;
   result += (-1) * tmp_2632;
   std::complex<double> tmp_2634;
   std::complex<double> tmp_2635;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      tmp_2635 += A0(MRpm(gI1))*CpURpmconjURpmconjRpmRpm(gO1,gO2,gI1,gI1);
   }
   tmp_2634 += tmp_2635;
   result += (-1) * tmp_2634;
   std::complex<double> tmp_2636;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      tmp_2636 += Conj(CpconjURpmconjRhVWm(gO2,gI1))*CpconjURpmconjRhVWm(gO1
         ,gI1)*F0(p,MRh(gI1),MVWm);
   }
   result += tmp_2636;
   std::complex<double> tmp_2637;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2638;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2638 += B0(p,MRh(gI1),MHpm(gI2))*Conj(CpconjURpmconjRhHpm(
            gO2,gI1,gI2))*CpconjURpmconjRhHpm(gO1,gI1,gI2);
      }
      tmp_2637 += tmp_2638;
   }
   result += tmp_2637;
   std::complex<double> tmp_2639;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2640;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2640 += B0(p,MRh(gI1),MHpm(gI2))*Conj(CpconjURpmRhHpm(gO2,
            gI1,gI2))*CpconjURpmRhHpm(gO1,gI1,gI2);
      }
      tmp_2639 += tmp_2640;
   }
   result += tmp_2639;
   std::complex<double> tmp_2641;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2642;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2642 += B0(p,MRpm(gI1),MAh(gI2))*Conj(CpconjURpmRpmAh(gO2,
            gI1,gI2))*CpconjURpmRpmAh(gO1,gI1,gI2);
      }
      tmp_2641 += tmp_2642;
   }
   result += tmp_2641;
   std::complex<double> tmp_2643;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2644;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2644 += B0(p,MRpm(gI1),Mhh(gI2))*Conj(CpconjURpmRpmhh(gO2,
            gI1,gI2))*CpconjURpmRpmhh(gO1,gI1,gI2);
      }
      tmp_2643 += tmp_2644;
   }
   result += tmp_2643;
   std::complex<double> tmp_2645;
   std::complex<double> tmp_2646;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      tmp_2646 += A0(MSv(gI1))*CpURpmconjURpmconjSvSv(gO1,gO2,gI1,gI1);
   }
   tmp_2645 += tmp_2646;
   result += (-1) * tmp_2645;
   std::complex<double> tmp_2647;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2648;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_2648 += B0(p,MSv(gI1),MSe(gI2))*Conj(CpconjURpmconjSvSe(gO2,
            gI1,gI2))*CpconjURpmconjSvSe(gO1,gI1,gI2);
      }
      tmp_2647 += tmp_2648;
   }
   result += tmp_2647;
   std::complex<double> tmp_2649;
   std::complex<double> tmp_2650;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      tmp_2650 += A0(MAh(gI1))*CpURpmconjURpmAhAh(gO1,gO2,gI1,gI1);
   }
   tmp_2649 += tmp_2650;
   result += (-0.5) * tmp_2649;
   std::complex<double> tmp_2651;
   std::complex<double> tmp_2652;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      tmp_2652 += A0(MHpm(gI1))*CpURpmconjURpmconjHpmHpm(gO1,gO2,gI1,gI1);
   }
   tmp_2651 += tmp_2652;
   result += (-1) * tmp_2651;
   std::complex<double> tmp_2653;
   std::complex<double> tmp_2654;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      tmp_2654 += A0(Mhh(gI1))*CpURpmconjURpmhhhh(gO1,gO2,gI1,gI1);
   }
   tmp_2653 += tmp_2654;
   result += (-0.5) * tmp_2653;
   std::complex<double> tmp_2655;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2656;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2656 += (Conj(CpconjURpmbarChibarCha1PL(gO2,gI1,gI2))*
            CpconjURpmbarChibarCha1PL(gO1,gI1,gI2) + Conj(
            CpconjURpmbarChibarCha1PR(gO2,gI1,gI2))*CpconjURpmbarChibarCha1PR(gO1,
            gI1,gI2))*G0(p,MChi(gI1),MCha1(gI2));
      }
      tmp_2655 += tmp_2656;
   }
   result += tmp_2655;
   std::complex<double> tmp_2657;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2658;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2658 += (Conj(CpconjURpmChiCha2PL(gO2,gI1,gI2))*
            CpconjURpmChiCha2PL(gO1,gI1,gI2) + Conj(CpconjURpmChiCha2PR(gO2,gI1,
            gI2))*CpconjURpmChiCha2PR(gO1,gI1,gI2))*G0(p,MChi(gI1),MCha2(gI2));
      }
      tmp_2657 += tmp_2658;
   }
   result += tmp_2657;
   std::complex<double> tmp_2659;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2660;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2660 += B0(p,MHpm(gI1),MAh(gI2))*Conj(CpconjURpmHpmAh(gO2,
            gI1,gI2))*CpconjURpmHpmAh(gO1,gI1,gI2);
      }
      tmp_2659 += tmp_2660;
   }
   result += tmp_2659;
   std::complex<double> tmp_2661;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2662;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2662 += B0(p,MHpm(gI1),Mhh(gI2))*Conj(CpconjURpmHpmhh(gO2,
            gI1,gI2))*CpconjURpmHpmhh(gO1,gI1,gI2);
      }
      tmp_2661 += tmp_2662;
   }
   result += tmp_2661;
   std::complex<double> tmp_2663;
   std::complex<double> tmp_2664;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2665;
      std::complex<double> tmp_2666;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2666 += B0(p,MChi(gI1),MCha1(gI2))*(Conj(
            CpconjURpmbarChibarCha1PR(gO2,gI1,gI2))*CpconjURpmbarChibarCha1PL(gO1,
            gI1,gI2) + Conj(CpconjURpmbarChibarCha1PL(gO2,gI1,gI2))*
            CpconjURpmbarChibarCha1PR(gO1,gI1,gI2))*MCha1(gI2);
      }
      tmp_2665 += tmp_2666;
      tmp_2664 += (MChi(gI1)) * tmp_2665;
   }
   tmp_2663 += tmp_2664;
   result += (-2) * tmp_2663;
   std::complex<double> tmp_2667;
   std::complex<double> tmp_2668;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2669;
      std::complex<double> tmp_2670;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2670 += B0(p,MChi(gI1),MCha2(gI2))*(Conj(CpconjURpmChiCha2PR
            (gO2,gI1,gI2))*CpconjURpmChiCha2PL(gO1,gI1,gI2) + Conj(
            CpconjURpmChiCha2PL(gO2,gI1,gI2))*CpconjURpmChiCha2PR(gO1,gI1,gI2))*
            MCha2(gI2);
      }
      tmp_2669 += tmp_2670;
      tmp_2668 += (MChi(gI1)) * tmp_2669;
   }
   tmp_2667 += tmp_2668;
   result += (-2) * tmp_2667;
   std::complex<double> tmp_2671;
   std::complex<double> tmp_2672;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      tmp_2672 += A0(MSd(gI1))*CpURpmconjURpmconjSdSd(gO1,gO2,gI1,gI1);
   }
   tmp_2671 += tmp_2672;
   result += (-3) * tmp_2671;
   std::complex<double> tmp_2673;
   std::complex<double> tmp_2674;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      tmp_2674 += A0(MSe(gI1))*CpURpmconjURpmconjSeSe(gO1,gO2,gI1,gI1);
   }
   tmp_2673 += tmp_2674;
   result += (-1) * tmp_2673;
   std::complex<double> tmp_2675;
   std::complex<double> tmp_2676;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      tmp_2676 += A0(MSu(gI1))*CpURpmconjURpmconjSuSu(gO1,gO2,gI1,gI1);
   }
   tmp_2675 += tmp_2676;
   result += (-3) * tmp_2675;
   std::complex<double> tmp_2677;
   std::complex<double> tmp_2678;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_2679;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_2679 += B0(p,MSu(gI1),MSd(gI2))*Conj(CpconjURpmconjSuSd(gO2,
            gI1,gI2))*CpconjURpmconjSuSd(gO1,gI1,gI2);
      }
      tmp_2678 += tmp_2679;
   }
   tmp_2677 += tmp_2678;
   result += (3) * tmp_2677;
   std::complex<double> tmp_2680;
   for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
      tmp_2680 += Conj(CpconjURpmVWmRh(gO2,gI2))*CpconjURpmVWmRh(gO1,gI2)*F0
         (p,MRh(gI2),MVWm);
   }
   result += tmp_2680;
   std::complex<double> tmp_2681;
   for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
      tmp_2681 += Conj(CpconjURpmVPRpm(gO2,gI2))*CpconjURpmVPRpm(gO1,gI2)*F0
         (p,MRpm(gI2),0);
   }
   result += tmp_2681;
   std::complex<double> tmp_2682;
   for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
      tmp_2682 += Conj(CpconjURpmVZRpm(gO2,gI2))*CpconjURpmVZRpm(gO1,gI2)*F0
         (p,MRpm(gI2),MVZ);
   }
   result += tmp_2682;

   return result * oneOver16PiSqr;

}

std::complex<double> CLASSNAME::self_energy_SOc(double p ) const
{
   std::complex<double> result;

   result += -(A0(MSOc)*CpSOcconjSOcconjSOcSOc());
   result += 3*AbsSqr(CpconjSOcVGSOc())*F0(p,MSOc,0);
   result += -1.5*(AbsSqr(CpconjSOcbarGluGluPL(1,1)) + AbsSqr(
      CpconjSOcbarGluGluPR(1,1)))*G0(p,MGlu,MGlu);
   std::complex<double> tmp_2683;
   std::complex<double> tmp_2684;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      tmp_2684 += A0(MSd(gI1))*CpSOcconjSOcconjSdSd(gI1,gI1);
   }
   tmp_2683 += tmp_2684;
   result += (-1) * tmp_2683;
   std::complex<double> tmp_2685;
   std::complex<double> tmp_2686;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      tmp_2686 += A0(MSu(gI1))*CpSOcconjSOcconjSuSu(gI1,gI1);
   }
   tmp_2685 += tmp_2686;
   result += (-1) * tmp_2685;
   std::complex<double> tmp_2687;
   std::complex<double> tmp_2688;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_2689;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_2689 += AbsSqr(CpconjSOcconjSdSd(gI1,gI2))*B0(p,MSd(gI1),MSd
            (gI2));
      }
      tmp_2688 += tmp_2689;
   }
   tmp_2687 += tmp_2688;
   result += (0.25) * tmp_2687;
   std::complex<double> tmp_2690;
   std::complex<double> tmp_2691;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_2692;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_2692 += AbsSqr(CpconjSOcconjSuSu(gI1,gI2))*B0(p,MSu(gI1),MSu
            (gI2));
      }
      tmp_2691 += tmp_2692;
   }
   tmp_2690 += tmp_2691;
   result += (0.25) * tmp_2690;
   result += 3*B0(p,MGlu,MGlu)*(Conj(CpconjSOcbarGluGluPR(1,1))*
      CpconjSOcbarGluGluPL(1,1) + Conj(CpconjSOcbarGluGluPL(1,1))*
      CpconjSOcbarGluGluPR(1,1))*Sqr(MGlu);

   return result * oneOver16PiSqr;

}

std::complex<double> CLASSNAME::self_energy_VZ(double p ) const
{
   std::complex<double> result;

   result += AbsSqr(CpVZbargWmCgWmC())*B00(p,MVWm,MVWm);
   result += AbsSqr(CpVZbargWmgWm())*B00(p,MVWm,MVWm);
   result += -(A0(MVWm)*(4*CpVZVZconjVWmVWm1() + CpVZVZconjVWmVWm2() +
      CpVZVZconjVWmVWm3()));
   std::complex<double> tmp_2693;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      tmp_2693 += A0(MRh(gI1))*CpVZVZconjRhRh(gI1,gI1);
   }
   result += tmp_2693;
   std::complex<double> tmp_2694;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      tmp_2694 += A0(MRpm(gI1))*CpVZVZconjRpmRpm(gI1,gI1);
   }
   result += tmp_2694;
   std::complex<double> tmp_2695;
   std::complex<double> tmp_2696;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2697;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2697 += AbsSqr(CpVZconjRhRh(gI1,gI2))*B00(p,MRh(gI1),MRh(gI2
            ));
      }
      tmp_2696 += tmp_2697;
   }
   tmp_2695 += tmp_2696;
   result += (-4) * tmp_2695;
   std::complex<double> tmp_2698;
   std::complex<double> tmp_2699;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2700;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2700 += AbsSqr(CpVZconjRpmRpm(gI1,gI2))*B00(p,MRpm(gI1),MRpm
            (gI2));
      }
      tmp_2699 += tmp_2700;
   }
   tmp_2698 += tmp_2699;
   result += (-4) * tmp_2698;
   std::complex<double> tmp_2701;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2702;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2702 += (AbsSqr(CpVZbarCha1Cha1PL(gI1,gI2)) + AbsSqr(
            CpVZbarCha1Cha1PR(gI1,gI2)))*H0(p,MCha1(gI1),MCha1(gI2));
         tmp_2702 += 4*B0(p,MCha1(gI1),MCha1(gI2))*MCha1(gI1)*MCha1(gI2)*
            Re(Conj(CpVZbarCha1Cha1PL(gI1,gI2))*CpVZbarCha1Cha1PR(gI1,gI2));
      }
      tmp_2701 += tmp_2702;
   }
   result += tmp_2701;
   std::complex<double> tmp_2703;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2704;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2704 += (AbsSqr(CpVZbarCha2Cha2PL(gI1,gI2)) + AbsSqr(
            CpVZbarCha2Cha2PR(gI1,gI2)))*H0(p,MCha2(gI1),MCha2(gI2));
         tmp_2704 += 4*B0(p,MCha2(gI1),MCha2(gI2))*MCha2(gI1)*MCha2(gI2)*
            Re(Conj(CpVZbarCha2Cha2PL(gI1,gI2))*CpVZbarCha2Cha2PR(gI1,gI2));
      }
      tmp_2703 += tmp_2704;
   }
   result += tmp_2703;
   std::complex<double> tmp_2705;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      tmp_2705 += A0(MSv(gI1))*CpVZVZconjSvSv(gI1,gI1);
   }
   result += tmp_2705;
   std::complex<double> tmp_2706;
   std::complex<double> tmp_2707;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2708;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_2708 += AbsSqr(CpVZconjSvSv(gI1,gI2))*B00(p,MSv(gI1),MSv(gI2
            ));
      }
      tmp_2707 += tmp_2708;
   }
   tmp_2706 += tmp_2707;
   result += (-4) * tmp_2706;
   std::complex<double> tmp_2709;
   std::complex<double> tmp_2710;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2711;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_2711 += (AbsSqr(CpVZbarFdFdPL(gI1,gI2)) + AbsSqr(
            CpVZbarFdFdPR(gI1,gI2)))*H0(p,MFd(gI1),MFd(gI2));
         tmp_2711 += 4*B0(p,MFd(gI1),MFd(gI2))*MFd(gI1)*MFd(gI2)*Re(Conj(
            CpVZbarFdFdPL(gI1,gI2))*CpVZbarFdFdPR(gI1,gI2));
      }
      tmp_2710 += tmp_2711;
   }
   tmp_2709 += tmp_2710;
   result += (3) * tmp_2709;
   std::complex<double> tmp_2712;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2713;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_2713 += (AbsSqr(CpVZbarFeFePL(gI1,gI2)) + AbsSqr(
            CpVZbarFeFePR(gI1,gI2)))*H0(p,MFe(gI1),MFe(gI2));
         tmp_2713 += 4*B0(p,MFe(gI1),MFe(gI2))*MFe(gI1)*MFe(gI2)*Re(Conj(
            CpVZbarFeFePL(gI1,gI2))*CpVZbarFeFePR(gI1,gI2));
      }
      tmp_2712 += tmp_2713;
   }
   result += tmp_2712;
   std::complex<double> tmp_2714;
   std::complex<double> tmp_2715;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2716;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_2716 += (AbsSqr(CpVZbarFuFuPL(gI1,gI2)) + AbsSqr(
            CpVZbarFuFuPR(gI1,gI2)))*H0(p,MFu(gI1),MFu(gI2));
         tmp_2716 += 4*B0(p,MFu(gI1),MFu(gI2))*MFu(gI1)*MFu(gI2)*Re(Conj(
            CpVZbarFuFuPL(gI1,gI2))*CpVZbarFuFuPR(gI1,gI2));
      }
      tmp_2715 += tmp_2716;
   }
   tmp_2714 += tmp_2715;
   result += (3) * tmp_2714;
   std::complex<double> tmp_2717;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2718;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_2718 += (AbsSqr(CpVZbarFvFvPL(gI1,gI2)) + AbsSqr(
            CpVZbarFvFvPR(gI1,gI2)))*H0(p,MFv(gI1),MFv(gI2));
         tmp_2718 += 4*B0(p,MFv(gI1),MFv(gI2))*MFv(gI1)*MFv(gI2)*Re(Conj(
            CpVZbarFvFvPL(gI1,gI2))*CpVZbarFvFvPR(gI1,gI2));
      }
      tmp_2717 += tmp_2718;
   }
   result += tmp_2717;
   std::complex<double> tmp_2719;
   std::complex<double> tmp_2720;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      tmp_2720 += A0(MAh(gI1))*CpVZVZAhAh(gI1,gI1);
   }
   tmp_2719 += tmp_2720;
   result += (0.5) * tmp_2719;
   std::complex<double> tmp_2721;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      tmp_2721 += A0(MHpm(gI1))*CpVZVZconjHpmHpm(gI1,gI1);
   }
   result += tmp_2721;
   std::complex<double> tmp_2722;
   std::complex<double> tmp_2723;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      tmp_2723 += A0(Mhh(gI1))*CpVZVZhhhh(gI1,gI1);
   }
   tmp_2722 += tmp_2723;
   result += (0.5) * tmp_2722;
   std::complex<double> tmp_2724;
   std::complex<double> tmp_2725;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2726;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2726 += AbsSqr(CpVZconjHpmHpm(gI1,gI2))*B00(p,MHpm(gI1),MHpm
            (gI2));
      }
      tmp_2725 += tmp_2726;
   }
   tmp_2724 += tmp_2725;
   result += (-4) * tmp_2724;
   std::complex<double> tmp_2727;
   std::complex<double> tmp_2728;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2729;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2729 += AbsSqr(CpVZhhAh(gI1,gI2))*B00(p,MAh(gI2),Mhh(gI1));
      }
      tmp_2728 += tmp_2729;
   }
   tmp_2727 += tmp_2728;
   result += (-4) * tmp_2727;
   std::complex<double> tmp_2730;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2731;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2731 += (AbsSqr(CpVZbarChiChiPL(gI1,gI2)) + AbsSqr(
            CpVZbarChiChiPR(gI1,gI2)))*H0(p,MChi(gI1),MChi(gI2));
         tmp_2731 += 4*B0(p,MChi(gI1),MChi(gI2))*MChi(gI1)*MChi(gI2)*Re(
            Conj(CpVZbarChiChiPL(gI1,gI2))*CpVZbarChiChiPR(gI1,gI2));
      }
      tmp_2730 += tmp_2731;
   }
   result += tmp_2730;
   std::complex<double> tmp_2732;
   std::complex<double> tmp_2733;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      tmp_2733 += A0(MSd(gI1))*CpVZVZconjSdSd(gI1,gI1);
   }
   tmp_2732 += tmp_2733;
   result += (3) * tmp_2732;
   std::complex<double> tmp_2734;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      tmp_2734 += A0(MSe(gI1))*CpVZVZconjSeSe(gI1,gI1);
   }
   result += tmp_2734;
   std::complex<double> tmp_2735;
   std::complex<double> tmp_2736;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      tmp_2736 += A0(MSu(gI1))*CpVZVZconjSuSu(gI1,gI1);
   }
   tmp_2735 += tmp_2736;
   result += (3) * tmp_2735;
   std::complex<double> tmp_2737;
   std::complex<double> tmp_2738;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_2739;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_2739 += AbsSqr(CpVZconjSdSd(gI1,gI2))*B00(p,MSd(gI1),MSd(gI2
            ));
      }
      tmp_2738 += tmp_2739;
   }
   tmp_2737 += tmp_2738;
   result += (-12) * tmp_2737;
   std::complex<double> tmp_2740;
   std::complex<double> tmp_2741;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_2742;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_2742 += AbsSqr(CpVZconjSeSe(gI1,gI2))*B00(p,MSe(gI1),MSe(gI2
            ));
      }
      tmp_2741 += tmp_2742;
   }
   tmp_2740 += tmp_2741;
   result += (-4) * tmp_2740;
   std::complex<double> tmp_2743;
   std::complex<double> tmp_2744;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_2745;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_2745 += AbsSqr(CpVZconjSuSu(gI1,gI2))*B00(p,MSu(gI1),MSu(gI2
            ));
      }
      tmp_2744 += tmp_2745;
   }
   tmp_2743 += tmp_2744;
   result += (-12) * tmp_2743;
   std::complex<double> tmp_2746;
   std::complex<double> tmp_2747;
   for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
      tmp_2747 += AbsSqr(CpVZconjVWmHpm(gI2))*B0(p,MVWm,MHpm(gI2));
   }
   tmp_2746 += tmp_2747;
   result += (2) * tmp_2746;
   std::complex<double> tmp_2748;
   for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
      tmp_2748 += AbsSqr(CpVZVZhh(gI2))*B0(p,MVZ,Mhh(gI2));
   }
   result += tmp_2748;
   result += -(AbsSqr(CpVZconjVWmVWm())*(2*A0(MVWm) + 10*B00(p,MVWm,MVWm) + B0(
      p,MVWm,MVWm)*(2*Sqr(MVWm) + 4*Sqr(p))));

   return result * oneOver16PiSqr;

}

std::complex<double> CLASSNAME::self_energy_VWm(double p ) const
{
   std::complex<double> result;

   result += AbsSqr(CpconjVWmbargPgWm())*B00(p,MVWm,MVP);
   result += AbsSqr(CpconjVWmbargWmCgP())*B00(p,MVP,MVWm);
   result += AbsSqr(CpconjVWmbargWmCgZ())*B00(p,MVZ,MVWm);
   result += AbsSqr(CpconjVWmbargZgWm())*B00(p,MVWm,MVZ);
   result += -(A0(MVWm)*(4*CpVWmconjVWmconjVWmVWm1() + CpVWmconjVWmconjVWmVWm2(
      ) + CpVWmconjVWmconjVWmVWm3()));
   result += 0;
   result += -0.5*A0(MVZ)*(4*CpVWmconjVWmVZVZ1() + CpVWmconjVWmVZVZ2() +
      CpVWmconjVWmVZVZ3());
   std::complex<double> tmp_2749;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      tmp_2749 += A0(MRh(gI1))*CpVWmconjVWmconjRhRh(gI1,gI1);
   }
   result += tmp_2749;
   std::complex<double> tmp_2750;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      tmp_2750 += A0(MRpm(gI1))*CpVWmconjVWmconjRpmRpm(gI1,gI1);
   }
   result += tmp_2750;
   std::complex<double> tmp_2751;
   std::complex<double> tmp_2752;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2753;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2753 += AbsSqr(CpconjVWmconjRhRpm(gI1,gI2))*B00(p,MRpm(gI2),
            MRh(gI1));
      }
      tmp_2752 += tmp_2753;
   }
   tmp_2751 += tmp_2752;
   result += (-4) * tmp_2751;
   std::complex<double> tmp_2754;
   std::complex<double> tmp_2755;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2756;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2756 += AbsSqr(CpconjVWmRpmRh(gI1,gI2))*B00(p,MRh(gI2),MRpm(
            gI1));
      }
      tmp_2755 += tmp_2756;
   }
   tmp_2754 += tmp_2755;
   result += (-4) * tmp_2754;
   std::complex<double> tmp_2757;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2758;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2758 += (AbsSqr(CpconjVWmbarCha1ChiPL(gI1,gI2)) + AbsSqr(
            CpconjVWmbarCha1ChiPR(gI1,gI2)))*H0(p,MCha1(gI1),MChi(gI2));
         tmp_2758 += 4*B0(p,MCha1(gI1),MChi(gI2))*MCha1(gI1)*MChi(gI2)*Re
            (Conj(CpconjVWmbarCha1ChiPL(gI1,gI2))*CpconjVWmbarCha1ChiPR(gI1,gI2));
      }
      tmp_2757 += tmp_2758;
   }
   result += tmp_2757;
   std::complex<double> tmp_2759;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      tmp_2759 += A0(MSv(gI1))*CpVWmconjVWmconjSvSv(gI1,gI1);
   }
   result += tmp_2759;
   std::complex<double> tmp_2760;
   std::complex<double> tmp_2761;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2762;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_2762 += (AbsSqr(CpconjVWmbarFuFdPL(gI1,gI2)) + AbsSqr(
            CpconjVWmbarFuFdPR(gI1,gI2)))*H0(p,MFu(gI1),MFd(gI2));
         tmp_2762 += 4*B0(p,MFu(gI1),MFd(gI2))*MFd(gI2)*MFu(gI1)*Re(Conj(
            CpconjVWmbarFuFdPL(gI1,gI2))*CpconjVWmbarFuFdPR(gI1,gI2));
      }
      tmp_2761 += tmp_2762;
   }
   tmp_2760 += tmp_2761;
   result += (3) * tmp_2760;
   std::complex<double> tmp_2763;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2764;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_2764 += (AbsSqr(CpconjVWmbarFvFePL(gI1,gI2)) + AbsSqr(
            CpconjVWmbarFvFePR(gI1,gI2)))*H0(p,MFv(gI1),MFe(gI2));
         tmp_2764 += 4*B0(p,MFv(gI1),MFe(gI2))*MFe(gI2)*MFv(gI1)*Re(Conj(
            CpconjVWmbarFvFePL(gI1,gI2))*CpconjVWmbarFvFePR(gI1,gI2));
      }
      tmp_2763 += tmp_2764;
   }
   result += tmp_2763;
   std::complex<double> tmp_2765;
   std::complex<double> tmp_2766;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2767;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_2767 += AbsSqr(CpconjVWmconjSvSe(gI1,gI2))*B00(p,MSe(gI2),
            MSv(gI1));
      }
      tmp_2766 += tmp_2767;
   }
   tmp_2765 += tmp_2766;
   result += (-4) * tmp_2765;
   std::complex<double> tmp_2768;
   std::complex<double> tmp_2769;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      tmp_2769 += A0(MAh(gI1))*CpVWmconjVWmAhAh(gI1,gI1);
   }
   tmp_2768 += tmp_2769;
   result += (0.5) * tmp_2768;
   std::complex<double> tmp_2770;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      tmp_2770 += A0(MHpm(gI1))*CpVWmconjVWmconjHpmHpm(gI1,gI1);
   }
   result += tmp_2770;
   std::complex<double> tmp_2771;
   std::complex<double> tmp_2772;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      tmp_2772 += A0(Mhh(gI1))*CpVWmconjVWmhhhh(gI1,gI1);
   }
   tmp_2771 += tmp_2772;
   result += (0.5) * tmp_2771;
   std::complex<double> tmp_2773;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2774;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2774 += (AbsSqr(CpconjVWmbarChiCha2PL(gI1,gI2)) + AbsSqr(
            CpconjVWmbarChiCha2PR(gI1,gI2)))*H0(p,MChi(gI1),MCha2(gI2));
         tmp_2774 += 4*B0(p,MChi(gI1),MCha2(gI2))*MCha2(gI2)*MChi(gI1)*Re
            (Conj(CpconjVWmbarChiCha2PL(gI1,gI2))*CpconjVWmbarChiCha2PR(gI1,gI2));
      }
      tmp_2773 += tmp_2774;
   }
   result += tmp_2773;
   std::complex<double> tmp_2775;
   std::complex<double> tmp_2776;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2777;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2777 += AbsSqr(CpconjVWmHpmAh(gI1,gI2))*B00(p,MAh(gI2),MHpm(
            gI1));
      }
      tmp_2776 += tmp_2777;
   }
   tmp_2775 += tmp_2776;
   result += (-4) * tmp_2775;
   std::complex<double> tmp_2778;
   std::complex<double> tmp_2779;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2780;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2780 += AbsSqr(CpconjVWmHpmhh(gI1,gI2))*B00(p,Mhh(gI2),MHpm(
            gI1));
      }
      tmp_2779 += tmp_2780;
   }
   tmp_2778 += tmp_2779;
   result += (-4) * tmp_2778;
   std::complex<double> tmp_2781;
   std::complex<double> tmp_2782;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      tmp_2782 += A0(MSd(gI1))*CpVWmconjVWmconjSdSd(gI1,gI1);
   }
   tmp_2781 += tmp_2782;
   result += (3) * tmp_2781;
   std::complex<double> tmp_2783;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      tmp_2783 += A0(MSe(gI1))*CpVWmconjVWmconjSeSe(gI1,gI1);
   }
   result += tmp_2783;
   std::complex<double> tmp_2784;
   std::complex<double> tmp_2785;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      tmp_2785 += A0(MSu(gI1))*CpVWmconjVWmconjSuSu(gI1,gI1);
   }
   tmp_2784 += tmp_2785;
   result += (3) * tmp_2784;
   std::complex<double> tmp_2786;
   std::complex<double> tmp_2787;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_2788;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_2788 += AbsSqr(CpconjVWmconjSuSd(gI1,gI2))*B00(p,MSd(gI2),
            MSu(gI1));
      }
      tmp_2787 += tmp_2788;
   }
   tmp_2786 += tmp_2787;
   result += (-12) * tmp_2786;
   std::complex<double> tmp_2789;
   for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
      tmp_2789 += AbsSqr(CpconjVWmVPHpm(gI2))*B0(p,0,MHpm(gI2));
   }
   result += tmp_2789;
   std::complex<double> tmp_2790;
   for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
      tmp_2790 += AbsSqr(CpconjVWmVWmhh(gI2))*B0(p,MVWm,Mhh(gI2));
   }
   result += tmp_2790;
   std::complex<double> tmp_2791;
   for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
      tmp_2791 += AbsSqr(CpconjVWmVZHpm(gI2))*B0(p,MVZ,MHpm(gI2));
   }
   result += tmp_2791;
   result += -(AbsSqr(CpconjVWmVWmVP())*(A0(MVWm) + 10*B00(p,MVWm,0) + B0(p,
      MVWm,0)*(Sqr(MVWm) + 4*Sqr(p))));
   result += -(AbsSqr(CpconjVWmVZVWm())*(A0(MVWm) + A0(MVZ) + 10*B00(p,MVZ,MVWm
      ) + B0(p,MVZ,MVWm)*(Sqr(MVWm) + Sqr(MVZ) + 4*Sqr(p))));

   return result * oneOver16PiSqr;

}

std::complex<double> CLASSNAME::self_energy_Chi_1(double p , unsigned gO1, unsigned gO2) const
{
   std::complex<double> result;

   std::complex<double> tmp_2792;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2793;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2793 += B0(p,MCha1(gI2),MRpm(gI1))*Conj(
            CpbarUChiconjRpmbarCha1PL(gO2,gI1,gI2))*CpbarUChiconjRpmbarCha1PR(gO1,
            gI1,gI2)*MCha1(gI2);
      }
      tmp_2792 += tmp_2793;
   }
   result += tmp_2792;
   std::complex<double> tmp_2794;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2795;
      std::complex<double> tmp_2796;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2796 += B0(p,MCha2(gI1),MRpm(gI2))*Conj(
            CpbarUChibarCha2RpmPL(gO2,gI1,gI2))*CpbarUChibarCha2RpmPR(gO1,gI1,gI2)
            ;
      }
      tmp_2795 += tmp_2796;
      tmp_2794 += (MCha2(gI1)) * tmp_2795;
   }
   result += tmp_2794;
   std::complex<double> tmp_2797;
   std::complex<double> tmp_2798;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2799;
      std::complex<double> tmp_2800;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_2800 += B0(p,MFd(gI1),MSd(gI2))*Conj(CpbarUChibarFdSdPL(gO2,
            gI1,gI2))*CpbarUChibarFdSdPR(gO1,gI1,gI2);
      }
      tmp_2799 += tmp_2800;
      tmp_2798 += (MFd(gI1)) * tmp_2799;
   }
   tmp_2797 += tmp_2798;
   result += (3) * tmp_2797;
   std::complex<double> tmp_2801;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2802;
      std::complex<double> tmp_2803;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_2803 += B0(p,MFe(gI1),MSe(gI2))*Conj(CpbarUChibarFeSePL(gO2,
            gI1,gI2))*CpbarUChibarFeSePR(gO1,gI1,gI2);
      }
      tmp_2802 += tmp_2803;
      tmp_2801 += (MFe(gI1)) * tmp_2802;
   }
   result += tmp_2801;
   std::complex<double> tmp_2804;
   std::complex<double> tmp_2805;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2806;
      std::complex<double> tmp_2807;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_2807 += B0(p,MFu(gI1),MSu(gI2))*Conj(CpbarUChibarFuSuPL(gO2,
            gI1,gI2))*CpbarUChibarFuSuPR(gO1,gI1,gI2);
      }
      tmp_2806 += tmp_2807;
      tmp_2805 += (MFu(gI1)) * tmp_2806;
   }
   tmp_2804 += tmp_2805;
   result += (3) * tmp_2804;
   std::complex<double> tmp_2808;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2809;
      std::complex<double> tmp_2810;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_2810 += B0(p,MFv(gI1),MSv(gI2))*Conj(CpbarUChibarFvSvPL(gO2,
            gI1,gI2))*CpbarUChibarFvSvPR(gO1,gI1,gI2);
      }
      tmp_2809 += tmp_2810;
      tmp_2808 += (MFv(gI1)) * tmp_2809;
   }
   result += tmp_2808;
   std::complex<double> tmp_2811;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2812;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2812 += B0(p,MCha1(gI2),MHpm(gI1))*Conj(CpbarUChiHpmCha1PL(
            gO2,gI1,gI2))*CpbarUChiHpmCha1PR(gO1,gI1,gI2)*MCha1(gI2);
      }
      tmp_2811 += tmp_2812;
   }
   result += tmp_2811;
   std::complex<double> tmp_2813;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2814;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2814 += B0(p,MCha2(gI2),MHpm(gI1))*Conj(
            CpbarUChiconjHpmCha2PL(gO2,gI1,gI2))*CpbarUChiconjHpmCha2PR(gO1,gI1,
            gI2)*MCha2(gI2);
      }
      tmp_2813 += tmp_2814;
   }
   result += tmp_2813;
   std::complex<double> tmp_2815;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2816;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2816 += B0(p,MChi(gI2),Mhh(gI1))*Conj(CpbarUChihhChiPL(gO2,
            gI1,gI2))*CpbarUChihhChiPR(gO1,gI1,gI2)*MChi(gI2);
      }
      tmp_2815 += tmp_2816;
   }
   result += tmp_2815;
   std::complex<double> tmp_2817;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2818;
      std::complex<double> tmp_2819;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2819 += B0(p,MChi(gI1),MRh(gI2))*Conj(CpbarUChibarChiRhPL(
            gO2,gI1,gI2))*CpbarUChibarChiRhPR(gO1,gI1,gI2);
      }
      tmp_2818 += tmp_2819;
      tmp_2817 += (MChi(gI1)) * tmp_2818;
   }
   result += tmp_2817;
   std::complex<double> tmp_2820;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2821;
      std::complex<double> tmp_2822;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2822 += B0(p,MChi(gI1),MAh(gI2))*Conj(CpbarUChiChiAhPL(gO2,
            gI1,gI2))*CpbarUChiChiAhPR(gO1,gI1,gI2);
      }
      tmp_2821 += tmp_2822;
      tmp_2820 += (MChi(gI1)) * tmp_2821;
   }
   result += tmp_2820;
   std::complex<double> tmp_2823;
   std::complex<double> tmp_2824;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_2825;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_2825 += B0(p,MFd(gI2),MSd(gI1))*Conj(CpbarUChiconjSdFdPL(gO2
            ,gI1,gI2))*CpbarUChiconjSdFdPR(gO1,gI1,gI2)*MFd(gI2);
      }
      tmp_2824 += tmp_2825;
   }
   tmp_2823 += tmp_2824;
   result += (3) * tmp_2823;
   std::complex<double> tmp_2826;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_2827;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_2827 += B0(p,MFe(gI2),MSe(gI1))*Conj(CpbarUChiconjSeFePL(gO2
            ,gI1,gI2))*CpbarUChiconjSeFePR(gO1,gI1,gI2)*MFe(gI2);
      }
      tmp_2826 += tmp_2827;
   }
   result += tmp_2826;
   std::complex<double> tmp_2828;
   std::complex<double> tmp_2829;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_2830;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_2830 += B0(p,MFu(gI2),MSu(gI1))*Conj(CpbarUChiconjSuFuPL(gO2
            ,gI1,gI2))*CpbarUChiconjSuFuPR(gO1,gI1,gI2)*MFu(gI2);
      }
      tmp_2829 += tmp_2830;
   }
   tmp_2828 += tmp_2829;
   result += (3) * tmp_2828;
   std::complex<double> tmp_2831;
   std::complex<double> tmp_2832;
   for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
      tmp_2832 += B0(p,MCha1(gI2),MVWm)*Conj(CpbarUChiVWmCha1PR(gO2,gI2))*
         CpbarUChiVWmCha1PL(gO1,gI2)*MCha1(gI2);
   }
   tmp_2831 += tmp_2832;
   result += (-4) * tmp_2831;
   std::complex<double> tmp_2833;
   std::complex<double> tmp_2834;
   for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
      tmp_2834 += B0(p,MCha2(gI2),MVWm)*Conj(CpbarUChiconjVWmCha2PR(gO2,gI2)
         )*CpbarUChiconjVWmCha2PL(gO1,gI2)*MCha2(gI2);
   }
   tmp_2833 += tmp_2834;
   result += (-4) * tmp_2833;
   std::complex<double> tmp_2835;
   std::complex<double> tmp_2836;
   for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
      tmp_2836 += B0(p,MChi(gI2),MVZ)*Conj(CpbarUChiVZChiPR(gO2,gI2))*
         CpbarUChiVZChiPL(gO1,gI2)*MChi(gI2);
   }
   tmp_2835 += tmp_2836;
   result += (-4) * tmp_2835;

   return result * oneOver16PiSqr;

}

std::complex<double> CLASSNAME::self_energy_Chi_PR(double p , unsigned gO1, unsigned gO2) const
{
   std::complex<double> result;

   std::complex<double> tmp_2837;
   std::complex<double> tmp_2838;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2839;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2839 += B1(p,MCha2(gI1),MRpm(gI2))*Conj(
            CpbarUChibarCha2RpmPR(gO2,gI1,gI2))*CpbarUChibarCha2RpmPR(gO1,gI1,gI2)
            ;
      }
      tmp_2838 += tmp_2839;
   }
   tmp_2837 += tmp_2838;
   result += (-0.5) * tmp_2837;
   std::complex<double> tmp_2840;
   std::complex<double> tmp_2841;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2842;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2842 += B1(p,MCha1(gI2),MRpm(gI1))*Conj(
            CpbarUChiconjRpmbarCha1PR(gO2,gI1,gI2))*CpbarUChiconjRpmbarCha1PR(gO1,
            gI1,gI2);
      }
      tmp_2841 += tmp_2842;
   }
   tmp_2840 += tmp_2841;
   result += (-0.5) * tmp_2840;
   std::complex<double> tmp_2843;
   std::complex<double> tmp_2844;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2845;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_2845 += B1(p,MFv(gI1),MSv(gI2))*Conj(CpbarUChibarFvSvPR(gO2,
            gI1,gI2))*CpbarUChibarFvSvPR(gO1,gI1,gI2);
      }
      tmp_2844 += tmp_2845;
   }
   tmp_2843 += tmp_2844;
   result += (-0.5) * tmp_2843;
   std::complex<double> tmp_2846;
   std::complex<double> tmp_2847;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2848;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_2848 += B1(p,MFd(gI1),MSd(gI2))*Conj(CpbarUChibarFdSdPR(gO2,
            gI1,gI2))*CpbarUChibarFdSdPR(gO1,gI1,gI2);
      }
      tmp_2847 += tmp_2848;
   }
   tmp_2846 += tmp_2847;
   result += (-1.5) * tmp_2846;
   std::complex<double> tmp_2849;
   std::complex<double> tmp_2850;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2851;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_2851 += B1(p,MFe(gI1),MSe(gI2))*Conj(CpbarUChibarFeSePR(gO2,
            gI1,gI2))*CpbarUChibarFeSePR(gO1,gI1,gI2);
      }
      tmp_2850 += tmp_2851;
   }
   tmp_2849 += tmp_2850;
   result += (-0.5) * tmp_2849;
   std::complex<double> tmp_2852;
   std::complex<double> tmp_2853;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2854;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_2854 += B1(p,MFu(gI1),MSu(gI2))*Conj(CpbarUChibarFuSuPR(gO2,
            gI1,gI2))*CpbarUChibarFuSuPR(gO1,gI1,gI2);
      }
      tmp_2853 += tmp_2854;
   }
   tmp_2852 += tmp_2853;
   result += (-1.5) * tmp_2852;
   std::complex<double> tmp_2855;
   std::complex<double> tmp_2856;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2857;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2857 += B1(p,MChi(gI1),MRh(gI2))*Conj(CpbarUChibarChiRhPR(
            gO2,gI1,gI2))*CpbarUChibarChiRhPR(gO1,gI1,gI2);
      }
      tmp_2856 += tmp_2857;
   }
   tmp_2855 += tmp_2856;
   result += (-0.5) * tmp_2855;
   std::complex<double> tmp_2858;
   std::complex<double> tmp_2859;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2860;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2860 += B1(p,MCha2(gI2),MHpm(gI1))*Conj(
            CpbarUChiconjHpmCha2PR(gO2,gI1,gI2))*CpbarUChiconjHpmCha2PR(gO1,gI1,
            gI2);
      }
      tmp_2859 += tmp_2860;
   }
   tmp_2858 += tmp_2859;
   result += (-0.5) * tmp_2858;
   std::complex<double> tmp_2861;
   std::complex<double> tmp_2862;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2863;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2863 += B1(p,MCha1(gI2),MHpm(gI1))*Conj(CpbarUChiHpmCha1PR(
            gO2,gI1,gI2))*CpbarUChiHpmCha1PR(gO1,gI1,gI2);
      }
      tmp_2862 += tmp_2863;
   }
   tmp_2861 += tmp_2862;
   result += (-0.5) * tmp_2861;
   std::complex<double> tmp_2864;
   std::complex<double> tmp_2865;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2866;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2866 += B1(p,MChi(gI1),MAh(gI2))*Conj(CpbarUChiChiAhPR(gO2,
            gI1,gI2))*CpbarUChiChiAhPR(gO1,gI1,gI2);
      }
      tmp_2865 += tmp_2866;
   }
   tmp_2864 += tmp_2865;
   result += (-0.5) * tmp_2864;
   std::complex<double> tmp_2867;
   std::complex<double> tmp_2868;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2869;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2869 += B1(p,MChi(gI2),Mhh(gI1))*Conj(CpbarUChihhChiPR(gO2,
            gI1,gI2))*CpbarUChihhChiPR(gO1,gI1,gI2);
      }
      tmp_2868 += tmp_2869;
   }
   tmp_2867 += tmp_2868;
   result += (-0.5) * tmp_2867;
   std::complex<double> tmp_2870;
   std::complex<double> tmp_2871;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_2872;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_2872 += B1(p,MFd(gI2),MSd(gI1))*Conj(CpbarUChiconjSdFdPR(gO2
            ,gI1,gI2))*CpbarUChiconjSdFdPR(gO1,gI1,gI2);
      }
      tmp_2871 += tmp_2872;
   }
   tmp_2870 += tmp_2871;
   result += (-1.5) * tmp_2870;
   std::complex<double> tmp_2873;
   std::complex<double> tmp_2874;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_2875;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_2875 += B1(p,MFe(gI2),MSe(gI1))*Conj(CpbarUChiconjSeFePR(gO2
            ,gI1,gI2))*CpbarUChiconjSeFePR(gO1,gI1,gI2);
      }
      tmp_2874 += tmp_2875;
   }
   tmp_2873 += tmp_2874;
   result += (-0.5) * tmp_2873;
   std::complex<double> tmp_2876;
   std::complex<double> tmp_2877;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_2878;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_2878 += B1(p,MFu(gI2),MSu(gI1))*Conj(CpbarUChiconjSuFuPR(gO2
            ,gI1,gI2))*CpbarUChiconjSuFuPR(gO1,gI1,gI2);
      }
      tmp_2877 += tmp_2878;
   }
   tmp_2876 += tmp_2877;
   result += (-1.5) * tmp_2876;
   std::complex<double> tmp_2879;
   std::complex<double> tmp_2880;
   for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
      tmp_2880 += B1(p,MCha2(gI2),MVWm)*Conj(CpbarUChiconjVWmCha2PL(gO2,gI2)
         )*CpbarUChiconjVWmCha2PL(gO1,gI2);
   }
   tmp_2879 += tmp_2880;
   result += (-1) * tmp_2879;
   std::complex<double> tmp_2881;
   std::complex<double> tmp_2882;
   for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
      tmp_2882 += B1(p,MCha1(gI2),MVWm)*Conj(CpbarUChiVWmCha1PL(gO2,gI2))*
         CpbarUChiVWmCha1PL(gO1,gI2);
   }
   tmp_2881 += tmp_2882;
   result += (-1) * tmp_2881;
   std::complex<double> tmp_2883;
   std::complex<double> tmp_2884;
   for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
      tmp_2884 += B1(p,MChi(gI2),MVZ)*Conj(CpbarUChiVZChiPL(gO2,gI2))*
         CpbarUChiVZChiPL(gO1,gI2);
   }
   tmp_2883 += tmp_2884;
   result += (-1) * tmp_2883;

   return result * oneOver16PiSqr;

}

std::complex<double> CLASSNAME::self_energy_Chi_PL(double p , unsigned gO1, unsigned gO2) const
{
   std::complex<double> result;

   std::complex<double> tmp_2885;
   std::complex<double> tmp_2886;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2887;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2887 += B1(p,MCha2(gI1),MRpm(gI2))*Conj(
            CpbarUChibarCha2RpmPL(gO2,gI1,gI2))*CpbarUChibarCha2RpmPL(gO1,gI1,gI2)
            ;
      }
      tmp_2886 += tmp_2887;
   }
   tmp_2885 += tmp_2886;
   result += (-0.5) * tmp_2885;
   std::complex<double> tmp_2888;
   std::complex<double> tmp_2889;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2890;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2890 += B1(p,MCha1(gI2),MRpm(gI1))*Conj(
            CpbarUChiconjRpmbarCha1PL(gO2,gI1,gI2))*CpbarUChiconjRpmbarCha1PL(gO1,
            gI1,gI2);
      }
      tmp_2889 += tmp_2890;
   }
   tmp_2888 += tmp_2889;
   result += (-0.5) * tmp_2888;
   std::complex<double> tmp_2891;
   std::complex<double> tmp_2892;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2893;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_2893 += B1(p,MFv(gI1),MSv(gI2))*Conj(CpbarUChibarFvSvPL(gO2,
            gI1,gI2))*CpbarUChibarFvSvPL(gO1,gI1,gI2);
      }
      tmp_2892 += tmp_2893;
   }
   tmp_2891 += tmp_2892;
   result += (-0.5) * tmp_2891;
   std::complex<double> tmp_2894;
   std::complex<double> tmp_2895;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2896;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_2896 += B1(p,MFd(gI1),MSd(gI2))*Conj(CpbarUChibarFdSdPL(gO2,
            gI1,gI2))*CpbarUChibarFdSdPL(gO1,gI1,gI2);
      }
      tmp_2895 += tmp_2896;
   }
   tmp_2894 += tmp_2895;
   result += (-1.5) * tmp_2894;
   std::complex<double> tmp_2897;
   std::complex<double> tmp_2898;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2899;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_2899 += B1(p,MFe(gI1),MSe(gI2))*Conj(CpbarUChibarFeSePL(gO2,
            gI1,gI2))*CpbarUChibarFeSePL(gO1,gI1,gI2);
      }
      tmp_2898 += tmp_2899;
   }
   tmp_2897 += tmp_2898;
   result += (-0.5) * tmp_2897;
   std::complex<double> tmp_2900;
   std::complex<double> tmp_2901;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2902;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_2902 += B1(p,MFu(gI1),MSu(gI2))*Conj(CpbarUChibarFuSuPL(gO2,
            gI1,gI2))*CpbarUChibarFuSuPL(gO1,gI1,gI2);
      }
      tmp_2901 += tmp_2902;
   }
   tmp_2900 += tmp_2901;
   result += (-1.5) * tmp_2900;
   std::complex<double> tmp_2903;
   std::complex<double> tmp_2904;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2905;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2905 += B1(p,MChi(gI1),MRh(gI2))*Conj(CpbarUChibarChiRhPL(
            gO2,gI1,gI2))*CpbarUChibarChiRhPL(gO1,gI1,gI2);
      }
      tmp_2904 += tmp_2905;
   }
   tmp_2903 += tmp_2904;
   result += (-0.5) * tmp_2903;
   std::complex<double> tmp_2906;
   std::complex<double> tmp_2907;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2908;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2908 += B1(p,MCha2(gI2),MHpm(gI1))*Conj(
            CpbarUChiconjHpmCha2PL(gO2,gI1,gI2))*CpbarUChiconjHpmCha2PL(gO1,gI1,
            gI2);
      }
      tmp_2907 += tmp_2908;
   }
   tmp_2906 += tmp_2907;
   result += (-0.5) * tmp_2906;
   std::complex<double> tmp_2909;
   std::complex<double> tmp_2910;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2911;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2911 += B1(p,MCha1(gI2),MHpm(gI1))*Conj(CpbarUChiHpmCha1PL(
            gO2,gI1,gI2))*CpbarUChiHpmCha1PL(gO1,gI1,gI2);
      }
      tmp_2910 += tmp_2911;
   }
   tmp_2909 += tmp_2910;
   result += (-0.5) * tmp_2909;
   std::complex<double> tmp_2912;
   std::complex<double> tmp_2913;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2914;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2914 += B1(p,MChi(gI1),MAh(gI2))*Conj(CpbarUChiChiAhPL(gO2,
            gI1,gI2))*CpbarUChiChiAhPL(gO1,gI1,gI2);
      }
      tmp_2913 += tmp_2914;
   }
   tmp_2912 += tmp_2913;
   result += (-0.5) * tmp_2912;
   std::complex<double> tmp_2915;
   std::complex<double> tmp_2916;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2917;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2917 += B1(p,MChi(gI2),Mhh(gI1))*Conj(CpbarUChihhChiPL(gO2,
            gI1,gI2))*CpbarUChihhChiPL(gO1,gI1,gI2);
      }
      tmp_2916 += tmp_2917;
   }
   tmp_2915 += tmp_2916;
   result += (-0.5) * tmp_2915;
   std::complex<double> tmp_2918;
   std::complex<double> tmp_2919;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_2920;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_2920 += B1(p,MFd(gI2),MSd(gI1))*Conj(CpbarUChiconjSdFdPL(gO2
            ,gI1,gI2))*CpbarUChiconjSdFdPL(gO1,gI1,gI2);
      }
      tmp_2919 += tmp_2920;
   }
   tmp_2918 += tmp_2919;
   result += (-1.5) * tmp_2918;
   std::complex<double> tmp_2921;
   std::complex<double> tmp_2922;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_2923;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_2923 += B1(p,MFe(gI2),MSe(gI1))*Conj(CpbarUChiconjSeFePL(gO2
            ,gI1,gI2))*CpbarUChiconjSeFePL(gO1,gI1,gI2);
      }
      tmp_2922 += tmp_2923;
   }
   tmp_2921 += tmp_2922;
   result += (-0.5) * tmp_2921;
   std::complex<double> tmp_2924;
   std::complex<double> tmp_2925;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_2926;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_2926 += B1(p,MFu(gI2),MSu(gI1))*Conj(CpbarUChiconjSuFuPL(gO2
            ,gI1,gI2))*CpbarUChiconjSuFuPL(gO1,gI1,gI2);
      }
      tmp_2925 += tmp_2926;
   }
   tmp_2924 += tmp_2925;
   result += (-1.5) * tmp_2924;
   std::complex<double> tmp_2927;
   std::complex<double> tmp_2928;
   for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
      tmp_2928 += B1(p,MCha2(gI2),MVWm)*Conj(CpbarUChiconjVWmCha2PR(gO2,gI2)
         )*CpbarUChiconjVWmCha2PR(gO1,gI2);
   }
   tmp_2927 += tmp_2928;
   result += (-1) * tmp_2927;
   std::complex<double> tmp_2929;
   std::complex<double> tmp_2930;
   for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
      tmp_2930 += B1(p,MCha1(gI2),MVWm)*Conj(CpbarUChiVWmCha1PR(gO2,gI2))*
         CpbarUChiVWmCha1PR(gO1,gI2);
   }
   tmp_2929 += tmp_2930;
   result += (-1) * tmp_2929;
   std::complex<double> tmp_2931;
   std::complex<double> tmp_2932;
   for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
      tmp_2932 += B1(p,MChi(gI2),MVZ)*Conj(CpbarUChiVZChiPR(gO2,gI2))*
         CpbarUChiVZChiPR(gO1,gI2);
   }
   tmp_2931 += tmp_2932;
   result += (-1) * tmp_2931;

   return result * oneOver16PiSqr;

}

std::complex<double> CLASSNAME::self_energy_Cha1_1(double p , unsigned gO1, unsigned gO2) const
{
   std::complex<double> result;

   std::complex<double> tmp_2933;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2934;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2934 += B0(p,MChi(gI2),MRpm(gI1))*Conj(
            CpbarUCha1conjRpmbarChiPL(gO2,gI1,gI2))*CpbarUCha1conjRpmbarChiPR(gO1,
            gI1,gI2)*MChi(gI2);
      }
      tmp_2933 += tmp_2934;
   }
   result += tmp_2933;
   std::complex<double> tmp_2935;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2936;
      std::complex<double> tmp_2937;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2937 += B0(p,MCha1(gI1),MAh(gI2))*Conj(CpbarUCha1Cha1AhPL(
            gO2,gI1,gI2))*CpbarUCha1Cha1AhPR(gO1,gI1,gI2);
      }
      tmp_2936 += tmp_2937;
      tmp_2935 += (MCha1(gI1)) * tmp_2936;
   }
   result += tmp_2935;
   std::complex<double> tmp_2938;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2939;
      std::complex<double> tmp_2940;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2940 += B0(p,MCha2(gI1),MRh(gI2))*Conj(CpbarUCha1barCha2RhPL
            (gO2,gI1,gI2))*CpbarUCha1barCha2RhPR(gO1,gI1,gI2);
      }
      tmp_2939 += tmp_2940;
      tmp_2938 += (MCha2(gI1)) * tmp_2939;
   }
   result += tmp_2938;
   std::complex<double> tmp_2941;
   std::complex<double> tmp_2942;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2943;
      std::complex<double> tmp_2944;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_2944 += B0(p,MFd(gI1),MSu(gI2))*Conj(CpbarUCha1barFdSuPL(gO2
            ,gI1,gI2))*CpbarUCha1barFdSuPR(gO1,gI1,gI2);
      }
      tmp_2943 += tmp_2944;
      tmp_2942 += (MFd(gI1)) * tmp_2943;
   }
   tmp_2941 += tmp_2942;
   result += (3) * tmp_2941;
   std::complex<double> tmp_2945;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2946;
      std::complex<double> tmp_2947;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_2947 += B0(p,MFe(gI1),MSv(gI2))*Conj(CpbarUCha1barFeSvPL(gO2
            ,gI1,gI2))*CpbarUCha1barFeSvPR(gO1,gI1,gI2);
      }
      tmp_2946 += tmp_2947;
      tmp_2945 += (MFe(gI1)) * tmp_2946;
   }
   result += tmp_2945;
   std::complex<double> tmp_2948;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2949;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2949 += B0(p,MCha1(gI2),Mhh(gI1))*Conj(CpbarUCha1hhCha1PL(
            gO2,gI1,gI2))*CpbarUCha1hhCha1PR(gO1,gI1,gI2)*MCha1(gI2);
      }
      tmp_2948 += tmp_2949;
   }
   result += tmp_2948;
   std::complex<double> tmp_2950;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2951;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2951 += B0(p,MChi(gI2),MHpm(gI1))*Conj(
            CpbarUCha1conjHpmChiPL(gO2,gI1,gI2))*CpbarUCha1conjHpmChiPR(gO1,gI1,
            gI2)*MChi(gI2);
      }
      tmp_2950 += tmp_2951;
   }
   result += tmp_2950;
   std::complex<double> tmp_2952;
   std::complex<double> tmp_2953;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_2954;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_2954 += B0(p,MFu(gI2),MSd(gI1))*Conj(CpbarUCha1conjSdFuPL(
            gO2,gI1,gI2))*CpbarUCha1conjSdFuPR(gO1,gI1,gI2)*MFu(gI2);
      }
      tmp_2953 += tmp_2954;
   }
   tmp_2952 += tmp_2953;
   result += (3) * tmp_2952;
   std::complex<double> tmp_2955;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_2956;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_2956 += B0(p,MFv(gI2),MSe(gI1))*Conj(CpbarUCha1conjSeFvPL(
            gO2,gI1,gI2))*CpbarUCha1conjSeFvPR(gO1,gI1,gI2)*MFv(gI2);
      }
      tmp_2955 += tmp_2956;
   }
   result += tmp_2955;
   std::complex<double> tmp_2957;
   std::complex<double> tmp_2958;
   for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
      tmp_2958 += B0(p,MCha1(gI2),0)*Conj(CpbarUCha1VPCha1PR(gO2,gI2))*
         CpbarUCha1VPCha1PL(gO1,gI2)*MCha1(gI2);
   }
   tmp_2957 += tmp_2958;
   result += (-4) * tmp_2957;
   std::complex<double> tmp_2959;
   std::complex<double> tmp_2960;
   for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
      tmp_2960 += B0(p,MCha1(gI2),MVZ)*Conj(CpbarUCha1VZCha1PR(gO2,gI2))*
         CpbarUCha1VZCha1PL(gO1,gI2)*MCha1(gI2);
   }
   tmp_2959 += tmp_2960;
   result += (-4) * tmp_2959;
   std::complex<double> tmp_2961;
   std::complex<double> tmp_2962;
   for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
      tmp_2962 += B0(p,MChi(gI2),MVWm)*Conj(CpbarUCha1conjVWmChiPR(gO2,gI2))
         *CpbarUCha1conjVWmChiPL(gO1,gI2)*MChi(gI2);
   }
   tmp_2961 += tmp_2962;
   result += (-4) * tmp_2961;

   return result * oneOver16PiSqr;

}

std::complex<double> CLASSNAME::self_energy_Cha1_PR(double p , unsigned gO1, unsigned gO2) const
{
   std::complex<double> result;

   std::complex<double> tmp_2963;
   std::complex<double> tmp_2964;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2965;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2965 += B1(p,MCha2(gI1),MRh(gI2))*Conj(CpbarUCha1barCha2RhPR
            (gO2,gI1,gI2))*CpbarUCha1barCha2RhPR(gO1,gI1,gI2);
      }
      tmp_2964 += tmp_2965;
   }
   tmp_2963 += tmp_2964;
   result += (-0.5) * tmp_2963;
   std::complex<double> tmp_2966;
   std::complex<double> tmp_2967;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2968;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2968 += B1(p,MCha1(gI1),MAh(gI2))*Conj(CpbarUCha1Cha1AhPR(
            gO2,gI1,gI2))*CpbarUCha1Cha1AhPR(gO1,gI1,gI2);
      }
      tmp_2967 += tmp_2968;
   }
   tmp_2966 += tmp_2967;
   result += (-0.5) * tmp_2966;
   std::complex<double> tmp_2969;
   std::complex<double> tmp_2970;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2971;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2971 += B1(p,MChi(gI2),MRpm(gI1))*Conj(
            CpbarUCha1conjRpmbarChiPR(gO2,gI1,gI2))*CpbarUCha1conjRpmbarChiPR(gO1,
            gI1,gI2);
      }
      tmp_2970 += tmp_2971;
   }
   tmp_2969 += tmp_2970;
   result += (-0.5) * tmp_2969;
   std::complex<double> tmp_2972;
   std::complex<double> tmp_2973;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2974;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_2974 += B1(p,MFe(gI1),MSv(gI2))*Conj(CpbarUCha1barFeSvPR(gO2
            ,gI1,gI2))*CpbarUCha1barFeSvPR(gO1,gI1,gI2);
      }
      tmp_2973 += tmp_2974;
   }
   tmp_2972 += tmp_2973;
   result += (-0.5) * tmp_2972;
   std::complex<double> tmp_2975;
   std::complex<double> tmp_2976;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_2977;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_2977 += B1(p,MFd(gI1),MSu(gI2))*Conj(CpbarUCha1barFdSuPR(gO2
            ,gI1,gI2))*CpbarUCha1barFdSuPR(gO1,gI1,gI2);
      }
      tmp_2976 += tmp_2977;
   }
   tmp_2975 += tmp_2976;
   result += (-1.5) * tmp_2975;
   std::complex<double> tmp_2978;
   std::complex<double> tmp_2979;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2980;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2980 += B1(p,MCha1(gI2),Mhh(gI1))*Conj(CpbarUCha1hhCha1PR(
            gO2,gI1,gI2))*CpbarUCha1hhCha1PR(gO1,gI1,gI2);
      }
      tmp_2979 += tmp_2980;
   }
   tmp_2978 += tmp_2979;
   result += (-0.5) * tmp_2978;
   std::complex<double> tmp_2981;
   std::complex<double> tmp_2982;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_2983;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_2983 += B1(p,MChi(gI2),MHpm(gI1))*Conj(
            CpbarUCha1conjHpmChiPR(gO2,gI1,gI2))*CpbarUCha1conjHpmChiPR(gO1,gI1,
            gI2);
      }
      tmp_2982 += tmp_2983;
   }
   tmp_2981 += tmp_2982;
   result += (-0.5) * tmp_2981;
   std::complex<double> tmp_2984;
   std::complex<double> tmp_2985;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_2986;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_2986 += B1(p,MFu(gI2),MSd(gI1))*Conj(CpbarUCha1conjSdFuPR(
            gO2,gI1,gI2))*CpbarUCha1conjSdFuPR(gO1,gI1,gI2);
      }
      tmp_2985 += tmp_2986;
   }
   tmp_2984 += tmp_2985;
   result += (-1.5) * tmp_2984;
   std::complex<double> tmp_2987;
   std::complex<double> tmp_2988;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_2989;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_2989 += B1(p,MFv(gI2),MSe(gI1))*Conj(CpbarUCha1conjSeFvPR(
            gO2,gI1,gI2))*CpbarUCha1conjSeFvPR(gO1,gI1,gI2);
      }
      tmp_2988 += tmp_2989;
   }
   tmp_2987 += tmp_2988;
   result += (-0.5) * tmp_2987;
   std::complex<double> tmp_2990;
   std::complex<double> tmp_2991;
   for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
      tmp_2991 += B1(p,MCha1(gI2),0)*Conj(CpbarUCha1VPCha1PL(gO2,gI2))*
         CpbarUCha1VPCha1PL(gO1,gI2);
   }
   tmp_2990 += tmp_2991;
   result += (-1) * tmp_2990;
   std::complex<double> tmp_2992;
   std::complex<double> tmp_2993;
   for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
      tmp_2993 += B1(p,MCha1(gI2),MVZ)*Conj(CpbarUCha1VZCha1PL(gO2,gI2))*
         CpbarUCha1VZCha1PL(gO1,gI2);
   }
   tmp_2992 += tmp_2993;
   result += (-1) * tmp_2992;
   std::complex<double> tmp_2994;
   std::complex<double> tmp_2995;
   for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
      tmp_2995 += B1(p,MChi(gI2),MVWm)*Conj(CpbarUCha1conjVWmChiPL(gO2,gI2))
         *CpbarUCha1conjVWmChiPL(gO1,gI2);
   }
   tmp_2994 += tmp_2995;
   result += (-1) * tmp_2994;

   return result * oneOver16PiSqr;

}

std::complex<double> CLASSNAME::self_energy_Cha1_PL(double p , unsigned gO1, unsigned gO2) const
{
   std::complex<double> result;

   std::complex<double> tmp_2996;
   std::complex<double> tmp_2997;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_2998;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_2998 += B1(p,MCha2(gI1),MRh(gI2))*Conj(CpbarUCha1barCha2RhPL
            (gO2,gI1,gI2))*CpbarUCha1barCha2RhPL(gO1,gI1,gI2);
      }
      tmp_2997 += tmp_2998;
   }
   tmp_2996 += tmp_2997;
   result += (-0.5) * tmp_2996;
   std::complex<double> tmp_2999;
   std::complex<double> tmp_3000;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_3001;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_3001 += B1(p,MCha1(gI1),MAh(gI2))*Conj(CpbarUCha1Cha1AhPL(
            gO2,gI1,gI2))*CpbarUCha1Cha1AhPL(gO1,gI1,gI2);
      }
      tmp_3000 += tmp_3001;
   }
   tmp_2999 += tmp_3000;
   result += (-0.5) * tmp_2999;
   std::complex<double> tmp_3002;
   std::complex<double> tmp_3003;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_3004;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_3004 += B1(p,MChi(gI2),MRpm(gI1))*Conj(
            CpbarUCha1conjRpmbarChiPL(gO2,gI1,gI2))*CpbarUCha1conjRpmbarChiPL(gO1,
            gI1,gI2);
      }
      tmp_3003 += tmp_3004;
   }
   tmp_3002 += tmp_3003;
   result += (-0.5) * tmp_3002;
   std::complex<double> tmp_3005;
   std::complex<double> tmp_3006;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_3007;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_3007 += B1(p,MFe(gI1),MSv(gI2))*Conj(CpbarUCha1barFeSvPL(gO2
            ,gI1,gI2))*CpbarUCha1barFeSvPL(gO1,gI1,gI2);
      }
      tmp_3006 += tmp_3007;
   }
   tmp_3005 += tmp_3006;
   result += (-0.5) * tmp_3005;
   std::complex<double> tmp_3008;
   std::complex<double> tmp_3009;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_3010;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_3010 += B1(p,MFd(gI1),MSu(gI2))*Conj(CpbarUCha1barFdSuPL(gO2
            ,gI1,gI2))*CpbarUCha1barFdSuPL(gO1,gI1,gI2);
      }
      tmp_3009 += tmp_3010;
   }
   tmp_3008 += tmp_3009;
   result += (-1.5) * tmp_3008;
   std::complex<double> tmp_3011;
   std::complex<double> tmp_3012;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3013;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_3013 += B1(p,MCha1(gI2),Mhh(gI1))*Conj(CpbarUCha1hhCha1PL(
            gO2,gI1,gI2))*CpbarUCha1hhCha1PL(gO1,gI1,gI2);
      }
      tmp_3012 += tmp_3013;
   }
   tmp_3011 += tmp_3012;
   result += (-0.5) * tmp_3011;
   std::complex<double> tmp_3014;
   std::complex<double> tmp_3015;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3016;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_3016 += B1(p,MChi(gI2),MHpm(gI1))*Conj(
            CpbarUCha1conjHpmChiPL(gO2,gI1,gI2))*CpbarUCha1conjHpmChiPL(gO1,gI1,
            gI2);
      }
      tmp_3015 += tmp_3016;
   }
   tmp_3014 += tmp_3015;
   result += (-0.5) * tmp_3014;
   std::complex<double> tmp_3017;
   std::complex<double> tmp_3018;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_3019;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_3019 += B1(p,MFu(gI2),MSd(gI1))*Conj(CpbarUCha1conjSdFuPL(
            gO2,gI1,gI2))*CpbarUCha1conjSdFuPL(gO1,gI1,gI2);
      }
      tmp_3018 += tmp_3019;
   }
   tmp_3017 += tmp_3018;
   result += (-1.5) * tmp_3017;
   std::complex<double> tmp_3020;
   std::complex<double> tmp_3021;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_3022;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_3022 += B1(p,MFv(gI2),MSe(gI1))*Conj(CpbarUCha1conjSeFvPL(
            gO2,gI1,gI2))*CpbarUCha1conjSeFvPL(gO1,gI1,gI2);
      }
      tmp_3021 += tmp_3022;
   }
   tmp_3020 += tmp_3021;
   result += (-0.5) * tmp_3020;
   std::complex<double> tmp_3023;
   std::complex<double> tmp_3024;
   for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
      tmp_3024 += B1(p,MCha1(gI2),0)*Conj(CpbarUCha1VPCha1PR(gO2,gI2))*
         CpbarUCha1VPCha1PR(gO1,gI2);
   }
   tmp_3023 += tmp_3024;
   result += (-1) * tmp_3023;
   std::complex<double> tmp_3025;
   std::complex<double> tmp_3026;
   for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
      tmp_3026 += B1(p,MCha1(gI2),MVZ)*Conj(CpbarUCha1VZCha1PR(gO2,gI2))*
         CpbarUCha1VZCha1PR(gO1,gI2);
   }
   tmp_3025 += tmp_3026;
   result += (-1) * tmp_3025;
   std::complex<double> tmp_3027;
   std::complex<double> tmp_3028;
   for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
      tmp_3028 += B1(p,MChi(gI2),MVWm)*Conj(CpbarUCha1conjVWmChiPR(gO2,gI2))
         *CpbarUCha1conjVWmChiPR(gO1,gI2);
   }
   tmp_3027 += tmp_3028;
   result += (-1) * tmp_3027;

   return result * oneOver16PiSqr;

}

std::complex<double> CLASSNAME::self_energy_Cha2_1(double p , unsigned gO1, unsigned gO2) const
{
   std::complex<double> result;

   std::complex<double> tmp_3029;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_3030;
      std::complex<double> tmp_3031;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_3031 += B0(p,MCha1(gI1),MRh(gI2))*Conj(CpbarUCha2barCha1RhPL
            (gO2,gI1,gI2))*CpbarUCha2barCha1RhPR(gO1,gI1,gI2);
      }
      tmp_3030 += tmp_3031;
      tmp_3029 += (MCha1(gI1)) * tmp_3030;
   }
   result += tmp_3029;
   std::complex<double> tmp_3032;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_3033;
      std::complex<double> tmp_3034;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_3034 += B0(p,MCha2(gI1),MAh(gI2))*Conj(CpbarUCha2Cha2AhPL(
            gO2,gI1,gI2))*CpbarUCha2Cha2AhPR(gO1,gI1,gI2);
      }
      tmp_3033 += tmp_3034;
      tmp_3032 += (MCha2(gI1)) * tmp_3033;
   }
   result += tmp_3032;
   std::complex<double> tmp_3035;
   std::complex<double> tmp_3036;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_3037;
      std::complex<double> tmp_3038;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_3038 += B0(p,MFu(gI1),MSd(gI2))*Conj(CpbarUCha2barFuSdPL(gO2
            ,gI1,gI2))*CpbarUCha2barFuSdPR(gO1,gI1,gI2);
      }
      tmp_3037 += tmp_3038;
      tmp_3036 += (MFu(gI1)) * tmp_3037;
   }
   tmp_3035 += tmp_3036;
   result += (3) * tmp_3035;
   std::complex<double> tmp_3039;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_3040;
      std::complex<double> tmp_3041;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_3041 += B0(p,MFv(gI1),MSe(gI2))*Conj(CpbarUCha2barFvSePL(gO2
            ,gI1,gI2))*CpbarUCha2barFvSePR(gO1,gI1,gI2);
      }
      tmp_3040 += tmp_3041;
      tmp_3039 += (MFv(gI1)) * tmp_3040;
   }
   result += tmp_3039;
   std::complex<double> tmp_3042;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3043;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_3043 += B0(p,MCha2(gI2),Mhh(gI1))*Conj(CpbarUCha2hhCha2PL(
            gO2,gI1,gI2))*CpbarUCha2hhCha2PR(gO1,gI1,gI2)*MCha2(gI2);
      }
      tmp_3042 += tmp_3043;
   }
   result += tmp_3042;
   std::complex<double> tmp_3044;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3045;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_3045 += B0(p,MChi(gI2),MHpm(gI1))*Conj(CpbarUCha2HpmChiPL(
            gO2,gI1,gI2))*CpbarUCha2HpmChiPR(gO1,gI1,gI2)*MChi(gI2);
      }
      tmp_3044 += tmp_3045;
   }
   result += tmp_3044;
   std::complex<double> tmp_3046;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3047;
      std::complex<double> tmp_3048;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_3048 += B0(p,MChi(gI1),MRpm(gI2))*Conj(CpbarUCha2barChiRpmPL
            (gO2,gI1,gI2))*CpbarUCha2barChiRpmPR(gO1,gI1,gI2);
      }
      tmp_3047 += tmp_3048;
      tmp_3046 += (MChi(gI1)) * tmp_3047;
   }
   result += tmp_3046;
   std::complex<double> tmp_3049;
   std::complex<double> tmp_3050;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_3051;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_3051 += B0(p,MFd(gI2),MSu(gI1))*Conj(CpbarUCha2conjSuFdPL(
            gO2,gI1,gI2))*CpbarUCha2conjSuFdPR(gO1,gI1,gI2)*MFd(gI2);
      }
      tmp_3050 += tmp_3051;
   }
   tmp_3049 += tmp_3050;
   result += (3) * tmp_3049;
   std::complex<double> tmp_3052;
   std::complex<double> tmp_3053;
   for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
      tmp_3053 += B0(p,MCha2(gI2),0)*Conj(CpbarUCha2VPCha2PR(gO2,gI2))*
         CpbarUCha2VPCha2PL(gO1,gI2)*MCha2(gI2);
   }
   tmp_3052 += tmp_3053;
   result += (-4) * tmp_3052;
   std::complex<double> tmp_3054;
   std::complex<double> tmp_3055;
   for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
      tmp_3055 += B0(p,MCha2(gI2),MVZ)*Conj(CpbarUCha2VZCha2PR(gO2,gI2))*
         CpbarUCha2VZCha2PL(gO1,gI2)*MCha2(gI2);
   }
   tmp_3054 += tmp_3055;
   result += (-4) * tmp_3054;
   std::complex<double> tmp_3056;
   std::complex<double> tmp_3057;
   for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
      tmp_3057 += B0(p,MChi(gI2),MVWm)*Conj(CpbarUCha2VWmChiPR(gO2,gI2))*
         CpbarUCha2VWmChiPL(gO1,gI2)*MChi(gI2);
   }
   tmp_3056 += tmp_3057;
   result += (-4) * tmp_3056;

   return result * oneOver16PiSqr;

}

std::complex<double> CLASSNAME::self_energy_Cha2_PR(double p , unsigned gO1, unsigned gO2) const
{
   std::complex<double> result;

   std::complex<double> tmp_3058;
   std::complex<double> tmp_3059;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_3060;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_3060 += B1(p,MCha1(gI1),MRh(gI2))*Conj(CpbarUCha2barCha1RhPR
            (gO2,gI1,gI2))*CpbarUCha2barCha1RhPR(gO1,gI1,gI2);
      }
      tmp_3059 += tmp_3060;
   }
   tmp_3058 += tmp_3059;
   result += (-0.5) * tmp_3058;
   std::complex<double> tmp_3061;
   std::complex<double> tmp_3062;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_3063;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_3063 += B1(p,MCha2(gI1),MAh(gI2))*Conj(CpbarUCha2Cha2AhPR(
            gO2,gI1,gI2))*CpbarUCha2Cha2AhPR(gO1,gI1,gI2);
      }
      tmp_3062 += tmp_3063;
   }
   tmp_3061 += tmp_3062;
   result += (-0.5) * tmp_3061;
   std::complex<double> tmp_3064;
   std::complex<double> tmp_3065;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_3066;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_3066 += B1(p,MFu(gI1),MSd(gI2))*Conj(CpbarUCha2barFuSdPR(gO2
            ,gI1,gI2))*CpbarUCha2barFuSdPR(gO1,gI1,gI2);
      }
      tmp_3065 += tmp_3066;
   }
   tmp_3064 += tmp_3065;
   result += (-1.5) * tmp_3064;
   std::complex<double> tmp_3067;
   std::complex<double> tmp_3068;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_3069;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_3069 += B1(p,MFv(gI1),MSe(gI2))*Conj(CpbarUCha2barFvSePR(gO2
            ,gI1,gI2))*CpbarUCha2barFvSePR(gO1,gI1,gI2);
      }
      tmp_3068 += tmp_3069;
   }
   tmp_3067 += tmp_3068;
   result += (-0.5) * tmp_3067;
   std::complex<double> tmp_3070;
   std::complex<double> tmp_3071;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3072;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_3072 += B1(p,MChi(gI1),MRpm(gI2))*Conj(CpbarUCha2barChiRpmPR
            (gO2,gI1,gI2))*CpbarUCha2barChiRpmPR(gO1,gI1,gI2);
      }
      tmp_3071 += tmp_3072;
   }
   tmp_3070 += tmp_3071;
   result += (-0.5) * tmp_3070;
   std::complex<double> tmp_3073;
   std::complex<double> tmp_3074;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3075;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_3075 += B1(p,MCha2(gI2),Mhh(gI1))*Conj(CpbarUCha2hhCha2PR(
            gO2,gI1,gI2))*CpbarUCha2hhCha2PR(gO1,gI1,gI2);
      }
      tmp_3074 += tmp_3075;
   }
   tmp_3073 += tmp_3074;
   result += (-0.5) * tmp_3073;
   std::complex<double> tmp_3076;
   std::complex<double> tmp_3077;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3078;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_3078 += B1(p,MChi(gI2),MHpm(gI1))*Conj(CpbarUCha2HpmChiPR(
            gO2,gI1,gI2))*CpbarUCha2HpmChiPR(gO1,gI1,gI2);
      }
      tmp_3077 += tmp_3078;
   }
   tmp_3076 += tmp_3077;
   result += (-0.5) * tmp_3076;
   std::complex<double> tmp_3079;
   std::complex<double> tmp_3080;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_3081;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_3081 += B1(p,MFd(gI2),MSu(gI1))*Conj(CpbarUCha2conjSuFdPR(
            gO2,gI1,gI2))*CpbarUCha2conjSuFdPR(gO1,gI1,gI2);
      }
      tmp_3080 += tmp_3081;
   }
   tmp_3079 += tmp_3080;
   result += (-1.5) * tmp_3079;
   std::complex<double> tmp_3082;
   std::complex<double> tmp_3083;
   for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
      tmp_3083 += B1(p,MCha2(gI2),0)*Conj(CpbarUCha2VPCha2PL(gO2,gI2))*
         CpbarUCha2VPCha2PL(gO1,gI2);
   }
   tmp_3082 += tmp_3083;
   result += (-1) * tmp_3082;
   std::complex<double> tmp_3084;
   std::complex<double> tmp_3085;
   for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
      tmp_3085 += B1(p,MCha2(gI2),MVZ)*Conj(CpbarUCha2VZCha2PL(gO2,gI2))*
         CpbarUCha2VZCha2PL(gO1,gI2);
   }
   tmp_3084 += tmp_3085;
   result += (-1) * tmp_3084;
   std::complex<double> tmp_3086;
   std::complex<double> tmp_3087;
   for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
      tmp_3087 += B1(p,MChi(gI2),MVWm)*Conj(CpbarUCha2VWmChiPL(gO2,gI2))*
         CpbarUCha2VWmChiPL(gO1,gI2);
   }
   tmp_3086 += tmp_3087;
   result += (-1) * tmp_3086;

   return result * oneOver16PiSqr;

}

std::complex<double> CLASSNAME::self_energy_Cha2_PL(double p , unsigned gO1, unsigned gO2) const
{
   std::complex<double> result;

   std::complex<double> tmp_3088;
   std::complex<double> tmp_3089;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_3090;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_3090 += B1(p,MCha1(gI1),MRh(gI2))*Conj(CpbarUCha2barCha1RhPL
            (gO2,gI1,gI2))*CpbarUCha2barCha1RhPL(gO1,gI1,gI2);
      }
      tmp_3089 += tmp_3090;
   }
   tmp_3088 += tmp_3089;
   result += (-0.5) * tmp_3088;
   std::complex<double> tmp_3091;
   std::complex<double> tmp_3092;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_3093;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_3093 += B1(p,MCha2(gI1),MAh(gI2))*Conj(CpbarUCha2Cha2AhPL(
            gO2,gI1,gI2))*CpbarUCha2Cha2AhPL(gO1,gI1,gI2);
      }
      tmp_3092 += tmp_3093;
   }
   tmp_3091 += tmp_3092;
   result += (-0.5) * tmp_3091;
   std::complex<double> tmp_3094;
   std::complex<double> tmp_3095;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_3096;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_3096 += B1(p,MFu(gI1),MSd(gI2))*Conj(CpbarUCha2barFuSdPL(gO2
            ,gI1,gI2))*CpbarUCha2barFuSdPL(gO1,gI1,gI2);
      }
      tmp_3095 += tmp_3096;
   }
   tmp_3094 += tmp_3095;
   result += (-1.5) * tmp_3094;
   std::complex<double> tmp_3097;
   std::complex<double> tmp_3098;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_3099;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_3099 += B1(p,MFv(gI1),MSe(gI2))*Conj(CpbarUCha2barFvSePL(gO2
            ,gI1,gI2))*CpbarUCha2barFvSePL(gO1,gI1,gI2);
      }
      tmp_3098 += tmp_3099;
   }
   tmp_3097 += tmp_3098;
   result += (-0.5) * tmp_3097;
   std::complex<double> tmp_3100;
   std::complex<double> tmp_3101;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3102;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_3102 += B1(p,MChi(gI1),MRpm(gI2))*Conj(CpbarUCha2barChiRpmPL
            (gO2,gI1,gI2))*CpbarUCha2barChiRpmPL(gO1,gI1,gI2);
      }
      tmp_3101 += tmp_3102;
   }
   tmp_3100 += tmp_3101;
   result += (-0.5) * tmp_3100;
   std::complex<double> tmp_3103;
   std::complex<double> tmp_3104;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3105;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_3105 += B1(p,MCha2(gI2),Mhh(gI1))*Conj(CpbarUCha2hhCha2PL(
            gO2,gI1,gI2))*CpbarUCha2hhCha2PL(gO1,gI1,gI2);
      }
      tmp_3104 += tmp_3105;
   }
   tmp_3103 += tmp_3104;
   result += (-0.5) * tmp_3103;
   std::complex<double> tmp_3106;
   std::complex<double> tmp_3107;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3108;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_3108 += B1(p,MChi(gI2),MHpm(gI1))*Conj(CpbarUCha2HpmChiPL(
            gO2,gI1,gI2))*CpbarUCha2HpmChiPL(gO1,gI1,gI2);
      }
      tmp_3107 += tmp_3108;
   }
   tmp_3106 += tmp_3107;
   result += (-0.5) * tmp_3106;
   std::complex<double> tmp_3109;
   std::complex<double> tmp_3110;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_3111;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_3111 += B1(p,MFd(gI2),MSu(gI1))*Conj(CpbarUCha2conjSuFdPL(
            gO2,gI1,gI2))*CpbarUCha2conjSuFdPL(gO1,gI1,gI2);
      }
      tmp_3110 += tmp_3111;
   }
   tmp_3109 += tmp_3110;
   result += (-1.5) * tmp_3109;
   std::complex<double> tmp_3112;
   std::complex<double> tmp_3113;
   for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
      tmp_3113 += B1(p,MCha2(gI2),0)*Conj(CpbarUCha2VPCha2PR(gO2,gI2))*
         CpbarUCha2VPCha2PR(gO1,gI2);
   }
   tmp_3112 += tmp_3113;
   result += (-1) * tmp_3112;
   std::complex<double> tmp_3114;
   std::complex<double> tmp_3115;
   for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
      tmp_3115 += B1(p,MCha2(gI2),MVZ)*Conj(CpbarUCha2VZCha2PR(gO2,gI2))*
         CpbarUCha2VZCha2PR(gO1,gI2);
   }
   tmp_3114 += tmp_3115;
   result += (-1) * tmp_3114;
   std::complex<double> tmp_3116;
   std::complex<double> tmp_3117;
   for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
      tmp_3117 += B1(p,MChi(gI2),MVWm)*Conj(CpbarUCha2VWmChiPR(gO2,gI2))*
         CpbarUCha2VWmChiPR(gO1,gI2);
   }
   tmp_3116 += tmp_3117;
   result += (-1) * tmp_3116;

   return result * oneOver16PiSqr;

}

std::complex<double> CLASSNAME::self_energy_Fe_1(double p , unsigned gO1, unsigned gO2) const
{
   std::complex<double> result;

   std::complex<double> tmp_3118;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_3119;
      std::complex<double> tmp_3120;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_3120 += B0(p,MCha1(gI1),MSv(gI2))*Conj(CpbarUFebarCha1SvPL(
            gO2,gI1,gI2))*CpbarUFebarCha1SvPR(gO1,gI1,gI2);
      }
      tmp_3119 += tmp_3120;
      tmp_3118 += (MCha1(gI1)) * tmp_3119;
   }
   result += tmp_3118;
   std::complex<double> tmp_3121;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_3122;
      std::complex<double> tmp_3123;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_3123 += B0(p,MFe(gI1),MAh(gI2))*Conj(CpbarUFeFeAhPL(gO2,gI1,
            gI2))*CpbarUFeFeAhPR(gO1,gI1,gI2);
      }
      tmp_3122 += tmp_3123;
      tmp_3121 += (MFe(gI1)) * tmp_3122;
   }
   result += tmp_3121;
   std::complex<double> tmp_3124;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3125;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_3125 += B0(p,MFe(gI2),Mhh(gI1))*Conj(CpbarUFehhFePL(gO2,gI1,
            gI2))*CpbarUFehhFePR(gO1,gI1,gI2)*MFe(gI2);
      }
      tmp_3124 += tmp_3125;
   }
   result += tmp_3124;
   std::complex<double> tmp_3126;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3127;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_3127 += B0(p,MFv(gI2),MHpm(gI1))*Conj(CpbarUFeHpmFvPL(gO2,
            gI1,gI2))*CpbarUFeHpmFvPR(gO1,gI1,gI2)*MFv(gI2);
      }
      tmp_3126 += tmp_3127;
   }
   result += tmp_3126;
   std::complex<double> tmp_3128;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3129;
      std::complex<double> tmp_3130;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_3130 += B0(p,MChi(gI1),MSe(gI2))*Conj(CpbarUFebarChiSePL(gO2
            ,gI1,gI2))*CpbarUFebarChiSePR(gO1,gI1,gI2);
      }
      tmp_3129 += tmp_3130;
      tmp_3128 += (MChi(gI1)) * tmp_3129;
   }
   result += tmp_3128;
   std::complex<double> tmp_3131;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_3132;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_3132 += B0(p,MChi(gI2),MSe(gI1))*Conj(CpbarUFeSeChiPL(gO2,
            gI1,gI2))*CpbarUFeSeChiPR(gO1,gI1,gI2)*MChi(gI2);
      }
      tmp_3131 += tmp_3132;
   }
   result += tmp_3131;
   std::complex<double> tmp_3133;
   std::complex<double> tmp_3134;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_3134 += B0(p,MFe(gI2),0)*Conj(CpbarUFeVPFePR(gO2,gI2))*
         CpbarUFeVPFePL(gO1,gI2)*MFe(gI2);
   }
   tmp_3133 += tmp_3134;
   result += (-4) * tmp_3133;
   std::complex<double> tmp_3135;
   std::complex<double> tmp_3136;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_3136 += B0(p,MFe(gI2),MVZ)*Conj(CpbarUFeVZFePR(gO2,gI2))*
         CpbarUFeVZFePL(gO1,gI2)*MFe(gI2);
   }
   tmp_3135 += tmp_3136;
   result += (-4) * tmp_3135;
   std::complex<double> tmp_3137;
   std::complex<double> tmp_3138;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_3138 += B0(p,MFv(gI2),MVWm)*Conj(CpbarUFeVWmFvPR(gO2,gI2))*
         CpbarUFeVWmFvPL(gO1,gI2)*MFv(gI2);
   }
   tmp_3137 += tmp_3138;
   result += (-4) * tmp_3137;

   return result * oneOver16PiSqr;

}

std::complex<double> CLASSNAME::self_energy_Fe_PR(double p , unsigned gO1, unsigned gO2) const
{
   std::complex<double> result;

   std::complex<double> tmp_3139;
   std::complex<double> tmp_3140;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_3141;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_3141 += B1(p,MCha1(gI1),MSv(gI2))*Conj(CpbarUFebarCha1SvPR(
            gO2,gI1,gI2))*CpbarUFebarCha1SvPR(gO1,gI1,gI2);
      }
      tmp_3140 += tmp_3141;
   }
   tmp_3139 += tmp_3140;
   result += (-0.5) * tmp_3139;
   std::complex<double> tmp_3142;
   std::complex<double> tmp_3143;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_3144;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_3144 += B1(p,MFe(gI1),MAh(gI2))*Conj(CpbarUFeFeAhPR(gO2,gI1,
            gI2))*CpbarUFeFeAhPR(gO1,gI1,gI2);
      }
      tmp_3143 += tmp_3144;
   }
   tmp_3142 += tmp_3143;
   result += (-0.5) * tmp_3142;
   std::complex<double> tmp_3145;
   std::complex<double> tmp_3146;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3147;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_3147 += B1(p,MFe(gI2),Mhh(gI1))*Conj(CpbarUFehhFePR(gO2,gI1,
            gI2))*CpbarUFehhFePR(gO1,gI1,gI2);
      }
      tmp_3146 += tmp_3147;
   }
   tmp_3145 += tmp_3146;
   result += (-0.5) * tmp_3145;
   std::complex<double> tmp_3148;
   std::complex<double> tmp_3149;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3150;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_3150 += B1(p,MFv(gI2),MHpm(gI1))*Conj(CpbarUFeHpmFvPR(gO2,
            gI1,gI2))*CpbarUFeHpmFvPR(gO1,gI1,gI2);
      }
      tmp_3149 += tmp_3150;
   }
   tmp_3148 += tmp_3149;
   result += (-0.5) * tmp_3148;
   std::complex<double> tmp_3151;
   std::complex<double> tmp_3152;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3153;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_3153 += B1(p,MChi(gI1),MSe(gI2))*Conj(CpbarUFebarChiSePR(gO2
            ,gI1,gI2))*CpbarUFebarChiSePR(gO1,gI1,gI2);
      }
      tmp_3152 += tmp_3153;
   }
   tmp_3151 += tmp_3152;
   result += (-0.5) * tmp_3151;
   std::complex<double> tmp_3154;
   std::complex<double> tmp_3155;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_3156;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_3156 += B1(p,MChi(gI2),MSe(gI1))*Conj(CpbarUFeSeChiPR(gO2,
            gI1,gI2))*CpbarUFeSeChiPR(gO1,gI1,gI2);
      }
      tmp_3155 += tmp_3156;
   }
   tmp_3154 += tmp_3155;
   result += (-0.5) * tmp_3154;
   std::complex<double> tmp_3157;
   std::complex<double> tmp_3158;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_3158 += B1(p,MFe(gI2),0)*Conj(CpbarUFeVPFePL(gO2,gI2))*
         CpbarUFeVPFePL(gO1,gI2);
   }
   tmp_3157 += tmp_3158;
   result += (-1) * tmp_3157;
   std::complex<double> tmp_3159;
   std::complex<double> tmp_3160;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_3160 += B1(p,MFv(gI2),MVWm)*Conj(CpbarUFeVWmFvPL(gO2,gI2))*
         CpbarUFeVWmFvPL(gO1,gI2);
   }
   tmp_3159 += tmp_3160;
   result += (-1) * tmp_3159;
   std::complex<double> tmp_3161;
   std::complex<double> tmp_3162;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_3162 += B1(p,MFe(gI2),MVZ)*Conj(CpbarUFeVZFePL(gO2,gI2))*
         CpbarUFeVZFePL(gO1,gI2);
   }
   tmp_3161 += tmp_3162;
   result += (-1) * tmp_3161;

   return result * oneOver16PiSqr;

}

std::complex<double> CLASSNAME::self_energy_Fe_PL(double p , unsigned gO1, unsigned gO2) const
{
   std::complex<double> result;

   std::complex<double> tmp_3163;
   std::complex<double> tmp_3164;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_3165;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_3165 += B1(p,MCha1(gI1),MSv(gI2))*Conj(CpbarUFebarCha1SvPL(
            gO2,gI1,gI2))*CpbarUFebarCha1SvPL(gO1,gI1,gI2);
      }
      tmp_3164 += tmp_3165;
   }
   tmp_3163 += tmp_3164;
   result += (-0.5) * tmp_3163;
   std::complex<double> tmp_3166;
   std::complex<double> tmp_3167;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_3168;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_3168 += B1(p,MFe(gI1),MAh(gI2))*Conj(CpbarUFeFeAhPL(gO2,gI1,
            gI2))*CpbarUFeFeAhPL(gO1,gI1,gI2);
      }
      tmp_3167 += tmp_3168;
   }
   tmp_3166 += tmp_3167;
   result += (-0.5) * tmp_3166;
   std::complex<double> tmp_3169;
   std::complex<double> tmp_3170;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3171;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_3171 += B1(p,MFe(gI2),Mhh(gI1))*Conj(CpbarUFehhFePL(gO2,gI1,
            gI2))*CpbarUFehhFePL(gO1,gI1,gI2);
      }
      tmp_3170 += tmp_3171;
   }
   tmp_3169 += tmp_3170;
   result += (-0.5) * tmp_3169;
   std::complex<double> tmp_3172;
   std::complex<double> tmp_3173;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3174;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_3174 += B1(p,MFv(gI2),MHpm(gI1))*Conj(CpbarUFeHpmFvPL(gO2,
            gI1,gI2))*CpbarUFeHpmFvPL(gO1,gI1,gI2);
      }
      tmp_3173 += tmp_3174;
   }
   tmp_3172 += tmp_3173;
   result += (-0.5) * tmp_3172;
   std::complex<double> tmp_3175;
   std::complex<double> tmp_3176;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3177;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_3177 += B1(p,MChi(gI1),MSe(gI2))*Conj(CpbarUFebarChiSePL(gO2
            ,gI1,gI2))*CpbarUFebarChiSePL(gO1,gI1,gI2);
      }
      tmp_3176 += tmp_3177;
   }
   tmp_3175 += tmp_3176;
   result += (-0.5) * tmp_3175;
   std::complex<double> tmp_3178;
   std::complex<double> tmp_3179;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_3180;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_3180 += B1(p,MChi(gI2),MSe(gI1))*Conj(CpbarUFeSeChiPL(gO2,
            gI1,gI2))*CpbarUFeSeChiPL(gO1,gI1,gI2);
      }
      tmp_3179 += tmp_3180;
   }
   tmp_3178 += tmp_3179;
   result += (-0.5) * tmp_3178;
   std::complex<double> tmp_3181;
   std::complex<double> tmp_3182;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_3182 += B1(p,MFe(gI2),0)*Conj(CpbarUFeVPFePR(gO2,gI2))*
         CpbarUFeVPFePR(gO1,gI2);
   }
   tmp_3181 += tmp_3182;
   result += (-1) * tmp_3181;
   std::complex<double> tmp_3183;
   std::complex<double> tmp_3184;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_3184 += B1(p,MFv(gI2),MVWm)*Conj(CpbarUFeVWmFvPR(gO2,gI2))*
         CpbarUFeVWmFvPR(gO1,gI2);
   }
   tmp_3183 += tmp_3184;
   result += (-1) * tmp_3183;
   std::complex<double> tmp_3185;
   std::complex<double> tmp_3186;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_3186 += B1(p,MFe(gI2),MVZ)*Conj(CpbarUFeVZFePR(gO2,gI2))*
         CpbarUFeVZFePR(gO1,gI2);
   }
   tmp_3185 += tmp_3186;
   result += (-1) * tmp_3185;

   return result * oneOver16PiSqr;

}

std::complex<double> CLASSNAME::self_energy_Fd_1(double p , unsigned gO1, unsigned gO2) const
{
   std::complex<double> result;

   std::complex<double> tmp_3187;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_3188;
      std::complex<double> tmp_3189;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_3189 += B0(p,MCha1(gI1),MSu(gI2))*Conj(CpbarUFdbarCha1SuPL(
            gO2,gI1,gI2))*CpbarUFdbarCha1SuPR(gO1,gI1,gI2);
      }
      tmp_3188 += tmp_3189;
      tmp_3187 += (MCha1(gI1)) * tmp_3188;
   }
   result += tmp_3187;
   std::complex<double> tmp_3190;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_3191;
      std::complex<double> tmp_3192;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_3192 += B0(p,MFd(gI1),MAh(gI2))*Conj(CpbarUFdFdAhPL(gO2,gI1,
            gI2))*CpbarUFdFdAhPR(gO1,gI1,gI2);
      }
      tmp_3191 += tmp_3192;
      tmp_3190 += (MFd(gI1)) * tmp_3191;
   }
   result += tmp_3190;
   std::complex<double> tmp_3193;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3194;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_3194 += B0(p,MFd(gI2),Mhh(gI1))*Conj(CpbarUFdhhFdPL(gO2,gI1,
            gI2))*CpbarUFdhhFdPR(gO1,gI1,gI2)*MFd(gI2);
      }
      tmp_3193 += tmp_3194;
   }
   result += tmp_3193;
   std::complex<double> tmp_3195;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3196;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_3196 += B0(p,MFu(gI2),MHpm(gI1))*Conj(CpbarUFdHpmFuPL(gO2,
            gI1,gI2))*CpbarUFdHpmFuPR(gO1,gI1,gI2)*MFu(gI2);
      }
      tmp_3195 += tmp_3196;
   }
   result += tmp_3195;
   std::complex<double> tmp_3197;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3198;
      std::complex<double> tmp_3199;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_3199 += B0(p,MChi(gI1),MSd(gI2))*Conj(CpbarUFdbarChiSdPL(gO2
            ,gI1,gI2))*CpbarUFdbarChiSdPR(gO1,gI1,gI2);
      }
      tmp_3198 += tmp_3199;
      tmp_3197 += (MChi(gI1)) * tmp_3198;
   }
   result += tmp_3197;
   std::complex<double> tmp_3200;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_3201;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_3201 += B0(p,MCha2(gI2),MSu(gI1))*Conj(CpbarUFdSuCha2PL(gO2,
            gI1,gI2))*CpbarUFdSuCha2PR(gO1,gI1,gI2)*MCha2(gI2);
      }
      tmp_3200 += tmp_3201;
   }
   result += tmp_3200;
   std::complex<double> tmp_3202;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_3203;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_3203 += B0(p,MChi(gI2),MSd(gI1))*Conj(CpbarUFdSdChiPL(gO2,
            gI1,gI2))*CpbarUFdSdChiPR(gO1,gI1,gI2)*MChi(gI2);
      }
      tmp_3202 += tmp_3203;
   }
   result += tmp_3202;
   std::complex<double> tmp_3204;
   std::complex<double> tmp_3205;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_3205 += B0(p,MFd(gI2),0)*Conj(CpbarUFdVGFdPR(gO2,gI2))*
         CpbarUFdVGFdPL(gO1,gI2)*MFd(gI2);
   }
   tmp_3204 += tmp_3205;
   result += (-5.333333333333333) * tmp_3204;
   std::complex<double> tmp_3206;
   std::complex<double> tmp_3207;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_3207 += B0(p,MFd(gI2),0)*Conj(CpbarUFdVPFdPR(gO2,gI2))*
         CpbarUFdVPFdPL(gO1,gI2)*MFd(gI2);
   }
   tmp_3206 += tmp_3207;
   result += (-4) * tmp_3206;
   std::complex<double> tmp_3208;
   std::complex<double> tmp_3209;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_3209 += B0(p,MFd(gI2),MVZ)*Conj(CpbarUFdVZFdPR(gO2,gI2))*
         CpbarUFdVZFdPL(gO1,gI2)*MFd(gI2);
   }
   tmp_3208 += tmp_3209;
   result += (-4) * tmp_3208;
   std::complex<double> tmp_3210;
   std::complex<double> tmp_3211;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_3211 += B0(p,MFu(gI2),MVWm)*Conj(CpbarUFdVWmFuPR(gO2,gI2))*
         CpbarUFdVWmFuPL(gO1,gI2)*MFu(gI2);
   }
   tmp_3210 += tmp_3211;
   result += (-4) * tmp_3210;
   std::complex<double> tmp_3212;
   std::complex<double> tmp_3213;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      tmp_3213 += B0(p,MGlu,MSd(gI1))*Conj(CpbarUFdSdGluPL(gO2,gI1,1))*
         CpbarUFdSdGluPR(gO1,gI1,1);
   }
   tmp_3212 += tmp_3213;
   result += (1.3333333333333333*MGlu) * tmp_3212;
   std::complex<double> tmp_3214;
   std::complex<double> tmp_3215;
   for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
      tmp_3215 += B0(p,MGlu,MSd(gI2))*Conj(CpbarUFdbarGluSdPL(gO2,1,gI2))*
         CpbarUFdbarGluSdPR(gO1,1,gI2);
   }
   tmp_3214 += tmp_3215;
   result += (1.3333333333333333*MGlu) * tmp_3214;

   return result * oneOver16PiSqr;

}

std::complex<double> CLASSNAME::self_energy_Fd_PR(double p , unsigned gO1, unsigned gO2) const
{
   std::complex<double> result;

   std::complex<double> tmp_3216;
   std::complex<double> tmp_3217;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_3218;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_3218 += B1(p,MCha1(gI1),MSu(gI2))*Conj(CpbarUFdbarCha1SuPR(
            gO2,gI1,gI2))*CpbarUFdbarCha1SuPR(gO1,gI1,gI2);
      }
      tmp_3217 += tmp_3218;
   }
   tmp_3216 += tmp_3217;
   result += (-0.5) * tmp_3216;
   std::complex<double> tmp_3219;
   std::complex<double> tmp_3220;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_3221;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_3221 += B1(p,MFd(gI1),MAh(gI2))*Conj(CpbarUFdFdAhPR(gO2,gI1,
            gI2))*CpbarUFdFdAhPR(gO1,gI1,gI2);
      }
      tmp_3220 += tmp_3221;
   }
   tmp_3219 += tmp_3220;
   result += (-0.5) * tmp_3219;
   std::complex<double> tmp_3222;
   std::complex<double> tmp_3223;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3224;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_3224 += B1(p,MFd(gI2),Mhh(gI1))*Conj(CpbarUFdhhFdPR(gO2,gI1,
            gI2))*CpbarUFdhhFdPR(gO1,gI1,gI2);
      }
      tmp_3223 += tmp_3224;
   }
   tmp_3222 += tmp_3223;
   result += (-0.5) * tmp_3222;
   std::complex<double> tmp_3225;
   std::complex<double> tmp_3226;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3227;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_3227 += B1(p,MFu(gI2),MHpm(gI1))*Conj(CpbarUFdHpmFuPR(gO2,
            gI1,gI2))*CpbarUFdHpmFuPR(gO1,gI1,gI2);
      }
      tmp_3226 += tmp_3227;
   }
   tmp_3225 += tmp_3226;
   result += (-0.5) * tmp_3225;
   std::complex<double> tmp_3228;
   std::complex<double> tmp_3229;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3230;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_3230 += B1(p,MChi(gI1),MSd(gI2))*Conj(CpbarUFdbarChiSdPR(gO2
            ,gI1,gI2))*CpbarUFdbarChiSdPR(gO1,gI1,gI2);
      }
      tmp_3229 += tmp_3230;
   }
   tmp_3228 += tmp_3229;
   result += (-0.5) * tmp_3228;
   std::complex<double> tmp_3231;
   std::complex<double> tmp_3232;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      tmp_3232 += B1(p,MGlu,MSd(gI1))*Conj(CpbarUFdSdGluPR(gO2,gI1,1))*
         CpbarUFdSdGluPR(gO1,gI1,1);
   }
   tmp_3231 += tmp_3232;
   result += (-0.6666666666666666) * tmp_3231;
   std::complex<double> tmp_3233;
   std::complex<double> tmp_3234;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_3235;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_3235 += B1(p,MCha2(gI2),MSu(gI1))*Conj(CpbarUFdSuCha2PR(gO2,
            gI1,gI2))*CpbarUFdSuCha2PR(gO1,gI1,gI2);
      }
      tmp_3234 += tmp_3235;
   }
   tmp_3233 += tmp_3234;
   result += (-0.5) * tmp_3233;
   std::complex<double> tmp_3236;
   std::complex<double> tmp_3237;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_3238;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_3238 += B1(p,MChi(gI2),MSd(gI1))*Conj(CpbarUFdSdChiPR(gO2,
            gI1,gI2))*CpbarUFdSdChiPR(gO1,gI1,gI2);
      }
      tmp_3237 += tmp_3238;
   }
   tmp_3236 += tmp_3237;
   result += (-0.5) * tmp_3236;
   std::complex<double> tmp_3239;
   std::complex<double> tmp_3240;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_3240 += B1(p,MFd(gI2),0)*Conj(CpbarUFdVGFdPL(gO2,gI2))*
         CpbarUFdVGFdPL(gO1,gI2);
   }
   tmp_3239 += tmp_3240;
   result += (-1.3333333333333333) * tmp_3239;
   std::complex<double> tmp_3241;
   std::complex<double> tmp_3242;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_3242 += B1(p,MFd(gI2),0)*Conj(CpbarUFdVPFdPL(gO2,gI2))*
         CpbarUFdVPFdPL(gO1,gI2);
   }
   tmp_3241 += tmp_3242;
   result += (-1) * tmp_3241;
   std::complex<double> tmp_3243;
   std::complex<double> tmp_3244;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_3244 += B1(p,MFu(gI2),MVWm)*Conj(CpbarUFdVWmFuPL(gO2,gI2))*
         CpbarUFdVWmFuPL(gO1,gI2);
   }
   tmp_3243 += tmp_3244;
   result += (-1) * tmp_3243;
   std::complex<double> tmp_3245;
   std::complex<double> tmp_3246;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_3246 += B1(p,MFd(gI2),MVZ)*Conj(CpbarUFdVZFdPL(gO2,gI2))*
         CpbarUFdVZFdPL(gO1,gI2);
   }
   tmp_3245 += tmp_3246;
   result += (-1) * tmp_3245;
   std::complex<double> tmp_3247;
   std::complex<double> tmp_3248;
   for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
      tmp_3248 += B1(p,MGlu,MSd(gI2))*Conj(CpbarUFdbarGluSdPR(gO2,1,gI2))*
         CpbarUFdbarGluSdPR(gO1,1,gI2);
   }
   tmp_3247 += tmp_3248;
   result += (-0.6666666666666666) * tmp_3247;

   return result * oneOver16PiSqr;

}

std::complex<double> CLASSNAME::self_energy_Fd_PL(double p , unsigned gO1, unsigned gO2) const
{
   std::complex<double> result;

   std::complex<double> tmp_3249;
   std::complex<double> tmp_3250;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_3251;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_3251 += B1(p,MCha1(gI1),MSu(gI2))*Conj(CpbarUFdbarCha1SuPL(
            gO2,gI1,gI2))*CpbarUFdbarCha1SuPL(gO1,gI1,gI2);
      }
      tmp_3250 += tmp_3251;
   }
   tmp_3249 += tmp_3250;
   result += (-0.5) * tmp_3249;
   std::complex<double> tmp_3252;
   std::complex<double> tmp_3253;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_3254;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_3254 += B1(p,MFd(gI1),MAh(gI2))*Conj(CpbarUFdFdAhPL(gO2,gI1,
            gI2))*CpbarUFdFdAhPL(gO1,gI1,gI2);
      }
      tmp_3253 += tmp_3254;
   }
   tmp_3252 += tmp_3253;
   result += (-0.5) * tmp_3252;
   std::complex<double> tmp_3255;
   std::complex<double> tmp_3256;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3257;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_3257 += B1(p,MFd(gI2),Mhh(gI1))*Conj(CpbarUFdhhFdPL(gO2,gI1,
            gI2))*CpbarUFdhhFdPL(gO1,gI1,gI2);
      }
      tmp_3256 += tmp_3257;
   }
   tmp_3255 += tmp_3256;
   result += (-0.5) * tmp_3255;
   std::complex<double> tmp_3258;
   std::complex<double> tmp_3259;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3260;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_3260 += B1(p,MFu(gI2),MHpm(gI1))*Conj(CpbarUFdHpmFuPL(gO2,
            gI1,gI2))*CpbarUFdHpmFuPL(gO1,gI1,gI2);
      }
      tmp_3259 += tmp_3260;
   }
   tmp_3258 += tmp_3259;
   result += (-0.5) * tmp_3258;
   std::complex<double> tmp_3261;
   std::complex<double> tmp_3262;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3263;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_3263 += B1(p,MChi(gI1),MSd(gI2))*Conj(CpbarUFdbarChiSdPL(gO2
            ,gI1,gI2))*CpbarUFdbarChiSdPL(gO1,gI1,gI2);
      }
      tmp_3262 += tmp_3263;
   }
   tmp_3261 += tmp_3262;
   result += (-0.5) * tmp_3261;
   std::complex<double> tmp_3264;
   std::complex<double> tmp_3265;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      tmp_3265 += B1(p,MGlu,MSd(gI1))*Conj(CpbarUFdSdGluPL(gO2,gI1,1))*
         CpbarUFdSdGluPL(gO1,gI1,1);
   }
   tmp_3264 += tmp_3265;
   result += (-0.6666666666666666) * tmp_3264;
   std::complex<double> tmp_3266;
   std::complex<double> tmp_3267;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_3268;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_3268 += B1(p,MCha2(gI2),MSu(gI1))*Conj(CpbarUFdSuCha2PL(gO2,
            gI1,gI2))*CpbarUFdSuCha2PL(gO1,gI1,gI2);
      }
      tmp_3267 += tmp_3268;
   }
   tmp_3266 += tmp_3267;
   result += (-0.5) * tmp_3266;
   std::complex<double> tmp_3269;
   std::complex<double> tmp_3270;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_3271;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_3271 += B1(p,MChi(gI2),MSd(gI1))*Conj(CpbarUFdSdChiPL(gO2,
            gI1,gI2))*CpbarUFdSdChiPL(gO1,gI1,gI2);
      }
      tmp_3270 += tmp_3271;
   }
   tmp_3269 += tmp_3270;
   result += (-0.5) * tmp_3269;
   std::complex<double> tmp_3272;
   std::complex<double> tmp_3273;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_3273 += B1(p,MFd(gI2),0)*Conj(CpbarUFdVGFdPR(gO2,gI2))*
         CpbarUFdVGFdPR(gO1,gI2);
   }
   tmp_3272 += tmp_3273;
   result += (-1.3333333333333333) * tmp_3272;
   std::complex<double> tmp_3274;
   std::complex<double> tmp_3275;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_3275 += B1(p,MFd(gI2),0)*Conj(CpbarUFdVPFdPR(gO2,gI2))*
         CpbarUFdVPFdPR(gO1,gI2);
   }
   tmp_3274 += tmp_3275;
   result += (-1) * tmp_3274;
   std::complex<double> tmp_3276;
   std::complex<double> tmp_3277;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_3277 += B1(p,MFu(gI2),MVWm)*Conj(CpbarUFdVWmFuPR(gO2,gI2))*
         CpbarUFdVWmFuPR(gO1,gI2);
   }
   tmp_3276 += tmp_3277;
   result += (-1) * tmp_3276;
   std::complex<double> tmp_3278;
   std::complex<double> tmp_3279;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_3279 += B1(p,MFd(gI2),MVZ)*Conj(CpbarUFdVZFdPR(gO2,gI2))*
         CpbarUFdVZFdPR(gO1,gI2);
   }
   tmp_3278 += tmp_3279;
   result += (-1) * tmp_3278;
   std::complex<double> tmp_3280;
   std::complex<double> tmp_3281;
   for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
      tmp_3281 += B1(p,MGlu,MSd(gI2))*Conj(CpbarUFdbarGluSdPL(gO2,1,gI2))*
         CpbarUFdbarGluSdPL(gO1,1,gI2);
   }
   tmp_3280 += tmp_3281;
   result += (-0.6666666666666666) * tmp_3280;

   return result * oneOver16PiSqr;

}

std::complex<double> CLASSNAME::self_energy_Fu_1(double p , unsigned gO1, unsigned gO2) const
{
   std::complex<double> result;

   std::complex<double> tmp_3282;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_3283;
      std::complex<double> tmp_3284;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_3284 += B0(p,MCha2(gI1),MSd(gI2))*Conj(CpbarUFubarCha2SdPL(
            gO2,gI1,gI2))*CpbarUFubarCha2SdPR(gO1,gI1,gI2);
      }
      tmp_3283 += tmp_3284;
      tmp_3282 += (MCha2(gI1)) * tmp_3283;
   }
   result += tmp_3282;
   std::complex<double> tmp_3285;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_3286;
      std::complex<double> tmp_3287;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_3287 += B0(p,MFu(gI1),MAh(gI2))*Conj(CpbarUFuFuAhPL(gO2,gI1,
            gI2))*CpbarUFuFuAhPR(gO1,gI1,gI2);
      }
      tmp_3286 += tmp_3287;
      tmp_3285 += (MFu(gI1)) * tmp_3286;
   }
   result += tmp_3285;
   std::complex<double> tmp_3288;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3289;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_3289 += B0(p,MFd(gI2),MHpm(gI1))*Conj(CpbarUFuconjHpmFdPL(
            gO2,gI1,gI2))*CpbarUFuconjHpmFdPR(gO1,gI1,gI2)*MFd(gI2);
      }
      tmp_3288 += tmp_3289;
   }
   result += tmp_3288;
   std::complex<double> tmp_3290;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3291;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_3291 += B0(p,MFu(gI2),Mhh(gI1))*Conj(CpbarUFuhhFuPL(gO2,gI1,
            gI2))*CpbarUFuhhFuPR(gO1,gI1,gI2)*MFu(gI2);
      }
      tmp_3290 += tmp_3291;
   }
   result += tmp_3290;
   std::complex<double> tmp_3292;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3293;
      std::complex<double> tmp_3294;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_3294 += B0(p,MChi(gI1),MSu(gI2))*Conj(CpbarUFubarChiSuPL(gO2
            ,gI1,gI2))*CpbarUFubarChiSuPR(gO1,gI1,gI2);
      }
      tmp_3293 += tmp_3294;
      tmp_3292 += (MChi(gI1)) * tmp_3293;
   }
   result += tmp_3292;
   std::complex<double> tmp_3295;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_3296;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_3296 += B0(p,MCha1(gI2),MSd(gI1))*Conj(CpbarUFuSdCha1PL(gO2,
            gI1,gI2))*CpbarUFuSdCha1PR(gO1,gI1,gI2)*MCha1(gI2);
      }
      tmp_3295 += tmp_3296;
   }
   result += tmp_3295;
   std::complex<double> tmp_3297;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_3298;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_3298 += B0(p,MChi(gI2),MSu(gI1))*Conj(CpbarUFuSuChiPL(gO2,
            gI1,gI2))*CpbarUFuSuChiPR(gO1,gI1,gI2)*MChi(gI2);
      }
      tmp_3297 += tmp_3298;
   }
   result += tmp_3297;
   std::complex<double> tmp_3299;
   std::complex<double> tmp_3300;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_3300 += B0(p,MFd(gI2),MVWm)*Conj(CpbarUFuconjVWmFdPR(gO2,gI2))*
         CpbarUFuconjVWmFdPL(gO1,gI2)*MFd(gI2);
   }
   tmp_3299 += tmp_3300;
   result += (-4) * tmp_3299;
   std::complex<double> tmp_3301;
   std::complex<double> tmp_3302;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_3302 += B0(p,MFu(gI2),0)*Conj(CpbarUFuVGFuPR(gO2,gI2))*
         CpbarUFuVGFuPL(gO1,gI2)*MFu(gI2);
   }
   tmp_3301 += tmp_3302;
   result += (-5.333333333333333) * tmp_3301;
   std::complex<double> tmp_3303;
   std::complex<double> tmp_3304;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_3304 += B0(p,MFu(gI2),0)*Conj(CpbarUFuVPFuPR(gO2,gI2))*
         CpbarUFuVPFuPL(gO1,gI2)*MFu(gI2);
   }
   tmp_3303 += tmp_3304;
   result += (-4) * tmp_3303;
   std::complex<double> tmp_3305;
   std::complex<double> tmp_3306;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_3306 += B0(p,MFu(gI2),MVZ)*Conj(CpbarUFuVZFuPR(gO2,gI2))*
         CpbarUFuVZFuPL(gO1,gI2)*MFu(gI2);
   }
   tmp_3305 += tmp_3306;
   result += (-4) * tmp_3305;
   std::complex<double> tmp_3307;
   std::complex<double> tmp_3308;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      tmp_3308 += B0(p,MGlu,MSu(gI1))*Conj(CpbarUFuSuGluPL(gO2,gI1,1))*
         CpbarUFuSuGluPR(gO1,gI1,1);
   }
   tmp_3307 += tmp_3308;
   result += (1.3333333333333333*MGlu) * tmp_3307;
   std::complex<double> tmp_3309;
   std::complex<double> tmp_3310;
   for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
      tmp_3310 += B0(p,MGlu,MSu(gI2))*Conj(CpbarUFubarGluSuPL(gO2,1,gI2))*
         CpbarUFubarGluSuPR(gO1,1,gI2);
   }
   tmp_3309 += tmp_3310;
   result += (1.3333333333333333*MGlu) * tmp_3309;

   return result * oneOver16PiSqr;

}

std::complex<double> CLASSNAME::self_energy_Fu_PR(double p , unsigned gO1, unsigned gO2) const
{
   std::complex<double> result;

   std::complex<double> tmp_3311;
   std::complex<double> tmp_3312;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_3313;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_3313 += B1(p,MCha2(gI1),MSd(gI2))*Conj(CpbarUFubarCha2SdPR(
            gO2,gI1,gI2))*CpbarUFubarCha2SdPR(gO1,gI1,gI2);
      }
      tmp_3312 += tmp_3313;
   }
   tmp_3311 += tmp_3312;
   result += (-0.5) * tmp_3311;
   std::complex<double> tmp_3314;
   std::complex<double> tmp_3315;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_3316;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_3316 += B1(p,MFu(gI1),MAh(gI2))*Conj(CpbarUFuFuAhPR(gO2,gI1,
            gI2))*CpbarUFuFuAhPR(gO1,gI1,gI2);
      }
      tmp_3315 += tmp_3316;
   }
   tmp_3314 += tmp_3315;
   result += (-0.5) * tmp_3314;
   std::complex<double> tmp_3317;
   std::complex<double> tmp_3318;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3319;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_3319 += B1(p,MFd(gI2),MHpm(gI1))*Conj(CpbarUFuconjHpmFdPR(
            gO2,gI1,gI2))*CpbarUFuconjHpmFdPR(gO1,gI1,gI2);
      }
      tmp_3318 += tmp_3319;
   }
   tmp_3317 += tmp_3318;
   result += (-0.5) * tmp_3317;
   std::complex<double> tmp_3320;
   std::complex<double> tmp_3321;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3322;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_3322 += B1(p,MFu(gI2),Mhh(gI1))*Conj(CpbarUFuhhFuPR(gO2,gI1,
            gI2))*CpbarUFuhhFuPR(gO1,gI1,gI2);
      }
      tmp_3321 += tmp_3322;
   }
   tmp_3320 += tmp_3321;
   result += (-0.5) * tmp_3320;
   std::complex<double> tmp_3323;
   std::complex<double> tmp_3324;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3325;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_3325 += B1(p,MChi(gI1),MSu(gI2))*Conj(CpbarUFubarChiSuPR(gO2
            ,gI1,gI2))*CpbarUFubarChiSuPR(gO1,gI1,gI2);
      }
      tmp_3324 += tmp_3325;
   }
   tmp_3323 += tmp_3324;
   result += (-0.5) * tmp_3323;
   std::complex<double> tmp_3326;
   std::complex<double> tmp_3327;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      tmp_3327 += B1(p,MGlu,MSu(gI1))*Conj(CpbarUFuSuGluPR(gO2,gI1,1))*
         CpbarUFuSuGluPR(gO1,gI1,1);
   }
   tmp_3326 += tmp_3327;
   result += (-0.6666666666666666) * tmp_3326;
   std::complex<double> tmp_3328;
   std::complex<double> tmp_3329;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_3330;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_3330 += B1(p,MCha1(gI2),MSd(gI1))*Conj(CpbarUFuSdCha1PR(gO2,
            gI1,gI2))*CpbarUFuSdCha1PR(gO1,gI1,gI2);
      }
      tmp_3329 += tmp_3330;
   }
   tmp_3328 += tmp_3329;
   result += (-0.5) * tmp_3328;
   std::complex<double> tmp_3331;
   std::complex<double> tmp_3332;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_3333;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_3333 += B1(p,MChi(gI2),MSu(gI1))*Conj(CpbarUFuSuChiPR(gO2,
            gI1,gI2))*CpbarUFuSuChiPR(gO1,gI1,gI2);
      }
      tmp_3332 += tmp_3333;
   }
   tmp_3331 += tmp_3332;
   result += (-0.5) * tmp_3331;
   std::complex<double> tmp_3334;
   std::complex<double> tmp_3335;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_3335 += B1(p,MFd(gI2),MVWm)*Conj(CpbarUFuconjVWmFdPL(gO2,gI2))*
         CpbarUFuconjVWmFdPL(gO1,gI2);
   }
   tmp_3334 += tmp_3335;
   result += (-1) * tmp_3334;
   std::complex<double> tmp_3336;
   std::complex<double> tmp_3337;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_3337 += B1(p,MFu(gI2),0)*Conj(CpbarUFuVGFuPL(gO2,gI2))*
         CpbarUFuVGFuPL(gO1,gI2);
   }
   tmp_3336 += tmp_3337;
   result += (-1.3333333333333333) * tmp_3336;
   std::complex<double> tmp_3338;
   std::complex<double> tmp_3339;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_3339 += B1(p,MFu(gI2),0)*Conj(CpbarUFuVPFuPL(gO2,gI2))*
         CpbarUFuVPFuPL(gO1,gI2);
   }
   tmp_3338 += tmp_3339;
   result += (-1) * tmp_3338;
   std::complex<double> tmp_3340;
   std::complex<double> tmp_3341;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_3341 += B1(p,MFu(gI2),MVZ)*Conj(CpbarUFuVZFuPL(gO2,gI2))*
         CpbarUFuVZFuPL(gO1,gI2);
   }
   tmp_3340 += tmp_3341;
   result += (-1) * tmp_3340;
   std::complex<double> tmp_3342;
   std::complex<double> tmp_3343;
   for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
      tmp_3343 += B1(p,MGlu,MSu(gI2))*Conj(CpbarUFubarGluSuPR(gO2,1,gI2))*
         CpbarUFubarGluSuPR(gO1,1,gI2);
   }
   tmp_3342 += tmp_3343;
   result += (-0.6666666666666666) * tmp_3342;

   return result * oneOver16PiSqr;

}

std::complex<double> CLASSNAME::self_energy_Fu_PL(double p , unsigned gO1, unsigned gO2) const
{
   std::complex<double> result;

   std::complex<double> tmp_3344;
   std::complex<double> tmp_3345;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_3346;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_3346 += B1(p,MCha2(gI1),MSd(gI2))*Conj(CpbarUFubarCha2SdPL(
            gO2,gI1,gI2))*CpbarUFubarCha2SdPL(gO1,gI1,gI2);
      }
      tmp_3345 += tmp_3346;
   }
   tmp_3344 += tmp_3345;
   result += (-0.5) * tmp_3344;
   std::complex<double> tmp_3347;
   std::complex<double> tmp_3348;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_3349;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_3349 += B1(p,MFu(gI1),MAh(gI2))*Conj(CpbarUFuFuAhPL(gO2,gI1,
            gI2))*CpbarUFuFuAhPL(gO1,gI1,gI2);
      }
      tmp_3348 += tmp_3349;
   }
   tmp_3347 += tmp_3348;
   result += (-0.5) * tmp_3347;
   std::complex<double> tmp_3350;
   std::complex<double> tmp_3351;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3352;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_3352 += B1(p,MFd(gI2),MHpm(gI1))*Conj(CpbarUFuconjHpmFdPL(
            gO2,gI1,gI2))*CpbarUFuconjHpmFdPL(gO1,gI1,gI2);
      }
      tmp_3351 += tmp_3352;
   }
   tmp_3350 += tmp_3351;
   result += (-0.5) * tmp_3350;
   std::complex<double> tmp_3353;
   std::complex<double> tmp_3354;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3355;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_3355 += B1(p,MFu(gI2),Mhh(gI1))*Conj(CpbarUFuhhFuPL(gO2,gI1,
            gI2))*CpbarUFuhhFuPL(gO1,gI1,gI2);
      }
      tmp_3354 += tmp_3355;
   }
   tmp_3353 += tmp_3354;
   result += (-0.5) * tmp_3353;
   std::complex<double> tmp_3356;
   std::complex<double> tmp_3357;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3358;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_3358 += B1(p,MChi(gI1),MSu(gI2))*Conj(CpbarUFubarChiSuPL(gO2
            ,gI1,gI2))*CpbarUFubarChiSuPL(gO1,gI1,gI2);
      }
      tmp_3357 += tmp_3358;
   }
   tmp_3356 += tmp_3357;
   result += (-0.5) * tmp_3356;
   std::complex<double> tmp_3359;
   std::complex<double> tmp_3360;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      tmp_3360 += B1(p,MGlu,MSu(gI1))*Conj(CpbarUFuSuGluPL(gO2,gI1,1))*
         CpbarUFuSuGluPL(gO1,gI1,1);
   }
   tmp_3359 += tmp_3360;
   result += (-0.6666666666666666) * tmp_3359;
   std::complex<double> tmp_3361;
   std::complex<double> tmp_3362;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_3363;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_3363 += B1(p,MCha1(gI2),MSd(gI1))*Conj(CpbarUFuSdCha1PL(gO2,
            gI1,gI2))*CpbarUFuSdCha1PL(gO1,gI1,gI2);
      }
      tmp_3362 += tmp_3363;
   }
   tmp_3361 += tmp_3362;
   result += (-0.5) * tmp_3361;
   std::complex<double> tmp_3364;
   std::complex<double> tmp_3365;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_3366;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_3366 += B1(p,MChi(gI2),MSu(gI1))*Conj(CpbarUFuSuChiPL(gO2,
            gI1,gI2))*CpbarUFuSuChiPL(gO1,gI1,gI2);
      }
      tmp_3365 += tmp_3366;
   }
   tmp_3364 += tmp_3365;
   result += (-0.5) * tmp_3364;
   std::complex<double> tmp_3367;
   std::complex<double> tmp_3368;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_3368 += B1(p,MFd(gI2),MVWm)*Conj(CpbarUFuconjVWmFdPR(gO2,gI2))*
         CpbarUFuconjVWmFdPR(gO1,gI2);
   }
   tmp_3367 += tmp_3368;
   result += (-1) * tmp_3367;
   std::complex<double> tmp_3369;
   std::complex<double> tmp_3370;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_3370 += B1(p,MFu(gI2),0)*Conj(CpbarUFuVGFuPR(gO2,gI2))*
         CpbarUFuVGFuPR(gO1,gI2);
   }
   tmp_3369 += tmp_3370;
   result += (-1.3333333333333333) * tmp_3369;
   std::complex<double> tmp_3371;
   std::complex<double> tmp_3372;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_3372 += B1(p,MFu(gI2),0)*Conj(CpbarUFuVPFuPR(gO2,gI2))*
         CpbarUFuVPFuPR(gO1,gI2);
   }
   tmp_3371 += tmp_3372;
   result += (-1) * tmp_3371;
   std::complex<double> tmp_3373;
   std::complex<double> tmp_3374;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_3374 += B1(p,MFu(gI2),MVZ)*Conj(CpbarUFuVZFuPR(gO2,gI2))*
         CpbarUFuVZFuPR(gO1,gI2);
   }
   tmp_3373 += tmp_3374;
   result += (-1) * tmp_3373;
   std::complex<double> tmp_3375;
   std::complex<double> tmp_3376;
   for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
      tmp_3376 += B1(p,MGlu,MSu(gI2))*Conj(CpbarUFubarGluSuPL(gO2,1,gI2))*
         CpbarUFubarGluSuPL(gO1,1,gI2);
   }
   tmp_3375 += tmp_3376;
   result += (-0.6666666666666666) * tmp_3375;

   return result * oneOver16PiSqr;

}

std::complex<double> CLASSNAME::self_energy_Glu_1(double p ) const
{
   std::complex<double> result;

   std::complex<double> tmp_3377;
   std::complex<double> tmp_3378;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_3379;
      std::complex<double> tmp_3380;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_3380 += B0(p,MFd(gI1),MSd(gI2))*Conj(CpbarGlubarFdSdPL(gI1,
            gI2))*CpbarGlubarFdSdPR(gI1,gI2);
      }
      tmp_3379 += tmp_3380;
      tmp_3378 += (MFd(gI1)) * tmp_3379;
   }
   tmp_3377 += tmp_3378;
   result += (0.5) * tmp_3377;
   std::complex<double> tmp_3381;
   std::complex<double> tmp_3382;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_3383;
      std::complex<double> tmp_3384;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_3384 += B0(p,MFu(gI1),MSu(gI2))*Conj(CpbarGlubarFuSuPL(gI1,
            gI2))*CpbarGlubarFuSuPR(gI1,gI2);
      }
      tmp_3383 += tmp_3384;
      tmp_3382 += (MFu(gI1)) * tmp_3383;
   }
   tmp_3381 += tmp_3382;
   result += (0.5) * tmp_3381;
   std::complex<double> tmp_3385;
   std::complex<double> tmp_3386;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_3387;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_3387 += B0(p,MFd(gI2),MSd(gI1))*Conj(CpbarGluconjSdFdPL(gI1,
            gI2))*CpbarGluconjSdFdPR(gI1,gI2)*MFd(gI2);
      }
      tmp_3386 += tmp_3387;
   }
   tmp_3385 += tmp_3386;
   result += (0.5) * tmp_3385;
   std::complex<double> tmp_3388;
   std::complex<double> tmp_3389;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_3390;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_3390 += B0(p,MFu(gI2),MSu(gI1))*Conj(CpbarGluconjSuFuPL(gI1,
            gI2))*CpbarGluconjSuFuPR(gI1,gI2)*MFu(gI2);
      }
      tmp_3389 += tmp_3390;
   }
   tmp_3388 += tmp_3389;
   result += (0.5) * tmp_3388;
   result += -3*MGlu*B0(p,MGlu,MSOc)*Conj(CpbarGluconjSOcGluPL())*
      CpbarGluconjSOcGluPR();
   result += -12*MGlu*B0(p,MGlu,0)*Conj(CpbarGluVGGluPR())*CpbarGluVGGluPL();

   return result * oneOver16PiSqr;

}

std::complex<double> CLASSNAME::self_energy_Glu_PR(double p ) const
{
   std::complex<double> result;

   result += 1.5*AbsSqr(CpbarGluconjSOcGluPR())*B1(p,MGlu,MSOc);
   result += -3*AbsSqr(CpbarGluVGGluPL())*B1(p,MGlu,0);
   std::complex<double> tmp_3391;
   std::complex<double> tmp_3392;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_3393;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_3393 += AbsSqr(CpbarGlubarFdSdPR(gI1,gI2))*B1(p,MFd(gI1),MSd
            (gI2));
      }
      tmp_3392 += tmp_3393;
   }
   tmp_3391 += tmp_3392;
   result += (-0.25) * tmp_3391;
   std::complex<double> tmp_3394;
   std::complex<double> tmp_3395;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_3396;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_3396 += AbsSqr(CpbarGlubarFuSuPR(gI1,gI2))*B1(p,MFu(gI1),MSu
            (gI2));
      }
      tmp_3395 += tmp_3396;
   }
   tmp_3394 += tmp_3395;
   result += (-0.25) * tmp_3394;
   std::complex<double> tmp_3397;
   std::complex<double> tmp_3398;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_3399;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_3399 += AbsSqr(CpbarGluconjSdFdPR(gI1,gI2))*B1(p,MFd(gI2),
            MSd(gI1));
      }
      tmp_3398 += tmp_3399;
   }
   tmp_3397 += tmp_3398;
   result += (-0.25) * tmp_3397;
   std::complex<double> tmp_3400;
   std::complex<double> tmp_3401;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_3402;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_3402 += AbsSqr(CpbarGluconjSuFuPR(gI1,gI2))*B1(p,MFu(gI2),
            MSu(gI1));
      }
      tmp_3401 += tmp_3402;
   }
   tmp_3400 += tmp_3401;
   result += (-0.25) * tmp_3400;

   return result * oneOver16PiSqr;

}

std::complex<double> CLASSNAME::self_energy_Glu_PL(double p ) const
{
   std::complex<double> result;

   result += 1.5*AbsSqr(CpbarGluconjSOcGluPL())*B1(p,MGlu,MSOc);
   result += -3*AbsSqr(CpbarGluVGGluPR())*B1(p,MGlu,0);
   std::complex<double> tmp_3403;
   std::complex<double> tmp_3404;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_3405;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_3405 += AbsSqr(CpbarGlubarFdSdPL(gI1,gI2))*B1(p,MFd(gI1),MSd
            (gI2));
      }
      tmp_3404 += tmp_3405;
   }
   tmp_3403 += tmp_3404;
   result += (-0.25) * tmp_3403;
   std::complex<double> tmp_3406;
   std::complex<double> tmp_3407;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_3408;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_3408 += AbsSqr(CpbarGlubarFuSuPL(gI1,gI2))*B1(p,MFu(gI1),MSu
            (gI2));
      }
      tmp_3407 += tmp_3408;
   }
   tmp_3406 += tmp_3407;
   result += (-0.25) * tmp_3406;
   std::complex<double> tmp_3409;
   std::complex<double> tmp_3410;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_3411;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_3411 += AbsSqr(CpbarGluconjSdFdPL(gI1,gI2))*B1(p,MFd(gI2),
            MSd(gI1));
      }
      tmp_3410 += tmp_3411;
   }
   tmp_3409 += tmp_3410;
   result += (-0.25) * tmp_3409;
   std::complex<double> tmp_3412;
   std::complex<double> tmp_3413;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_3414;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_3414 += AbsSqr(CpbarGluconjSuFuPL(gI1,gI2))*B1(p,MFu(gI2),
            MSu(gI1));
      }
      tmp_3413 += tmp_3414;
   }
   tmp_3412 += tmp_3413;
   result += (-0.25) * tmp_3412;

   return result * oneOver16PiSqr;

}

std::complex<double> CLASSNAME::self_energy_VZ_heavy(double p ) const
{
   std::complex<double> result;

   std::complex<double> tmp_3415;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      tmp_3415 += A0(MRh(gI1))*CpVZVZconjRhRh(gI1,gI1);
   }
   result += tmp_3415;
   std::complex<double> tmp_3416;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      tmp_3416 += A0(MRpm(gI1))*CpVZVZconjRpmRpm(gI1,gI1);
   }
   result += tmp_3416;
   std::complex<double> tmp_3417;
   std::complex<double> tmp_3418;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_3419;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_3419 += AbsSqr(CpVZconjRhRh(gI1,gI2))*B00(p,MRh(gI1),MRh(gI2
            ));
      }
      tmp_3418 += tmp_3419;
   }
   tmp_3417 += tmp_3418;
   result += (-4) * tmp_3417;
   std::complex<double> tmp_3420;
   std::complex<double> tmp_3421;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_3422;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_3422 += AbsSqr(CpVZconjRpmRpm(gI1,gI2))*B00(p,MRpm(gI1),MRpm
            (gI2));
      }
      tmp_3421 += tmp_3422;
   }
   tmp_3420 += tmp_3421;
   result += (-4) * tmp_3420;
   std::complex<double> tmp_3423;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_3424;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_3424 += (AbsSqr(CpVZbarCha1Cha1PL(gI1,gI2)) + AbsSqr(
            CpVZbarCha1Cha1PR(gI1,gI2)))*H0(p,MCha1(gI1),MCha1(gI2));
         tmp_3424 += 4*B0(p,MCha1(gI1),MCha1(gI2))*MCha1(gI1)*MCha1(gI2)*
            Re(Conj(CpVZbarCha1Cha1PL(gI1,gI2))*CpVZbarCha1Cha1PR(gI1,gI2));
      }
      tmp_3423 += tmp_3424;
   }
   result += tmp_3423;
   std::complex<double> tmp_3425;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_3426;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_3426 += (AbsSqr(CpVZbarCha2Cha2PL(gI1,gI2)) + AbsSqr(
            CpVZbarCha2Cha2PR(gI1,gI2)))*H0(p,MCha2(gI1),MCha2(gI2));
         tmp_3426 += 4*B0(p,MCha2(gI1),MCha2(gI2))*MCha2(gI1)*MCha2(gI2)*
            Re(Conj(CpVZbarCha2Cha2PL(gI1,gI2))*CpVZbarCha2Cha2PR(gI1,gI2));
      }
      tmp_3425 += tmp_3426;
   }
   result += tmp_3425;
   std::complex<double> tmp_3427;
   std::complex<double> tmp_3428;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      tmp_3428 += A0(MAh(1 + gI1))*CpVZVZAhAh(1 + gI1,1 + gI1);
   }
   tmp_3427 += tmp_3428;
   result += (0.5) * tmp_3427;
   std::complex<double> tmp_3429;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      tmp_3429 += A0(MHpm(1 + gI1))*CpVZVZconjHpmHpm(1 + gI1,1 + gI1);
   }
   result += tmp_3429;
   std::complex<double> tmp_3430;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      tmp_3430 += A0(MSv(gI1))*CpVZVZconjSvSv(gI1,gI1);
   }
   result += tmp_3430;
   std::complex<double> tmp_3431;
   std::complex<double> tmp_3432;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_3433;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_3433 += AbsSqr(CpVZconjHpmHpm(1 + gI1,1 + gI2))*B00(p,MHpm(1
            + gI1),MHpm(1 + gI2));
      }
      tmp_3432 += tmp_3433;
   }
   tmp_3431 += tmp_3432;
   result += (-4) * tmp_3431;
   std::complex<double> tmp_3434;
   std::complex<double> tmp_3435;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_3436;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_3436 += AbsSqr(CpVZconjSvSv(gI1,gI2))*B00(p,MSv(gI1),MSv(gI2
            ));
      }
      tmp_3435 += tmp_3436;
   }
   tmp_3434 += tmp_3435;
   result += (-4) * tmp_3434;
   std::complex<double> tmp_3437;
   std::complex<double> tmp_3438;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      tmp_3438 += A0(Mhh(gI1))*CpVZVZhhhh(gI1,gI1);
   }
   tmp_3437 += tmp_3438;
   result += (0.5) * tmp_3437;
   std::complex<double> tmp_3439;
   std::complex<double> tmp_3440;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3441;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_3441 += AbsSqr(CpVZhhAh(gI1,1 + gI2))*B00(p,MAh(1 + gI2),Mhh
            (gI1));
      }
      tmp_3440 += tmp_3441;
   }
   tmp_3439 += tmp_3440;
   result += (-4) * tmp_3439;
   std::complex<double> tmp_3442;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3443;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_3443 += (AbsSqr(CpVZbarChiChiPL(gI1,gI2)) + AbsSqr(
            CpVZbarChiChiPR(gI1,gI2)))*H0(p,MChi(gI1),MChi(gI2));
         tmp_3443 += 4*B0(p,MChi(gI1),MChi(gI2))*MChi(gI1)*MChi(gI2)*Re(
            Conj(CpVZbarChiChiPL(gI1,gI2))*CpVZbarChiChiPR(gI1,gI2));
      }
      tmp_3442 += tmp_3443;
   }
   result += tmp_3442;
   std::complex<double> tmp_3444;
   std::complex<double> tmp_3445;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      tmp_3445 += A0(MSd(gI1))*CpVZVZconjSdSd(gI1,gI1);
   }
   tmp_3444 += tmp_3445;
   result += (3) * tmp_3444;
   std::complex<double> tmp_3446;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      tmp_3446 += A0(MSe(gI1))*CpVZVZconjSeSe(gI1,gI1);
   }
   result += tmp_3446;
   std::complex<double> tmp_3447;
   std::complex<double> tmp_3448;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      tmp_3448 += A0(MSu(gI1))*CpVZVZconjSuSu(gI1,gI1);
   }
   tmp_3447 += tmp_3448;
   result += (3) * tmp_3447;
   std::complex<double> tmp_3449;
   std::complex<double> tmp_3450;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_3451;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_3451 += AbsSqr(CpVZconjSdSd(gI1,gI2))*B00(p,MSd(gI1),MSd(gI2
            ));
      }
      tmp_3450 += tmp_3451;
   }
   tmp_3449 += tmp_3450;
   result += (-12) * tmp_3449;
   std::complex<double> tmp_3452;
   std::complex<double> tmp_3453;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_3454;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_3454 += AbsSqr(CpVZconjSeSe(gI1,gI2))*B00(p,MSe(gI1),MSe(gI2
            ));
      }
      tmp_3453 += tmp_3454;
   }
   tmp_3452 += tmp_3453;
   result += (-4) * tmp_3452;
   std::complex<double> tmp_3455;
   std::complex<double> tmp_3456;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_3457;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_3457 += AbsSqr(CpVZconjSuSu(gI1,gI2))*B00(p,MSu(gI1),MSu(gI2
            ));
      }
      tmp_3456 += tmp_3457;
   }
   tmp_3455 += tmp_3456;
   result += (-12) * tmp_3455;
   std::complex<double> tmp_3458;
   std::complex<double> tmp_3459;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_3459 += AbsSqr(CpVZconjVWmHpm(1 + gI2))*B0(p,MVWm,MHpm(1 + gI2));
   }
   tmp_3458 += tmp_3459;
   result += (2) * tmp_3458;
   std::complex<double> tmp_3460;
   for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
      tmp_3460 += AbsSqr(CpVZVZhh(gI2))*B0(p,MVZ,Mhh(gI2));
   }
   result += tmp_3460;

   return result * oneOver16PiSqr;

}

std::complex<double> CLASSNAME::self_energy_VWm_heavy(double p ) const
{
   std::complex<double> result;

   std::complex<double> tmp_3461;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      tmp_3461 += A0(MRh(gI1))*CpVWmconjVWmconjRhRh(gI1,gI1);
   }
   result += tmp_3461;
   std::complex<double> tmp_3462;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      tmp_3462 += A0(MRpm(gI1))*CpVWmconjVWmconjRpmRpm(gI1,gI1);
   }
   result += tmp_3462;
   std::complex<double> tmp_3463;
   std::complex<double> tmp_3464;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_3465;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_3465 += AbsSqr(CpconjVWmconjRhRpm(gI1,gI2))*B00(p,MRpm(gI2),
            MRh(gI1));
      }
      tmp_3464 += tmp_3465;
   }
   tmp_3463 += tmp_3464;
   result += (-4) * tmp_3463;
   std::complex<double> tmp_3466;
   std::complex<double> tmp_3467;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_3468;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_3468 += AbsSqr(CpconjVWmRpmRh(gI1,gI2))*B00(p,MRh(gI2),MRpm(
            gI1));
      }
      tmp_3467 += tmp_3468;
   }
   tmp_3466 += tmp_3467;
   result += (-4) * tmp_3466;
   std::complex<double> tmp_3469;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_3470;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_3470 += (AbsSqr(CpconjVWmbarCha1ChiPL(gI1,gI2)) + AbsSqr(
            CpconjVWmbarCha1ChiPR(gI1,gI2)))*H0(p,MCha1(gI1),MChi(gI2));
         tmp_3470 += 4*B0(p,MCha1(gI1),MChi(gI2))*MCha1(gI1)*MChi(gI2)*Re
            (Conj(CpconjVWmbarCha1ChiPL(gI1,gI2))*CpconjVWmbarCha1ChiPR(gI1,gI2));
      }
      tmp_3469 += tmp_3470;
   }
   result += tmp_3469;
   std::complex<double> tmp_3471;
   std::complex<double> tmp_3472;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      tmp_3472 += A0(MAh(1 + gI1))*CpVWmconjVWmAhAh(1 + gI1,1 + gI1);
   }
   tmp_3471 += tmp_3472;
   result += (0.5) * tmp_3471;
   std::complex<double> tmp_3473;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      tmp_3473 += A0(MHpm(1 + gI1))*CpVWmconjVWmconjHpmHpm(1 + gI1,1 + gI1);
   }
   result += tmp_3473;
   std::complex<double> tmp_3474;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      tmp_3474 += A0(MSv(gI1))*CpVWmconjVWmconjSvSv(gI1,gI1);
   }
   result += tmp_3474;
   std::complex<double> tmp_3475;
   std::complex<double> tmp_3476;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_3477;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_3477 += AbsSqr(CpconjVWmHpmAh(1 + gI1,1 + gI2))*B00(p,MAh(1
            + gI2),MHpm(1 + gI1));
      }
      tmp_3476 += tmp_3477;
   }
   tmp_3475 += tmp_3476;
   result += (-4) * tmp_3475;
   std::complex<double> tmp_3478;
   std::complex<double> tmp_3479;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_3480;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_3480 += AbsSqr(CpconjVWmHpmhh(1 + gI1,gI2))*B00(p,Mhh(gI2),
            MHpm(1 + gI1));
      }
      tmp_3479 += tmp_3480;
   }
   tmp_3478 += tmp_3479;
   result += (-4) * tmp_3478;
   std::complex<double> tmp_3481;
   std::complex<double> tmp_3482;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_3483;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_3483 += AbsSqr(CpconjVWmconjSvSe(gI1,gI2))*B00(p,MSe(gI2),
            MSv(gI1));
      }
      tmp_3482 += tmp_3483;
   }
   tmp_3481 += tmp_3482;
   result += (-4) * tmp_3481;
   std::complex<double> tmp_3484;
   std::complex<double> tmp_3485;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      tmp_3485 += A0(Mhh(gI1))*CpVWmconjVWmhhhh(gI1,gI1);
   }
   tmp_3484 += tmp_3485;
   result += (0.5) * tmp_3484;
   std::complex<double> tmp_3486;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3487;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_3487 += (AbsSqr(CpconjVWmbarChiCha2PL(gI1,gI2)) + AbsSqr(
            CpconjVWmbarChiCha2PR(gI1,gI2)))*H0(p,MChi(gI1),MCha2(gI2));
         tmp_3487 += 4*B0(p,MChi(gI1),MCha2(gI2))*MCha2(gI2)*MChi(gI1)*Re
            (Conj(CpconjVWmbarChiCha2PL(gI1,gI2))*CpconjVWmbarChiCha2PR(gI1,gI2));
      }
      tmp_3486 += tmp_3487;
   }
   result += tmp_3486;
   std::complex<double> tmp_3488;
   std::complex<double> tmp_3489;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      tmp_3489 += A0(MSd(gI1))*CpVWmconjVWmconjSdSd(gI1,gI1);
   }
   tmp_3488 += tmp_3489;
   result += (3) * tmp_3488;
   std::complex<double> tmp_3490;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      tmp_3490 += A0(MSe(gI1))*CpVWmconjVWmconjSeSe(gI1,gI1);
   }
   result += tmp_3490;
   std::complex<double> tmp_3491;
   std::complex<double> tmp_3492;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      tmp_3492 += A0(MSu(gI1))*CpVWmconjVWmconjSuSu(gI1,gI1);
   }
   tmp_3491 += tmp_3492;
   result += (3) * tmp_3491;
   std::complex<double> tmp_3493;
   std::complex<double> tmp_3494;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_3495;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_3495 += AbsSqr(CpconjVWmconjSuSd(gI1,gI2))*B00(p,MSd(gI2),
            MSu(gI1));
      }
      tmp_3494 += tmp_3495;
   }
   tmp_3493 += tmp_3494;
   result += (-12) * tmp_3493;
   std::complex<double> tmp_3496;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_3496 += AbsSqr(CpconjVWmVPHpm(1 + gI2))*B0(p,0,MHpm(1 + gI2));
   }
   result += tmp_3496;
   std::complex<double> tmp_3497;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_3497 += AbsSqr(CpconjVWmVZHpm(1 + gI2))*B0(p,MVZ,MHpm(1 + gI2));
   }
   result += tmp_3497;
   std::complex<double> tmp_3498;
   for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
      tmp_3498 += AbsSqr(CpconjVWmVWmhh(gI2))*B0(p,MVWm,Mhh(gI2));
   }
   result += tmp_3498;

   return result * oneOver16PiSqr;

}

std::complex<double> CLASSNAME::self_energy_Fe_1_heavy_rotated(double p , unsigned gO1, unsigned gO2) const
{
   std::complex<double> result;

   std::complex<double> tmp_3499;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_3500;
      std::complex<double> tmp_3501;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_3501 += B0(p,MCha1(gI1),MSv(gI2))*Conj(CpbarFebarCha1SvPL(
            gO2,gI1,gI2))*CpbarFebarCha1SvPR(gO1,gI1,gI2);
      }
      tmp_3500 += tmp_3501;
      tmp_3499 += (MCha1(gI1)) * tmp_3500;
   }
   result += tmp_3499;
   std::complex<double> tmp_3502;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_3503;
      std::complex<double> tmp_3504;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_3504 += B0(p,MFe(gI1),MAh(gI2))*Conj(CpbarFeFeAhPL(gO2,gI1,
            gI2))*CpbarFeFeAhPR(gO1,gI1,gI2);
      }
      tmp_3503 += tmp_3504;
      tmp_3502 += (MFe(gI1)) * tmp_3503;
   }
   result += tmp_3502;
   std::complex<double> tmp_3505;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3506;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_3506 += B0(p,MFe(gI2),Mhh(gI1))*Conj(CpbarFehhFePL(gO2,gI1,
            gI2))*CpbarFehhFePR(gO1,gI1,gI2)*MFe(gI2);
      }
      tmp_3505 += tmp_3506;
   }
   result += tmp_3505;
   std::complex<double> tmp_3507;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3508;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_3508 += B0(p,MFv(gI2),MHpm(gI1))*Conj(CpbarFeHpmFvPL(gO2,gI1
            ,gI2))*CpbarFeHpmFvPR(gO1,gI1,gI2)*MFv(gI2);
      }
      tmp_3507 += tmp_3508;
   }
   result += tmp_3507;
   std::complex<double> tmp_3509;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3510;
      std::complex<double> tmp_3511;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_3511 += B0(p,MChi(gI1),MSe(gI2))*Conj(CpbarFebarChiSePL(gO2,
            gI1,gI2))*CpbarFebarChiSePR(gO1,gI1,gI2);
      }
      tmp_3510 += tmp_3511;
      tmp_3509 += (MChi(gI1)) * tmp_3510;
   }
   result += tmp_3509;
   std::complex<double> tmp_3512;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_3513;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_3513 += B0(p,MChi(gI2),MSe(gI1))*Conj(CpbarFeSeChiPL(gO2,gI1
            ,gI2))*CpbarFeSeChiPR(gO1,gI1,gI2)*MChi(gI2);
      }
      tmp_3512 += tmp_3513;
   }
   result += tmp_3512;
   std::complex<double> tmp_3514;
   std::complex<double> tmp_3515;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_3515 += B0(p,MFe(gI2),MVZ)*Conj(CpbarFeVZFePR(gO2,gI2))*
         CpbarFeVZFePL(gO1,gI2)*MFe(gI2);
   }
   tmp_3514 += tmp_3515;
   result += (-4) * tmp_3514;
   std::complex<double> tmp_3516;
   std::complex<double> tmp_3517;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_3517 += B0(p,MFv(gI2),MVWm)*Conj(CpbarFeVWmFvPR(gO2,gI2))*
         CpbarFeVWmFvPL(gO1,gI2)*MFv(gI2);
   }
   tmp_3516 += tmp_3517;
   result += (-4) * tmp_3516;

   return result * oneOver16PiSqr;

}

std::complex<double> CLASSNAME::self_energy_Fe_PR_heavy_rotated(double p , unsigned gO1, unsigned gO2) const
{
   std::complex<double> result;

   std::complex<double> tmp_3518;
   std::complex<double> tmp_3519;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_3520;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_3520 += B1(p,MCha1(gI1),MSv(gI2))*Conj(CpbarFebarCha1SvPR(
            gO2,gI1,gI2))*CpbarFebarCha1SvPR(gO1,gI1,gI2);
      }
      tmp_3519 += tmp_3520;
   }
   tmp_3518 += tmp_3519;
   result += (-0.5) * tmp_3518;
   std::complex<double> tmp_3521;
   std::complex<double> tmp_3522;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_3523;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_3523 += B1(p,MFe(gI1),MAh(gI2))*Conj(CpbarFeFeAhPR(gO2,gI1,
            gI2))*CpbarFeFeAhPR(gO1,gI1,gI2);
      }
      tmp_3522 += tmp_3523;
   }
   tmp_3521 += tmp_3522;
   result += (-0.5) * tmp_3521;
   std::complex<double> tmp_3524;
   std::complex<double> tmp_3525;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3526;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_3526 += B1(p,MFe(gI2),Mhh(gI1))*Conj(CpbarFehhFePR(gO2,gI1,
            gI2))*CpbarFehhFePR(gO1,gI1,gI2);
      }
      tmp_3525 += tmp_3526;
   }
   tmp_3524 += tmp_3525;
   result += (-0.5) * tmp_3524;
   std::complex<double> tmp_3527;
   std::complex<double> tmp_3528;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3529;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_3529 += B1(p,MFv(gI2),MHpm(gI1))*Conj(CpbarFeHpmFvPR(gO2,gI1
            ,gI2))*CpbarFeHpmFvPR(gO1,gI1,gI2);
      }
      tmp_3528 += tmp_3529;
   }
   tmp_3527 += tmp_3528;
   result += (-0.5) * tmp_3527;
   std::complex<double> tmp_3530;
   std::complex<double> tmp_3531;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3532;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_3532 += B1(p,MChi(gI1),MSe(gI2))*Conj(CpbarFebarChiSePR(gO2,
            gI1,gI2))*CpbarFebarChiSePR(gO1,gI1,gI2);
      }
      tmp_3531 += tmp_3532;
   }
   tmp_3530 += tmp_3531;
   result += (-0.5) * tmp_3530;
   std::complex<double> tmp_3533;
   std::complex<double> tmp_3534;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_3535;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_3535 += B1(p,MChi(gI2),MSe(gI1))*Conj(CpbarFeSeChiPR(gO2,gI1
            ,gI2))*CpbarFeSeChiPR(gO1,gI1,gI2);
      }
      tmp_3534 += tmp_3535;
   }
   tmp_3533 += tmp_3534;
   result += (-0.5) * tmp_3533;
   std::complex<double> tmp_3536;
   std::complex<double> tmp_3537;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_3537 += B1(p,MFv(gI2),MVWm)*Conj(CpbarFeVWmFvPL(gO2,gI2))*
         CpbarFeVWmFvPL(gO1,gI2);
   }
   tmp_3536 += tmp_3537;
   result += (-1) * tmp_3536;
   std::complex<double> tmp_3538;
   std::complex<double> tmp_3539;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_3539 += B1(p,MFe(gI2),MVZ)*Conj(CpbarFeVZFePL(gO2,gI2))*
         CpbarFeVZFePL(gO1,gI2);
   }
   tmp_3538 += tmp_3539;
   result += (-1) * tmp_3538;

   return result * oneOver16PiSqr;

}

std::complex<double> CLASSNAME::self_energy_Fe_PL_heavy_rotated(double p , unsigned gO1, unsigned gO2) const
{
   std::complex<double> result;

   std::complex<double> tmp_3540;
   std::complex<double> tmp_3541;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_3542;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_3542 += B1(p,MCha1(gI1),MSv(gI2))*Conj(CpbarFebarCha1SvPL(
            gO2,gI1,gI2))*CpbarFebarCha1SvPL(gO1,gI1,gI2);
      }
      tmp_3541 += tmp_3542;
   }
   tmp_3540 += tmp_3541;
   result += (-0.5) * tmp_3540;
   std::complex<double> tmp_3543;
   std::complex<double> tmp_3544;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_3545;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_3545 += B1(p,MFe(gI1),MAh(gI2))*Conj(CpbarFeFeAhPL(gO2,gI1,
            gI2))*CpbarFeFeAhPL(gO1,gI1,gI2);
      }
      tmp_3544 += tmp_3545;
   }
   tmp_3543 += tmp_3544;
   result += (-0.5) * tmp_3543;
   std::complex<double> tmp_3546;
   std::complex<double> tmp_3547;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3548;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_3548 += B1(p,MFe(gI2),Mhh(gI1))*Conj(CpbarFehhFePL(gO2,gI1,
            gI2))*CpbarFehhFePL(gO1,gI1,gI2);
      }
      tmp_3547 += tmp_3548;
   }
   tmp_3546 += tmp_3547;
   result += (-0.5) * tmp_3546;
   std::complex<double> tmp_3549;
   std::complex<double> tmp_3550;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3551;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_3551 += B1(p,MFv(gI2),MHpm(gI1))*Conj(CpbarFeHpmFvPL(gO2,gI1
            ,gI2))*CpbarFeHpmFvPL(gO1,gI1,gI2);
      }
      tmp_3550 += tmp_3551;
   }
   tmp_3549 += tmp_3550;
   result += (-0.5) * tmp_3549;
   std::complex<double> tmp_3552;
   std::complex<double> tmp_3553;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3554;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_3554 += B1(p,MChi(gI1),MSe(gI2))*Conj(CpbarFebarChiSePL(gO2,
            gI1,gI2))*CpbarFebarChiSePL(gO1,gI1,gI2);
      }
      tmp_3553 += tmp_3554;
   }
   tmp_3552 += tmp_3553;
   result += (-0.5) * tmp_3552;
   std::complex<double> tmp_3555;
   std::complex<double> tmp_3556;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_3557;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_3557 += B1(p,MChi(gI2),MSe(gI1))*Conj(CpbarFeSeChiPL(gO2,gI1
            ,gI2))*CpbarFeSeChiPL(gO1,gI1,gI2);
      }
      tmp_3556 += tmp_3557;
   }
   tmp_3555 += tmp_3556;
   result += (-0.5) * tmp_3555;
   std::complex<double> tmp_3558;
   std::complex<double> tmp_3559;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_3559 += B1(p,MFv(gI2),MVWm)*Conj(CpbarFeVWmFvPR(gO2,gI2))*
         CpbarFeVWmFvPR(gO1,gI2);
   }
   tmp_3558 += tmp_3559;
   result += (-1) * tmp_3558;
   std::complex<double> tmp_3560;
   std::complex<double> tmp_3561;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_3561 += B1(p,MFe(gI2),MVZ)*Conj(CpbarFeVZFePR(gO2,gI2))*
         CpbarFeVZFePR(gO1,gI2);
   }
   tmp_3560 += tmp_3561;
   result += (-1) * tmp_3560;

   return result * oneOver16PiSqr;

}

std::complex<double> CLASSNAME::self_energy_Fd_1_heavy_rotated(double p , unsigned gO1, unsigned gO2) const
{
   std::complex<double> result;

   std::complex<double> tmp_3562;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_3563;
      std::complex<double> tmp_3564;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_3564 += B0(p,MCha1(gI1),MSu(gI2))*Conj(CpbarFdbarCha1SuPL(
            gO2,gI1,gI2))*CpbarFdbarCha1SuPR(gO1,gI1,gI2);
      }
      tmp_3563 += tmp_3564;
      tmp_3562 += (MCha1(gI1)) * tmp_3563;
   }
   result += tmp_3562;
   std::complex<double> tmp_3565;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_3566;
      std::complex<double> tmp_3567;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_3567 += B0(p,MFd(gI1),MAh(gI2))*Conj(CpbarFdFdAhPL(gO2,gI1,
            gI2))*CpbarFdFdAhPR(gO1,gI1,gI2);
      }
      tmp_3566 += tmp_3567;
      tmp_3565 += (MFd(gI1)) * tmp_3566;
   }
   result += tmp_3565;
   std::complex<double> tmp_3568;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3569;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_3569 += B0(p,MFd(gI2),Mhh(gI1))*Conj(CpbarFdhhFdPL(gO2,gI1,
            gI2))*CpbarFdhhFdPR(gO1,gI1,gI2)*MFd(gI2);
      }
      tmp_3568 += tmp_3569;
   }
   result += tmp_3568;
   std::complex<double> tmp_3570;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3571;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_3571 += B0(p,MFu(gI2),MHpm(gI1))*Conj(CpbarFdHpmFuPL(gO2,gI1
            ,gI2))*CpbarFdHpmFuPR(gO1,gI1,gI2)*MFu(gI2);
      }
      tmp_3570 += tmp_3571;
   }
   result += tmp_3570;
   std::complex<double> tmp_3572;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3573;
      std::complex<double> tmp_3574;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_3574 += B0(p,MChi(gI1),MSd(gI2))*Conj(CpbarFdbarChiSdPL(gO2,
            gI1,gI2))*CpbarFdbarChiSdPR(gO1,gI1,gI2);
      }
      tmp_3573 += tmp_3574;
      tmp_3572 += (MChi(gI1)) * tmp_3573;
   }
   result += tmp_3572;
   std::complex<double> tmp_3575;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_3576;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_3576 += B0(p,MCha2(gI2),MSu(gI1))*Conj(CpbarFdSuCha2PL(gO2,
            gI1,gI2))*CpbarFdSuCha2PR(gO1,gI1,gI2)*MCha2(gI2);
      }
      tmp_3575 += tmp_3576;
   }
   result += tmp_3575;
   std::complex<double> tmp_3577;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_3578;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_3578 += B0(p,MChi(gI2),MSd(gI1))*Conj(CpbarFdSdChiPL(gO2,gI1
            ,gI2))*CpbarFdSdChiPR(gO1,gI1,gI2)*MChi(gI2);
      }
      tmp_3577 += tmp_3578;
   }
   result += tmp_3577;
   std::complex<double> tmp_3579;
   std::complex<double> tmp_3580;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_3580 += B0(p,MFd(gI2),MVZ)*Conj(CpbarFdVZFdPR(gO2,gI2))*
         CpbarFdVZFdPL(gO1,gI2)*MFd(gI2);
   }
   tmp_3579 += tmp_3580;
   result += (-4) * tmp_3579;
   std::complex<double> tmp_3581;
   std::complex<double> tmp_3582;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_3582 += B0(p,MFu(gI2),MVWm)*Conj(CpbarFdVWmFuPR(gO2,gI2))*
         CpbarFdVWmFuPL(gO1,gI2)*MFu(gI2);
   }
   tmp_3581 += tmp_3582;
   result += (-4) * tmp_3581;
   std::complex<double> tmp_3583;
   std::complex<double> tmp_3584;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      tmp_3584 += B0(p,MGlu,MSd(gI1))*Conj(CpbarFdSdGluPL(gO2,gI1,1))*
         CpbarFdSdGluPR(gO1,gI1,1);
   }
   tmp_3583 += tmp_3584;
   result += (1.3333333333333333*MGlu) * tmp_3583;
   std::complex<double> tmp_3585;
   std::complex<double> tmp_3586;
   for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
      tmp_3586 += B0(p,MGlu,MSd(gI2))*Conj(CpbarFdbarGluSdPL(gO2,1,gI2))*
         CpbarFdbarGluSdPR(gO1,1,gI2);
   }
   tmp_3585 += tmp_3586;
   result += (1.3333333333333333*MGlu) * tmp_3585;

   return result * oneOver16PiSqr;

}

std::complex<double> CLASSNAME::self_energy_Fd_PR_heavy_rotated(double p , unsigned gO1, unsigned gO2) const
{
   std::complex<double> result;

   std::complex<double> tmp_3587;
   std::complex<double> tmp_3588;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_3589;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_3589 += B1(p,MCha1(gI1),MSu(gI2))*Conj(CpbarFdbarCha1SuPR(
            gO2,gI1,gI2))*CpbarFdbarCha1SuPR(gO1,gI1,gI2);
      }
      tmp_3588 += tmp_3589;
   }
   tmp_3587 += tmp_3588;
   result += (-0.5) * tmp_3587;
   std::complex<double> tmp_3590;
   std::complex<double> tmp_3591;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_3592;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_3592 += B1(p,MFd(gI1),MAh(gI2))*Conj(CpbarFdFdAhPR(gO2,gI1,
            gI2))*CpbarFdFdAhPR(gO1,gI1,gI2);
      }
      tmp_3591 += tmp_3592;
   }
   tmp_3590 += tmp_3591;
   result += (-0.5) * tmp_3590;
   std::complex<double> tmp_3593;
   std::complex<double> tmp_3594;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3595;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_3595 += B1(p,MFd(gI2),Mhh(gI1))*Conj(CpbarFdhhFdPR(gO2,gI1,
            gI2))*CpbarFdhhFdPR(gO1,gI1,gI2);
      }
      tmp_3594 += tmp_3595;
   }
   tmp_3593 += tmp_3594;
   result += (-0.5) * tmp_3593;
   std::complex<double> tmp_3596;
   std::complex<double> tmp_3597;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3598;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_3598 += B1(p,MFu(gI2),MHpm(gI1))*Conj(CpbarFdHpmFuPR(gO2,gI1
            ,gI2))*CpbarFdHpmFuPR(gO1,gI1,gI2);
      }
      tmp_3597 += tmp_3598;
   }
   tmp_3596 += tmp_3597;
   result += (-0.5) * tmp_3596;
   std::complex<double> tmp_3599;
   std::complex<double> tmp_3600;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3601;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_3601 += B1(p,MChi(gI1),MSd(gI2))*Conj(CpbarFdbarChiSdPR(gO2,
            gI1,gI2))*CpbarFdbarChiSdPR(gO1,gI1,gI2);
      }
      tmp_3600 += tmp_3601;
   }
   tmp_3599 += tmp_3600;
   result += (-0.5) * tmp_3599;
   std::complex<double> tmp_3602;
   std::complex<double> tmp_3603;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      tmp_3603 += B1(p,MGlu,MSd(gI1))*Conj(CpbarFdSdGluPR(gO2,gI1,1))*
         CpbarFdSdGluPR(gO1,gI1,1);
   }
   tmp_3602 += tmp_3603;
   result += (-0.6666666666666666) * tmp_3602;
   std::complex<double> tmp_3604;
   std::complex<double> tmp_3605;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_3606;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_3606 += B1(p,MCha2(gI2),MSu(gI1))*Conj(CpbarFdSuCha2PR(gO2,
            gI1,gI2))*CpbarFdSuCha2PR(gO1,gI1,gI2);
      }
      tmp_3605 += tmp_3606;
   }
   tmp_3604 += tmp_3605;
   result += (-0.5) * tmp_3604;
   std::complex<double> tmp_3607;
   std::complex<double> tmp_3608;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_3609;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_3609 += B1(p,MChi(gI2),MSd(gI1))*Conj(CpbarFdSdChiPR(gO2,gI1
            ,gI2))*CpbarFdSdChiPR(gO1,gI1,gI2);
      }
      tmp_3608 += tmp_3609;
   }
   tmp_3607 += tmp_3608;
   result += (-0.5) * tmp_3607;
   std::complex<double> tmp_3610;
   std::complex<double> tmp_3611;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_3611 += B1(p,MFu(gI2),MVWm)*Conj(CpbarFdVWmFuPL(gO2,gI2))*
         CpbarFdVWmFuPL(gO1,gI2);
   }
   tmp_3610 += tmp_3611;
   result += (-1) * tmp_3610;
   std::complex<double> tmp_3612;
   std::complex<double> tmp_3613;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_3613 += B1(p,MFd(gI2),MVZ)*Conj(CpbarFdVZFdPL(gO2,gI2))*
         CpbarFdVZFdPL(gO1,gI2);
   }
   tmp_3612 += tmp_3613;
   result += (-1) * tmp_3612;
   std::complex<double> tmp_3614;
   std::complex<double> tmp_3615;
   for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
      tmp_3615 += B1(p,MGlu,MSd(gI2))*Conj(CpbarFdbarGluSdPR(gO2,1,gI2))*
         CpbarFdbarGluSdPR(gO1,1,gI2);
   }
   tmp_3614 += tmp_3615;
   result += (-0.6666666666666666) * tmp_3614;

   return result * oneOver16PiSqr;

}

std::complex<double> CLASSNAME::self_energy_Fd_PL_heavy_rotated(double p , unsigned gO1, unsigned gO2) const
{
   std::complex<double> result;

   std::complex<double> tmp_3616;
   std::complex<double> tmp_3617;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_3618;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_3618 += B1(p,MCha1(gI1),MSu(gI2))*Conj(CpbarFdbarCha1SuPL(
            gO2,gI1,gI2))*CpbarFdbarCha1SuPL(gO1,gI1,gI2);
      }
      tmp_3617 += tmp_3618;
   }
   tmp_3616 += tmp_3617;
   result += (-0.5) * tmp_3616;
   std::complex<double> tmp_3619;
   std::complex<double> tmp_3620;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_3621;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_3621 += B1(p,MFd(gI1),MAh(gI2))*Conj(CpbarFdFdAhPL(gO2,gI1,
            gI2))*CpbarFdFdAhPL(gO1,gI1,gI2);
      }
      tmp_3620 += tmp_3621;
   }
   tmp_3619 += tmp_3620;
   result += (-0.5) * tmp_3619;
   std::complex<double> tmp_3622;
   std::complex<double> tmp_3623;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3624;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_3624 += B1(p,MFd(gI2),Mhh(gI1))*Conj(CpbarFdhhFdPL(gO2,gI1,
            gI2))*CpbarFdhhFdPL(gO1,gI1,gI2);
      }
      tmp_3623 += tmp_3624;
   }
   tmp_3622 += tmp_3623;
   result += (-0.5) * tmp_3622;
   std::complex<double> tmp_3625;
   std::complex<double> tmp_3626;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3627;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_3627 += B1(p,MFu(gI2),MHpm(gI1))*Conj(CpbarFdHpmFuPL(gO2,gI1
            ,gI2))*CpbarFdHpmFuPL(gO1,gI1,gI2);
      }
      tmp_3626 += tmp_3627;
   }
   tmp_3625 += tmp_3626;
   result += (-0.5) * tmp_3625;
   std::complex<double> tmp_3628;
   std::complex<double> tmp_3629;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3630;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_3630 += B1(p,MChi(gI1),MSd(gI2))*Conj(CpbarFdbarChiSdPL(gO2,
            gI1,gI2))*CpbarFdbarChiSdPL(gO1,gI1,gI2);
      }
      tmp_3629 += tmp_3630;
   }
   tmp_3628 += tmp_3629;
   result += (-0.5) * tmp_3628;
   std::complex<double> tmp_3631;
   std::complex<double> tmp_3632;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      tmp_3632 += B1(p,MGlu,MSd(gI1))*Conj(CpbarFdSdGluPL(gO2,gI1,1))*
         CpbarFdSdGluPL(gO1,gI1,1);
   }
   tmp_3631 += tmp_3632;
   result += (-0.6666666666666666) * tmp_3631;
   std::complex<double> tmp_3633;
   std::complex<double> tmp_3634;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_3635;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_3635 += B1(p,MCha2(gI2),MSu(gI1))*Conj(CpbarFdSuCha2PL(gO2,
            gI1,gI2))*CpbarFdSuCha2PL(gO1,gI1,gI2);
      }
      tmp_3634 += tmp_3635;
   }
   tmp_3633 += tmp_3634;
   result += (-0.5) * tmp_3633;
   std::complex<double> tmp_3636;
   std::complex<double> tmp_3637;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_3638;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_3638 += B1(p,MChi(gI2),MSd(gI1))*Conj(CpbarFdSdChiPL(gO2,gI1
            ,gI2))*CpbarFdSdChiPL(gO1,gI1,gI2);
      }
      tmp_3637 += tmp_3638;
   }
   tmp_3636 += tmp_3637;
   result += (-0.5) * tmp_3636;
   std::complex<double> tmp_3639;
   std::complex<double> tmp_3640;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_3640 += B1(p,MFu(gI2),MVWm)*Conj(CpbarFdVWmFuPR(gO2,gI2))*
         CpbarFdVWmFuPR(gO1,gI2);
   }
   tmp_3639 += tmp_3640;
   result += (-1) * tmp_3639;
   std::complex<double> tmp_3641;
   std::complex<double> tmp_3642;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_3642 += B1(p,MFd(gI2),MVZ)*Conj(CpbarFdVZFdPR(gO2,gI2))*
         CpbarFdVZFdPR(gO1,gI2);
   }
   tmp_3641 += tmp_3642;
   result += (-1) * tmp_3641;
   std::complex<double> tmp_3643;
   std::complex<double> tmp_3644;
   for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
      tmp_3644 += B1(p,MGlu,MSd(gI2))*Conj(CpbarFdbarGluSdPL(gO2,1,gI2))*
         CpbarFdbarGluSdPL(gO1,1,gI2);
   }
   tmp_3643 += tmp_3644;
   result += (-0.6666666666666666) * tmp_3643;

   return result * oneOver16PiSqr;

}

std::complex<double> CLASSNAME::self_energy_Fu_1_heavy_rotated(double p , unsigned gO1, unsigned gO2) const
{
   std::complex<double> result;

   std::complex<double> tmp_3645;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_3646;
      std::complex<double> tmp_3647;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_3647 += B0(p,MCha2(gI1),MSd(gI2))*Conj(CpbarFubarCha2SdPL(
            gO2,gI1,gI2))*CpbarFubarCha2SdPR(gO1,gI1,gI2);
      }
      tmp_3646 += tmp_3647;
      tmp_3645 += (MCha2(gI1)) * tmp_3646;
   }
   result += tmp_3645;
   std::complex<double> tmp_3648;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_3649;
      std::complex<double> tmp_3650;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_3650 += B0(p,MFu(gI1),MAh(gI2))*Conj(CpbarFuFuAhPL(gO2,gI1,
            gI2))*CpbarFuFuAhPR(gO1,gI1,gI2);
      }
      tmp_3649 += tmp_3650;
      tmp_3648 += (MFu(gI1)) * tmp_3649;
   }
   result += tmp_3648;
   std::complex<double> tmp_3651;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3652;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_3652 += B0(p,MFd(gI2),MHpm(gI1))*Conj(CpbarFuconjHpmFdPL(gO2
            ,gI1,gI2))*CpbarFuconjHpmFdPR(gO1,gI1,gI2)*MFd(gI2);
      }
      tmp_3651 += tmp_3652;
   }
   result += tmp_3651;
   std::complex<double> tmp_3653;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3654;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_3654 += B0(p,MFu(gI2),Mhh(gI1))*Conj(CpbarFuhhFuPL(gO2,gI1,
            gI2))*CpbarFuhhFuPR(gO1,gI1,gI2)*MFu(gI2);
      }
      tmp_3653 += tmp_3654;
   }
   result += tmp_3653;
   std::complex<double> tmp_3655;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3656;
      std::complex<double> tmp_3657;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_3657 += B0(p,MChi(gI1),MSu(gI2))*Conj(CpbarFubarChiSuPL(gO2,
            gI1,gI2))*CpbarFubarChiSuPR(gO1,gI1,gI2);
      }
      tmp_3656 += tmp_3657;
      tmp_3655 += (MChi(gI1)) * tmp_3656;
   }
   result += tmp_3655;
   std::complex<double> tmp_3658;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_3659;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_3659 += B0(p,MCha1(gI2),MSd(gI1))*Conj(CpbarFuSdCha1PL(gO2,
            gI1,gI2))*CpbarFuSdCha1PR(gO1,gI1,gI2)*MCha1(gI2);
      }
      tmp_3658 += tmp_3659;
   }
   result += tmp_3658;
   std::complex<double> tmp_3660;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_3661;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_3661 += B0(p,MChi(gI2),MSu(gI1))*Conj(CpbarFuSuChiPL(gO2,gI1
            ,gI2))*CpbarFuSuChiPR(gO1,gI1,gI2)*MChi(gI2);
      }
      tmp_3660 += tmp_3661;
   }
   result += tmp_3660;
   std::complex<double> tmp_3662;
   std::complex<double> tmp_3663;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_3663 += B0(p,MFd(gI2),MVWm)*Conj(CpbarFuconjVWmFdPR(gO2,gI2))*
         CpbarFuconjVWmFdPL(gO1,gI2)*MFd(gI2);
   }
   tmp_3662 += tmp_3663;
   result += (-4) * tmp_3662;
   std::complex<double> tmp_3664;
   std::complex<double> tmp_3665;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_3665 += B0(p,MFu(gI2),0)*Conj(CpbarFuVPFuPR(gO2,gI2))*
         CpbarFuVPFuPL(gO1,gI2)*MFu(gI2);
   }
   tmp_3664 += tmp_3665;
   result += (-4) * tmp_3664;
   std::complex<double> tmp_3666;
   std::complex<double> tmp_3667;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_3667 += B0(p,MFu(gI2),MVZ)*Conj(CpbarFuVZFuPR(gO2,gI2))*
         CpbarFuVZFuPL(gO1,gI2)*MFu(gI2);
   }
   tmp_3666 += tmp_3667;
   result += (-4) * tmp_3666;
   std::complex<double> tmp_3668;
   std::complex<double> tmp_3669;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      tmp_3669 += B0(p,MGlu,MSu(gI1))*Conj(CpbarFuSuGluPL(gO2,gI1,1))*
         CpbarFuSuGluPR(gO1,gI1,1);
   }
   tmp_3668 += tmp_3669;
   result += (1.3333333333333333*MGlu) * tmp_3668;
   std::complex<double> tmp_3670;
   std::complex<double> tmp_3671;
   for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
      tmp_3671 += B0(p,MGlu,MSu(gI2))*Conj(CpbarFubarGluSuPL(gO2,1,gI2))*
         CpbarFubarGluSuPR(gO1,1,gI2);
   }
   tmp_3670 += tmp_3671;
   result += (1.3333333333333333*MGlu) * tmp_3670;

   return result * oneOver16PiSqr;

}

std::complex<double> CLASSNAME::self_energy_Fu_PR_heavy_rotated(double p , unsigned gO1, unsigned gO2) const
{
   std::complex<double> result;

   std::complex<double> tmp_3672;
   std::complex<double> tmp_3673;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_3674;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_3674 += B1(p,MCha2(gI1),MSd(gI2))*Conj(CpbarFubarCha2SdPR(
            gO2,gI1,gI2))*CpbarFubarCha2SdPR(gO1,gI1,gI2);
      }
      tmp_3673 += tmp_3674;
   }
   tmp_3672 += tmp_3673;
   result += (-0.5) * tmp_3672;
   std::complex<double> tmp_3675;
   std::complex<double> tmp_3676;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_3677;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_3677 += B1(p,MFu(gI1),MAh(gI2))*Conj(CpbarFuFuAhPR(gO2,gI1,
            gI2))*CpbarFuFuAhPR(gO1,gI1,gI2);
      }
      tmp_3676 += tmp_3677;
   }
   tmp_3675 += tmp_3676;
   result += (-0.5) * tmp_3675;
   std::complex<double> tmp_3678;
   std::complex<double> tmp_3679;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3680;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_3680 += B1(p,MFd(gI2),MHpm(gI1))*Conj(CpbarFuconjHpmFdPR(gO2
            ,gI1,gI2))*CpbarFuconjHpmFdPR(gO1,gI1,gI2);
      }
      tmp_3679 += tmp_3680;
   }
   tmp_3678 += tmp_3679;
   result += (-0.5) * tmp_3678;
   std::complex<double> tmp_3681;
   std::complex<double> tmp_3682;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3683;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_3683 += B1(p,MFu(gI2),Mhh(gI1))*Conj(CpbarFuhhFuPR(gO2,gI1,
            gI2))*CpbarFuhhFuPR(gO1,gI1,gI2);
      }
      tmp_3682 += tmp_3683;
   }
   tmp_3681 += tmp_3682;
   result += (-0.5) * tmp_3681;
   std::complex<double> tmp_3684;
   std::complex<double> tmp_3685;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3686;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_3686 += B1(p,MChi(gI1),MSu(gI2))*Conj(CpbarFubarChiSuPR(gO2,
            gI1,gI2))*CpbarFubarChiSuPR(gO1,gI1,gI2);
      }
      tmp_3685 += tmp_3686;
   }
   tmp_3684 += tmp_3685;
   result += (-0.5) * tmp_3684;
   std::complex<double> tmp_3687;
   std::complex<double> tmp_3688;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      tmp_3688 += B1(p,MGlu,MSu(gI1))*Conj(CpbarFuSuGluPR(gO2,gI1,1))*
         CpbarFuSuGluPR(gO1,gI1,1);
   }
   tmp_3687 += tmp_3688;
   result += (-0.6666666666666666) * tmp_3687;
   std::complex<double> tmp_3689;
   std::complex<double> tmp_3690;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_3691;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_3691 += B1(p,MCha1(gI2),MSd(gI1))*Conj(CpbarFuSdCha1PR(gO2,
            gI1,gI2))*CpbarFuSdCha1PR(gO1,gI1,gI2);
      }
      tmp_3690 += tmp_3691;
   }
   tmp_3689 += tmp_3690;
   result += (-0.5) * tmp_3689;
   std::complex<double> tmp_3692;
   std::complex<double> tmp_3693;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_3694;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_3694 += B1(p,MChi(gI2),MSu(gI1))*Conj(CpbarFuSuChiPR(gO2,gI1
            ,gI2))*CpbarFuSuChiPR(gO1,gI1,gI2);
      }
      tmp_3693 += tmp_3694;
   }
   tmp_3692 += tmp_3693;
   result += (-0.5) * tmp_3692;
   std::complex<double> tmp_3695;
   std::complex<double> tmp_3696;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_3696 += B1(p,MFd(gI2),MVWm)*Conj(CpbarFuconjVWmFdPL(gO2,gI2))*
         CpbarFuconjVWmFdPL(gO1,gI2);
   }
   tmp_3695 += tmp_3696;
   result += (-1) * tmp_3695;
   std::complex<double> tmp_3697;
   std::complex<double> tmp_3698;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_3698 += B1(p,MFu(gI2),0)*Conj(CpbarFuVPFuPL(gO2,gI2))*
         CpbarFuVPFuPL(gO1,gI2);
   }
   tmp_3697 += tmp_3698;
   result += (-1) * tmp_3697;
   std::complex<double> tmp_3699;
   std::complex<double> tmp_3700;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_3700 += B1(p,MFu(gI2),MVZ)*Conj(CpbarFuVZFuPL(gO2,gI2))*
         CpbarFuVZFuPL(gO1,gI2);
   }
   tmp_3699 += tmp_3700;
   result += (-1) * tmp_3699;
   std::complex<double> tmp_3701;
   std::complex<double> tmp_3702;
   for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
      tmp_3702 += B1(p,MGlu,MSu(gI2))*Conj(CpbarFubarGluSuPR(gO2,1,gI2))*
         CpbarFubarGluSuPR(gO1,1,gI2);
   }
   tmp_3701 += tmp_3702;
   result += (-0.6666666666666666) * tmp_3701;

   return result * oneOver16PiSqr;

}

std::complex<double> CLASSNAME::self_energy_Fu_PL_heavy_rotated(double p , unsigned gO1, unsigned gO2) const
{
   std::complex<double> result;

   std::complex<double> tmp_3703;
   std::complex<double> tmp_3704;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      std::complex<double> tmp_3705;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_3705 += B1(p,MCha2(gI1),MSd(gI2))*Conj(CpbarFubarCha2SdPL(
            gO2,gI1,gI2))*CpbarFubarCha2SdPL(gO1,gI1,gI2);
      }
      tmp_3704 += tmp_3705;
   }
   tmp_3703 += tmp_3704;
   result += (-0.5) * tmp_3703;
   std::complex<double> tmp_3706;
   std::complex<double> tmp_3707;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      std::complex<double> tmp_3708;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_3708 += B1(p,MFu(gI1),MAh(gI2))*Conj(CpbarFuFuAhPL(gO2,gI1,
            gI2))*CpbarFuFuAhPL(gO1,gI1,gI2);
      }
      tmp_3707 += tmp_3708;
   }
   tmp_3706 += tmp_3707;
   result += (-0.5) * tmp_3706;
   std::complex<double> tmp_3709;
   std::complex<double> tmp_3710;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3711;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_3711 += B1(p,MFd(gI2),MHpm(gI1))*Conj(CpbarFuconjHpmFdPL(gO2
            ,gI1,gI2))*CpbarFuconjHpmFdPL(gO1,gI1,gI2);
      }
      tmp_3710 += tmp_3711;
   }
   tmp_3709 += tmp_3710;
   result += (-0.5) * tmp_3709;
   std::complex<double> tmp_3712;
   std::complex<double> tmp_3713;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3714;
      for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
         tmp_3714 += B1(p,MFu(gI2),Mhh(gI1))*Conj(CpbarFuhhFuPL(gO2,gI1,
            gI2))*CpbarFuhhFuPL(gO1,gI1,gI2);
      }
      tmp_3713 += tmp_3714;
   }
   tmp_3712 += tmp_3713;
   result += (-0.5) * tmp_3712;
   std::complex<double> tmp_3715;
   std::complex<double> tmp_3716;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      std::complex<double> tmp_3717;
      for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
         tmp_3717 += B1(p,MChi(gI1),MSu(gI2))*Conj(CpbarFubarChiSuPL(gO2,
            gI1,gI2))*CpbarFubarChiSuPL(gO1,gI1,gI2);
      }
      tmp_3716 += tmp_3717;
   }
   tmp_3715 += tmp_3716;
   result += (-0.5) * tmp_3715;
   std::complex<double> tmp_3718;
   std::complex<double> tmp_3719;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      tmp_3719 += B1(p,MGlu,MSu(gI1))*Conj(CpbarFuSuGluPL(gO2,gI1,1))*
         CpbarFuSuGluPL(gO1,gI1,1);
   }
   tmp_3718 += tmp_3719;
   result += (-0.6666666666666666) * tmp_3718;
   std::complex<double> tmp_3720;
   std::complex<double> tmp_3721;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_3722;
      for (unsigned gI2 = 0; gI2 < 2; ++gI2) {
         tmp_3722 += B1(p,MCha1(gI2),MSd(gI1))*Conj(CpbarFuSdCha1PL(gO2,
            gI1,gI2))*CpbarFuSdCha1PL(gO1,gI1,gI2);
      }
      tmp_3721 += tmp_3722;
   }
   tmp_3720 += tmp_3721;
   result += (-0.5) * tmp_3720;
   std::complex<double> tmp_3723;
   std::complex<double> tmp_3724;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      std::complex<double> tmp_3725;
      for (unsigned gI2 = 0; gI2 < 4; ++gI2) {
         tmp_3725 += B1(p,MChi(gI2),MSu(gI1))*Conj(CpbarFuSuChiPL(gO2,gI1
            ,gI2))*CpbarFuSuChiPL(gO1,gI1,gI2);
      }
      tmp_3724 += tmp_3725;
   }
   tmp_3723 += tmp_3724;
   result += (-0.5) * tmp_3723;
   std::complex<double> tmp_3726;
   std::complex<double> tmp_3727;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_3727 += B1(p,MFd(gI2),MVWm)*Conj(CpbarFuconjVWmFdPR(gO2,gI2))*
         CpbarFuconjVWmFdPR(gO1,gI2);
   }
   tmp_3726 += tmp_3727;
   result += (-1) * tmp_3726;
   std::complex<double> tmp_3728;
   std::complex<double> tmp_3729;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_3729 += B1(p,MFu(gI2),0)*Conj(CpbarFuVPFuPR(gO2,gI2))*
         CpbarFuVPFuPR(gO1,gI2);
   }
   tmp_3728 += tmp_3729;
   result += (-1) * tmp_3728;
   std::complex<double> tmp_3730;
   std::complex<double> tmp_3731;
   for (unsigned gI2 = 0; gI2 < 3; ++gI2) {
      tmp_3731 += B1(p,MFu(gI2),MVZ)*Conj(CpbarFuVZFuPR(gO2,gI2))*
         CpbarFuVZFuPR(gO1,gI2);
   }
   tmp_3730 += tmp_3731;
   result += (-1) * tmp_3730;
   std::complex<double> tmp_3732;
   std::complex<double> tmp_3733;
   for (unsigned gI2 = 0; gI2 < 6; ++gI2) {
      tmp_3733 += B1(p,MGlu,MSu(gI2))*Conj(CpbarFubarGluSuPL(gO2,1,gI2))*
         CpbarFubarGluSuPL(gO1,1,gI2);
   }
   tmp_3732 += tmp_3733;
   result += (-0.6666666666666666) * tmp_3732;

   return result * oneOver16PiSqr;

}

std::complex<double> CLASSNAME::tadpole_hh(unsigned gO1) const
{
   std::complex<double> result;

   result += A0(MVWm)*CpUhhbargWmCgWmC(gO1);
   result += A0(MVWm)*CpUhhbargWmgWm(gO1);
   result += A0(MVZ)*CpUhhbargZgZ(gO1);
   result += 4*A0(MVWm)*CpUhhconjVWmVWm(gO1);
   result += 2*A0(MVZ)*CpUhhVZVZ(gO1);
   std::complex<double> tmp_3734;
   std::complex<double> tmp_3735;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      tmp_3735 += A0(MRh(gI1))*CpUhhconjRhRh(gO1,gI1,gI1);
   }
   tmp_3734 += tmp_3735;
   result += (-1) * tmp_3734;
   std::complex<double> tmp_3736;
   std::complex<double> tmp_3737;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      tmp_3737 += A0(MRpm(gI1))*CpUhhconjRpmRpm(gO1,gI1,gI1);
   }
   tmp_3736 += tmp_3737;
   result += (-1) * tmp_3736;
   std::complex<double> tmp_3738;
   std::complex<double> tmp_3739;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      tmp_3739 += A0(MCha1(gI1))*(CpUhhbarCha1Cha1PL(gO1,gI1,gI1) +
         CpUhhbarCha1Cha1PR(gO1,gI1,gI1))*MCha1(gI1);
   }
   tmp_3738 += tmp_3739;
   result += (2) * tmp_3738;
   std::complex<double> tmp_3740;
   std::complex<double> tmp_3741;
   for (unsigned gI1 = 0; gI1 < 2; ++gI1) {
      tmp_3741 += A0(MCha2(gI1))*(CpUhhbarCha2Cha2PL(gO1,gI1,gI1) +
         CpUhhbarCha2Cha2PR(gO1,gI1,gI1))*MCha2(gI1);
   }
   tmp_3740 += tmp_3741;
   result += (2) * tmp_3740;
   std::complex<double> tmp_3742;
   std::complex<double> tmp_3743;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      tmp_3743 += A0(MSv(gI1))*CpUhhconjSvSv(gO1,gI1,gI1);
   }
   tmp_3742 += tmp_3743;
   result += (-1) * tmp_3742;
   std::complex<double> tmp_3744;
   std::complex<double> tmp_3745;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      tmp_3745 += A0(MFd(gI1))*(CpUhhbarFdFdPL(gO1,gI1,gI1) + CpUhhbarFdFdPR
         (gO1,gI1,gI1))*MFd(gI1);
   }
   tmp_3744 += tmp_3745;
   result += (6) * tmp_3744;
   std::complex<double> tmp_3746;
   std::complex<double> tmp_3747;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      tmp_3747 += A0(MFe(gI1))*(CpUhhbarFeFePL(gO1,gI1,gI1) + CpUhhbarFeFePR
         (gO1,gI1,gI1))*MFe(gI1);
   }
   tmp_3746 += tmp_3747;
   result += (2) * tmp_3746;
   std::complex<double> tmp_3748;
   std::complex<double> tmp_3749;
   for (unsigned gI1 = 0; gI1 < 3; ++gI1) {
      tmp_3749 += A0(MFu(gI1))*(CpUhhbarFuFuPL(gO1,gI1,gI1) + CpUhhbarFuFuPR
         (gO1,gI1,gI1))*MFu(gI1);
   }
   tmp_3748 += tmp_3749;
   result += (6) * tmp_3748;
   std::complex<double> tmp_3750;
   std::complex<double> tmp_3751;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      tmp_3751 += A0(MAh(gI1))*CpUhhAhAh(gO1,gI1,gI1);
   }
   tmp_3750 += tmp_3751;
   result += (-0.5) * tmp_3750;
   std::complex<double> tmp_3752;
   std::complex<double> tmp_3753;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      tmp_3753 += A0(MHpm(gI1))*CpUhhconjHpmHpm(gO1,gI1,gI1);
   }
   tmp_3752 += tmp_3753;
   result += (-1) * tmp_3752;
   std::complex<double> tmp_3754;
   std::complex<double> tmp_3755;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      tmp_3755 += A0(Mhh(gI1))*CpUhhhhhh(gO1,gI1,gI1);
   }
   tmp_3754 += tmp_3755;
   result += (-0.5) * tmp_3754;
   std::complex<double> tmp_3756;
   std::complex<double> tmp_3757;
   for (unsigned gI1 = 0; gI1 < 4; ++gI1) {
      tmp_3757 += A0(MChi(gI1))*(CpUhhbarChiChiPL(gO1,gI1,gI1) +
         CpUhhbarChiChiPR(gO1,gI1,gI1))*MChi(gI1);
   }
   tmp_3756 += tmp_3757;
   result += (2) * tmp_3756;
   std::complex<double> tmp_3758;
   std::complex<double> tmp_3759;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      tmp_3759 += A0(MSd(gI1))*CpUhhconjSdSd(gO1,gI1,gI1);
   }
   tmp_3758 += tmp_3759;
   result += (-3) * tmp_3758;
   std::complex<double> tmp_3760;
   std::complex<double> tmp_3761;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      tmp_3761 += A0(MSe(gI1))*CpUhhconjSeSe(gO1,gI1,gI1);
   }
   tmp_3760 += tmp_3761;
   result += (-1) * tmp_3760;
   std::complex<double> tmp_3762;
   std::complex<double> tmp_3763;
   for (unsigned gI1 = 0; gI1 < 6; ++gI1) {
      tmp_3763 += A0(MSu(gI1))*CpUhhconjSuSu(gO1,gI1,gI1);
   }
   tmp_3762 += tmp_3763;
   result += (-3) * tmp_3762;

   return result * oneOver16PiSqr;

}








void CLASSNAME::calculate_MGlu_pole()
{
   // diagonalization with medium precision
   const double p = MGlu;
   const double self_energy_1  = Re(self_energy_Glu_1(p));
   const double self_energy_PL = Re(self_energy_Glu_PL(p));
   const double self_energy_PR = Re(self_energy_Glu_PR(p));
   PHYSICAL(MGlu) = MGlu - self_energy_1 - MGlu * (self_energy_PL +
      self_energy_PR);
}

void CLASSNAME::calculate_MFv_pole()
{
   // diagonalization with medium precision
   PHYSICAL(MFv).setConstant(0.);
}

void CLASSNAME::calculate_MSOc_pole()
{
   if (problems.is_tachyon(SOc))
      return;
   // diagonalization with medium precision
   const double p = MSOc;
   const double self_energy = Re(self_energy_SOc(p));
   const double mass_sqr = Sqr(MSOc) - self_energy;

   if (mass_sqr < 0.)
      problems.flag_tachyon(SOc);

   PHYSICAL(MSOc) = AbsSqrt(mass_sqr);
}

void CLASSNAME::calculate_MVZ_pole()
{
   if (problems.is_tachyon(VZ))
      return;
   // diagonalization with medium precision
   const double p = MVZ;
   const double self_energy = Re(self_energy_VZ(p));
   const double mass_sqr = Sqr(MVZ) - self_energy;

   if (mass_sqr < 0.)
      problems.flag_tachyon(VZ);

   PHYSICAL(MVZ) = AbsSqrt(mass_sqr);
}

void CLASSNAME::calculate_MSd_pole()
{
   if (problems.is_tachyon(Sd))
      return;
   // diagonalization with medium precision
   Eigen::Matrix<double,6,6> self_energy;
   const Eigen::Matrix<double,6,6> M_tree(get_mass_matrix_Sd());

   for (unsigned es = 0; es < 6; ++es) {
      const double p = Abs(MSd(es));
      for (unsigned i1 = 0; i1 < 6; ++i1) {
         for (unsigned i2 = i1; i2 < 6; ++i2) {
            self_energy(i1,i2) = Re(self_energy_Sd(p,i1,i2));
         }
      }

      Symmetrize(self_energy);
      const Eigen::Matrix<double,6,6> M_1loop(M_tree - self_energy);
      Eigen::Array<double,6,1> eigen_values;
      Eigen::Matrix<double,6,6> mix_ZD;
      fs_diagonalize_hermitian(M_1loop, eigen_values, mix_ZD);

      if (eigen_values(es) < 0.)
         problems.flag_tachyon(Sd);

      PHYSICAL(MSd(es)) = AbsSqrt(eigen_values(es));
      if (es == 0)
         PHYSICAL(ZD) = mix_ZD;
   }
}

void CLASSNAME::calculate_MSv_pole()
{
   if (problems.is_tachyon(Sv))
      return;
   // diagonalization with medium precision
   Eigen::Matrix<double,3,3> self_energy;
   const Eigen::Matrix<double,3,3> M_tree(get_mass_matrix_Sv());

   for (unsigned es = 0; es < 3; ++es) {
      const double p = Abs(MSv(es));
      for (unsigned i1 = 0; i1 < 3; ++i1) {
         for (unsigned i2 = i1; i2 < 3; ++i2) {
            self_energy(i1,i2) = Re(self_energy_Sv(p,i1,i2));
         }
      }

      Symmetrize(self_energy);
      const Eigen::Matrix<double,3,3> M_1loop(M_tree - self_energy);
      Eigen::Array<double,3,1> eigen_values;
      Eigen::Matrix<double,3,3> mix_ZV;
      fs_diagonalize_hermitian(M_1loop, eigen_values, mix_ZV);

      if (eigen_values(es) < 0.)
         problems.flag_tachyon(Sv);

      PHYSICAL(MSv(es)) = AbsSqrt(eigen_values(es));
      if (es == 0)
         PHYSICAL(ZV) = mix_ZV;
   }
}

void CLASSNAME::calculate_MSu_pole()
{
   if (problems.is_tachyon(Su))
      return;
   // diagonalization with medium precision
   Eigen::Matrix<double,6,6> self_energy;
   const Eigen::Matrix<double,6,6> M_tree(get_mass_matrix_Su());

   for (unsigned es = 0; es < 6; ++es) {
      const double p = Abs(MSu(es));
      for (unsigned i1 = 0; i1 < 6; ++i1) {
         for (unsigned i2 = i1; i2 < 6; ++i2) {
            self_energy(i1,i2) = Re(self_energy_Su(p,i1,i2));
         }
      }

      Symmetrize(self_energy);
      const Eigen::Matrix<double,6,6> M_1loop(M_tree - self_energy);
      Eigen::Array<double,6,1> eigen_values;
      Eigen::Matrix<double,6,6> mix_ZU;
      fs_diagonalize_hermitian(M_1loop, eigen_values, mix_ZU);

      if (eigen_values(es) < 0.)
         problems.flag_tachyon(Su);

      PHYSICAL(MSu(es)) = AbsSqrt(eigen_values(es));
      if (es == 0)
         PHYSICAL(ZU) = mix_ZU;
   }
}

void CLASSNAME::calculate_MSe_pole()
{
   if (problems.is_tachyon(Se))
      return;
   // diagonalization with medium precision
   Eigen::Matrix<double,6,6> self_energy;
   const Eigen::Matrix<double,6,6> M_tree(get_mass_matrix_Se());

   for (unsigned es = 0; es < 6; ++es) {
      const double p = Abs(MSe(es));
      for (unsigned i1 = 0; i1 < 6; ++i1) {
         for (unsigned i2 = i1; i2 < 6; ++i2) {
            self_energy(i1,i2) = Re(self_energy_Se(p,i1,i2));
         }
      }

      Symmetrize(self_energy);
      const Eigen::Matrix<double,6,6> M_1loop(M_tree - self_energy);
      Eigen::Array<double,6,1> eigen_values;
      Eigen::Matrix<double,6,6> mix_ZE;
      fs_diagonalize_hermitian(M_1loop, eigen_values, mix_ZE);

      if (eigen_values(es) < 0.)
         problems.flag_tachyon(Se);

      PHYSICAL(MSe(es)) = AbsSqrt(eigen_values(es));
      if (es == 0)
         PHYSICAL(ZE) = mix_ZE;
   }
}

void CLASSNAME::calculate_Mhh_pole()
{
   if (problems.is_tachyon(hh))
      return;
   // diagonalization with high precision
   unsigned iteration = 0;
   double diff = 0.0;
   decltype(Mhh) old_Mhh(Mhh), new_Mhh(Mhh);

   do {
      Eigen::Matrix<double,4,4> self_energy;
      const Eigen::Matrix<double,4,4> M_tree(get_mass_matrix_hh());

      for (unsigned es = 0; es < 4; ++es) {
         const double p = Abs(old_Mhh(es));
         for (unsigned i1 = 0; i1 < 4; ++i1) {
            for (unsigned i2 = i1; i2 < 4; ++i2) {
               self_energy(i1,i2) = Re(self_energy_hh(p,i1,i2
                  ));
            }
         }

         Symmetrize(self_energy);
         const Eigen::Matrix<double,4,4> M_1loop(M_tree -
            self_energy);
         Eigen::Array<double,4,1> eigen_values;
         Eigen::Matrix<double,4,4> mix_ZH;
         fs_diagonalize_hermitian(M_1loop, eigen_values, mix_ZH);

         if (eigen_values(es) < 0.)
            problems.flag_tachyon(hh);

         PHYSICAL(Mhh(es)) = AbsSqrt(eigen_values(es));
         if (es == 0)
            PHYSICAL(ZH) = mix_ZH;
      }

      new_Mhh = PHYSICAL(Mhh);
      diff = MaxRelDiff(new_Mhh, old_Mhh);
      old_Mhh = new_Mhh;
      iteration++;
   } while (diff > precision
            && iteration < number_of_mass_iterations);
}

void CLASSNAME::calculate_MAh_pole()
{
   if (problems.is_tachyon(Ah))
      return;
   // diagonalization with high precision
   unsigned iteration = 0;
   double diff = 0.0;
   decltype(MAh) old_MAh(MAh), new_MAh(MAh);

   do {
      Eigen::Matrix<double,4,4> self_energy;
      const Eigen::Matrix<double,4,4> M_tree(get_mass_matrix_Ah());

      for (unsigned es = 0; es < 4; ++es) {
         const double p = Abs(old_MAh(es));
         for (unsigned i1 = 0; i1 < 4; ++i1) {
            for (unsigned i2 = i1; i2 < 4; ++i2) {
               self_energy(i1,i2) = Re(self_energy_Ah(p,i1,i2
                  ));
            }
         }

         Symmetrize(self_energy);
         const Eigen::Matrix<double,4,4> M_1loop(M_tree -
            self_energy);
         Eigen::Array<double,4,1> eigen_values;
         Eigen::Matrix<double,4,4> mix_ZA;
         fs_diagonalize_hermitian(M_1loop, eigen_values, mix_ZA);

         if (eigen_values(es) < 0.)
            problems.flag_tachyon(Ah);

         PHYSICAL(MAh(es)) = AbsSqrt(eigen_values(es));
         if (es == 0)
            PHYSICAL(ZA) = mix_ZA;
      }

      new_MAh = PHYSICAL(MAh);
      diff = MaxRelDiff(new_MAh, old_MAh);
      old_MAh = new_MAh;
      iteration++;
   } while (diff > precision
            && iteration < number_of_mass_iterations);
}

void CLASSNAME::calculate_MRh_pole()
{
   if (problems.is_tachyon(Rh))
      return;
   // diagonalization with medium precision
   Eigen::Matrix<double,2,2> self_energy;
   const Eigen::Matrix<double,2,2> M_tree(get_mass_matrix_Rh());

   for (unsigned es = 0; es < 2; ++es) {
      const double p = Abs(MRh(es));
      for (unsigned i1 = 0; i1 < 2; ++i1) {
         for (unsigned i2 = i1; i2 < 2; ++i2) {
            self_energy(i1,i2) = Re(self_energy_Rh(p,i1,i2));
         }
      }

      Symmetrize(self_energy);
      const Eigen::Matrix<double,2,2> M_1loop(M_tree - self_energy);
      Eigen::Array<double,2,1> eigen_values;
      Eigen::Matrix<double,2,2> mix_ZHR;
      fs_diagonalize_hermitian(M_1loop, eigen_values, mix_ZHR);

      if (eigen_values(es) < 0.)
         problems.flag_tachyon(Rh);

      PHYSICAL(MRh(es)) = AbsSqrt(eigen_values(es));
      if (es == 0)
         PHYSICAL(ZHR) = mix_ZHR;
   }
}

void CLASSNAME::calculate_MHpm_pole()
{
   if (problems.is_tachyon(Hpm))
      return;
   // diagonalization with high precision
   unsigned iteration = 0;
   double diff = 0.0;
   decltype(MHpm) old_MHpm(MHpm), new_MHpm(MHpm);

   do {
      Eigen::Matrix<double,4,4> self_energy;
      const Eigen::Matrix<double,4,4> M_tree(get_mass_matrix_Hpm());

      for (unsigned es = 0; es < 4; ++es) {
         const double p = Abs(old_MHpm(es));
         for (unsigned i1 = 0; i1 < 4; ++i1) {
            for (unsigned i2 = i1; i2 < 4; ++i2) {
               self_energy(i1,i2) = Re(self_energy_Hpm(p,i1,
                  i2));
            }
         }

         Symmetrize(self_energy);
         const Eigen::Matrix<double,4,4> M_1loop(M_tree -
            self_energy);
         Eigen::Array<double,4,1> eigen_values;
         Eigen::Matrix<double,4,4> mix_ZP;
         fs_diagonalize_hermitian(M_1loop, eigen_values, mix_ZP);

         if (eigen_values(es) < 0.)
            problems.flag_tachyon(Hpm);

         PHYSICAL(MHpm(es)) = AbsSqrt(eigen_values(es));
         if (es == 0)
            PHYSICAL(ZP) = mix_ZP;
      }

      new_MHpm = PHYSICAL(MHpm);
      diff = MaxRelDiff(new_MHpm, old_MHpm);
      old_MHpm = new_MHpm;
      iteration++;
   } while (diff > precision
            && iteration < number_of_mass_iterations);
}

void CLASSNAME::calculate_MRpm_pole()
{
   if (problems.is_tachyon(Rpm))
      return;
   // diagonalization with medium precision
   Eigen::Matrix<double,2,2> self_energy;
   const Eigen::Matrix<double,2,2> M_tree(get_mass_matrix_Rpm());

   for (unsigned es = 0; es < 2; ++es) {
      const double p = Abs(MRpm(es));
      for (unsigned i1 = 0; i1 < 2; ++i1) {
         for (unsigned i2 = i1; i2 < 2; ++i2) {
            self_energy(i1,i2) = Re(self_energy_Rpm(p,i1,i2));
         }
      }

      Symmetrize(self_energy);
      const Eigen::Matrix<double,2,2> M_1loop(M_tree - self_energy);
      Eigen::Array<double,2,1> eigen_values;
      Eigen::Matrix<double,2,2> mix_ZRP;
      fs_diagonalize_hermitian(M_1loop, eigen_values, mix_ZRP);

      if (eigen_values(es) < 0.)
         problems.flag_tachyon(Rpm);

      PHYSICAL(MRpm(es)) = AbsSqrt(eigen_values(es));
      if (es == 0)
         PHYSICAL(ZRP) = mix_ZRP;
   }
}

void CLASSNAME::calculate_MChi_pole()
{
   // diagonalization with medium precision
   Eigen::Matrix<double,4,4> self_energy_1;
   Eigen::Matrix<double,4,4> self_energy_PL;
   Eigen::Matrix<double,4,4> self_energy_PR;
   const Eigen::Matrix<double,4,4> M_tree(get_mass_matrix_Chi());
   for (unsigned es = 0; es < 4; ++es) {
      const double p = Abs(MChi(es));
      for (unsigned i1 = 0; i1 < 4; ++i1) {
         for (unsigned i2 = 0; i2 < 4; ++i2) {
            self_energy_1(i1,i2)  = Re(self_energy_Chi_1(p,i1,i2
               ));
            self_energy_PL(i1,i2) = Re(self_energy_Chi_PL(p,i1,
               i2));
            self_energy_PR(i1,i2) = Re(self_energy_Chi_PR(p,i1,
               i2));
         }
      }
      const Eigen::Matrix<double,4,4> delta_M(- self_energy_PR *
         M_tree - M_tree * self_energy_PL - self_energy_1);
      const Eigen::Matrix<double,4,4> M_1loop(M_tree + delta_M);
      Eigen::Array<double,4,1> eigen_values;
      decltype(ZN1) mix_ZN1;
      decltype(ZN2) mix_ZN2;
      fs_svd(M_1loop, eigen_values, mix_ZN1, mix_ZN2);
      if (es == 0) {
         PHYSICAL(ZN1) = mix_ZN1;
         PHYSICAL(ZN2) = mix_ZN2;
      }
      PHYSICAL(MChi(es)) = Abs(eigen_values(es));
   }
}

void CLASSNAME::calculate_MCha1_pole()
{
   // diagonalization with medium precision
   Eigen::Matrix<double,2,2> self_energy_1;
   Eigen::Matrix<double,2,2> self_energy_PL;
   Eigen::Matrix<double,2,2> self_energy_PR;
   const Eigen::Matrix<double,2,2> M_tree(get_mass_matrix_Cha1());
   for (unsigned es = 0; es < 2; ++es) {
      const double p = Abs(MCha1(es));
      for (unsigned i1 = 0; i1 < 2; ++i1) {
         for (unsigned i2 = 0; i2 < 2; ++i2) {
            self_energy_1(i1,i2)  = Re(self_energy_Cha1_1(p,i1,
               i2));
            self_energy_PL(i1,i2) = Re(self_energy_Cha1_PL(p,i1,
               i2));
            self_energy_PR(i1,i2) = Re(self_energy_Cha1_PR(p,i1,
               i2));
         }
      }
      const Eigen::Matrix<double,2,2> delta_M(- self_energy_PR *
         M_tree - M_tree * self_energy_PL - self_energy_1);
      const Eigen::Matrix<double,2,2> M_1loop(M_tree + delta_M);
      Eigen::Array<double,2,1> eigen_values;
      decltype(UM1) mix_UM1;
      decltype(UP1) mix_UP1;
      fs_svd(M_1loop, eigen_values, mix_UM1, mix_UP1);
      if (es == 0) {
         PHYSICAL(UM1) = mix_UM1;
         PHYSICAL(UP1) = mix_UP1;
      }
      PHYSICAL(MCha1(es)) = Abs(eigen_values(es));
   }
}

void CLASSNAME::calculate_MCha2_pole()
{
   // diagonalization with medium precision
   Eigen::Matrix<double,2,2> self_energy_1;
   Eigen::Matrix<double,2,2> self_energy_PL;
   Eigen::Matrix<double,2,2> self_energy_PR;
   const Eigen::Matrix<double,2,2> M_tree(get_mass_matrix_Cha2());
   for (unsigned es = 0; es < 2; ++es) {
      const double p = Abs(MCha2(es));
      for (unsigned i1 = 0; i1 < 2; ++i1) {
         for (unsigned i2 = 0; i2 < 2; ++i2) {
            self_energy_1(i1,i2)  = Re(self_energy_Cha2_1(p,i1,
               i2));
            self_energy_PL(i1,i2) = Re(self_energy_Cha2_PL(p,i1,
               i2));
            self_energy_PR(i1,i2) = Re(self_energy_Cha2_PR(p,i1,
               i2));
         }
      }
      const Eigen::Matrix<double,2,2> delta_M(- self_energy_PR *
         M_tree - M_tree * self_energy_PL - self_energy_1);
      const Eigen::Matrix<double,2,2> M_1loop(M_tree + delta_M);
      Eigen::Array<double,2,1> eigen_values;
      decltype(UM2) mix_UM2;
      decltype(UP2) mix_UP2;
      fs_svd(M_1loop, eigen_values, mix_UM2, mix_UP2);
      if (es == 0) {
         PHYSICAL(UM2) = mix_UM2;
         PHYSICAL(UP2) = mix_UP2;
      }
      PHYSICAL(MCha2(es)) = Abs(eigen_values(es));
   }
}

void CLASSNAME::calculate_MFe_pole()
{
   // diagonalization with medium precision
   Eigen::Matrix<double,3,3> self_energy_1;
   Eigen::Matrix<double,3,3> self_energy_PL;
   Eigen::Matrix<double,3,3> self_energy_PR;
   const Eigen::Matrix<double,3,3> M_tree(get_mass_matrix_Fe());
   for (unsigned es = 0; es < 3; ++es) {
      const double p = Abs(MFe(es));
      for (unsigned i1 = 0; i1 < 3; ++i1) {
         for (unsigned i2 = 0; i2 < 3; ++i2) {
            self_energy_1(i1,i2)  = Re(self_energy_Fe_1(p,i1,i2)
               );
            self_energy_PL(i1,i2) = Re(self_energy_Fe_PL(p,i1,i2
               ));
            self_energy_PR(i1,i2) = Re(self_energy_Fe_PR(p,i1,i2
               ));
         }
      }
      const Eigen::Matrix<double,3,3> delta_M(- self_energy_PR *
         M_tree - M_tree * self_energy_PL - self_energy_1);
      const Eigen::Matrix<double,3,3> M_1loop(M_tree + delta_M);
      Eigen::Array<double,3,1> eigen_values;
      decltype(ZEL) mix_ZEL;
      decltype(ZER) mix_ZER;
      fs_svd(M_1loop, eigen_values, mix_ZEL, mix_ZER);
      if (es == 0) {
         PHYSICAL(ZEL) = mix_ZEL;
         PHYSICAL(ZER) = mix_ZER;
      }
      PHYSICAL(MFe(es)) = Abs(eigen_values(es));
   }
}

void CLASSNAME::calculate_MFd_pole()
{
   // diagonalization with medium precision
   Eigen::Matrix<double,3,3> self_energy_1;
   Eigen::Matrix<double,3,3> self_energy_PL;
   Eigen::Matrix<double,3,3> self_energy_PR;
   const Eigen::Matrix<double,3,3> M_tree(get_mass_matrix_Fd());
   for (unsigned es = 0; es < 3; ++es) {
      const double p = Abs(MFd(es));
      for (unsigned i1 = 0; i1 < 3; ++i1) {
         for (unsigned i2 = 0; i2 < 3; ++i2) {
            self_energy_1(i1,i2)  = Re(self_energy_Fd_1(p,i1,i2)
               );
            self_energy_PL(i1,i2) = Re(self_energy_Fd_PL(p,i1,i2
               ));
            self_energy_PR(i1,i2) = Re(self_energy_Fd_PR(p,i1,i2
               ));
         }
      }
      const Eigen::Matrix<double,3,3> delta_M(- self_energy_PR *
         M_tree - M_tree * self_energy_PL - self_energy_1);
      const Eigen::Matrix<double,3,3> M_1loop(M_tree + delta_M);
      Eigen::Array<double,3,1> eigen_values;
      decltype(ZDL) mix_ZDL;
      decltype(ZDR) mix_ZDR;
      fs_svd(M_1loop, eigen_values, mix_ZDL, mix_ZDR);
      if (es == 0) {
         PHYSICAL(ZDL) = mix_ZDL;
         PHYSICAL(ZDR) = mix_ZDR;
      }
      PHYSICAL(MFd(es)) = Abs(eigen_values(es));
   }
}

void CLASSNAME::calculate_MFu_pole()
{
   // diagonalization with medium precision
   Eigen::Matrix<double,3,3> self_energy_1;
   Eigen::Matrix<double,3,3> self_energy_PL;
   Eigen::Matrix<double,3,3> self_energy_PR;
   const Eigen::Matrix<double,3,3> M_tree(get_mass_matrix_Fu());
   for (unsigned es = 0; es < 3; ++es) {
      const double p = Abs(MFu(es));
      for (unsigned i1 = 0; i1 < 3; ++i1) {
         for (unsigned i2 = 0; i2 < 3; ++i2) {
            self_energy_1(i1,i2)  = Re(self_energy_Fu_1(p,i1,i2)
               );
            self_energy_PL(i1,i2) = Re(self_energy_Fu_PL(p,i1,i2
               ));
            self_energy_PR(i1,i2) = Re(self_energy_Fu_PR(p,i1,i2
               ));
         }
      }
      const Eigen::Matrix<double,3,3> delta_M(- self_energy_PR *
         M_tree - M_tree * self_energy_PL - self_energy_1);
      const Eigen::Matrix<double,3,3> M_1loop(M_tree + delta_M);
      Eigen::Array<double,3,1> eigen_values;
      decltype(ZUL) mix_ZUL;
      decltype(ZUR) mix_ZUR;
      fs_svd(M_1loop, eigen_values, mix_ZUL, mix_ZUR);
      if (es == 0) {
         PHYSICAL(ZUL) = mix_ZUL;
         PHYSICAL(ZUR) = mix_ZUR;
      }
      PHYSICAL(MFu(es)) = Abs(eigen_values(es));
   }
}

void CLASSNAME::calculate_MVG_pole()
{
   // diagonalization with medium precision
   PHYSICAL(MVG) = 0.;
}

void CLASSNAME::calculate_MVP_pole()
{
   // diagonalization with medium precision
   PHYSICAL(MVP) = 0.;
}

void CLASSNAME::calculate_MVWm_pole()
{
   if (problems.is_tachyon(VWm))
      return;
   // diagonalization with medium precision
   const double p = MVWm;
   const double self_energy = Re(self_energy_VWm(p));
   const double mass_sqr = Sqr(MVWm) - self_energy;

   if (mass_sqr < 0.)
      problems.flag_tachyon(VWm);

   PHYSICAL(MVWm) = AbsSqrt(mass_sqr);
}


double CLASSNAME::calculate_MFu_DRbar(double m_pole, int idx) const
{
   const double p = m_pole;
   const double self_energy_1  = Re(self_energy_Fu_1_heavy_rotated(p, idx
      , idx));
   const double self_energy_PL = Re(self_energy_Fu_PL_heavy_rotated(p,
      idx, idx));
   const double self_energy_PR = Re(self_energy_Fu_PR_heavy_rotated(p,
      idx, idx));

   const double currentScale = get_scale();
   const double qcd_1l = 0.025330295910584444*(-1.6666666666666667 + 1.*
      Log(Sqr(MFu(2))/Sqr(currentScale)))*Sqr(g3);
   const double qcd_2l = -0.003408916029785599*Power(g3,4) +
      0.0011495761378943394*Power(g3,4)*Log(Sqr(MFu(2))/Sqr(currentScale)) -
      0.00024060895909416413*Power(g3,4)*Sqr(Log(Power(MFu(2),2)/Sqr(
      currentScale)));

   const double m_susy_drbar = m_pole + self_energy_1 + m_pole * (
      self_energy_PL + self_energy_PR + qcd_1l + qcd_2l);

   return m_susy_drbar;
}

double CLASSNAME::calculate_MFd_DRbar(double m_sm_msbar, int idx) const
{
   const double p = m_sm_msbar;
   const double self_energy_1  = Re(self_energy_Fd_1_heavy_rotated(p, idx
      , idx));
   const double self_energy_PL = Re(self_energy_Fd_PL_heavy_rotated(p,
      idx, idx));
   const double self_energy_PR = Re(self_energy_Fd_PR_heavy_rotated(p,
      idx, idx));
   const double m_tree = MFd(2);
   const double m_sm_drbar = m_sm_msbar * (1 - 0.00020496318737651018*
      Power(g3,4) + 0.0006860288475783287*Sqr(g1) + 0.0023747152416172916*Sqr(
      g2) - 0.008443431970194815*Sqr(g3));

   const double m_susy_drbar = m_sm_drbar / (1.0 - self_energy_1/m_tree -
      self_energy_PL - self_energy_PR);

   return m_susy_drbar;
}

double CLASSNAME::calculate_MFe_DRbar(double m_sm_msbar, int idx) const
{
   const double p = m_sm_msbar;
   const double self_energy_1  = Re(self_energy_Fe_1_heavy_rotated(p, idx
      , idx));
   const double self_energy_PL = Re(self_energy_Fe_PL_heavy_rotated(p,
      idx, idx));
   const double self_energy_PR = Re(self_energy_Fe_PR_heavy_rotated(p,
      idx, idx));
   const double m_sm_drbar = m_sm_msbar * (1 - 0.0023747152416172916*(0.6
      *Sqr(g1) - Sqr(g2)));

   const double m_susy_drbar = m_sm_drbar + self_energy_1 + m_sm_drbar *
      (self_energy_PL + self_energy_PR);

   return m_susy_drbar;
}

double CLASSNAME::calculate_MFv_DRbar(double, int) const
{
   return 0.0;
}

double CLASSNAME::calculate_MVP_DRbar(double)
{
   return 0.0;
}

double CLASSNAME::calculate_MVZ_DRbar(double m_pole)
{
   const double p = m_pole;
   const double self_energy = Re(self_energy_VZ(p));
   const double mass_sqr = Sqr(m_pole) + self_energy;

   if (mass_sqr < 0.) {
      problems.flag_tachyon(VZ);
      return m_pole;
   }

   return AbsSqrt(mass_sqr);
}

double CLASSNAME::calculate_MVWm_DRbar(double m_pole)
{
   const double p = m_pole;
   const double self_energy = Re(self_energy_VWm(p));
   const double mass_sqr = Sqr(m_pole) + self_energy;

   if (mass_sqr < 0.) {
      problems.flag_tachyon(VWm);
      return m_pole;
   }

   return AbsSqrt(mass_sqr);
}


double CLASSNAME::ThetaW() const
{
   return ArcTan((0.7745966692414834*g1)/g2);
}

double CLASSNAME::v() const
{
   return 2*Sqrt(Sqr(MVWm)/Sqr(g2));
}


std::ostream& operator<<(std::ostream& ostr, const MRSSM<Two_scale>& model)
{
   model.print(ostr);
   return ostr;
}

} // namespace flexiblesusy
